# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_federation_discovery_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_federation_discovery_pb2 as protos_dot_ydb__federation__discovery__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_federation_discovery_v1.proto',
  package='Ydb.FederationDiscovery.V1',
  syntax='proto3',
  serialized_options=b'\n&tech.ydb.proto.federation.discovery.v1ZBgithub.com/ydb-platform/ydb-go-genproto/Ydb_FederationDiscovery_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!ydb_federation_discovery_v1.proto\x12\x1aYdb.FederationDiscovery.V1\x1a%protos/ydb_federation_discovery.proto2\xab\x01\n\x1a\x46\x65\x64\x65rationDiscoveryService\x12\x8c\x01\n\x17ListFederationDatabases\x12\x37.Ydb.FederationDiscovery.ListFederationDatabasesRequest\x1a\x38.Ydb.FederationDiscovery.ListFederationDatabasesResponseBl\n&tech.ydb.proto.federation.discovery.v1ZBgithub.com/ydb-platform/ydb-go-genproto/Ydb_FederationDiscovery_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__federation__discovery__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_FEDERATIONDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='FederationDiscoveryService',
  full_name='Ydb.FederationDiscovery.V1.FederationDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=105,
  serialized_end=276,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFederationDatabases',
    full_name='Ydb.FederationDiscovery.V1.FederationDiscoveryService.ListFederationDatabases',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__federation__discovery__pb2._LISTFEDERATIONDATABASESREQUEST,
    output_type=protos_dot_ydb__federation__discovery__pb2._LISTFEDERATIONDATABASESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEDERATIONDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['FederationDiscoveryService'] = _FEDERATIONDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
