# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/protos/ydb_object_storage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/protos/ydb_object_storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v6.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v6.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%draft/protos/ydb_object_storage.proto\x12\x11Ydb.ObjectStorage\x1a\x1eprotos/ydb_issue_message.proto\x1a\x16protos/ydb_value.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xd6\x02\n\x0eListingRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12#\n\nkey_prefix\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x1a\n\x12path_column_prefix\x18\x03 \x01(\t\x12\x1d\n\x15path_column_delimiter\x18\x04 \x01(\t\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\x0c\x12/\n\x16start_after_key_suffix\x18\x06 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x10\n\x08max_keys\x18\x07 \x01(\x05\x12\x19\n\x11\x63olumns_to_return\x18\x08 \x03(\t\x12(\n\x0fmatching_filter\x18\n \x01(\x0b\x32\x0f.Ydb.TypedValue\"&\n\nEMatchType\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01J\x04\x08\t\x10\n\"\xd7\x01\n\x0fListingResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x17\n\x0f\x63ommon_prefixes\x18\x03 \x03(\t\x12 \n\x08\x63ontents\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12\x14\n\x0cis_truncated\x18\x05 \x01(\x08\x12\x1f\n\x17next_continuation_token\x18\x06 \x01(\x0c\x42p\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_object_storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\370\001\001'
  _globals['_LISTINGREQUEST']._serialized_start=148
  _globals['_LISTINGREQUEST']._serialized_end=490
  _globals['_LISTINGREQUEST_EMATCHTYPE']._serialized_start=446
  _globals['_LISTINGREQUEST_EMATCHTYPE']._serialized_end=484
  _globals['_LISTINGRESPONSE']._serialized_start=493
  _globals['_LISTINGRESPONSE']._serialized_end=708
# @@protoc_insertion_point(module_scope)
