# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_cms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14protos/ydb_cms.proto\x12\x07Ydb.Cms\x1a\x1aprotos/ydb_operation.proto\"0\n\x0cStorageUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"Q\n\x12\x43omputationalUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"K\n\x1a\x41llocatedComputationalUnit\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x11\n\tunit_kind\x18\x03 \x01(\t\"s\n\tResources\x12,\n\rstorage_units\x18\x01 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12\x38\n\x13\x63omputational_units\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\"3\n\x13ServerlessResources\x12\x1c\n\x14shared_database_path\x18\x01 \x01(\t\"j\n\x0f\x44\x61tabaseOptions\x12\x1a\n\x12\x64isable_tx_service\x18\x01 \x01(\x08\x12\"\n\x1a\x64isable_external_subdomain\x18\x02 \x01(\x08\x12\x17\n\x0fplan_resolution\x18\x03 \x01(\r\"\x9c\x01\n\x15SchemaOperationQuotas\x12G\n\x13leaky_bucket_quotas\x18\x01 \x03(\x0b\x32*.Ydb.Cms.SchemaOperationQuotas.LeakyBucket\x1a:\n\x0bLeakyBucket\x12\x13\n\x0b\x62ucket_size\x18\x01 \x01(\x01\x12\x16\n\x0e\x62ucket_seconds\x18\x02 \x01(\x04\"\xc0\x01\n\x0e\x44\x61tabaseQuotas\x12\x1c\n\x14\x64\x61ta_size_hard_quota\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x61ta_size_soft_quota\x18\x02 \x01(\x04\x12 \n\x18\x64\x61ta_stream_shards_quota\x18\x03 \x01(\x04\x12*\n\"data_stream_reserved_storage_quota\x18\x05 \x01(\x04\x12$\n\x1cttl_min_run_internal_seconds\x18\x04 \x01(\r\"\xb7\x04\n\x15\x43reateDatabaseRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\'\n\tresources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12.\n\x10shared_resources\x18\x06 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x07 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12)\n\x07options\x18\x04 \x01(\x0b\x32\x18.Ydb.Cms.DatabaseOptions\x12\x42\n\nattributes\x18\x05 \x03(\x0b\x32..Ydb.Cms.CreateDatabaseRequest.AttributesEntry\x12?\n\x17schema_operation_quotas\x18\x08 \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\t \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eresources_kind\"F\n\x16\x43reateDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"c\n\x18GetDatabaseStatusRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"I\n\x19GetDatabaseStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x05\n\x17GetDatabaseStatusResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x35\n\x05state\x18\x02 \x01(\x0e\x32&.Ydb.Cms.GetDatabaseStatusResult.State\x12\x30\n\x12required_resources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12\x37\n\x19required_shared_resources\x18\x07 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x08 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12/\n\x13\x61llocated_resources\x18\x04 \x01(\x0b\x32\x12.Ydb.Cms.Resources\x12\x41\n\x14registered_resources\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x12\n\ngeneration\x18\x06 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"o\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08REMOVING\x10\x03\x12\x15\n\x11PENDING_RESOURCES\x10\x04\x12\x0f\n\x0b\x43ONFIGURING\x10\x05\x42\x10\n\x0eresources_kind\"\xdd\x05\n\x14\x41lterDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12?\n\x1a\x63omputational_units_to_add\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x42\n\x1d\x63omputational_units_to_remove\x18\x03 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x33\n\x14storage_units_to_add\x18\x04 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12L\n\x1f\x63omputational_units_to_register\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12N\n!computational_units_to_deregister\x18\x06 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x39\n\x10operation_params\x18\x07 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\ngeneration\x18\x08 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\n \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\x0b \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12L\n\x10\x61lter_attributes\x18\x0c \x03(\x0b\x32\x32.Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x15\x41lterDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x14ListDatabasesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15ListDatabasesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"$\n\x13ListDatabasesResult\x12\r\n\x05paths\x18\x01 \x03(\t\"`\n\x15RemoveDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"F\n\x16RemoveDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x92\x01\n\x16StorageUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12;\n\x06labels\x18\x02 \x03(\x0b\x32+.Ydb.Cms.StorageUnitDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1b\x41vailabilityZoneDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x06labels\x18\x02 \x03(\x0b\x32\x30.Ydb.Cms.AvailabilityZoneDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x1c\x43omputationalUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Cms.ComputationalUnitDescription.LabelsEntry\x12\"\n\x1a\x61llowed_availability_zones\x18\x03 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x1e\x44\x65scribeDatabaseOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"O\n\x1f\x44\x65scribeDatabaseOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xdd\x01\n\x1d\x44\x65scribeDatabaseOptionsResult\x12\x36\n\rstorage_units\x18\x01 \x03(\x0b\x32\x1f.Ydb.Cms.StorageUnitDescription\x12@\n\x12\x61vailability_zones\x18\x02 \x03(\x0b\x32$.Ydb.Cms.AvailabilityZoneDescription\x12\x42\n\x13\x63omputational_units\x18\x03 \x03(\x0b\x32%.Ydb.Cms.ComputationalUnitDescriptionBO\n\x12tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_cms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\370\001\001'
  _CREATEDATABASEREQUEST_ATTRIBUTESENTRY._options = None
  _CREATEDATABASEREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _STORAGEUNITDESCRIPTION_LABELSENTRY._options = None
  _STORAGEUNITDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _AVAILABILITYZONEDESCRIPTION_LABELSENTRY._options = None
  _AVAILABILITYZONEDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._options = None
  _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _STORAGEUNITS._serialized_start=61
  _STORAGEUNITS._serialized_end=109
  _COMPUTATIONALUNITS._serialized_start=111
  _COMPUTATIONALUNITS._serialized_end=192
  _ALLOCATEDCOMPUTATIONALUNIT._serialized_start=194
  _ALLOCATEDCOMPUTATIONALUNIT._serialized_end=269
  _RESOURCES._serialized_start=271
  _RESOURCES._serialized_end=386
  _SERVERLESSRESOURCES._serialized_start=388
  _SERVERLESSRESOURCES._serialized_end=439
  _DATABASEOPTIONS._serialized_start=441
  _DATABASEOPTIONS._serialized_end=547
  _SCHEMAOPERATIONQUOTAS._serialized_start=550
  _SCHEMAOPERATIONQUOTAS._serialized_end=706
  _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET._serialized_start=648
  _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET._serialized_end=706
  _DATABASEQUOTAS._serialized_start=709
  _DATABASEQUOTAS._serialized_end=901
  _CREATEDATABASEREQUEST._serialized_start=904
  _CREATEDATABASEREQUEST._serialized_end=1471
  _CREATEDATABASEREQUEST_ATTRIBUTESENTRY._serialized_start=1404
  _CREATEDATABASEREQUEST_ATTRIBUTESENTRY._serialized_end=1453
  _CREATEDATABASERESPONSE._serialized_start=1473
  _CREATEDATABASERESPONSE._serialized_end=1543
  _GETDATABASESTATUSREQUEST._serialized_start=1545
  _GETDATABASESTATUSREQUEST._serialized_end=1644
  _GETDATABASESTATUSRESPONSE._serialized_start=1646
  _GETDATABASESTATUSRESPONSE._serialized_end=1719
  _GETDATABASESTATUSRESULT._serialized_start=1722
  _GETDATABASESTATUSRESULT._serialized_end=2367
  _GETDATABASESTATUSRESULT_STATE._serialized_start=2238
  _GETDATABASESTATUSRESULT_STATE._serialized_end=2349
  _ALTERDATABASEREQUEST._serialized_start=2370
  _ALTERDATABASEREQUEST._serialized_end=3103
  _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._serialized_start=3049
  _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._serialized_end=3103
  _ALTERDATABASERESPONSE._serialized_start=3105
  _ALTERDATABASERESPONSE._serialized_end=3174
  _LISTDATABASESREQUEST._serialized_start=3176
  _LISTDATABASESREQUEST._serialized_end=3257
  _LISTDATABASESRESPONSE._serialized_start=3259
  _LISTDATABASESRESPONSE._serialized_end=3328
  _LISTDATABASESRESULT._serialized_start=3330
  _LISTDATABASESRESULT._serialized_end=3366
  _REMOVEDATABASEREQUEST._serialized_start=3368
  _REMOVEDATABASEREQUEST._serialized_end=3464
  _REMOVEDATABASERESPONSE._serialized_start=3466
  _REMOVEDATABASERESPONSE._serialized_end=3536
  _STORAGEUNITDESCRIPTION._serialized_start=3539
  _STORAGEUNITDESCRIPTION._serialized_end=3685
  _STORAGEUNITDESCRIPTION_LABELSENTRY._serialized_start=3640
  _STORAGEUNITDESCRIPTION_LABELSENTRY._serialized_end=3685
  _AVAILABILITYZONEDESCRIPTION._serialized_start=3688
  _AVAILABILITYZONEDESCRIPTION._serialized_end=3844
  _AVAILABILITYZONEDESCRIPTION_LABELSENTRY._serialized_start=3640
  _AVAILABILITYZONEDESCRIPTION_LABELSENTRY._serialized_end=3685
  _COMPUTATIONALUNITDESCRIPTION._serialized_start=3847
  _COMPUTATIONALUNITDESCRIPTION._serialized_end=4041
  _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._serialized_start=3640
  _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._serialized_end=3685
  _DESCRIBEDATABASEOPTIONSREQUEST._serialized_start=4043
  _DESCRIBEDATABASEOPTIONSREQUEST._serialized_end=4134
  _DESCRIBEDATABASEOPTIONSRESPONSE._serialized_start=4136
  _DESCRIBEDATABASEOPTIONSRESPONSE._serialized_end=4215
  _DESCRIBEDATABASEOPTIONSRESULT._serialized_start=4218
  _DESCRIBEDATABASEOPTIONSRESULT._serialized_end=4439
# @@protoc_insertion_point(module_scope)
