# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ydb_query_v1.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ydb_query_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v6.protos import ydb_query_pb2 as protos_dot_ydb__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ydb_query_v1.proto\x12\x0cYdb.Query.V1\x1a\x1aprotos/ydb_operation.proto\x1a\x16protos/ydb_query.proto2\xad\x06\n\x0cQueryService\x12R\n\rCreateSession\x12\x1f.Ydb.Query.CreateSessionRequest\x1a .Ydb.Query.CreateSessionResponse\x12R\n\rDeleteSession\x12\x1f.Ydb.Query.DeleteSessionRequest\x1a .Ydb.Query.DeleteSessionResponse\x12K\n\rAttachSession\x12\x1f.Ydb.Query.AttachSessionRequest\x1a\x17.Ydb.Query.SessionState0\x01\x12[\n\x10\x42\x65ginTransaction\x12\".Ydb.Query.BeginTransactionRequest\x1a#.Ydb.Query.BeginTransactionResponse\x12^\n\x11\x43ommitTransaction\x12#.Ydb.Query.CommitTransactionRequest\x1a$.Ydb.Query.CommitTransactionResponse\x12\x64\n\x13RollbackTransaction\x12%.Ydb.Query.RollbackTransactionRequest\x1a&.Ydb.Query.RollbackTransactionResponse\x12U\n\x0c\x45xecuteQuery\x12\x1e.Ydb.Query.ExecuteQueryRequest\x1a#.Ydb.Query.ExecuteQueryResponsePart0\x01\x12K\n\rExecuteScript\x12\x1f.Ydb.Query.ExecuteScriptRequest\x1a\x19.Ydb.Operations.Operation\x12\x61\n\x12\x46\x65tchScriptResults\x12$.Ydb.Query.FetchScriptResultsRequest\x1a%.Ydb.Query.FetchScriptResultsResponseBO\n\x17tech.ydb.proto.query.v1Z4github.com/ydb-platform/ydb-go-genproto/Ydb_Query_V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb_query_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027tech.ydb.proto.query.v1Z4github.com/ydb-platform/ydb-go-genproto/Ydb_Query_V1'
  _globals['_QUERYSERVICE']._serialized_start=89
  _globals['_QUERYSERVICE']._serialized_end=902
# @@protoc_insertion_point(module_scope)
