# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from ydb._grpc.v6.draft.protos import ydb_federated_query_pb2 as draft_dot_protos_dot_ydb__federated__query__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in draft/ydb_federated_query_v1_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class FederatedQueryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateQuery = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/CreateQuery',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryResponse.FromString,
                _registered_method=True)
        self.ListQueries = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ListQueries',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesResponse.FromString,
                _registered_method=True)
        self.DescribeQuery = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DescribeQuery',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryResponse.FromString,
                _registered_method=True)
        self.GetQueryStatus = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/GetQueryStatus',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusResponse.FromString,
                _registered_method=True)
        self.ModifyQuery = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ModifyQuery',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryResponse.FromString,
                _registered_method=True)
        self.DeleteQuery = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DeleteQuery',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryResponse.FromString,
                _registered_method=True)
        self.ControlQuery = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ControlQuery',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryResponse.FromString,
                _registered_method=True)
        self.GetResultData = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/GetResultData',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataResponse.FromString,
                _registered_method=True)
        self.ListJobs = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ListJobs',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsResponse.FromString,
                _registered_method=True)
        self.DescribeJob = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DescribeJob',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobResponse.FromString,
                _registered_method=True)
        self.CreateConnection = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/CreateConnection',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionResponse.FromString,
                _registered_method=True)
        self.ListConnections = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ListConnections',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsResponse.FromString,
                _registered_method=True)
        self.DescribeConnection = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DescribeConnection',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionResponse.FromString,
                _registered_method=True)
        self.ModifyConnection = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ModifyConnection',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionResponse.FromString,
                _registered_method=True)
        self.DeleteConnection = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DeleteConnection',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionResponse.FromString,
                _registered_method=True)
        self.TestConnection = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/TestConnection',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionResponse.FromString,
                _registered_method=True)
        self.CreateBinding = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/CreateBinding',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingResponse.FromString,
                _registered_method=True)
        self.ListBindings = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ListBindings',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsResponse.FromString,
                _registered_method=True)
        self.DescribeBinding = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DescribeBinding',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingResponse.FromString,
                _registered_method=True)
        self.ModifyBinding = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/ModifyBinding',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingResponse.FromString,
                _registered_method=True)
        self.DeleteBinding = channel.unary_unary(
                '/FederatedQuery.V1.FederatedQueryService/DeleteBinding',
                request_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingResponse.FromString,
                _registered_method=True)


class FederatedQueryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateQuery(self, request, context):
        """Query
        Query is the text of an SQL request, the results of the last run and the state after the last run (partitions offsets, consumer in YDS)
        Create a query object with a given SQL
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListQueries(self, request, context):
        """Get a list of brief queries objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeQuery(self, request, context):
        """Get full information about the object of the query
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQueryStatus(self, request, context):
        """Get status of the query
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyQuery(self, request, context):
        """Change the attributes of the query (acl, name, ...)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteQuery(self, request, context):
        """Completely delete the query
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ControlQuery(self, request, context):
        """Change the state of the query lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResultData(self, request, context):
        """Get a results page
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobs(self, request, context):
        """Job
        Job - appears immediately after starting the request and contains the request metadata
        Get a list of jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeJob(self, request, context):
        """Get information about the job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Connection
        Connection - entity that describes connection points. This can be imagined as an analogue of a network address.
        Create a connection object (ObjectStorage, YDB, YDS, ...)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnections(self, request, context):
        """Get a list of connections objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeConnection(self, request, context):
        """Get information about the object of the connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyConnection(self, request, context):
        """Change the attributes of the connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Completely delete the connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestConnection(self, request, context):
        """Test the connection (permissions, network, ...)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBinding(self, request, context):
        """Binding
        Binding - entity using which a schema is assigned to non-schematic data
        Create a binding object - bind schema with ObjectStorage object or YDS stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBindings(self, request, context):
        """Get a list of bindings objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeBinding(self, request, context):
        """Get information about the object of the binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyBinding(self, request, context):
        """Change the attributes of the binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBinding(self, request, context):
        """Completely delete the binding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FederatedQueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateQuery,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryResponse.SerializeToString,
            ),
            'ListQueries': grpc.unary_unary_rpc_method_handler(
                    servicer.ListQueries,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesResponse.SerializeToString,
            ),
            'DescribeQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeQuery,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryResponse.SerializeToString,
            ),
            'GetQueryStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQueryStatus,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusResponse.SerializeToString,
            ),
            'ModifyQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyQuery,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryResponse.SerializeToString,
            ),
            'DeleteQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteQuery,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryResponse.SerializeToString,
            ),
            'ControlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ControlQuery,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryResponse.SerializeToString,
            ),
            'GetResultData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResultData,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataResponse.SerializeToString,
            ),
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsResponse.SerializeToString,
            ),
            'DescribeJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeJob,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'ListConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnections,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsResponse.SerializeToString,
            ),
            'DescribeConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeConnection,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionResponse.SerializeToString,
            ),
            'ModifyConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyConnection,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionResponse.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionResponse.SerializeToString,
            ),
            'TestConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.TestConnection,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionResponse.SerializeToString,
            ),
            'CreateBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBinding,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingResponse.SerializeToString,
            ),
            'ListBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBindings,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsResponse.SerializeToString,
            ),
            'DescribeBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeBinding,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingResponse.SerializeToString,
            ),
            'ModifyBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyBinding,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingResponse.SerializeToString,
            ),
            'DeleteBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBinding,
                    request_deserializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'FederatedQuery.V1.FederatedQueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('FederatedQuery.V1.FederatedQueryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class FederatedQueryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/CreateQuery',
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListQueries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ListQueries',
            draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ListQueriesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DescribeQuery',
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetQueryStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/GetQueryStatus',
            draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.GetQueryStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ModifyQuery',
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DeleteQuery',
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ControlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ControlQuery',
            draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ControlQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetResultData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/GetResultData',
            draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.GetResultDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ListJobs',
            draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ListJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DescribeJob',
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeJobResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/CreateConnection',
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ListConnections',
            draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ListConnectionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DescribeConnection',
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ModifyConnection',
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DeleteConnection',
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TestConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/TestConnection',
            draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.TestConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/CreateBinding',
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.CreateBindingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ListBindings',
            draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ListBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DescribeBinding',
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DescribeBindingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/ModifyBinding',
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.ModifyBindingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/FederatedQuery.V1.FederatedQueryService/DeleteBinding',
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingRequest.SerializeToString,
            draft_dot_protos_dot_ydb__federated__query__pb2.DeleteBindingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
