# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_object_storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_object_storage.proto',
  package='Ydb.ObjectStorage',
  syntax='proto3',
  serialized_options=b'\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%draft/protos/ydb_object_storage.proto\x12\x11Ydb.ObjectStorage\x1a\x1eprotos/ydb_issue_message.proto\x1a\x16protos/ydb_value.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xd6\x02\n\x0eListingRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12#\n\nkey_prefix\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x1a\n\x12path_column_prefix\x18\x03 \x01(\t\x12\x1d\n\x15path_column_delimiter\x18\x04 \x01(\t\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\x0c\x12/\n\x16start_after_key_suffix\x18\x06 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x10\n\x08max_keys\x18\x07 \x01(\x05\x12\x19\n\x11\x63olumns_to_return\x18\x08 \x03(\t\x12(\n\x0fmatching_filter\x18\n \x01(\x0b\x32\x0f.Ydb.TypedValue\"&\n\nEMatchType\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01J\x04\x08\t\x10\n\"\xd7\x01\n\x0fListingResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x17\n\x0f\x63ommon_prefixes\x18\x03 \x03(\t\x12 \n\x08\x63ontents\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12\x14\n\x0cis_truncated\x18\x05 \x01(\x08\x12\x1f\n\x17next_continuation_token\x18\x06 \x01(\x0c\x42p\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__value__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,])



_LISTINGREQUEST_EMATCHTYPE = _descriptor.EnumDescriptor(
  name='EMatchType',
  full_name='Ydb.ObjectStorage.ListingRequest.EMatchType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=446,
  serialized_end=484,
)
_sym_db.RegisterEnumDescriptor(_LISTINGREQUEST_EMATCHTYPE)


_LISTINGREQUEST = _descriptor.Descriptor(
  name='ListingRequest',
  full_name='Ydb.ObjectStorage.ListingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='Ydb.ObjectStorage.ListingRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_prefix', full_name='Ydb.ObjectStorage.ListingRequest.key_prefix', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_column_prefix', full_name='Ydb.ObjectStorage.ListingRequest.path_column_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_column_delimiter', full_name='Ydb.ObjectStorage.ListingRequest.path_column_delimiter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='Ydb.ObjectStorage.ListingRequest.continuation_token', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_after_key_suffix', full_name='Ydb.ObjectStorage.ListingRequest.start_after_key_suffix', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_keys', full_name='Ydb.ObjectStorage.ListingRequest.max_keys', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns_to_return', full_name='Ydb.ObjectStorage.ListingRequest.columns_to_return', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matching_filter', full_name='Ydb.ObjectStorage.ListingRequest.matching_filter', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LISTINGREQUEST_EMATCHTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=490,
)


_LISTINGRESPONSE = _descriptor.Descriptor(
  name='ListingResponse',
  full_name='Ydb.ObjectStorage.ListingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.ObjectStorage.ListingResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.ObjectStorage.ListingResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='common_prefixes', full_name='Ydb.ObjectStorage.ListingResponse.common_prefixes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contents', full_name='Ydb.ObjectStorage.ListingResponse.contents', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_truncated', full_name='Ydb.ObjectStorage.ListingResponse.is_truncated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_continuation_token', full_name='Ydb.ObjectStorage.ListingResponse.next_continuation_token', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=708,
)

_LISTINGREQUEST.fields_by_name['key_prefix'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_LISTINGREQUEST.fields_by_name['start_after_key_suffix'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_LISTINGREQUEST.fields_by_name['matching_filter'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_LISTINGREQUEST_EMATCHTYPE.containing_type = _LISTINGREQUEST
_LISTINGRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_LISTINGRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_LISTINGRESPONSE.fields_by_name['contents'].message_type = protos_dot_ydb__value__pb2._RESULTSET
DESCRIPTOR.message_types_by_name['ListingRequest'] = _LISTINGREQUEST
DESCRIPTOR.message_types_by_name['ListingResponse'] = _LISTINGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListingRequest = _reflection.GeneratedProtocolMessageType('ListingRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINGREQUEST,
  '__module__' : 'draft.protos.ydb_object_storage_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.ObjectStorage.ListingRequest)
  })
_sym_db.RegisterMessage(ListingRequest)

ListingResponse = _reflection.GeneratedProtocolMessageType('ListingResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINGRESPONSE,
  '__module__' : 'draft.protos.ydb_object_storage_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.ObjectStorage.ListingResponse)
  })
_sym_db.RegisterMessage(ListingResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
