# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_keyvalue_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.draft.protos import ydb_keyvalue_pb2 as draft_dot_protos_dot_ydb__keyvalue__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64raft/ydb_keyvalue_v1.proto\x12\x0fYdb.KeyValue.V1\x1a\x1f\x64raft/protos/ydb_keyvalue.proto2\xe6\x07\n\x0fKeyValueService\x12U\n\x0c\x43reateVolume\x12!.Ydb.KeyValue.CreateVolumeRequest\x1a\".Ydb.KeyValue.CreateVolumeResponse\x12O\n\nDropVolume\x12\x1f.Ydb.KeyValue.DropVolumeRequest\x1a .Ydb.KeyValue.DropVolumeResponse\x12R\n\x0b\x41lterVolume\x12 .Ydb.KeyValue.AlterVolumeRequest\x1a!.Ydb.KeyValue.AlterVolumeResponse\x12[\n\x0e\x44\x65scribeVolume\x12#.Ydb.KeyValue.DescribeVolumeRequest\x1a$.Ydb.KeyValue.DescribeVolumeResponse\x12j\n\x13ListLocalPartitions\x12(.Ydb.KeyValue.ListLocalPartitionsRequest\x1a).Ydb.KeyValue.ListLocalPartitionsResponse\x12R\n\x0b\x41\x63quireLock\x12 .Ydb.KeyValue.AcquireLockRequest\x1a!.Ydb.KeyValue.AcquireLockResponse\x12g\n\x12\x45xecuteTransaction\x12\'.Ydb.KeyValue.ExecuteTransactionRequest\x1a(.Ydb.KeyValue.ExecuteTransactionResponse\x12=\n\x04Read\x12\x19.Ydb.KeyValue.ReadRequest\x1a\x1a.Ydb.KeyValue.ReadResponse\x12L\n\tReadRange\x12\x1e.Ydb.KeyValue.ReadRangeRequest\x1a\x1f.Ydb.KeyValue.ReadRangeResponse\x12L\n\tListRange\x12\x1e.Ydb.KeyValue.ListRangeRequest\x1a\x1f.Ydb.KeyValue.ListRangeResponse\x12v\n\x17GetStorageChannelStatus\x12,.Ydb.KeyValue.GetStorageChannelStatusRequest\x1a-.Ydb.KeyValue.GetStorageChannelStatusResponseB^\n\x1dtech.ydb.proto.draft.keyvalueZ=github.com/ydb-platform/ydb-go-genproto/draft/Ydb_KeyValue_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.ydb_keyvalue_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035tech.ydb.proto.draft.keyvalueZ=github.com/ydb-platform/ydb-go-genproto/draft/Ydb_KeyValue_V1'
  _KEYVALUESERVICE._serialized_start=82
  _KEYVALUESERVICE._serialized_end=1080
# @@protoc_insertion_point(module_scope)
