from protos import ydb_operation_pb2 as _ydb_operation_pb2
from protos import ydb_query_pb2 as _ydb_query_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
