# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/ydb_scheme.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protos/ydb_scheme.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17protos/ydb_scheme.proto\x12\nYdb.Scheme\x1a\x17protos/ydb_common.proto\x1a\x1aprotos/ydb_operation.proto\"_\n\x14MakeDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15MakeDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"a\n\x16RemoveDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"G\n\x17RemoveDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x14ListDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15ListDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"8\n\x0bPermissions\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x18\n\x10permission_names\x18\x02 \x03(\t\"\xc1\x04\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12$\n\x04type\x18\x05 \x01(\x0e\x32\x16.Ydb.Scheme.Entry.Type\x12\x36\n\x15\x65\x66\x66\x65\x63tive_permissions\x18\x06 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12,\n\x0bpermissions\x18\x07 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12\x12\n\nsize_bytes\x18\x08 \x01(\x04\x12)\n\ncreated_at\x18\t \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\"\xcf\x02\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDIRECTORY\x10\x01\x12\t\n\x05TABLE\x10\x02\x12\x14\n\x10PERS_QUEUE_GROUP\x10\x03\x12\x0c\n\x08\x44\x41TABASE\x10\x04\x12\x0f\n\x0bRTMR_VOLUME\x10\x05\x12\x16\n\x12\x42LOCK_STORE_VOLUME\x10\x06\x12\x15\n\x11\x43OORDINATION_NODE\x10\x07\x12\x10\n\x0c\x43OLUMN_STORE\x10\x0c\x12\x10\n\x0c\x43OLUMN_TABLE\x10\r\x12\x0c\n\x08SEQUENCE\x10\x0f\x12\x0f\n\x0bREPLICATION\x10\x10\x12\t\n\x05TOPIC\x10\x11\x12\x12\n\x0e\x45XTERNAL_TABLE\x10\x12\x12\x18\n\x14\x45XTERNAL_DATA_SOURCE\x10\x13\x12\x08\n\x04VIEW\x10\x14\x12\x11\n\rRESOURCE_POOL\x10\x15\x12\x0c\n\x08TRANSFER\x10\x17\x12\x0c\n\x08SYS_VIEW\x10\x18\"[\n\x13ListDirectoryResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.Ydb.Scheme.Entry\"^\n\x13\x44\x65scribePathRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"D\n\x14\x44\x65scribePathResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"5\n\x12\x44\x65scribePathResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\"\xb2\x01\n\x11PermissionsAction\x12(\n\x05grant\x18\x01 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12)\n\x06revoke\x18\x02 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12&\n\x03set\x18\x03 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12\x16\n\x0c\x63hange_owner\x18\x04 \x01(\tH\x00\x42\x08\n\x06\x61\x63tion\"\xde\x01\n\x18ModifyPermissionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12.\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x1d.Ydb.Scheme.PermissionsAction\x12\x19\n\x11\x63lear_permissions\x18\x04 \x01(\x08\x12\x1f\n\x15interrupt_inheritance\x18\x05 \x01(\x08H\x00\x42\r\n\x0binheritance\"I\n\x19ModifyPermissionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBl\n\x15tech.ydb.proto.schemeB\x15SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_scheme_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025tech.ydb.proto.schemeB\025SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\370\001\001'
  _globals['_MAKEDIRECTORYREQUEST']._serialized_start=92
  _globals['_MAKEDIRECTORYREQUEST']._serialized_end=187
  _globals['_MAKEDIRECTORYRESPONSE']._serialized_start=189
  _globals['_MAKEDIRECTORYRESPONSE']._serialized_end=258
  _globals['_REMOVEDIRECTORYREQUEST']._serialized_start=260
  _globals['_REMOVEDIRECTORYREQUEST']._serialized_end=357
  _globals['_REMOVEDIRECTORYRESPONSE']._serialized_start=359
  _globals['_REMOVEDIRECTORYRESPONSE']._serialized_end=430
  _globals['_LISTDIRECTORYREQUEST']._serialized_start=432
  _globals['_LISTDIRECTORYREQUEST']._serialized_end=527
  _globals['_LISTDIRECTORYRESPONSE']._serialized_start=529
  _globals['_LISTDIRECTORYRESPONSE']._serialized_end=598
  _globals['_PERMISSIONS']._serialized_start=600
  _globals['_PERMISSIONS']._serialized_end=656
  _globals['_ENTRY']._serialized_start=659
  _globals['_ENTRY']._serialized_end=1236
  _globals['_ENTRY_TYPE']._serialized_start=901
  _globals['_ENTRY_TYPE']._serialized_end=1236
  _globals['_LISTDIRECTORYRESULT']._serialized_start=1238
  _globals['_LISTDIRECTORYRESULT']._serialized_end=1329
  _globals['_DESCRIBEPATHREQUEST']._serialized_start=1331
  _globals['_DESCRIBEPATHREQUEST']._serialized_end=1425
  _globals['_DESCRIBEPATHRESPONSE']._serialized_start=1427
  _globals['_DESCRIBEPATHRESPONSE']._serialized_end=1495
  _globals['_DESCRIBEPATHRESULT']._serialized_start=1497
  _globals['_DESCRIBEPATHRESULT']._serialized_end=1550
  _globals['_PERMISSIONSACTION']._serialized_start=1553
  _globals['_PERMISSIONSACTION']._serialized_end=1731
  _globals['_MODIFYPERMISSIONSREQUEST']._serialized_start=1734
  _globals['_MODIFYPERMISSIONSREQUEST']._serialized_end=1956
  _globals['_MODIFYPERMISSIONSRESPONSE']._serialized_start=1958
  _globals['_MODIFYPERMISSIONSRESPONSE']._serialized_end=2031
# @@protoc_insertion_point(module_scope)
