# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/ydb_operation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protos/ydb_operation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ydb._grpc.v6.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v6.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v6.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v6.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprotos/ydb_operation.proto\x12\x0eYdb.Operations\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xb6\x03\n\x0fOperationParams\x12\x45\n\x0eoperation_mode\x18\x01 \x01(\x0e\x32-.Ydb.Operations.OperationParams.OperationMode\x12\x34\n\x11operation_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0c\x63\x61ncel_after\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12M\n\x06labels\x18\x04 \x03(\x0b\x32+.Ydb.Operations.OperationParams.LabelsEntryB\x10\xa2\xe6*\x03\x18\x80\x01\xaa\xe6*\x05\n\x03\x18\x80\x01\x12\x31\n\x10report_cost_info\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\rOperationMode\x12\x1e\n\x1aOPERATION_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SYNC\x10\x01\x12\t\n\x05\x41SYNC\x10\x02\"\'\n\x13GetOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"D\n\x14GetOperationResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"*\n\x16\x43\x61ncelOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"m\n\x17\x43\x61ncelOperationResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"*\n\x16\x46orgetOperationRequest\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\x90\xe6*\x01\"m\n\x17\x46orgetOperationResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"R\n\x15ListOperationsRequest\x12\x12\n\x04kind\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x04\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xb4\x01\n\x16ListOperationsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\noperations\x18\x03 \x03(\x0b\x32\x19.Ydb.Operations.Operation\x12\x17\n\x0fnext_page_token\x18\x04 \x01(\t\"\xea\x01\n\tOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05ready\x18\x02 \x01(\x08\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12$\n\x06result\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\x08metadata\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12 \n\tcost_info\x18\x07 \x01(\x0b\x32\r.Ydb.CostInfoBc\n\x0etech.ydb.protoB\x0fOperationProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Operations\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_operation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016tech.ydb.protoB\017OperationProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Operations\370\001\001'
  _globals['_OPERATIONPARAMS_LABELSENTRY']._loaded_options = None
  _globals['_OPERATIONPARAMS_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_OPERATIONPARAMS'].fields_by_name['labels']._loaded_options = None
  _globals['_OPERATIONPARAMS'].fields_by_name['labels']._serialized_options = b'\242\346*\003\030\200\001\252\346*\005\n\003\030\200\001'
  _globals['_GETOPERATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETOPERATIONREQUEST'].fields_by_name['id']._serialized_options = b'\220\346*\001'
  _globals['_CANCELOPERATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_CANCELOPERATIONREQUEST'].fields_by_name['id']._serialized_options = b'\220\346*\001'
  _globals['_FORGETOPERATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_FORGETOPERATIONREQUEST'].fields_by_name['id']._serialized_options = b'\220\346*\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['kind']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['kind']._serialized_options = b'\220\346*\001'
  _globals['_OPERATIONPARAMS']._serialized_start=231
  _globals['_OPERATIONPARAMS']._serialized_end=669
  _globals['_OPERATIONPARAMS_LABELSENTRY']._serialized_start=554
  _globals['_OPERATIONPARAMS_LABELSENTRY']._serialized_end=599
  _globals['_OPERATIONPARAMS_OPERATIONMODE']._serialized_start=601
  _globals['_OPERATIONPARAMS_OPERATIONMODE']._serialized_end=669
  _globals['_GETOPERATIONREQUEST']._serialized_start=671
  _globals['_GETOPERATIONREQUEST']._serialized_end=710
  _globals['_GETOPERATIONRESPONSE']._serialized_start=712
  _globals['_GETOPERATIONRESPONSE']._serialized_end=780
  _globals['_CANCELOPERATIONREQUEST']._serialized_start=782
  _globals['_CANCELOPERATIONREQUEST']._serialized_end=824
  _globals['_CANCELOPERATIONRESPONSE']._serialized_start=826
  _globals['_CANCELOPERATIONRESPONSE']._serialized_end=935
  _globals['_FORGETOPERATIONREQUEST']._serialized_start=937
  _globals['_FORGETOPERATIONREQUEST']._serialized_end=979
  _globals['_FORGETOPERATIONRESPONSE']._serialized_start=981
  _globals['_FORGETOPERATIONRESPONSE']._serialized_end=1090
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=1092
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=1174
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=1177
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=1357
  _globals['_OPERATION']._serialized_start=1360
  _globals['_OPERATION']._serialized_end=1594
# @@protoc_insertion_point(module_scope)
