# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_export_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_export_pb2 as protos_dot_ydb__export__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_export_v1.proto',
  package='Ydb.Export.V1',
  syntax='proto3',
  serialized_options=b'\n\030tech.ydb.proto.export.v1Z5github.com/ydb-platform/ydb-go-genproto/Ydb_Export_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13ydb_export_v1.proto\x12\rYdb.Export.V1\x1a\x17protos/ydb_export.proto2\xf6\x01\n\rExportService\x12K\n\nExportToYt\x12\x1d.Ydb.Export.ExportToYtRequest\x1a\x1e.Ydb.Export.ExportToYtResponse\x12K\n\nExportToS3\x12\x1d.Ydb.Export.ExportToS3Request\x1a\x1e.Ydb.Export.ExportToS3Response\x12K\n\nExportToFs\x12\x1d.Ydb.Export.ExportToFsRequest\x1a\x1e.Ydb.Export.ExportToFsResponseBQ\n\x18tech.ydb.proto.export.v1Z5github.com/ydb-platform/ydb-go-genproto/Ydb_Export_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__export__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_EXPORTSERVICE = _descriptor.ServiceDescriptor(
  name='ExportService',
  full_name='Ydb.Export.V1.ExportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=64,
  serialized_end=310,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExportToYt',
    full_name='Ydb.Export.V1.ExportService.ExportToYt',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__export__pb2._EXPORTTOYTREQUEST,
    output_type=protos_dot_ydb__export__pb2._EXPORTTOYTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExportToS3',
    full_name='Ydb.Export.V1.ExportService.ExportToS3',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__export__pb2._EXPORTTOS3REQUEST,
    output_type=protos_dot_ydb__export__pb2._EXPORTTOS3RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExportToFs',
    full_name='Ydb.Export.V1.ExportService.ExportToFs',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__export__pb2._EXPORTTOFSREQUEST,
    output_type=protos_dot_ydb__export__pb2._EXPORTTOFSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPORTSERVICE)

DESCRIPTOR.services_by_name['ExportService'] = _EXPORTSERVICE

# @@protoc_insertion_point(module_scope)
