# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_operation_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_operation_v1.proto',
  package='Ydb.Operation.V1',
  syntax='proto3',
  serialized_options=b'\n\033tech.ydb.proto.operation.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Operation_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16ydb_operation_v1.proto\x12\x10Ydb.Operation.V1\x1a\x1aprotos/ydb_operation.proto2\x96\x03\n\x10OperationService\x12Y\n\x0cGetOperation\x12#.Ydb.Operations.GetOperationRequest\x1a$.Ydb.Operations.GetOperationResponse\x12\x62\n\x0f\x43\x61ncelOperation\x12&.Ydb.Operations.CancelOperationRequest\x1a\'.Ydb.Operations.CancelOperationResponse\x12\x62\n\x0f\x46orgetOperation\x12&.Ydb.Operations.ForgetOperationRequest\x1a\'.Ydb.Operations.ForgetOperationResponse\x12_\n\x0eListOperations\x12%.Ydb.Operations.ListOperationsRequest\x1a&.Ydb.Operations.ListOperationsResponseBW\n\x1btech.ydb.proto.operation.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Operation_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_OPERATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OperationService',
  full_name='Ydb.Operation.V1.OperationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=73,
  serialized_end=479,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetOperation',
    full_name='Ydb.Operation.V1.OperationService.GetOperation',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__operation__pb2._GETOPERATIONREQUEST,
    output_type=protos_dot_ydb__operation__pb2._GETOPERATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelOperation',
    full_name='Ydb.Operation.V1.OperationService.CancelOperation',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__operation__pb2._CANCELOPERATIONREQUEST,
    output_type=protos_dot_ydb__operation__pb2._CANCELOPERATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForgetOperation',
    full_name='Ydb.Operation.V1.OperationService.ForgetOperation',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__operation__pb2._FORGETOPERATIONREQUEST,
    output_type=protos_dot_ydb__operation__pb2._FORGETOPERATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='Ydb.Operation.V1.OperationService.ListOperations',
    index=3,
    containing_service=None,
    input_type=protos_dot_ydb__operation__pb2._LISTOPERATIONSREQUEST,
    output_type=protos_dot_ydb__operation__pb2._LISTOPERATIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPERATIONSERVICE)

DESCRIPTOR.services_by_name['OperationService'] = _OPERATIONSERVICE

# @@protoc_insertion_point(module_scope)
