# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_monitoring.proto',
  package='Ydb.Monitoring',
  syntax='proto3',
  serialized_options=b'\n\031tech.ydb.proto.monitoringB\020MonitoringProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Monitoring\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bprotos/ydb_monitoring.proto\x12\x0eYdb.Monitoring\x1a\x1aprotos/ydb_operation.proto\"g\n\nStatusFlag\"Y\n\x06Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04GREY\x10\x01\x12\t\n\x05GREEN\x10\x02\x12\x08\n\x04\x42LUE\x10\x03\x12\n\n\x06YELLOW\x10\x04\x12\n\n\x06ORANGE\x10\x05\x12\x07\n\x03RED\x10\x06\"\xbe\x01\n\x10SelfCheckRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x15return_verbose_status\x18\x02 \x01(\x08\x12\x39\n\x0eminimum_status\x18\x03 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x15\n\rmaximum_level\x18\x04 \x01(\r\"A\n\x11SelfCheckResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"M\n\x10NodeCheckRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11NodeCheckResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"g\n\tSelfCheck\"Z\n\x06Result\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04GOOD\x10\x01\x12\x0c\n\x08\x44\x45GRADED\x10\x02\x12\x18\n\x14MAINTENANCE_REQUIRED\x10\x03\x12\r\n\tEMERGENCY\x10\x04\"T\n\x12StoragePDiskStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\"\xc0\x01\n\x12StorageVDiskStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x37\n\x0cvdisk_status\x18\x03 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x31\n\x05pdisk\x18\x04 \x01(\x0b\x32\".Ydb.Monitoring.StoragePDiskStatus\"\x88\x01\n\x12StorageGroupStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x32\n\x06vdisks\x18\x03 \x03(\x0b\x32\".Ydb.Monitoring.StorageVDiskStatus\"\x87\x01\n\x11StoragePoolStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x32\n\x06groups\x18\x03 \x03(\x0b\x32\".Ydb.Monitoring.StorageGroupStatus\"u\n\rStorageStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x30\n\x05pools\x18\x02 \x03(\x0b\x32!.Ydb.Monitoring.StoragePoolStatus\"\x81\x01\n\x13\x43omputeTabletStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x03(\t\"c\n\x10ThreadPoolStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05usage\x18\x03 \x01(\x02\"d\n\x11LoadAverageStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04load\x18\x02 \x01(\x02\x12\r\n\x05\x63ores\x18\x03 \x01(\r\"\xeb\x01\n\x11\x43omputeNodeStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x34\n\x07tablets\x18\x03 \x03(\x0b\x32#.Ydb.Monitoring.ComputeTabletStatus\x12/\n\x05pools\x18\x04 \x03(\x0b\x32 .Ydb.Monitoring.ThreadPoolStatus\x12/\n\x04load\x18\x05 \x01(\x0b\x32!.Ydb.Monitoring.LoadAverageStatus\"\xab\x01\n\rComputeStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x30\n\x05nodes\x18\x02 \x03(\x0b\x32!.Ydb.Monitoring.ComputeNodeStatus\x12\x34\n\x07tablets\x18\x03 \x03(\x0b\x32#.Ydb.Monitoring.ComputeTabletStatus\"6\n\x0cLocationNode\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\"0\n\x14LocationStoragePDisk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"W\n\x14LocationStorageVDisk\x12\n\n\x02id\x18\x01 \x03(\t\x12\x33\n\x05pdisk\x18\x02 \x03(\x0b\x32$.Ydb.Monitoring.LocationStoragePDisk\"W\n\x14LocationStorageGroup\x12\n\n\x02id\x18\x01 \x03(\t\x12\x33\n\x05vdisk\x18\x02 \x01(\x0b\x32$.Ydb.Monitoring.LocationStorageVDisk\"X\n\x13LocationStoragePool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\x05group\x18\x02 \x01(\x0b\x32$.Ydb.Monitoring.LocationStorageGroup\"p\n\x0fLocationStorage\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x1c.Ydb.Monitoring.LocationNode\x12\x31\n\x04pool\x18\x02 \x01(\x0b\x32#.Ydb.Monitoring.LocationStoragePool\"#\n\x13LocationComputePool\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x15LocationComputeTablet\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x03(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xa7\x01\n\x0fLocationCompute\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x1c.Ydb.Monitoring.LocationNode\x12\x31\n\x04pool\x18\x02 \x01(\x0b\x32#.Ydb.Monitoring.LocationComputePool\x12\x35\n\x06tablet\x18\x03 \x01(\x0b\x32%.Ydb.Monitoring.LocationComputeTablet\" \n\x10LocationDatabase\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa2\x01\n\x08Location\x12\x30\n\x07storage\x18\x01 \x01(\x0b\x32\x1f.Ydb.Monitoring.LocationStorage\x12\x30\n\x07\x63ompute\x18\x02 \x01(\x0b\x32\x1f.Ydb.Monitoring.LocationCompute\x12\x32\n\x08\x64\x61tabase\x18\x03 \x01(\x0b\x32 .Ydb.Monitoring.LocationDatabase\"\xd2\x01\n\x08IssueLog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x06status\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0f\n\x07message\x18\x03 \x01(\t\x12*\n\x08location\x18\x04 \x01(\x0b\x32\x18.Ydb.Monitoring.Location\x12\x0e\n\x06reason\x18\x05 \x03(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\r\n\x05level\x18\x07 \x01(\r\x12\x0e\n\x06listed\x18\x08 \x01(\r\x12\r\n\x05\x63ount\x18\t \x01(\r\"\xb2\x01\n\x0e\x44\x61tabaseStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12.\n\x07storage\x18\x03 \x01(\x0b\x32\x1d.Ydb.Monitoring.StorageStatus\x12.\n\x07\x63ompute\x18\x04 \x01(\x0b\x32\x1d.Ydb.Monitoring.ComputeStatus\"\xb4\x01\n\x0fSelfCheckResult\x12;\n\x11self_check_result\x18\x01 \x01(\x0e\x32 .Ydb.Monitoring.SelfCheck.Result\x12+\n\tissue_log\x18\x02 \x03(\x0b\x32\x18.Ydb.Monitoring.IssueLog\x12\x37\n\x0f\x64\x61tabase_status\x18\x03 \x03(\x0b\x32\x1e.Ydb.Monitoring.DatabaseStatusBo\n\x19tech.ydb.proto.monitoringB\x10MonitoringProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Monitoring\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_STATUSFLAG_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='Ydb.Monitoring.StatusFlag.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORANGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=89,
  serialized_end=178,
)
_sym_db.RegisterEnumDescriptor(_STATUSFLAG_STATUS)

_SELFCHECK_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='Ydb.Monitoring.SelfCheck.Result',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEGRADED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAINTENANCE_REQUIRED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=599,
  serialized_end=689,
)
_sym_db.RegisterEnumDescriptor(_SELFCHECK_RESULT)


_STATUSFLAG = _descriptor.Descriptor(
  name='StatusFlag',
  full_name='Ydb.Monitoring.StatusFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUSFLAG_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=178,
)


_SELFCHECKREQUEST = _descriptor.Descriptor(
  name='SelfCheckRequest',
  full_name='Ydb.Monitoring.SelfCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Monitoring.SelfCheckRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_verbose_status', full_name='Ydb.Monitoring.SelfCheckRequest.return_verbose_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_status', full_name='Ydb.Monitoring.SelfCheckRequest.minimum_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_level', full_name='Ydb.Monitoring.SelfCheckRequest.maximum_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=371,
)


_SELFCHECKRESPONSE = _descriptor.Descriptor(
  name='SelfCheckResponse',
  full_name='Ydb.Monitoring.SelfCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Monitoring.SelfCheckResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=438,
)


_NODECHECKREQUEST = _descriptor.Descriptor(
  name='NodeCheckRequest',
  full_name='Ydb.Monitoring.NodeCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Monitoring.NodeCheckRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=517,
)


_NODECHECKRESPONSE = _descriptor.Descriptor(
  name='NodeCheckResponse',
  full_name='Ydb.Monitoring.NodeCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Monitoring.NodeCheckResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=584,
)


_SELFCHECK = _descriptor.Descriptor(
  name='SelfCheck',
  full_name='Ydb.Monitoring.SelfCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SELFCHECK_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=689,
)


_STORAGEPDISKSTATUS = _descriptor.Descriptor(
  name='StoragePDiskStatus',
  full_name='Ydb.Monitoring.StoragePDiskStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StoragePDiskStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StoragePDiskStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=775,
)


_STORAGEVDISKSTATUS = _descriptor.Descriptor(
  name='StorageVDiskStatus',
  full_name='Ydb.Monitoring.StorageVDiskStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StorageVDiskStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageVDiskStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisk_status', full_name='Ydb.Monitoring.StorageVDiskStatus.vdisk_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdisk', full_name='Ydb.Monitoring.StorageVDiskStatus.pdisk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=970,
)


_STORAGEGROUPSTATUS = _descriptor.Descriptor(
  name='StorageGroupStatus',
  full_name='Ydb.Monitoring.StorageGroupStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StorageGroupStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageGroupStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisks', full_name='Ydb.Monitoring.StorageGroupStatus.vdisks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1109,
)


_STORAGEPOOLSTATUS = _descriptor.Descriptor(
  name='StoragePoolStatus',
  full_name='Ydb.Monitoring.StoragePoolStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StoragePoolStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StoragePoolStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='Ydb.Monitoring.StoragePoolStatus.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1247,
)


_STORAGESTATUS = _descriptor.Descriptor(
  name='StorageStatus',
  full_name='Ydb.Monitoring.StorageStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pools', full_name='Ydb.Monitoring.StorageStatus.pools', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1366,
)


_COMPUTETABLETSTATUS = _descriptor.Descriptor(
  name='ComputeTabletStatus',
  full_name='Ydb.Monitoring.ComputeTabletStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeTabletStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.ComputeTabletStatus.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Monitoring.ComputeTabletStatus.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.ComputeTabletStatus.count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.ComputeTabletStatus.id', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1498,
)


_THREADPOOLSTATUS = _descriptor.Descriptor(
  name='ThreadPoolStatus',
  full_name='Ydb.Monitoring.ThreadPoolStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ThreadPoolStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.ThreadPoolStatus.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='Ydb.Monitoring.ThreadPoolStatus.usage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1500,
  serialized_end=1599,
)


_LOADAVERAGESTATUS = _descriptor.Descriptor(
  name='LoadAverageStatus',
  full_name='Ydb.Monitoring.LoadAverageStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.LoadAverageStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='Ydb.Monitoring.LoadAverageStatus.load', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='Ydb.Monitoring.LoadAverageStatus.cores', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1701,
)


_COMPUTENODESTATUS = _descriptor.Descriptor(
  name='ComputeNodeStatus',
  full_name='Ydb.Monitoring.ComputeNodeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.ComputeNodeStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeNodeStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablets', full_name='Ydb.Monitoring.ComputeNodeStatus.tablets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pools', full_name='Ydb.Monitoring.ComputeNodeStatus.pools', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='Ydb.Monitoring.ComputeNodeStatus.load', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1704,
  serialized_end=1939,
)


_COMPUTESTATUS = _descriptor.Descriptor(
  name='ComputeStatus',
  full_name='Ydb.Monitoring.ComputeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='Ydb.Monitoring.ComputeStatus.nodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablets', full_name='Ydb.Monitoring.ComputeStatus.tablets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1942,
  serialized_end=2113,
)


_LOCATIONNODE = _descriptor.Descriptor(
  name='LocationNode',
  full_name='Ydb.Monitoring.LocationNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationNode.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Monitoring.LocationNode.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Monitoring.LocationNode.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2169,
)


_LOCATIONSTORAGEPDISK = _descriptor.Descriptor(
  name='LocationStoragePDisk',
  full_name='Ydb.Monitoring.LocationStoragePDisk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStoragePDisk.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Monitoring.LocationStoragePDisk.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2171,
  serialized_end=2219,
)


_LOCATIONSTORAGEVDISK = _descriptor.Descriptor(
  name='LocationStorageVDisk',
  full_name='Ydb.Monitoring.LocationStorageVDisk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStorageVDisk.id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdisk', full_name='Ydb.Monitoring.LocationStorageVDisk.pdisk', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2221,
  serialized_end=2308,
)


_LOCATIONSTORAGEGROUP = _descriptor.Descriptor(
  name='LocationStorageGroup',
  full_name='Ydb.Monitoring.LocationStorageGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStorageGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisk', full_name='Ydb.Monitoring.LocationStorageGroup.vdisk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2310,
  serialized_end=2397,
)


_LOCATIONSTORAGEPOOL = _descriptor.Descriptor(
  name='LocationStoragePool',
  full_name='Ydb.Monitoring.LocationStoragePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationStoragePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='Ydb.Monitoring.LocationStoragePool.group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2487,
)


_LOCATIONSTORAGE = _descriptor.Descriptor(
  name='LocationStorage',
  full_name='Ydb.Monitoring.LocationStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='Ydb.Monitoring.LocationStorage.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='Ydb.Monitoring.LocationStorage.pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=2601,
)


_LOCATIONCOMPUTEPOOL = _descriptor.Descriptor(
  name='LocationComputePool',
  full_name='Ydb.Monitoring.LocationComputePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationComputePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2603,
  serialized_end=2638,
)


_LOCATIONCOMPUTETABLET = _descriptor.Descriptor(
  name='LocationComputeTablet',
  full_name='Ydb.Monitoring.LocationComputeTablet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.LocationComputeTablet.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationComputeTablet.id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.LocationComputeTablet.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2640,
  serialized_end=2704,
)


_LOCATIONCOMPUTE = _descriptor.Descriptor(
  name='LocationCompute',
  full_name='Ydb.Monitoring.LocationCompute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='Ydb.Monitoring.LocationCompute.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='Ydb.Monitoring.LocationCompute.pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablet', full_name='Ydb.Monitoring.LocationCompute.tablet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2707,
  serialized_end=2874,
)


_LOCATIONDATABASE = _descriptor.Descriptor(
  name='LocationDatabase',
  full_name='Ydb.Monitoring.LocationDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationDatabase.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2908,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='Ydb.Monitoring.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='Ydb.Monitoring.Location.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute', full_name='Ydb.Monitoring.Location.compute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='Ydb.Monitoring.Location.database', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2911,
  serialized_end=3073,
)


_ISSUELOG = _descriptor.Descriptor(
  name='IssueLog',
  full_name='Ydb.Monitoring.IssueLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.IssueLog.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Monitoring.IssueLog.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='Ydb.Monitoring.IssueLog.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='Ydb.Monitoring.IssueLog.location', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='Ydb.Monitoring.IssueLog.reason', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.IssueLog.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='Ydb.Monitoring.IssueLog.level', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listed', full_name='Ydb.Monitoring.IssueLog.listed', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.IssueLog.count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3286,
)


_DATABASESTATUS = _descriptor.Descriptor(
  name='DatabaseStatus',
  full_name='Ydb.Monitoring.DatabaseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.DatabaseStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.DatabaseStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage', full_name='Ydb.Monitoring.DatabaseStatus.storage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute', full_name='Ydb.Monitoring.DatabaseStatus.compute', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3289,
  serialized_end=3467,
)


_SELFCHECKRESULT = _descriptor.Descriptor(
  name='SelfCheckResult',
  full_name='Ydb.Monitoring.SelfCheckResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self_check_result', full_name='Ydb.Monitoring.SelfCheckResult.self_check_result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue_log', full_name='Ydb.Monitoring.SelfCheckResult.issue_log', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_status', full_name='Ydb.Monitoring.SelfCheckResult.database_status', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3470,
  serialized_end=3650,
)

_STATUSFLAG_STATUS.containing_type = _STATUSFLAG
_SELFCHECKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_SELFCHECKREQUEST.fields_by_name['minimum_status'].enum_type = _STATUSFLAG_STATUS
_SELFCHECKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_NODECHECKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_NODECHECKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_SELFCHECK_RESULT.containing_type = _SELFCHECK
_STORAGEPDISKSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['vdisk_status'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['pdisk'].message_type = _STORAGEPDISKSTATUS
_STORAGEGROUPSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEGROUPSTATUS.fields_by_name['vdisks'].message_type = _STORAGEVDISKSTATUS
_STORAGEPOOLSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEPOOLSTATUS.fields_by_name['groups'].message_type = _STORAGEGROUPSTATUS
_STORAGESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGESTATUS.fields_by_name['pools'].message_type = _STORAGEPOOLSTATUS
_COMPUTETABLETSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_THREADPOOLSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_LOADAVERAGESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTENODESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTENODESTATUS.fields_by_name['tablets'].message_type = _COMPUTETABLETSTATUS
_COMPUTENODESTATUS.fields_by_name['pools'].message_type = _THREADPOOLSTATUS
_COMPUTENODESTATUS.fields_by_name['load'].message_type = _LOADAVERAGESTATUS
_COMPUTESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTESTATUS.fields_by_name['nodes'].message_type = _COMPUTENODESTATUS
_COMPUTESTATUS.fields_by_name['tablets'].message_type = _COMPUTETABLETSTATUS
_LOCATIONSTORAGEVDISK.fields_by_name['pdisk'].message_type = _LOCATIONSTORAGEPDISK
_LOCATIONSTORAGEGROUP.fields_by_name['vdisk'].message_type = _LOCATIONSTORAGEVDISK
_LOCATIONSTORAGEPOOL.fields_by_name['group'].message_type = _LOCATIONSTORAGEGROUP
_LOCATIONSTORAGE.fields_by_name['node'].message_type = _LOCATIONNODE
_LOCATIONSTORAGE.fields_by_name['pool'].message_type = _LOCATIONSTORAGEPOOL
_LOCATIONCOMPUTE.fields_by_name['node'].message_type = _LOCATIONNODE
_LOCATIONCOMPUTE.fields_by_name['pool'].message_type = _LOCATIONCOMPUTEPOOL
_LOCATIONCOMPUTE.fields_by_name['tablet'].message_type = _LOCATIONCOMPUTETABLET
_LOCATION.fields_by_name['storage'].message_type = _LOCATIONSTORAGE
_LOCATION.fields_by_name['compute'].message_type = _LOCATIONCOMPUTE
_LOCATION.fields_by_name['database'].message_type = _LOCATIONDATABASE
_ISSUELOG.fields_by_name['status'].enum_type = _STATUSFLAG_STATUS
_ISSUELOG.fields_by_name['location'].message_type = _LOCATION
_DATABASESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_DATABASESTATUS.fields_by_name['storage'].message_type = _STORAGESTATUS
_DATABASESTATUS.fields_by_name['compute'].message_type = _COMPUTESTATUS
_SELFCHECKRESULT.fields_by_name['self_check_result'].enum_type = _SELFCHECK_RESULT
_SELFCHECKRESULT.fields_by_name['issue_log'].message_type = _ISSUELOG
_SELFCHECKRESULT.fields_by_name['database_status'].message_type = _DATABASESTATUS
DESCRIPTOR.message_types_by_name['StatusFlag'] = _STATUSFLAG
DESCRIPTOR.message_types_by_name['SelfCheckRequest'] = _SELFCHECKREQUEST
DESCRIPTOR.message_types_by_name['SelfCheckResponse'] = _SELFCHECKRESPONSE
DESCRIPTOR.message_types_by_name['NodeCheckRequest'] = _NODECHECKREQUEST
DESCRIPTOR.message_types_by_name['NodeCheckResponse'] = _NODECHECKRESPONSE
DESCRIPTOR.message_types_by_name['SelfCheck'] = _SELFCHECK
DESCRIPTOR.message_types_by_name['StoragePDiskStatus'] = _STORAGEPDISKSTATUS
DESCRIPTOR.message_types_by_name['StorageVDiskStatus'] = _STORAGEVDISKSTATUS
DESCRIPTOR.message_types_by_name['StorageGroupStatus'] = _STORAGEGROUPSTATUS
DESCRIPTOR.message_types_by_name['StoragePoolStatus'] = _STORAGEPOOLSTATUS
DESCRIPTOR.message_types_by_name['StorageStatus'] = _STORAGESTATUS
DESCRIPTOR.message_types_by_name['ComputeTabletStatus'] = _COMPUTETABLETSTATUS
DESCRIPTOR.message_types_by_name['ThreadPoolStatus'] = _THREADPOOLSTATUS
DESCRIPTOR.message_types_by_name['LoadAverageStatus'] = _LOADAVERAGESTATUS
DESCRIPTOR.message_types_by_name['ComputeNodeStatus'] = _COMPUTENODESTATUS
DESCRIPTOR.message_types_by_name['ComputeStatus'] = _COMPUTESTATUS
DESCRIPTOR.message_types_by_name['LocationNode'] = _LOCATIONNODE
DESCRIPTOR.message_types_by_name['LocationStoragePDisk'] = _LOCATIONSTORAGEPDISK
DESCRIPTOR.message_types_by_name['LocationStorageVDisk'] = _LOCATIONSTORAGEVDISK
DESCRIPTOR.message_types_by_name['LocationStorageGroup'] = _LOCATIONSTORAGEGROUP
DESCRIPTOR.message_types_by_name['LocationStoragePool'] = _LOCATIONSTORAGEPOOL
DESCRIPTOR.message_types_by_name['LocationStorage'] = _LOCATIONSTORAGE
DESCRIPTOR.message_types_by_name['LocationComputePool'] = _LOCATIONCOMPUTEPOOL
DESCRIPTOR.message_types_by_name['LocationComputeTablet'] = _LOCATIONCOMPUTETABLET
DESCRIPTOR.message_types_by_name['LocationCompute'] = _LOCATIONCOMPUTE
DESCRIPTOR.message_types_by_name['LocationDatabase'] = _LOCATIONDATABASE
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['IssueLog'] = _ISSUELOG
DESCRIPTOR.message_types_by_name['DatabaseStatus'] = _DATABASESTATUS
DESCRIPTOR.message_types_by_name['SelfCheckResult'] = _SELFCHECKRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusFlag = _reflection.GeneratedProtocolMessageType('StatusFlag', (_message.Message,), {
  'DESCRIPTOR' : _STATUSFLAG,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StatusFlag)
  })
_sym_db.RegisterMessage(StatusFlag)

SelfCheckRequest = _reflection.GeneratedProtocolMessageType('SelfCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKREQUEST,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckRequest)
  })
_sym_db.RegisterMessage(SelfCheckRequest)

SelfCheckResponse = _reflection.GeneratedProtocolMessageType('SelfCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKRESPONSE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckResponse)
  })
_sym_db.RegisterMessage(SelfCheckResponse)

NodeCheckRequest = _reflection.GeneratedProtocolMessageType('NodeCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODECHECKREQUEST,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.NodeCheckRequest)
  })
_sym_db.RegisterMessage(NodeCheckRequest)

NodeCheckResponse = _reflection.GeneratedProtocolMessageType('NodeCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODECHECKRESPONSE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.NodeCheckResponse)
  })
_sym_db.RegisterMessage(NodeCheckResponse)

SelfCheck = _reflection.GeneratedProtocolMessageType('SelfCheck', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheck)
  })
_sym_db.RegisterMessage(SelfCheck)

StoragePDiskStatus = _reflection.GeneratedProtocolMessageType('StoragePDiskStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPDISKSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StoragePDiskStatus)
  })
_sym_db.RegisterMessage(StoragePDiskStatus)

StorageVDiskStatus = _reflection.GeneratedProtocolMessageType('StorageVDiskStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEVDISKSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageVDiskStatus)
  })
_sym_db.RegisterMessage(StorageVDiskStatus)

StorageGroupStatus = _reflection.GeneratedProtocolMessageType('StorageGroupStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEGROUPSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageGroupStatus)
  })
_sym_db.RegisterMessage(StorageGroupStatus)

StoragePoolStatus = _reflection.GeneratedProtocolMessageType('StoragePoolStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPOOLSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StoragePoolStatus)
  })
_sym_db.RegisterMessage(StoragePoolStatus)

StorageStatus = _reflection.GeneratedProtocolMessageType('StorageStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageStatus)
  })
_sym_db.RegisterMessage(StorageStatus)

ComputeTabletStatus = _reflection.GeneratedProtocolMessageType('ComputeTabletStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTETABLETSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeTabletStatus)
  })
_sym_db.RegisterMessage(ComputeTabletStatus)

ThreadPoolStatus = _reflection.GeneratedProtocolMessageType('ThreadPoolStatus', (_message.Message,), {
  'DESCRIPTOR' : _THREADPOOLSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ThreadPoolStatus)
  })
_sym_db.RegisterMessage(ThreadPoolStatus)

LoadAverageStatus = _reflection.GeneratedProtocolMessageType('LoadAverageStatus', (_message.Message,), {
  'DESCRIPTOR' : _LOADAVERAGESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LoadAverageStatus)
  })
_sym_db.RegisterMessage(LoadAverageStatus)

ComputeNodeStatus = _reflection.GeneratedProtocolMessageType('ComputeNodeStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeNodeStatus)
  })
_sym_db.RegisterMessage(ComputeNodeStatus)

ComputeStatus = _reflection.GeneratedProtocolMessageType('ComputeStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeStatus)
  })
_sym_db.RegisterMessage(ComputeStatus)

LocationNode = _reflection.GeneratedProtocolMessageType('LocationNode', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONNODE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationNode)
  })
_sym_db.RegisterMessage(LocationNode)

LocationStoragePDisk = _reflection.GeneratedProtocolMessageType('LocationStoragePDisk', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEPDISK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStoragePDisk)
  })
_sym_db.RegisterMessage(LocationStoragePDisk)

LocationStorageVDisk = _reflection.GeneratedProtocolMessageType('LocationStorageVDisk', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEVDISK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorageVDisk)
  })
_sym_db.RegisterMessage(LocationStorageVDisk)

LocationStorageGroup = _reflection.GeneratedProtocolMessageType('LocationStorageGroup', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEGROUP,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorageGroup)
  })
_sym_db.RegisterMessage(LocationStorageGroup)

LocationStoragePool = _reflection.GeneratedProtocolMessageType('LocationStoragePool', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEPOOL,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStoragePool)
  })
_sym_db.RegisterMessage(LocationStoragePool)

LocationStorage = _reflection.GeneratedProtocolMessageType('LocationStorage', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorage)
  })
_sym_db.RegisterMessage(LocationStorage)

LocationComputePool = _reflection.GeneratedProtocolMessageType('LocationComputePool', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTEPOOL,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationComputePool)
  })
_sym_db.RegisterMessage(LocationComputePool)

LocationComputeTablet = _reflection.GeneratedProtocolMessageType('LocationComputeTablet', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTETABLET,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationComputeTablet)
  })
_sym_db.RegisterMessage(LocationComputeTablet)

LocationCompute = _reflection.GeneratedProtocolMessageType('LocationCompute', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationCompute)
  })
_sym_db.RegisterMessage(LocationCompute)

LocationDatabase = _reflection.GeneratedProtocolMessageType('LocationDatabase', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONDATABASE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationDatabase)
  })
_sym_db.RegisterMessage(LocationDatabase)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.Location)
  })
_sym_db.RegisterMessage(Location)

IssueLog = _reflection.GeneratedProtocolMessageType('IssueLog', (_message.Message,), {
  'DESCRIPTOR' : _ISSUELOG,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.IssueLog)
  })
_sym_db.RegisterMessage(IssueLog)

DatabaseStatus = _reflection.GeneratedProtocolMessageType('DatabaseStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATABASESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.DatabaseStatus)
  })
_sym_db.RegisterMessage(DatabaseStatus)

SelfCheckResult = _reflection.GeneratedProtocolMessageType('SelfCheckResult', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKRESULT,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckResult)
  })
_sym_db.RegisterMessage(SelfCheckResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
