# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_import.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v5.protos import ydb_export_pb2 as protos_dot_ydb__export__pb2
from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17protos/ydb_import.proto\x12\nYdb.Import\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_export.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x01\n\x0eImportProgress\"\xdb\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x16\n\x12PROGRESS_PREPARING\x10\x01\x12\x1a\n\x16PROGRESS_TRANSFER_DATA\x10\x02\x12\x1a\n\x16PROGRESS_BUILD_INDEXES\x10\x03\x12\x11\n\rPROGRESS_DONE\x10\x04\x12\x19\n\x15PROGRESS_CANCELLATION\x10\x05\x12\x16\n\x12PROGRESS_CANCELLED\x10\x06\x12\x1f\n\x1bPROGRESS_CREATE_CHANGEFEEDS\x10\x07\"\xa0\x01\n\x12ImportItemProgress\x12\x13\n\x0bparts_total\x18\x01 \x01(\r\x12\x17\n\x0fparts_completed\x18\x02 \x01(\r\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xfb\x06\n\x14ImportFromS3Settings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x06 \x03(\x0b\x32%.Ydb.Import.ImportFromS3Settings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x08 \x01(\r\x12\x0e\n\x06region\x18\t \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\n \x01(\x08\x12\x0e\n\x06no_acl\x18\x0b \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x0c \x01(\x08\x12\x15\n\rsource_prefix\x18\r \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x0e \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0f \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12M\n\x12index_filling_mode\x18\x10 \x01(\x0e\x32\x31.Ydb.Import.ImportFromS3Settings.IndexFillingMode\x12\x17\n\x0f\x65xclude_regexps\x18\x11 \x03(\t\x1aZ\n\x04Item\x12\x17\n\rsource_prefix\x18\x01 \x01(\tH\x00\x12\x15\n\x0bsource_path\x18\x03 \x01(\tH\x00\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\tB\x08\n\x06Source\".\n\x06Scheme\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\"\x90\x01\n\x10IndexFillingMode\x12\"\n\x1eINDEX_FILLING_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x18INDEX_FILLING_MODE_BUILD\x10\x01\x12\x1d\n\x19INDEX_FILLING_MODE_IMPORT\x10\x02\x12\x1b\n\x17INDEX_FILLING_MODE_AUTO\x10\x03\"\x14\n\x12ImportFromS3Result\"\xb9\x01\n\x14ImportFromS3Metadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromS3Settings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromS3Request\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromS3Response\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xf7\x02\n\x14ImportFromFsSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.Ydb.Import.ImportFromFsSettings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x04 \x01(\r\x12\x0e\n\x06no_acl\x18\x05 \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x06 \x01(\x08\x12\x18\n\x10\x64\x65stination_path\x18\x07 \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x08 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\t \x03(\t\x1a\x35\n\x04Item\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\"\x14\n\x12ImportFromFsResult\"\xb9\x01\n\x14ImportFromFsMetadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromFsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromFsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc4\x03\n\x1dListObjectsInS3ExportSettings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x06 \x03(\x0b\x32..Ydb.Import.ListObjectsInS3ExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x07 \x01(\r\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\t \x01(\x08\x12\x0e\n\x06prefix\x18\n \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0b \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x0c \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x99\x01\n\x1bListObjectsInS3ExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInS3ExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a$\n\x04Item\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInS3ExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInS3ExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInS3ExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xfe\x01\n\x1dListObjectsInFsExportSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x02 \x03(\x0b\x32..Ydb.Import.ListObjectsInFsExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x03 \x01(\r\x12;\n\x13\x65ncryption_settings\x18\x04 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x05 \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x9d\x01\n\x1bListObjectsInFsExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInFsExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a(\n\x04Item\x12\x0f\n\x07\x66s_path\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInFsExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInFsExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInFsExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\" \n\rYdbDumpFormat\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\"\x12\n\x10ImportDataResult\"\xae\x01\n\x11ImportDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\t\xa2\xe6*\x05\x18\x80\x80\x80\x08\x12-\n\x08ydb_dump\x18\x04 \x01(\x0b\x32\x19.Ydb.Import.YdbDumpFormatH\x00\x42\x08\n\x06\x66ormat\"B\n\x12ImportDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBV\n\x16tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_import_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\370\001\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['endpoint']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['endpoint']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['bucket']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['bucket']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['access_key']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['access_key']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['secret_key']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['secret_key']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['description']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _IMPORTFROMS3REQUEST.fields_by_name['settings']._options = None
  _IMPORTFROMS3REQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _IMPORTFROMFSSETTINGS.fields_by_name['base_path']._options = None
  _IMPORTFROMFSSETTINGS.fields_by_name['base_path']._serialized_options = b'\220\346*\001'
  _IMPORTFROMFSSETTINGS.fields_by_name['description']._options = None
  _IMPORTFROMFSSETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _IMPORTFROMFSREQUEST.fields_by_name['settings']._options = None
  _IMPORTFROMFSREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['endpoint']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['endpoint']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['bucket']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['bucket']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['access_key']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['access_key']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['secret_key']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['secret_key']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings']._options = None
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['page_size']._options = None
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\010<= 10000'
  _LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['base_path']._options = None
  _LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['base_path']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings']._options = None
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['page_size']._options = None
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\010<= 10000'
  _IMPORTDATAREQUEST.fields_by_name['data']._options = None
  _IMPORTDATAREQUEST.fields_by_name['data']._serialized_options = b'\242\346*\005\030\200\200\200\010'
  _IMPORTPROGRESS._serialized_start=163
  _IMPORTPROGRESS._serialized_end=401
  _IMPORTPROGRESS_PROGRESS._serialized_start=182
  _IMPORTPROGRESS_PROGRESS._serialized_end=401
  _IMPORTITEMPROGRESS._serialized_start=404
  _IMPORTITEMPROGRESS._serialized_end=564
  _IMPORTFROMS3SETTINGS._serialized_start=567
  _IMPORTFROMS3SETTINGS._serialized_end=1458
  _IMPORTFROMS3SETTINGS_ITEM._serialized_start=1173
  _IMPORTFROMS3SETTINGS_ITEM._serialized_end=1263
  _IMPORTFROMS3SETTINGS_SCHEME._serialized_start=1265
  _IMPORTFROMS3SETTINGS_SCHEME._serialized_end=1311
  _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE._serialized_start=1314
  _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE._serialized_end=1458
  _IMPORTFROMS3RESULT._serialized_start=1460
  _IMPORTFROMS3RESULT._serialized_end=1480
  _IMPORTFROMS3METADATA._serialized_start=1483
  _IMPORTFROMS3METADATA._serialized_end=1668
  _IMPORTFROMS3REQUEST._serialized_start=1671
  _IMPORTFROMS3REQUEST._serialized_end=1809
  _IMPORTFROMS3RESPONSE._serialized_start=1811
  _IMPORTFROMS3RESPONSE._serialized_end=1879
  _IMPORTFROMFSSETTINGS._serialized_start=1882
  _IMPORTFROMFSSETTINGS._serialized_end=2257
  _IMPORTFROMFSSETTINGS_ITEM._serialized_start=2204
  _IMPORTFROMFSSETTINGS_ITEM._serialized_end=2257
  _IMPORTFROMFSRESULT._serialized_start=2259
  _IMPORTFROMFSRESULT._serialized_end=2279
  _IMPORTFROMFSMETADATA._serialized_start=2282
  _IMPORTFROMFSMETADATA._serialized_end=2467
  _IMPORTFROMFSREQUEST._serialized_start=2470
  _IMPORTFROMFSREQUEST._serialized_end=2608
  _IMPORTFROMFSRESPONSE._serialized_start=2610
  _IMPORTFROMFSRESPONSE._serialized_end=2678
  _LISTOBJECTSINS3EXPORTSETTINGS._serialized_start=2681
  _LISTOBJECTSINS3EXPORTSETTINGS._serialized_end=3133
  _LISTOBJECTSINS3EXPORTSETTINGS_ITEM._serialized_start=3113
  _LISTOBJECTSINS3EXPORTSETTINGS_ITEM._serialized_end=3133
  _LISTOBJECTSINS3EXPORTRESULT._serialized_start=3136
  _LISTOBJECTSINS3EXPORTRESULT._serialized_end=3289
  _LISTOBJECTSINS3EXPORTRESULT_ITEM._serialized_start=3253
  _LISTOBJECTSINS3EXPORTRESULT_ITEM._serialized_end=3289
  _LISTOBJECTSINS3EXPORTREQUEST._serialized_start=3292
  _LISTOBJECTSINS3EXPORTREQUEST._serialized_end=3501
  _LISTOBJECTSINS3EXPORTRESPONSE._serialized_start=3503
  _LISTOBJECTSINS3EXPORTRESPONSE._serialized_end=3580
  _LISTOBJECTSINFSEXPORTSETTINGS._serialized_start=3583
  _LISTOBJECTSINFSEXPORTSETTINGS._serialized_end=3837
  _LISTOBJECTSINFSEXPORTSETTINGS_ITEM._serialized_start=3113
  _LISTOBJECTSINFSEXPORTSETTINGS_ITEM._serialized_end=3133
  _LISTOBJECTSINFSEXPORTRESULT._serialized_start=3840
  _LISTOBJECTSINFSEXPORTRESULT._serialized_end=3997
  _LISTOBJECTSINFSEXPORTRESULT_ITEM._serialized_start=3957
  _LISTOBJECTSINFSEXPORTRESULT_ITEM._serialized_end=3997
  _LISTOBJECTSINFSEXPORTREQUEST._serialized_start=4000
  _LISTOBJECTSINFSEXPORTREQUEST._serialized_end=4209
  _LISTOBJECTSINFSEXPORTRESPONSE._serialized_start=4211
  _LISTOBJECTSINFSEXPORTRESPONSE._serialized_end=4288
  _YDBDUMPFORMAT._serialized_start=4290
  _YDBDUMPFORMAT._serialized_end=4322
  _IMPORTDATARESULT._serialized_start=4324
  _IMPORTDATARESULT._serialized_end=4342
  _IMPORTDATAREQUEST._serialized_start=4345
  _IMPORTDATAREQUEST._serialized_end=4519
  _IMPORTDATARESPONSE._serialized_start=4521
  _IMPORTDATARESPONSE._serialized_end=4587
# @@protoc_insertion_point(module_scope)
