from draft.protos import ydb_object_storage_pb2 as _ydb_object_storage_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
