# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_cms.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_cms.proto',
  package='Ydb.Cms',
  syntax='proto3',
  serialized_options=b'\n\022tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14protos/ydb_cms.proto\x12\x07Ydb.Cms\x1a\x1aprotos/ydb_operation.proto\"0\n\x0cStorageUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"Q\n\x12\x43omputationalUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"K\n\x1a\x41llocatedComputationalUnit\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x11\n\tunit_kind\x18\x03 \x01(\t\"s\n\tResources\x12,\n\rstorage_units\x18\x01 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12\x38\n\x13\x63omputational_units\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\"3\n\x13ServerlessResources\x12\x1c\n\x14shared_database_path\x18\x01 \x01(\t\"j\n\x0f\x44\x61tabaseOptions\x12\x1a\n\x12\x64isable_tx_service\x18\x01 \x01(\x08\x12\"\n\x1a\x64isable_external_subdomain\x18\x02 \x01(\x08\x12\x17\n\x0fplan_resolution\x18\x03 \x01(\r\"\x9c\x01\n\x15SchemaOperationQuotas\x12G\n\x13leaky_bucket_quotas\x18\x01 \x03(\x0b\x32*.Ydb.Cms.SchemaOperationQuotas.LeakyBucket\x1a:\n\x0bLeakyBucket\x12\x13\n\x0b\x62ucket_size\x18\x01 \x01(\x01\x12\x16\n\x0e\x62ucket_seconds\x18\x02 \x01(\x04\"\xc0\x01\n\x0e\x44\x61tabaseQuotas\x12\x1c\n\x14\x64\x61ta_size_hard_quota\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x61ta_size_soft_quota\x18\x02 \x01(\x04\x12 \n\x18\x64\x61ta_stream_shards_quota\x18\x03 \x01(\x04\x12*\n\"data_stream_reserved_storage_quota\x18\x05 \x01(\x04\x12$\n\x1cttl_min_run_internal_seconds\x18\x04 \x01(\r\"\xb7\x04\n\x15\x43reateDatabaseRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\'\n\tresources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12.\n\x10shared_resources\x18\x06 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x07 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12)\n\x07options\x18\x04 \x01(\x0b\x32\x18.Ydb.Cms.DatabaseOptions\x12\x42\n\nattributes\x18\x05 \x03(\x0b\x32..Ydb.Cms.CreateDatabaseRequest.AttributesEntry\x12?\n\x17schema_operation_quotas\x18\x08 \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\t \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eresources_kind\"F\n\x16\x43reateDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"c\n\x18GetDatabaseStatusRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"I\n\x19GetDatabaseStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x05\n\x17GetDatabaseStatusResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x35\n\x05state\x18\x02 \x01(\x0e\x32&.Ydb.Cms.GetDatabaseStatusResult.State\x12\x30\n\x12required_resources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12\x37\n\x19required_shared_resources\x18\x07 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x08 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12/\n\x13\x61llocated_resources\x18\x04 \x01(\x0b\x32\x12.Ydb.Cms.Resources\x12\x41\n\x14registered_resources\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x12\n\ngeneration\x18\x06 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"o\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08REMOVING\x10\x03\x12\x15\n\x11PENDING_RESOURCES\x10\x04\x12\x0f\n\x0b\x43ONFIGURING\x10\x05\x42\x10\n\x0eresources_kind\"\xdd\x05\n\x14\x41lterDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12?\n\x1a\x63omputational_units_to_add\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x42\n\x1d\x63omputational_units_to_remove\x18\x03 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x33\n\x14storage_units_to_add\x18\x04 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12L\n\x1f\x63omputational_units_to_register\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12N\n!computational_units_to_deregister\x18\x06 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x39\n\x10operation_params\x18\x07 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\ngeneration\x18\x08 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\n \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\x0b \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12L\n\x10\x61lter_attributes\x18\x0c \x03(\x0b\x32\x32.Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x15\x41lterDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x14ListDatabasesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15ListDatabasesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"$\n\x13ListDatabasesResult\x12\r\n\x05paths\x18\x01 \x03(\t\"`\n\x15RemoveDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"F\n\x16RemoveDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x92\x01\n\x16StorageUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12;\n\x06labels\x18\x02 \x03(\x0b\x32+.Ydb.Cms.StorageUnitDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1b\x41vailabilityZoneDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x06labels\x18\x02 \x03(\x0b\x32\x30.Ydb.Cms.AvailabilityZoneDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x1c\x43omputationalUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Cms.ComputationalUnitDescription.LabelsEntry\x12\"\n\x1a\x61llowed_availability_zones\x18\x03 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x1e\x44\x65scribeDatabaseOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"O\n\x1f\x44\x65scribeDatabaseOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xdd\x01\n\x1d\x44\x65scribeDatabaseOptionsResult\x12\x36\n\rstorage_units\x18\x01 \x03(\x0b\x32\x1f.Ydb.Cms.StorageUnitDescription\x12@\n\x12\x61vailability_zones\x18\x02 \x03(\x0b\x32$.Ydb.Cms.AvailabilityZoneDescription\x12\x42\n\x13\x63omputational_units\x18\x03 \x03(\x0b\x32%.Ydb.Cms.ComputationalUnitDescriptionBO\n\x12tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_GETDATABASESTATUSRESULT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='Ydb.Cms.GetDatabaseStatusResult.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_RESOURCES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIGURING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2238,
  serialized_end=2349,
)
_sym_db.RegisterEnumDescriptor(_GETDATABASESTATUSRESULT_STATE)


_STORAGEUNITS = _descriptor.Descriptor(
  name='StorageUnits',
  full_name='Ydb.Cms.StorageUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.StorageUnits.unit_kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Cms.StorageUnits.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=109,
)


_COMPUTATIONALUNITS = _descriptor.Descriptor(
  name='ComputationalUnits',
  full_name='Ydb.Cms.ComputationalUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.ComputationalUnits.unit_kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_zone', full_name='Ydb.Cms.ComputationalUnits.availability_zone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Cms.ComputationalUnits.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=192,
)


_ALLOCATEDCOMPUTATIONALUNIT = _descriptor.Descriptor(
  name='AllocatedComputationalUnit',
  full_name='Ydb.Cms.AllocatedComputationalUnit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Cms.AllocatedComputationalUnit.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Cms.AllocatedComputationalUnit.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.AllocatedComputationalUnit.unit_kind', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=269,
)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='Ydb.Cms.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_units', full_name='Ydb.Cms.Resources.storage_units', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units', full_name='Ydb.Cms.Resources.computational_units', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=386,
)


_SERVERLESSRESOURCES = _descriptor.Descriptor(
  name='ServerlessResources',
  full_name='Ydb.Cms.ServerlessResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shared_database_path', full_name='Ydb.Cms.ServerlessResources.shared_database_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=439,
)


_DATABASEOPTIONS = _descriptor.Descriptor(
  name='DatabaseOptions',
  full_name='Ydb.Cms.DatabaseOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable_tx_service', full_name='Ydb.Cms.DatabaseOptions.disable_tx_service', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_external_subdomain', full_name='Ydb.Cms.DatabaseOptions.disable_external_subdomain', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_resolution', full_name='Ydb.Cms.DatabaseOptions.plan_resolution', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=547,
)


_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET = _descriptor.Descriptor(
  name='LeakyBucket',
  full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_size', full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket.bucket_size', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_seconds', full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket.bucket_seconds', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=706,
)

_SCHEMAOPERATIONQUOTAS = _descriptor.Descriptor(
  name='SchemaOperationQuotas',
  full_name='Ydb.Cms.SchemaOperationQuotas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='leaky_bucket_quotas', full_name='Ydb.Cms.SchemaOperationQuotas.leaky_bucket_quotas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=706,
)


_DATABASEQUOTAS = _descriptor.Descriptor(
  name='DatabaseQuotas',
  full_name='Ydb.Cms.DatabaseQuotas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_size_hard_quota', full_name='Ydb.Cms.DatabaseQuotas.data_size_hard_quota', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size_soft_quota', full_name='Ydb.Cms.DatabaseQuotas.data_size_soft_quota', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream_shards_quota', full_name='Ydb.Cms.DatabaseQuotas.data_stream_shards_quota', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream_reserved_storage_quota', full_name='Ydb.Cms.DatabaseQuotas.data_stream_reserved_storage_quota', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_min_run_internal_seconds', full_name='Ydb.Cms.DatabaseQuotas.ttl_min_run_internal_seconds', index=4,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=901,
)


_CREATEDATABASEREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1453,
)

_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='Ydb.Cms.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.CreateDatabaseRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.CreateDatabaseRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='Ydb.Cms.CreateDatabaseRequest.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_resources', full_name='Ydb.Cms.CreateDatabaseRequest.shared_resources', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_resources', full_name='Ydb.Cms.CreateDatabaseRequest.serverless_resources', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='Ydb.Cms.CreateDatabaseRequest.options', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Cms.CreateDatabaseRequest.attributes', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.CreateDatabaseRequest.schema_operation_quotas', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='Ydb.Cms.CreateDatabaseRequest.idempotency_key', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.CreateDatabaseRequest.database_quotas', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDATABASEREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resources_kind', full_name='Ydb.Cms.CreateDatabaseRequest.resources_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=904,
  serialized_end=1471,
)


_CREATEDATABASERESPONSE = _descriptor.Descriptor(
  name='CreateDatabaseResponse',
  full_name='Ydb.Cms.CreateDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.CreateDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1543,
)


_GETDATABASESTATUSREQUEST = _descriptor.Descriptor(
  name='GetDatabaseStatusRequest',
  full_name='Ydb.Cms.GetDatabaseStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.GetDatabaseStatusRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.GetDatabaseStatusRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1545,
  serialized_end=1644,
)


_GETDATABASESTATUSRESPONSE = _descriptor.Descriptor(
  name='GetDatabaseStatusResponse',
  full_name='Ydb.Cms.GetDatabaseStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.GetDatabaseStatusResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1719,
)


_GETDATABASESTATUSRESULT = _descriptor.Descriptor(
  name='GetDatabaseStatusResult',
  full_name='Ydb.Cms.GetDatabaseStatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.GetDatabaseStatusResult.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Cms.GetDatabaseStatusResult.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.required_resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_shared_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.required_shared_resources', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.serverless_resources', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocated_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.allocated_resources', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registered_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.registered_resources', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='Ydb.Cms.GetDatabaseStatusResult.generation', index=7,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.GetDatabaseStatusResult.schema_operation_quotas', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.GetDatabaseStatusResult.database_quotas', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETDATABASESTATUSRESULT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resources_kind', full_name='Ydb.Cms.GetDatabaseStatusResult.resources_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1722,
  serialized_end=2367,
)


_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AlterAttributesEntry',
  full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3049,
  serialized_end=3103,
)

_ALTERDATABASEREQUEST = _descriptor.Descriptor(
  name='AlterDatabaseRequest',
  full_name='Ydb.Cms.AlterDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.AlterDatabaseRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_add', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_remove', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_remove', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_units_to_add', full_name='Ydb.Cms.AlterDatabaseRequest.storage_units_to_add', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_register', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_register', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_deregister', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_deregister', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.AlterDatabaseRequest.operation_params', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='Ydb.Cms.AlterDatabaseRequest.generation', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.AlterDatabaseRequest.schema_operation_quotas', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='Ydb.Cms.AlterDatabaseRequest.idempotency_key', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.AlterDatabaseRequest.database_quotas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_attributes', full_name='Ydb.Cms.AlterDatabaseRequest.alter_attributes', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=3103,
)


_ALTERDATABASERESPONSE = _descriptor.Descriptor(
  name='AlterDatabaseResponse',
  full_name='Ydb.Cms.AlterDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.AlterDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3105,
  serialized_end=3174,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='Ydb.Cms.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.ListDatabasesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3176,
  serialized_end=3257,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='Ydb.Cms.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.ListDatabasesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3259,
  serialized_end=3328,
)


_LISTDATABASESRESULT = _descriptor.Descriptor(
  name='ListDatabasesResult',
  full_name='Ydb.Cms.ListDatabasesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paths', full_name='Ydb.Cms.ListDatabasesResult.paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3330,
  serialized_end=3366,
)


_REMOVEDATABASEREQUEST = _descriptor.Descriptor(
  name='RemoveDatabaseRequest',
  full_name='Ydb.Cms.RemoveDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.RemoveDatabaseRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.RemoveDatabaseRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3464,
)


_REMOVEDATABASERESPONSE = _descriptor.Descriptor(
  name='RemoveDatabaseResponse',
  full_name='Ydb.Cms.RemoveDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.RemoveDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3466,
  serialized_end=3536,
)


_STORAGEUNITDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_STORAGEUNITDESCRIPTION = _descriptor.Descriptor(
  name='StorageUnitDescription',
  full_name='Ydb.Cms.StorageUnitDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='Ydb.Cms.StorageUnitDescription.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.StorageUnitDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STORAGEUNITDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3539,
  serialized_end=3685,
)


_AVAILABILITYZONEDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_AVAILABILITYZONEDESCRIPTION = _descriptor.Descriptor(
  name='AvailabilityZoneDescription',
  full_name='Ydb.Cms.AvailabilityZoneDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Cms.AvailabilityZoneDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.AvailabilityZoneDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AVAILABILITYZONEDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3688,
  serialized_end=3844,
)


_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_COMPUTATIONALUNITDESCRIPTION = _descriptor.Descriptor(
  name='ComputationalUnitDescription',
  full_name='Ydb.Cms.ComputationalUnitDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='Ydb.Cms.ComputationalUnitDescription.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.ComputationalUnitDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_availability_zones', full_name='Ydb.Cms.ComputationalUnitDescription.allowed_availability_zones', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3847,
  serialized_end=4041,
)


_DESCRIBEDATABASEOPTIONSREQUEST = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsRequest',
  full_name='Ydb.Cms.DescribeDatabaseOptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.DescribeDatabaseOptionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4043,
  serialized_end=4134,
)


_DESCRIBEDATABASEOPTIONSRESPONSE = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsResponse',
  full_name='Ydb.Cms.DescribeDatabaseOptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.DescribeDatabaseOptionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4136,
  serialized_end=4215,
)


_DESCRIBEDATABASEOPTIONSRESULT = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsResult',
  full_name='Ydb.Cms.DescribeDatabaseOptionsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_units', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.storage_units', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_zones', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.availability_zones', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.computational_units', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4218,
  serialized_end=4439,
)

_RESOURCES.fields_by_name['storage_units'].message_type = _STORAGEUNITS
_RESOURCES.fields_by_name['computational_units'].message_type = _COMPUTATIONALUNITS
_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET.containing_type = _SCHEMAOPERATIONQUOTAS
_SCHEMAOPERATIONQUOTAS.fields_by_name['leaky_bucket_quotas'].message_type = _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET
_CREATEDATABASEREQUEST_ATTRIBUTESENTRY.containing_type = _CREATEDATABASEREQUEST
_CREATEDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEDATABASEREQUEST.fields_by_name['resources'].message_type = _RESOURCES
_CREATEDATABASEREQUEST.fields_by_name['shared_resources'].message_type = _RESOURCES
_CREATEDATABASEREQUEST.fields_by_name['serverless_resources'].message_type = _SERVERLESSRESOURCES
_CREATEDATABASEREQUEST.fields_by_name['options'].message_type = _DATABASEOPTIONS
_CREATEDATABASEREQUEST.fields_by_name['attributes'].message_type = _CREATEDATABASEREQUEST_ATTRIBUTESENTRY
_CREATEDATABASEREQUEST.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_CREATEDATABASEREQUEST.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['resources'])
_CREATEDATABASEREQUEST.fields_by_name['resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['shared_resources'])
_CREATEDATABASEREQUEST.fields_by_name['shared_resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['serverless_resources'])
_CREATEDATABASEREQUEST.fields_by_name['serverless_resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETDATABASESTATUSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETDATABASESTATUSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETDATABASESTATUSRESULT.fields_by_name['state'].enum_type = _GETDATABASESTATUSRESULT_STATE
_GETDATABASESTATUSRESULT.fields_by_name['required_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'].message_type = _SERVERLESSRESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['allocated_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['registered_resources'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_GETDATABASESTATUSRESULT.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_GETDATABASESTATUSRESULT.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_GETDATABASESTATUSRESULT_STATE.containing_type = _GETDATABASESTATUSRESULT
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['required_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['required_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY.containing_type = _ALTERDATABASEREQUEST
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_add'].message_type = _COMPUTATIONALUNITS
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_remove'].message_type = _COMPUTATIONALUNITS
_ALTERDATABASEREQUEST.fields_by_name['storage_units_to_add'].message_type = _STORAGEUNITS
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_register'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_deregister'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_ALTERDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERDATABASEREQUEST.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_ALTERDATABASEREQUEST.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_ALTERDATABASEREQUEST.fields_by_name['alter_attributes'].message_type = _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY
_ALTERDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTDATABASESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTDATABASESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_REMOVEDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REMOVEDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_STORAGEUNITDESCRIPTION_LABELSENTRY.containing_type = _STORAGEUNITDESCRIPTION
_STORAGEUNITDESCRIPTION.fields_by_name['labels'].message_type = _STORAGEUNITDESCRIPTION_LABELSENTRY
_AVAILABILITYZONEDESCRIPTION_LABELSENTRY.containing_type = _AVAILABILITYZONEDESCRIPTION
_AVAILABILITYZONEDESCRIPTION.fields_by_name['labels'].message_type = _AVAILABILITYZONEDESCRIPTION_LABELSENTRY
_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY.containing_type = _COMPUTATIONALUNITDESCRIPTION
_COMPUTATIONALUNITDESCRIPTION.fields_by_name['labels'].message_type = _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY
_DESCRIBEDATABASEOPTIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEDATABASEOPTIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['storage_units'].message_type = _STORAGEUNITDESCRIPTION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['availability_zones'].message_type = _AVAILABILITYZONEDESCRIPTION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['computational_units'].message_type = _COMPUTATIONALUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['StorageUnits'] = _STORAGEUNITS
DESCRIPTOR.message_types_by_name['ComputationalUnits'] = _COMPUTATIONALUNITS
DESCRIPTOR.message_types_by_name['AllocatedComputationalUnit'] = _ALLOCATEDCOMPUTATIONALUNIT
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['ServerlessResources'] = _SERVERLESSRESOURCES
DESCRIPTOR.message_types_by_name['DatabaseOptions'] = _DATABASEOPTIONS
DESCRIPTOR.message_types_by_name['SchemaOperationQuotas'] = _SCHEMAOPERATIONQUOTAS
DESCRIPTOR.message_types_by_name['DatabaseQuotas'] = _DATABASEQUOTAS
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseResponse'] = _CREATEDATABASERESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseStatusRequest'] = _GETDATABASESTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetDatabaseStatusResponse'] = _GETDATABASESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseStatusResult'] = _GETDATABASESTATUSRESULT
DESCRIPTOR.message_types_by_name['AlterDatabaseRequest'] = _ALTERDATABASEREQUEST
DESCRIPTOR.message_types_by_name['AlterDatabaseResponse'] = _ALTERDATABASERESPONSE
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['ListDatabasesResult'] = _LISTDATABASESRESULT
DESCRIPTOR.message_types_by_name['RemoveDatabaseRequest'] = _REMOVEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['RemoveDatabaseResponse'] = _REMOVEDATABASERESPONSE
DESCRIPTOR.message_types_by_name['StorageUnitDescription'] = _STORAGEUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['AvailabilityZoneDescription'] = _AVAILABILITYZONEDESCRIPTION
DESCRIPTOR.message_types_by_name['ComputationalUnitDescription'] = _COMPUTATIONALUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsRequest'] = _DESCRIBEDATABASEOPTIONSREQUEST
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsResponse'] = _DESCRIBEDATABASEOPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsResult'] = _DESCRIBEDATABASEOPTIONSRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StorageUnits = _reflection.GeneratedProtocolMessageType('StorageUnits', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEUNITS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnits)
  })
_sym_db.RegisterMessage(StorageUnits)

ComputationalUnits = _reflection.GeneratedProtocolMessageType('ComputationalUnits', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTATIONALUNITS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnits)
  })
_sym_db.RegisterMessage(ComputationalUnits)

AllocatedComputationalUnit = _reflection.GeneratedProtocolMessageType('AllocatedComputationalUnit', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATEDCOMPUTATIONALUNIT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AllocatedComputationalUnit)
  })
_sym_db.RegisterMessage(AllocatedComputationalUnit)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.Resources)
  })
_sym_db.RegisterMessage(Resources)

ServerlessResources = _reflection.GeneratedProtocolMessageType('ServerlessResources', (_message.Message,), {
  'DESCRIPTOR' : _SERVERLESSRESOURCES,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ServerlessResources)
  })
_sym_db.RegisterMessage(ServerlessResources)

DatabaseOptions = _reflection.GeneratedProtocolMessageType('DatabaseOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEOPTIONS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DatabaseOptions)
  })
_sym_db.RegisterMessage(DatabaseOptions)

SchemaOperationQuotas = _reflection.GeneratedProtocolMessageType('SchemaOperationQuotas', (_message.Message,), {

  'LeakyBucket' : _reflection.GeneratedProtocolMessageType('LeakyBucket', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.SchemaOperationQuotas.LeakyBucket)
    })
  ,
  'DESCRIPTOR' : _SCHEMAOPERATIONQUOTAS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.SchemaOperationQuotas)
  })
_sym_db.RegisterMessage(SchemaOperationQuotas)
_sym_db.RegisterMessage(SchemaOperationQuotas.LeakyBucket)

DatabaseQuotas = _reflection.GeneratedProtocolMessageType('DatabaseQuotas', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEQUOTAS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DatabaseQuotas)
  })
_sym_db.RegisterMessage(DatabaseQuotas)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATABASEREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)
_sym_db.RegisterMessage(CreateDatabaseRequest.AttributesEntry)

CreateDatabaseResponse = _reflection.GeneratedProtocolMessageType('CreateDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseResponse)
  })
_sym_db.RegisterMessage(CreateDatabaseResponse)

GetDatabaseStatusRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusRequest)
  })
_sym_db.RegisterMessage(GetDatabaseStatusRequest)

GetDatabaseStatusResponse = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusResponse)
  })
_sym_db.RegisterMessage(GetDatabaseStatusResponse)

GetDatabaseStatusResult = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusResult', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusResult)
  })
_sym_db.RegisterMessage(GetDatabaseStatusResult)

AlterDatabaseRequest = _reflection.GeneratedProtocolMessageType('AlterDatabaseRequest', (_message.Message,), {

  'AlterAttributesEntry' : _reflection.GeneratedProtocolMessageType('AlterAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _ALTERDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseRequest)
  })
_sym_db.RegisterMessage(AlterDatabaseRequest)
_sym_db.RegisterMessage(AlterDatabaseRequest.AlterAttributesEntry)

AlterDatabaseResponse = _reflection.GeneratedProtocolMessageType('AlterDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseResponse)
  })
_sym_db.RegisterMessage(AlterDatabaseResponse)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

ListDatabasesResult = _reflection.GeneratedProtocolMessageType('ListDatabasesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesResult)
  })
_sym_db.RegisterMessage(ListDatabasesResult)

RemoveDatabaseRequest = _reflection.GeneratedProtocolMessageType('RemoveDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.RemoveDatabaseRequest)
  })
_sym_db.RegisterMessage(RemoveDatabaseRequest)

RemoveDatabaseResponse = _reflection.GeneratedProtocolMessageType('RemoveDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.RemoveDatabaseResponse)
  })
_sym_db.RegisterMessage(RemoveDatabaseResponse)

StorageUnitDescription = _reflection.GeneratedProtocolMessageType('StorageUnitDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STORAGEUNITDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnitDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _STORAGEUNITDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnitDescription)
  })
_sym_db.RegisterMessage(StorageUnitDescription)
_sym_db.RegisterMessage(StorageUnitDescription.LabelsEntry)

AvailabilityZoneDescription = _reflection.GeneratedProtocolMessageType('AvailabilityZoneDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _AVAILABILITYZONEDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.AvailabilityZoneDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _AVAILABILITYZONEDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AvailabilityZoneDescription)
  })
_sym_db.RegisterMessage(AvailabilityZoneDescription)
_sym_db.RegisterMessage(AvailabilityZoneDescription.LabelsEntry)

ComputationalUnitDescription = _reflection.GeneratedProtocolMessageType('ComputationalUnitDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnitDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _COMPUTATIONALUNITDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnitDescription)
  })
_sym_db.RegisterMessage(ComputationalUnitDescription)
_sym_db.RegisterMessage(ComputationalUnitDescription.LabelsEntry)

DescribeDatabaseOptionsRequest = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsRequest)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsRequest)

DescribeDatabaseOptionsResponse = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsResponse)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsResponse)

DescribeDatabaseOptionsResult = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsResult)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsResult)


DESCRIPTOR._options = None
_CREATEDATABASEREQUEST_ATTRIBUTESENTRY._options = None
_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._options = None
_STORAGEUNITDESCRIPTION_LABELSENTRY._options = None
_AVAILABILITYZONEDESCRIPTION_LABELSENTRY._options = None
_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
