# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/protos/ydb_keyvalue.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/protos/ydb_keyvalue.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64raft/protos/ydb_keyvalue.proto\x12\x0cYdb.KeyValue\x1a\x1aprotos/ydb_operation.proto\"\xf0\x01\n\x12StorageChannelInfo\x12\x17\n\x0fstorage_channel\x18\x01 \x01(\r\x12@\n\x0bstatus_flag\x18\x02 \x01(\x0e\x32+.Ydb.KeyValue.StorageChannelInfo.StatusFlag\"\x7f\n\nStatusFlag\x12\x1b\n\x17STATUS_FLAG_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_FLAG_GREEN\x10\n\x12\x1b\n\x17STATUS_FLAG_YELLOW_STOP\x10\x14\x12 \n\x1cSTATUS_FLAG_ORANGE_OUT_SPACE\x10\x1e\"b\n\nPriorities\"T\n\x08Priority\x12\x18\n\x14PRIORITY_UNSPECIFIED\x10\x00\x12\x15\n\x11PRIORITY_REALTIME\x10\x01\x12\x17\n\x13PRIORITY_BACKGROUND\x10\x02\"k\n\rStorageConfig\x12:\n\x07\x63hannel\x18\x01 \x03(\x0b\x32).Ydb.KeyValue.StorageConfig.ChannelConfig\x1a\x1e\n\rChannelConfig\x12\r\n\x05media\x18\x01 \x01(\t\"\x98\x01\n\x08KeyRange\x12\x1c\n\x12\x66rom_key_inclusive\x18\x01 \x01(\tH\x00\x12\x1c\n\x12\x66rom_key_exclusive\x18\x02 \x01(\tH\x00\x12\x1a\n\x10to_key_inclusive\x18\x03 \x01(\tH\x01\x12\x1a\n\x10to_key_exclusive\x18\x04 \x01(\tH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"s\n\x12\x41\x63quireLockRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\"C\n\x13\x41\x63quireLockResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"=\n\x11\x41\x63quireLockResult\x12\x17\n\x0flock_generation\x18\x01 \x01(\x04\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\xac\t\n\x19\x45xecuteTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x41\n\x08\x63ommands\x18\x05 \x03(\x0b\x32/.Ydb.KeyValue.ExecuteTransactionRequest.Command\x1a\xba\x07\n\x07\x43ommand\x12S\n\x0c\x64\x65lete_range\x18\x01 \x01(\x0b\x32;.Ydb.KeyValue.ExecuteTransactionRequest.Command.DeleteRangeH\x00\x12H\n\x06rename\x18\x02 \x01(\x0b\x32\x36.Ydb.KeyValue.ExecuteTransactionRequest.Command.RenameH\x00\x12O\n\ncopy_range\x18\x03 \x01(\x0b\x32\x39.Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRangeH\x00\x12H\n\x06\x63oncat\x18\x04 \x01(\x0b\x32\x36.Ydb.KeyValue.ExecuteTransactionRequest.Command.ConcatH\x00\x12\x46\n\x05write\x18\x05 \x01(\x0b\x32\x35.Ydb.KeyValue.ExecuteTransactionRequest.Command.WriteH\x00\x1a*\n\x06Rename\x12\x0f\n\x07old_key\x18\x01 \x01(\t\x12\x0f\n\x07new_key\x18\x02 \x01(\t\x1a\x45\n\x06\x43oncat\x12\x12\n\ninput_keys\x18\x01 \x03(\t\x12\x12\n\noutput_key\x18\x02 \x01(\t\x12\x13\n\x0bkeep_inputs\x18\x03 \x01(\x08\x1a\x63\n\tCopyRange\x12%\n\x05range\x18\x01 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x18\n\x10prefix_to_remove\x18\x02 \x01(\t\x12\x15\n\rprefix_to_add\x18\x03 \x01(\t\x1a\x94\x02\n\x05Write\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x17\n\x0fstorage_channel\x18\x03 \x01(\r\x12\x33\n\x08priority\x18\x04 \x01(\x0e\x32!.Ydb.KeyValue.Priorities.Priority\x12L\n\x06tactic\x18\x05 \x01(\x0e\x32<.Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.Tactic\"S\n\x06Tactic\x12\x16\n\x12TACTIC_UNSPECIFIED\x10\x00\x12\x19\n\x15TACTIC_MAX_THROUGHPUT\x10\x01\x12\x16\n\x12TACTIC_MIN_LATENCY\x10\x02\x1a\x34\n\x0b\x44\x65leteRange\x12%\n\x05range\x18\x01 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRangeB\x08\n\x06\x61\x63tionB\x12\n\x10_lock_generation\"J\n\x1a\x45xecuteTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"k\n\x18\x45xecuteTransactionResult\x12>\n\x14storage_channel_info\x18\x01 \x03(\x0b\x32 .Ydb.KeyValue.StorageChannelInfo\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\x93\x02\n\x0bReadRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x04\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x13\n\x0blimit_bytes\x18\x08 \x01(\x04\x12\x33\n\x08priority\x18\t \x01(\x0e\x32!.Ydb.KeyValue.Priorities.PriorityB\x12\n\x10_lock_generation\"<\n\x0cReadResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x89\x01\n\nReadResult\x12\x15\n\rrequested_key\x18\x01 \x01(\t\x12\x18\n\x10requested_offset\x18\x02 \x01(\x04\x12\x16\n\x0erequested_size\x18\x03 \x01(\x04\x12\r\n\x05value\x18\x04 \x01(\x0c\x12\x12\n\nis_overrun\x18\x05 \x01(\x08\x12\x0f\n\x07node_id\x18\x06 \x01(\r\"\x94\x02\n\x10ReadRangeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12%\n\x05range\x18\x05 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x13\n\x0blimit_bytes\x18\x06 \x01(\x04\x12\x33\n\x08priority\x18\x07 \x01(\x0e\x32!.Ydb.KeyValue.Priorities.PriorityB\x12\n\x10_lock_generation\"A\n\x11ReadRangeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd1\x01\n\x0fReadRangeResult\x12\x38\n\x04pair\x18\x01 \x03(\x0b\x32*.Ydb.KeyValue.ReadRangeResult.KeyValuePair\x12\x12\n\nis_overrun\x18\x02 \x01(\x08\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x1a_\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63reation_unix_time\x18\x04 \x01(\x04\x12\x17\n\x0fstorage_channel\x18\x05 \x01(\r\"\xdf\x01\n\x10ListRangeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12%\n\x05range\x18\x05 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x13\n\x0blimit_bytes\x18\x06 \x01(\x04\x42\x12\n\x10_lock_generation\"A\n\x11ListRangeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xcb\x01\n\x0fListRangeResult\x12\x32\n\x03key\x18\x01 \x03(\x0b\x32%.Ydb.KeyValue.ListRangeResult.KeyInfo\x12\x12\n\nis_overrun\x18\x02 \x01(\x08\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x1a_\n\x07KeyInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_size\x18\x02 \x01(\r\x12\x1a\n\x12\x63reation_unix_time\x18\x03 \x01(\x04\x12\x17\n\x0fstorage_channel\x18\x04 \x01(\r\"\xca\x01\n\x1eGetStorageChannelStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x17\n\x0fstorage_channel\x18\x05 \x03(\rB\x12\n\x10_lock_generation\"O\n\x1fGetStorageChannelStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"p\n\x1dGetStorageChannelStatusResult\x12>\n\x14storage_channel_info\x18\x01 \x03(\x0b\x32 .Ydb.KeyValue.StorageChannelInfo\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\xac\x01\n\x13\x43reateVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x0fpartition_count\x18\x04 \x01(\r\x12\x33\n\x0estorage_config\x18\x05 \x01(\x0b\x32\x1b.Ydb.KeyValue.StorageConfig\"D\n\x14\x43reateVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43reateVolumeResult\"\\\n\x11\x44ropVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"B\n\x12\x44ropVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x44ropVolumeResult\"\xb1\x01\n\x12\x41lterVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1d\n\x15\x61lter_partition_count\x18\x03 \x01(\r\x12\x33\n\x0estorage_config\x18\x04 \x01(\x0b\x32\x1b.Ydb.KeyValue.StorageConfig\"C\n\x13\x41lterVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x41lterVolumeResult\"`\n\x15\x44\x65scribeVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"F\n\x16\x44\x65scribeVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"=\n\x14\x44\x65scribeVolumeResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x17\n\x0fpartition_count\x18\x02 \x01(\x04\"v\n\x1aListLocalPartitionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0f\n\x07node_id\x18\x03 \x01(\x04\"K\n\x1bListLocalPartitionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x19ListLocalPartitionsResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x04\x12\x15\n\rpartition_ids\x18\x03 \x03(\x04\x42h\n tech.ydb.proto.draft.keyvalue.v1ZAgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_KeyValue\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_keyvalue_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n tech.ydb.proto.draft.keyvalue.v1ZAgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_KeyValue\370\001\001'
  _globals['_STORAGECHANNELINFO']._serialized_start=78
  _globals['_STORAGECHANNELINFO']._serialized_end=318
  _globals['_STORAGECHANNELINFO_STATUSFLAG']._serialized_start=191
  _globals['_STORAGECHANNELINFO_STATUSFLAG']._serialized_end=318
  _globals['_PRIORITIES']._serialized_start=320
  _globals['_PRIORITIES']._serialized_end=418
  _globals['_PRIORITIES_PRIORITY']._serialized_start=334
  _globals['_PRIORITIES_PRIORITY']._serialized_end=418
  _globals['_STORAGECONFIG']._serialized_start=420
  _globals['_STORAGECONFIG']._serialized_end=527
  _globals['_STORAGECONFIG_CHANNELCONFIG']._serialized_start=497
  _globals['_STORAGECONFIG_CHANNELCONFIG']._serialized_end=527
  _globals['_KEYRANGE']._serialized_start=530
  _globals['_KEYRANGE']._serialized_end=682
  _globals['_ACQUIRELOCKREQUEST']._serialized_start=684
  _globals['_ACQUIRELOCKREQUEST']._serialized_end=799
  _globals['_ACQUIRELOCKRESPONSE']._serialized_start=801
  _globals['_ACQUIRELOCKRESPONSE']._serialized_end=868
  _globals['_ACQUIRELOCKRESULT']._serialized_start=870
  _globals['_ACQUIRELOCKRESULT']._serialized_end=931
  _globals['_EXECUTETRANSACTIONREQUEST']._serialized_start=934
  _globals['_EXECUTETRANSACTIONREQUEST']._serialized_end=2130
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND']._serialized_start=1156
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND']._serialized_end=2110
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_RENAME']._serialized_start=1553
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_RENAME']._serialized_end=1595
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT']._serialized_start=1597
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT']._serialized_end=1666
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE']._serialized_start=1668
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE']._serialized_end=1767
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE']._serialized_start=1770
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE']._serialized_end=2046
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC']._serialized_start=1963
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC']._serialized_end=2046
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE']._serialized_start=2048
  _globals['_EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE']._serialized_end=2100
  _globals['_EXECUTETRANSACTIONRESPONSE']._serialized_start=2132
  _globals['_EXECUTETRANSACTIONRESPONSE']._serialized_end=2206
  _globals['_EXECUTETRANSACTIONRESULT']._serialized_start=2208
  _globals['_EXECUTETRANSACTIONRESULT']._serialized_end=2315
  _globals['_READREQUEST']._serialized_start=2318
  _globals['_READREQUEST']._serialized_end=2593
  _globals['_READRESPONSE']._serialized_start=2595
  _globals['_READRESPONSE']._serialized_end=2655
  _globals['_READRESULT']._serialized_start=2658
  _globals['_READRESULT']._serialized_end=2795
  _globals['_READRANGEREQUEST']._serialized_start=2798
  _globals['_READRANGEREQUEST']._serialized_end=3074
  _globals['_READRANGERESPONSE']._serialized_start=3076
  _globals['_READRANGERESPONSE']._serialized_end=3141
  _globals['_READRANGERESULT']._serialized_start=3144
  _globals['_READRANGERESULT']._serialized_end=3353
  _globals['_READRANGERESULT_KEYVALUEPAIR']._serialized_start=3258
  _globals['_READRANGERESULT_KEYVALUEPAIR']._serialized_end=3353
  _globals['_LISTRANGEREQUEST']._serialized_start=3356
  _globals['_LISTRANGEREQUEST']._serialized_end=3579
  _globals['_LISTRANGERESPONSE']._serialized_start=3581
  _globals['_LISTRANGERESPONSE']._serialized_end=3646
  _globals['_LISTRANGERESULT']._serialized_start=3649
  _globals['_LISTRANGERESULT']._serialized_end=3852
  _globals['_LISTRANGERESULT_KEYINFO']._serialized_start=3757
  _globals['_LISTRANGERESULT_KEYINFO']._serialized_end=3852
  _globals['_GETSTORAGECHANNELSTATUSREQUEST']._serialized_start=3855
  _globals['_GETSTORAGECHANNELSTATUSREQUEST']._serialized_end=4057
  _globals['_GETSTORAGECHANNELSTATUSRESPONSE']._serialized_start=4059
  _globals['_GETSTORAGECHANNELSTATUSRESPONSE']._serialized_end=4138
  _globals['_GETSTORAGECHANNELSTATUSRESULT']._serialized_start=4140
  _globals['_GETSTORAGECHANNELSTATUSRESULT']._serialized_end=4252
  _globals['_CREATEVOLUMEREQUEST']._serialized_start=4255
  _globals['_CREATEVOLUMEREQUEST']._serialized_end=4427
  _globals['_CREATEVOLUMERESPONSE']._serialized_start=4429
  _globals['_CREATEVOLUMERESPONSE']._serialized_end=4497
  _globals['_CREATEVOLUMERESULT']._serialized_start=4499
  _globals['_CREATEVOLUMERESULT']._serialized_end=4519
  _globals['_DROPVOLUMEREQUEST']._serialized_start=4521
  _globals['_DROPVOLUMEREQUEST']._serialized_end=4613
  _globals['_DROPVOLUMERESPONSE']._serialized_start=4615
  _globals['_DROPVOLUMERESPONSE']._serialized_end=4681
  _globals['_DROPVOLUMERESULT']._serialized_start=4683
  _globals['_DROPVOLUMERESULT']._serialized_end=4701
  _globals['_ALTERVOLUMEREQUEST']._serialized_start=4704
  _globals['_ALTERVOLUMEREQUEST']._serialized_end=4881
  _globals['_ALTERVOLUMERESPONSE']._serialized_start=4883
  _globals['_ALTERVOLUMERESPONSE']._serialized_end=4950
  _globals['_ALTERVOLUMERESULT']._serialized_start=4952
  _globals['_ALTERVOLUMERESULT']._serialized_end=4971
  _globals['_DESCRIBEVOLUMEREQUEST']._serialized_start=4973
  _globals['_DESCRIBEVOLUMEREQUEST']._serialized_end=5069
  _globals['_DESCRIBEVOLUMERESPONSE']._serialized_start=5071
  _globals['_DESCRIBEVOLUMERESPONSE']._serialized_end=5141
  _globals['_DESCRIBEVOLUMERESULT']._serialized_start=5143
  _globals['_DESCRIBEVOLUMERESULT']._serialized_end=5204
  _globals['_LISTLOCALPARTITIONSREQUEST']._serialized_start=5206
  _globals['_LISTLOCALPARTITIONSREQUEST']._serialized_end=5324
  _globals['_LISTLOCALPARTITIONSRESPONSE']._serialized_start=5326
  _globals['_LISTLOCALPARTITIONSRESPONSE']._serialized_end=5401
  _globals['_LISTLOCALPARTITIONSRESULT']._serialized_start=5403
  _globals['_LISTLOCALPARTITIONSRESULT']._serialized_end=5484
# @@protoc_insertion_point(module_scope)
