# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_topic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v4.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v4.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v4.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v4.protos.annotations import sensitive_pb2 as protos_dot_annotations_dot_sensitive__pb2
from ydb._grpc.v4.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_topic.proto\x12\tYdb.Topic\x1a\x1aprotos/ydb_operation.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\"protos/annotations/sensitive.proto\x1a#protos/annotations/validation.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x0fSupportedCodecs\x12$\n\x06\x63odecs\x18\x01 \x03(\x05\x42\x14\xb2\xe6*\n[1; 19999]\x9a\xe6*\x02\x18\x64\"*\n\x0cOffsetsRange\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\")\n\x12UpdateTokenRequest\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\xb8\xe6*\x01\"\x15\n\x13UpdateTokenResponse\"C\n\x17PartitionWithGeneration\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x12\n\ngeneration\x18\x02 \x01(\x03\"*\n\x0cMetadataItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x9e\x14\n\x12StreamWriteMessage\x1a\xe5\x01\n\nFromClient\x12\x41\n\x0cinit_request\x18\x01 \x01(\x0b\x32).Ydb.Topic.StreamWriteMessage.InitRequestH\x00\x12\x43\n\rwrite_request\x18\x02 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.WriteRequestH\x00\x12=\n\x14update_token_request\x18\x03 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x42\x10\n\x0e\x63lient_message\x1a\xbf\x02\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x43\n\rinit_response\x18\x03 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.InitResponseH\x00\x12\x45\n\x0ewrite_response\x18\x04 \x01(\x0b\x32+.Ydb.Topic.StreamWriteMessage.WriteResponseH\x00\x12?\n\x15update_token_response\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x42\x10\n\x0eserver_message\x1a\xfe\x02\n\x0bInitRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x1c\n\x0bproducer_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x10\x12[\n\x12write_session_meta\x18\x03 \x03(\x0b\x32?.Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry\x12#\n\x10message_group_id\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x10H\x00\x12\x16\n\x0cpartition_id\x18\x05 \x01(\x03H\x00\x12G\n\x19partition_with_generation\x18\x07 \x01(\x0b\x32\".Ydb.Topic.PartitionWithGenerationH\x00\x12\x17\n\x0fget_last_seq_no\x18\x06 \x01(\x08\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cpartitioning\x1a\x83\x01\n\x0cInitResponse\x12\x13\n\x0blast_seq_no\x18\x01 \x01(\x03\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x04 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x1a\xe8\x03\n\x0cWriteRequest\x12H\n\x08messages\x18\x01 \x03(\x0b\x32\x36.Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData\x12\r\n\x05\x63odec\x18\x02 \x01(\x05\x12/\n\x02tx\x18\x03 \x01(\x0b\x32\x1e.Ydb.Topic.TransactionIdentityH\x00\x88\x01\x01\x1a\xc6\x02\n\x0bMessageData\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x04 \x01(\x03\x12#\n\x10message_group_id\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x10H\x00\x12\x16\n\x0cpartition_id\x18\x06 \x01(\x03H\x00\x12G\n\x19partition_with_generation\x18\x08 \x01(\x0b\x32\".Ydb.Topic.PartitionWithGenerationH\x00\x12\x38\n\x0emetadata_items\x18\x07 \x03(\x0b\x32\x17.Ydb.Topic.MetadataItemB\x07\x9a\xe6*\x03\x18\xe8\x07\x42\x0e\n\x0cpartitioningB\x05\n\x03_tx\x1a\xeb\x07\n\rWriteResponse\x12\x42\n\x04\x61\x63ks\x18\x01 \x03(\x0b\x32\x34.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck\x12\x14\n\x0cpartition_id\x18\x02 \x01(\x03\x12U\n\x10write_statistics\x18\x03 \x01(\x0b\x32;.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics\x1a\xf8\x03\n\x08WriteAck\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12O\n\x07written\x18\x02 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.WrittenH\x00\x12O\n\x07skipped\x18\x03 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.SkippedH\x00\x12Y\n\rwritten_in_tx\x18\x04 \x01(\x0b\x32@.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.WrittenInTxH\x00\x1a\x19\n\x07Written\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x1a\x9c\x01\n\x07Skipped\x12S\n\x06reason\x18\x01 \x01(\x0e\x32\x43.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason\"<\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x1a\n\x16REASON_ALREADY_WRITTEN\x10\x01\x1a\r\n\x0bWrittenInTxB\x16\n\x14message_write_status\x1a\xad\x02\n\x0fWriteStatistics\x12\x32\n\x0fpersisting_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13min_queue_wait_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13max_queue_wait_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x19partition_quota_wait_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15topic_quota_wait_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x9c#\n\x11StreamReadMessage\x1aT\n\x10PartitionSession\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x1a\xb1\x05\n\nFromClient\x12@\n\x0cinit_request\x18\x01 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.InitRequestH\x00\x12@\n\x0cread_request\x18\x02 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.ReadRequestH\x00\x12Q\n\x15\x63ommit_offset_request\x18\x03 \x01(\x0b\x32\x30.Ydb.Topic.StreamReadMessage.CommitOffsetRequestH\x00\x12\x66\n partition_session_status_request\x18\x04 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequestH\x00\x12=\n\x14update_token_request\x18\x05 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x12\x45\n\x0f\x64irect_read_ack\x18\x08 \x01(\x0b\x32*.Ydb.Topic.StreamReadMessage.DirectReadAckH\x00\x12\x66\n start_partition_session_response\x18\x06 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.StartPartitionSessionResponseH\x00\x12\x64\n\x1fstop_partition_session_response\x18\x07 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StopPartitionSessionResponseH\x00\x42\x10\n\x0e\x63lient_message\x1a\xf0\x06\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x42\n\rinit_response\x18\x03 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.InitResponseH\x00\x12\x42\n\rread_response\x18\x04 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.ReadResponseH\x00\x12S\n\x16\x63ommit_offset_response\x18\x05 \x01(\x0b\x32\x31.Ydb.Topic.StreamReadMessage.CommitOffsetResponseH\x00\x12h\n!partition_session_status_response\x18\x06 \x01(\x0b\x32;.Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponseH\x00\x12?\n\x15update_token_response\x18\x07 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x12\x64\n\x1fstart_partition_session_request\x18\x08 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StartPartitionSessionRequestH\x00\x12\x62\n\x1estop_partition_session_request\x18\t \x01(\x0b\x32\x38.Ydb.Topic.StreamReadMessage.StopPartitionSessionRequestH\x00\x12W\n\x18update_partition_session\x18\n \x01(\x0b\x32\x33.Ydb.Topic.StreamReadMessage.UpdatePartitionSessionH\x00\x12Q\n\x15\x65nd_partition_session\x18\x0b \x01(\x0b\x32\x30.Ydb.Topic.StreamReadMessage.EndPartitionSessionH\x00\x42\x10\n\x0eserver_message\x1a\xdc\x02\n\x0bInitRequest\x12X\n\x14topics_read_settings\x18\x01 \x03(\x0b\x32:.Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings\x12\x10\n\x08\x63onsumer\x18\x02 \x01(\t\x12\x13\n\x0breader_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64irect_read\x18\x04 \x01(\x08\x12!\n\x19\x61uto_partitioning_support\x18\x05 \x01(\x08\x1a\x93\x01\n\x11TopicReadSettings\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rpartition_ids\x18\x02 \x03(\x03\x12*\n\x07max_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\tread_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\"\n\x0cInitResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x1a!\n\x0bReadRequest\x12\x12\n\nbytes_size\x18\x01 \x01(\x03\x1a\x91\x06\n\x0cReadResponse\x12O\n\x0epartition_data\x18\x01 \x03(\x0b\x32\x37.Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData\x12\x12\n\nbytes_size\x18\x02 \x01(\x03\x1a\xda\x01\n\x0bMessageData\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0e\n\x06seq_no\x18\x02 \x01(\x03\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x06 \x01(\x03\x12!\n\x10message_group_id\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x10\x12/\n\x0emetadata_items\x18\x08 \x03(\x0b\x32\x17.Ydb.Topic.MetadataItem\x1a\xcd\x02\n\x05\x42\x61tch\x12K\n\x0cmessage_data\x18\x01 \x03(\x0b\x32\x35.Ydb.Topic.StreamReadMessage.ReadResponse.MessageData\x12\x1c\n\x0bproducer_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x10\x12\x61\n\x12write_session_meta\x18\x03 \x03(\x0b\x32\x45.Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry\x12\r\n\x05\x63odec\x18\x04 \x01(\x05\x12.\n\nwritten_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1ao\n\rPartitionData\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12@\n\x07\x62\x61tches\x18\x02 \x03(\x0b\x32/.Ydb.Topic.StreamReadMessage.ReadResponse.Batch\x1a\xd6\x01\n\x13\x43ommitOffsetRequest\x12^\n\x0e\x63ommit_offsets\x18\x01 \x03(\x0b\x32\x46.Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset\x1a_\n\x15PartitionCommitOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12(\n\x07offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x1a\xdc\x01\n\x14\x43ommitOffsetResponse\x12p\n\x1cpartitions_committed_offsets\x18\x01 \x03(\x0b\x32J.Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset\x1aR\n\x18PartitionCommittedOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x1a=\n\x1dPartitionSessionStatusRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x1a\xcb\x01\n\x1ePartitionSessionStatusResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x12=\n\x19write_time_high_watermark\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xf0\x01\n\x1cStartPartitionSessionRequest\x12H\n\x11partition_session\x18\x01 \x01(\x0b\x32-.Ydb.Topic.StreamReadMessage.PartitionSession\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x03 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x38\n\x12partition_location\x18\x04 \x01(\x0b\x32\x1c.Ydb.Topic.PartitionLocation\x1a\x95\x01\n\x1dStartPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x0bread_offset\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rcommit_offset\x18\x03 \x01(\x03H\x01\x88\x01\x01\x42\x0e\n\x0c_read_offsetB\x10\n\x0e_commit_offset\x1a\x84\x01\n\x1bStopPartitionSessionRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x10\n\x08graceful\x18\x02 \x01(\x08\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x12\x1b\n\x13last_direct_read_id\x18\x04 \x01(\x03\x1aN\n\x1cStopPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x10\n\x08graceful\x18\x02 \x01(\x08\x1ap\n\x16UpdatePartitionSession\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x38\n\x12partition_location\x18\x02 \x01(\x0b\x32\x1c.Ydb.Topic.PartitionLocation\x1a\x45\n\rDirectReadAck\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x64irect_read_id\x18\x02 \x01(\x03\x1ap\n\x13\x45ndPartitionSession\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x1e\n\x16\x61\x64jacent_partition_ids\x18\x02 \x03(\x03\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\"\x8b\r\n\x17StreamDirectReadMessage\x1a\xa8\x02\n\nFromClient\x12\x46\n\x0cinit_request\x18\x01 \x01(\x0b\x32..Ydb.Topic.StreamDirectReadMessage.InitRequestH\x00\x12\x80\x01\n+start_direct_read_partition_session_request\x18\x02 \x01(\x0b\x32I.Ydb.Topic.StreamDirectReadMessage.StartDirectReadPartitionSessionRequestH\x00\x12=\n\x14update_token_request\x18\x03 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x42\x10\n\x0e\x63lient_message\x1a\xca\x04\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12H\n\rinit_response\x18\x06 \x01(\x0b\x32/.Ydb.Topic.StreamDirectReadMessage.InitResponseH\x00\x12\x82\x01\n,start_direct_read_partition_session_response\x18\x07 \x01(\x0b\x32J.Ydb.Topic.StreamDirectReadMessage.StartDirectReadPartitionSessionResponseH\x00\x12o\n\"stop_direct_read_partition_session\x18\x03 \x01(\x0b\x32\x41.Ydb.Topic.StreamDirectReadMessage.StopDirectReadPartitionSessionH\x00\x12U\n\x14\x64irect_read_response\x18\x04 \x01(\x0b\x32\x35.Ydb.Topic.StreamDirectReadMessage.DirectReadResponseH\x00\x12?\n\x15update_token_response\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x42\x10\n\x0eserver_message\x1a\xb6\x01\n\x0bInitRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12^\n\x14topics_read_settings\x18\x02 \x03(\x0b\x32@.Ydb.Topic.StreamDirectReadMessage.InitRequest.TopicReadSettings\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x1a!\n\x11TopicReadSettings\x12\x0c\n\x04path\x18\x01 \x01(\t\x1a\x0e\n\x0cInitResponse\x1aw\n&StartDirectReadPartitionSessionRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x1b\n\x13last_direct_read_id\x18\x02 \x01(\x03\x12\x12\n\ngeneration\x18\x03 \x01(\x03\x1a[\n\'StartDirectReadPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x12\n\ngeneration\x18\x02 \x01(\x03\x1a\xa6\x01\n\x1eStopDirectReadPartitionSession\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1c\n\x14partition_session_id\x18\x03 \x01(\x03\x12\x12\n\ngeneration\x18\x04 \x01(\x03\x1a\xaf\x01\n\x12\x44irectReadResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x64irect_read_id\x18\x02 \x01(\x03\x12O\n\x0epartition_data\x18\x03 \x01(\x0b\x32\x37.Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData\x12\x12\n\nbytes_size\x18\x04 \x01(\x03\"2\n\x13TransactionIdentity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07session\x18\x02 \x01(\t\"\xc4\x03\n!UpdateOffsetsInTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12*\n\x02tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Topic.TransactionIdentity\x12I\n\x06topics\x18\x03 \x03(\x0b\x32\x39.Ydb.Topic.UpdateOffsetsInTransactionRequest.TopicOffsets\x12\x10\n\x08\x63onsumer\x18\x04 \x01(\t\x1a\xda\x01\n\x0cTopicOffsets\x12\x0c\n\x04path\x18\x01 \x01(\t\x12^\n\npartitions\x18\x02 \x03(\x0b\x32J.Ydb.Topic.UpdateOffsetsInTransactionRequest.TopicOffsets.PartitionOffsets\x1a\\\n\x10PartitionOffsets\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\"R\n\"UpdateOffsetsInTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\"\n UpdateOffsetsInTransactionResult\"\xaf\x01\n\x13\x43ommitOffsetRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x10\n\x08\x63onsumer\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x03\x12\x17\n\x0fread_session_id\x18\x06 \x01(\t\"D\n\x14\x43ommitOffsetResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ommitOffsetResult\"L\n\x13MultipleWindowsStat\x12\x12\n\nper_minute\x18\x01 \x01(\x03\x12\x10\n\x08per_hour\x18\x02 \x01(\x03\x12\x0f\n\x07per_day\x18\x03 \x01(\x03\"\xc3\x05\n\x08\x43onsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\timportant\x18\x02 \x01(\x08\x12-\n\tread_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x37\n\nattributes\x18\x06 \x03(\x0b\x32#.Ydb.Topic.Consumer.AttributesEntry\x12\x39\n\x0e\x63onsumer_stats\x18\x07 \x01(\x0b\x32!.Ydb.Topic.Consumer.ConsumerStats\x12;\n\x13\x61vailability_period\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x88\x01\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xae\x02\n\rConsumerStats\x12\x41\n\x1dmin_partitions_last_read_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x16max_committed_time_lag\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatB\x16\n\x14_availability_periodJ\x04\x08\x04\x10\x05\"\xd8\x03\n\rAlterConsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\rset_important\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x31\n\rset_read_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14set_supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12G\n\x10\x61lter_attributes\x18\x06 \x03(\x0b\x32-.Ydb.Topic.AlterConsumer.AlterAttributesEntry\x12<\n\x17set_availability_period\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12;\n\x19reset_availability_period\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1c\n\x1a\x61vailability_period_actionB\x10\n\x0e_set_importantJ\x04\x08\x04\x10\x05\"\xdc\x01\n\x14PartitioningSettings\x12\'\n\x15min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\'\n\x15max_active_partitions\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12)\n\x15partition_count_limit\x18\x02 \x01(\x03\x42\n\x18\x01\xb2\xe6*\x04>= 0\x12G\n\x1a\x61uto_partitioning_settings\x18\x04 \x01(\x0b\x32#.Ydb.Topic.AutoPartitioningSettings\"\x9f\x01\n\x18\x41utoPartitioningSettings\x12\x35\n\x08strategy\x18\x01 \x01(\x0e\x32#.Ydb.Topic.AutoPartitioningStrategy\x12L\n\x15partition_write_speed\x18\x02 \x01(\x0b\x32-.Ydb.Topic.AutoPartitioningWriteSpeedStrategy\"\xb3\x01\n\"AutoPartitioningWriteSpeedStrategy\x12\x37\n\x14stabilization_window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x16up_utilization_percent\x18\x02 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\x12*\n\x18\x64own_utilization_percent\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\"\x8b\x03\n\x19\x41lterPartitioningSettings\x12\x30\n\x19set_min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x30\n\x19set_max_active_partitions\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x12\x32\n\x19set_partition_count_limit\x18\x02 \x01(\x03\x42\n\x18\x01\xb2\xe6*\x04>= 0H\x02\x88\x01\x01\x12W\n alter_auto_partitioning_settings\x18\x04 \x01(\x0b\x32(.Ydb.Topic.AlterAutoPartitioningSettingsH\x03\x88\x01\x01\x42\x1c\n\x1a_set_min_active_partitionsB\x1c\n\x1a_set_max_active_partitionsB\x1c\n\x1a_set_partition_count_limitB#\n!_alter_auto_partitioning_settings\"\xea\x01\n\x1d\x41lterAutoPartitioningSettings\x12>\n\x0cset_strategy\x18\x01 \x01(\x0e\x32#.Ydb.Topic.AutoPartitioningStrategyH\x00\x88\x01\x01\x12Z\n\x19set_partition_write_speed\x18\x02 \x01(\x0b\x32\x32.Ydb.Topic.AlterAutoPartitioningWriteSpeedStrategyH\x01\x88\x01\x01\x42\x0f\n\r_set_strategyB\x1c\n\x1a_set_partition_write_speed\"\xb0\x02\n\'AlterAutoPartitioningWriteSpeedStrategy\x12@\n\x18set_stabilization_window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x88\x01\x01\x12\x31\n\x1aset_up_utilization_percent\x18\x02 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x12\x33\n\x1cset_down_utilization_percent\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0H\x02\x88\x01\x01\x42\x1b\n\x19_set_stabilization_windowB\x1d\n\x1b_set_up_utilization_percentB\x1f\n\x1d_set_down_utilization_percent\"\xf6\x04\n\x12\x43reateTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12>\n\x15partitioning_settings\x18\x03 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x14retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x38\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x41\n\nattributes\x18\n \x03(\x0b\x32-.Ydb.Topic.CreateTopicRequest.AttributesEntry\x12/\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"C\n\x13\x43reateTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x43reateTopicResult\"8\n\x11PartitionLocation\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x12\n\ngeneration\x18\x02 \x01(\x03\"\x90\x01\n\x14\x44\x65scribeTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x15\n\rinclude_stats\x18\x03 \x01(\x08\x12\x18\n\x10include_location\x18\x04 \x01(\x08\"E\n\x15\x44\x65scribeTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x11PartitionKeyRange\x12\x17\n\nfrom_bound\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x15\n\x08to_bound\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\r\n\x0b_from_boundB\x0b\n\t_to_bound\"\xfa\t\n\x13\x44\x65scribeTopicResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12>\n\x15partitioning_settings\x18\x02 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12@\n\npartitions\x18\x03 \x03(\x0b\x32,.Ydb.Topic.DescribeTopicResult.PartitionInfo\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1c\n\x14retention_storage_mb\x18\x05 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12.\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x12\x33\n+partition_total_read_speed_bytes_per_second\x18\x0e \x01(\x03\x12\x36\n.partition_consumer_read_speed_bytes_per_second\x18\x0f \x01(\x03\x12#\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Topic.DescribeTopicResult.AttributesEntry\x12&\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.Consumer\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x12>\n\x0btopic_stats\x18\r \x01(\x0b\x32).Ydb.Topic.DescribeTopicResult.TopicStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8f\x02\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x12\x38\n\x12partition_location\x18\x06 \x01(\x0b\x32\x1c.Ydb.Topic.PartitionLocation\x12/\n\tkey_range\x18\x07 \x01(\x0b\x32\x1c.Ydb.Topic.PartitionKeyRange\x1a\xcd\x01\n\nTopicStats\x12\x18\n\x10store_size_bytes\x18\x01 \x01(\x03\x12\x37\n\x13min_last_write_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatJ\x04\x08\x06\x10\x07\"\xaa\x01\n\x18\x44\x65scribePartitionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x15\n\rinclude_stats\x18\x04 \x01(\x08\x12\x18\n\x10include_location\x18\x05 \x01(\x08\"I\n\x19\x44\x65scribePartitionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Z\n\x17\x44\x65scribePartitionResult\x12?\n\tpartition\x18\x01 \x01(\x0b\x32,.Ydb.Topic.DescribeTopicResult.PartitionInfo\"\xa5\x01\n\x17\x44\x65scribeConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x12\x15\n\rinclude_stats\x18\x04 \x01(\x08\x12\x18\n\x10include_location\x18\x05 \x01(\x08\"H\n\x18\x44\x65scribeConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd3\x07\n\x16\x44\x65scribeConsumerResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12%\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32\x13.Ydb.Topic.Consumer\x12\x43\n\npartitions\x18\x03 \x03(\x0b\x32/.Ydb.Topic.DescribeConsumerResult.PartitionInfo\x1a\xba\x02\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x12Z\n\x18partition_consumer_stats\x18\x06 \x01(\x0b\x32\x38.Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats\x12\x38\n\x12partition_location\x18\x07 \x01(\x0b\x32\x1c.Ydb.Topic.PartitionLocation\x1a\xee\x03\n\x16PartitionConsumerStats\x12\x18\n\x10last_read_offset\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x17\n\x0fread_session_id\x18\x03 \x01(\t\x12\x46\n\"partition_read_session_create_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_read_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x16max_committed_time_lag\x18\r \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x08 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x13\n\x0breader_name\x18\x0b \x01(\t\x12\x1a\n\x12\x63onnection_node_id\x18\x0c \x01(\x05\"\xa0\x02\n\x0ePartitionStats\x12\x32\n\x11partition_offsets\x18\x01 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10store_size_bytes\x18\x02 \x01(\x03\x12\x33\n\x0flast_write_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x1d\n\x11partition_node_id\x18\x08 \x01(\x05\x42\x02\x18\x01\"\x87\x07\n\x11\x41lterTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12I\n\x1b\x61lter_partitioning_settings\x18\x03 \x01(\x0b\x32$.Ydb.Topic.AlterPartitioningSettings\x12\x37\n\x14set_retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x18set_retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x38\n\x14set_supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x41\n*set_partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x12\x36\n\x1fset_partition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x02\x88\x01\x01\x12K\n\x10\x61lter_attributes\x18\n \x03(\x0b\x32\x31.Ydb.Topic.AlterTopicRequest.AlterAttributesEntry\x12\x33\n\radd_consumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x1f\n\x0e\x64rop_consumers\x18\x0c \x03(\tB\x07\x9a\xe6*\x03\x18\xb8\x17\x12:\n\x0f\x61lter_consumers\x18\r \x03(\x0b\x32\x18.Ydb.Topic.AlterConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x32\n\x11set_metering_mode\x18\x0e \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1b\n\x19_set_retention_storage_mbB-\n+_set_partition_write_speed_bytes_per_secondB\"\n _set_partition_write_burst_bytesJ\x04\x08\x06\x10\x07\"B\n\x12\x41lterTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x41lterTopicResult\"[\n\x10\x44ropTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x11\x44ropTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x11\n\x0f\x44ropTopicResult*\x83\x01\n\x05\x43odec\x12\x15\n\x11\x43ODEC_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_RAW\x10\x01\x12\x0e\n\nCODEC_GZIP\x10\x02\x12\x0e\n\nCODEC_LZOP\x10\x03\x12\x0e\n\nCODEC_ZSTD\x10\x04\x12\x11\n\x0c\x43ODEC_CUSTOM\x10\x90N\"\x05\x08\x05\x10\x8fN\"\n\x08\xa0\x9c\x01\x10\xff\xff\xff\xff\x07*\xf1\x01\n\x18\x41utoPartitioningStrategy\x12*\n&AUTO_PARTITIONING_STRATEGY_UNSPECIFIED\x10\x00\x12\'\n#AUTO_PARTITIONING_STRATEGY_DISABLED\x10\x01\x12\'\n#AUTO_PARTITIONING_STRATEGY_SCALE_UP\x10\x02\x12\x30\n,AUTO_PARTITIONING_STRATEGY_SCALE_UP_AND_DOWN\x10\x03\x12%\n!AUTO_PARTITIONING_STRATEGY_PAUSED\x10\x04*s\n\x0cMeteringMode\x12\x1d\n\x19METERING_MODE_UNSPECIFIED\x10\x00\x12#\n\x1fMETERING_MODE_RESERVED_CAPACITY\x10\x01\x12\x1f\n\x1bMETERING_MODE_REQUEST_UNITS\x10\x02\x42S\n\x14tech.ydb.proto.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_topic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024tech.ydb.proto.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\370\001\001'
  _SUPPORTEDCODECS.fields_by_name['codecs']._options = None
  _SUPPORTEDCODECS.fields_by_name['codecs']._serialized_options = b'\262\346*\n[1; 19999]\232\346*\002\030d'
  _UPDATETOKENREQUEST.fields_by_name['token']._options = None
  _UPDATETOKENREQUEST.fields_by_name['token']._serialized_options = b'\270\346*\001'
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._options = None
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_options = b'8\001'
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['producer_id']._options = None
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['producer_id']._serialized_options = b'\242\346*\003\030\200\020'
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['message_group_id']._options = None
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['message_group_id']._serialized_options = b'\242\346*\003\030\200\020'
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['message_group_id']._options = None
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['message_group_id']._serialized_options = b'\242\346*\003\030\200\020'
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['metadata_items']._options = None
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['metadata_items']._serialized_options = b'\232\346*\003\030\350\007'
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA.fields_by_name['message_group_id']._options = None
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA.fields_by_name['message_group_id']._serialized_options = b'\242\346*\003\030\200\020'
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._options = None
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_options = b'8\001'
  _STREAMREADMESSAGE_READRESPONSE_BATCH.fields_by_name['producer_id']._options = None
  _STREAMREADMESSAGE_READRESPONSE_BATCH.fields_by_name['producer_id']._serialized_options = b'\242\346*\003\030\200\020'
  _CONSUMER_ATTRIBUTESENTRY._options = None
  _CONSUMER_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._options = None
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _PARTITIONINGSETTINGS.fields_by_name['min_active_partitions']._options = None
  _PARTITIONINGSETTINGS.fields_by_name['min_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _PARTITIONINGSETTINGS.fields_by_name['max_active_partitions']._options = None
  _PARTITIONINGSETTINGS.fields_by_name['max_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _PARTITIONINGSETTINGS.fields_by_name['partition_count_limit']._options = None
  _PARTITIONINGSETTINGS.fields_by_name['partition_count_limit']._serialized_options = b'\030\001\262\346*\004>= 0'
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['up_utilization_percent']._options = None
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['up_utilization_percent']._serialized_options = b'\262\346*\004>= 0'
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['down_utilization_percent']._options = None
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['down_utilization_percent']._serialized_options = b'\262\346*\004>= 0'
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions']._options = None
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_max_active_partitions']._options = None
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_max_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit']._options = None
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit']._serialized_options = b'\030\001\262\346*\004>= 0'
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['set_up_utilization_percent']._options = None
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['set_up_utilization_percent']._serialized_options = b'\262\346*\004>= 0'
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['set_down_utilization_percent']._options = None
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY.fields_by_name['set_down_utilization_percent']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._options = None
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETOPICREQUEST.fields_by_name['retention_storage_mb']._options = None
  _CREATETOPICREQUEST.fields_by_name['retention_storage_mb']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['partition_write_speed_bytes_per_second']._options = None
  _CREATETOPICREQUEST.fields_by_name['partition_write_speed_bytes_per_second']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['partition_write_burst_bytes']._options = None
  _CREATETOPICREQUEST.fields_by_name['partition_write_burst_bytes']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['consumers']._options = None
  _CREATETOPICREQUEST.fields_by_name['consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._options = None
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PARTITIONSTATS.fields_by_name['partition_node_id']._options = None
  _PARTITIONSTATS.fields_by_name['partition_node_id']._serialized_options = b'\030\001'
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['add_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['add_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _ALTERTOPICREQUEST.fields_by_name['drop_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['drop_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _ALTERTOPICREQUEST.fields_by_name['alter_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['alter_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _CODEC._serialized_start=18453
  _CODEC._serialized_end=18584
  _AUTOPARTITIONINGSTRATEGY._serialized_start=18587
  _AUTOPARTITIONINGSTRATEGY._serialized_end=18828
  _METERINGMODE._serialized_start=18830
  _METERINGMODE._serialized_end=18945
  _SUPPORTEDCODECS._serialized_start=320
  _SUPPORTEDCODECS._serialized_end=375
  _OFFSETSRANGE._serialized_start=377
  _OFFSETSRANGE._serialized_end=419
  _UPDATETOKENREQUEST._serialized_start=421
  _UPDATETOKENREQUEST._serialized_end=462
  _UPDATETOKENRESPONSE._serialized_start=464
  _UPDATETOKENRESPONSE._serialized_end=485
  _PARTITIONWITHGENERATION._serialized_start=487
  _PARTITIONWITHGENERATION._serialized_end=554
  _METADATAITEM._serialized_start=556
  _METADATAITEM._serialized_end=598
  _STREAMWRITEMESSAGE._serialized_start=601
  _STREAMWRITEMESSAGE._serialized_end=3191
  _STREAMWRITEMESSAGE_FROMCLIENT._serialized_start=624
  _STREAMWRITEMESSAGE_FROMCLIENT._serialized_end=853
  _STREAMWRITEMESSAGE_FROMSERVER._serialized_start=856
  _STREAMWRITEMESSAGE_FROMSERVER._serialized_end=1175
  _STREAMWRITEMESSAGE_INITREQUEST._serialized_start=1178
  _STREAMWRITEMESSAGE_INITREQUEST._serialized_end=1560
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_start=1489
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_end=1544
  _STREAMWRITEMESSAGE_INITRESPONSE._serialized_start=1563
  _STREAMWRITEMESSAGE_INITRESPONSE._serialized_end=1694
  _STREAMWRITEMESSAGE_WRITEREQUEST._serialized_start=1697
  _STREAMWRITEMESSAGE_WRITEREQUEST._serialized_end=2185
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA._serialized_start=1852
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA._serialized_end=2178
  _STREAMWRITEMESSAGE_WRITERESPONSE._serialized_start=2188
  _STREAMWRITEMESSAGE_WRITERESPONSE._serialized_end=3191
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK._serialized_start=2383
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK._serialized_end=2887
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN._serialized_start=2664
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN._serialized_end=2689
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED._serialized_start=2692
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED._serialized_end=2848
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON._serialized_start=2788
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON._serialized_end=2848
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTENINTX._serialized_start=2850
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTENINTX._serialized_end=2863
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS._serialized_start=2890
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS._serialized_end=3191
  _STREAMREADMESSAGE._serialized_start=3194
  _STREAMREADMESSAGE._serialized_end=7702
  _STREAMREADMESSAGE_PARTITIONSESSION._serialized_start=3215
  _STREAMREADMESSAGE_PARTITIONSESSION._serialized_end=3299
  _STREAMREADMESSAGE_FROMCLIENT._serialized_start=3302
  _STREAMREADMESSAGE_FROMCLIENT._serialized_end=3991
  _STREAMREADMESSAGE_FROMSERVER._serialized_start=3994
  _STREAMREADMESSAGE_FROMSERVER._serialized_end=4874
  _STREAMREADMESSAGE_INITREQUEST._serialized_start=4877
  _STREAMREADMESSAGE_INITREQUEST._serialized_end=5225
  _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_start=5078
  _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_end=5225
  _STREAMREADMESSAGE_INITRESPONSE._serialized_start=5227
  _STREAMREADMESSAGE_INITRESPONSE._serialized_end=5261
  _STREAMREADMESSAGE_READREQUEST._serialized_start=5263
  _STREAMREADMESSAGE_READREQUEST._serialized_end=5296
  _STREAMREADMESSAGE_READRESPONSE._serialized_start=5299
  _STREAMREADMESSAGE_READRESPONSE._serialized_end=6084
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA._serialized_start=5417
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA._serialized_end=5635
  _STREAMREADMESSAGE_READRESPONSE_BATCH._serialized_start=5638
  _STREAMREADMESSAGE_READRESPONSE_BATCH._serialized_end=5971
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_start=1489
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_end=1544
  _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA._serialized_start=5973
  _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA._serialized_end=6084
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST._serialized_start=6087
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST._serialized_end=6301
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET._serialized_start=6206
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET._serialized_end=6301
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE._serialized_start=6304
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE._serialized_end=6524
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_start=6442
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_end=6524
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_start=6526
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_end=6587
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_start=6590
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_end=6793
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_start=6796
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_end=7036
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_start=7039
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_end=7188
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_start=7191
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_end=7323
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_start=7325
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_end=7403
  _STREAMREADMESSAGE_UPDATEPARTITIONSESSION._serialized_start=7405
  _STREAMREADMESSAGE_UPDATEPARTITIONSESSION._serialized_end=7517
  _STREAMREADMESSAGE_DIRECTREADACK._serialized_start=7519
  _STREAMREADMESSAGE_DIRECTREADACK._serialized_end=7588
  _STREAMREADMESSAGE_ENDPARTITIONSESSION._serialized_start=7590
  _STREAMREADMESSAGE_ENDPARTITIONSESSION._serialized_end=7702
  _STREAMDIRECTREADMESSAGE._serialized_start=7705
  _STREAMDIRECTREADMESSAGE._serialized_end=9380
  _STREAMDIRECTREADMESSAGE_FROMCLIENT._serialized_start=7733
  _STREAMDIRECTREADMESSAGE_FROMCLIENT._serialized_end=8029
  _STREAMDIRECTREADMESSAGE_FROMSERVER._serialized_start=8032
  _STREAMDIRECTREADMESSAGE_FROMSERVER._serialized_end=8618
  _STREAMDIRECTREADMESSAGE_INITREQUEST._serialized_start=8621
  _STREAMDIRECTREADMESSAGE_INITREQUEST._serialized_end=8803
  _STREAMDIRECTREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_start=5078
  _STREAMDIRECTREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_end=5111
  _STREAMDIRECTREADMESSAGE_INITRESPONSE._serialized_start=1563
  _STREAMDIRECTREADMESSAGE_INITRESPONSE._serialized_end=1577
  _STREAMDIRECTREADMESSAGE_STARTDIRECTREADPARTITIONSESSIONREQUEST._serialized_start=8821
  _STREAMDIRECTREADMESSAGE_STARTDIRECTREADPARTITIONSESSIONREQUEST._serialized_end=8940
  _STREAMDIRECTREADMESSAGE_STARTDIRECTREADPARTITIONSESSIONRESPONSE._serialized_start=8942
  _STREAMDIRECTREADMESSAGE_STARTDIRECTREADPARTITIONSESSIONRESPONSE._serialized_end=9033
  _STREAMDIRECTREADMESSAGE_STOPDIRECTREADPARTITIONSESSION._serialized_start=9036
  _STREAMDIRECTREADMESSAGE_STOPDIRECTREADPARTITIONSESSION._serialized_end=9202
  _STREAMDIRECTREADMESSAGE_DIRECTREADRESPONSE._serialized_start=9205
  _STREAMDIRECTREADMESSAGE_DIRECTREADRESPONSE._serialized_end=9380
  _TRANSACTIONIDENTITY._serialized_start=9382
  _TRANSACTIONIDENTITY._serialized_end=9432
  _UPDATEOFFSETSINTRANSACTIONREQUEST._serialized_start=9435
  _UPDATEOFFSETSINTRANSACTIONREQUEST._serialized_end=9887
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS._serialized_start=9669
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS._serialized_end=9887
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS._serialized_start=9795
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS._serialized_end=9887
  _UPDATEOFFSETSINTRANSACTIONRESPONSE._serialized_start=9889
  _UPDATEOFFSETSINTRANSACTIONRESPONSE._serialized_end=9971
  _UPDATEOFFSETSINTRANSACTIONRESULT._serialized_start=9973
  _UPDATEOFFSETSINTRANSACTIONRESULT._serialized_end=10007
  _COMMITOFFSETREQUEST._serialized_start=10010
  _COMMITOFFSETREQUEST._serialized_end=10185
  _COMMITOFFSETRESPONSE._serialized_start=10187
  _COMMITOFFSETRESPONSE._serialized_end=10255
  _COMMITOFFSETRESULT._serialized_start=10257
  _COMMITOFFSETRESULT._serialized_end=10277
  _MULTIPLEWINDOWSSTAT._serialized_start=10279
  _MULTIPLEWINDOWSSTAT._serialized_end=10355
  _CONSUMER._serialized_start=10358
  _CONSUMER._serialized_end=11065
  _CONSUMER_ATTRIBUTESENTRY._serialized_start=10681
  _CONSUMER_ATTRIBUTESENTRY._serialized_end=10730
  _CONSUMER_CONSUMERSTATS._serialized_start=10733
  _CONSUMER_CONSUMERSTATS._serialized_end=11035
  _ALTERCONSUMER._serialized_start=11068
  _ALTERCONSUMER._serialized_end=11540
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_start=11432
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_end=11486
  _PARTITIONINGSETTINGS._serialized_start=11543
  _PARTITIONINGSETTINGS._serialized_end=11763
  _AUTOPARTITIONINGSETTINGS._serialized_start=11766
  _AUTOPARTITIONINGSETTINGS._serialized_end=11925
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY._serialized_start=11928
  _AUTOPARTITIONINGWRITESPEEDSTRATEGY._serialized_end=12107
  _ALTERPARTITIONINGSETTINGS._serialized_start=12110
  _ALTERPARTITIONINGSETTINGS._serialized_end=12505
  _ALTERAUTOPARTITIONINGSETTINGS._serialized_start=12508
  _ALTERAUTOPARTITIONINGSETTINGS._serialized_end=12742
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY._serialized_start=12745
  _ALTERAUTOPARTITIONINGWRITESPEEDSTRATEGY._serialized_end=13049
  _CREATETOPICREQUEST._serialized_start=13052
  _CREATETOPICREQUEST._serialized_end=13682
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_start=10681
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_end=10730
  _CREATETOPICRESPONSE._serialized_start=13684
  _CREATETOPICRESPONSE._serialized_end=13751
  _CREATETOPICRESULT._serialized_start=13753
  _CREATETOPICRESULT._serialized_end=13772
  _PARTITIONLOCATION._serialized_start=13774
  _PARTITIONLOCATION._serialized_end=13830
  _DESCRIBETOPICREQUEST._serialized_start=13833
  _DESCRIBETOPICREQUEST._serialized_end=13977
  _DESCRIBETOPICRESPONSE._serialized_start=13979
  _DESCRIBETOPICRESPONSE._serialized_end=14048
  _PARTITIONKEYRANGE._serialized_start=14050
  _PARTITIONKEYRANGE._serialized_end=14145
  _DESCRIBETOPICRESULT._serialized_start=14148
  _DESCRIBETOPICRESULT._serialized_end=15422
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_start=10681
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_end=10730
  _DESCRIBETOPICRESULT_PARTITIONINFO._serialized_start=14937
  _DESCRIBETOPICRESULT_PARTITIONINFO._serialized_end=15208
  _DESCRIBETOPICRESULT_TOPICSTATS._serialized_start=15211
  _DESCRIBETOPICRESULT_TOPICSTATS._serialized_end=15416
  _DESCRIBEPARTITIONREQUEST._serialized_start=15425
  _DESCRIBEPARTITIONREQUEST._serialized_end=15595
  _DESCRIBEPARTITIONRESPONSE._serialized_start=15597
  _DESCRIBEPARTITIONRESPONSE._serialized_end=15670
  _DESCRIBEPARTITIONRESULT._serialized_start=15672
  _DESCRIBEPARTITIONRESULT._serialized_end=15762
  _DESCRIBECONSUMERREQUEST._serialized_start=15765
  _DESCRIBECONSUMERREQUEST._serialized_end=15930
  _DESCRIBECONSUMERRESPONSE._serialized_start=15932
  _DESCRIBECONSUMERRESPONSE._serialized_end=16004
  _DESCRIBECONSUMERRESULT._serialized_start=16007
  _DESCRIBECONSUMERRESULT._serialized_end=16986
  _DESCRIBECONSUMERRESULT_PARTITIONINFO._serialized_start=16175
  _DESCRIBECONSUMERRESULT_PARTITIONINFO._serialized_end=16489
  _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS._serialized_start=16492
  _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS._serialized_end=16986
  _PARTITIONSTATS._serialized_start=16989
  _PARTITIONSTATS._serialized_end=17277
  _ALTERTOPICREQUEST._serialized_start=17280
  _ALTERTOPICREQUEST._serialized_end=18183
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_start=11432
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_end=11486
  _ALTERTOPICRESPONSE._serialized_start=18185
  _ALTERTOPICRESPONSE._serialized_end=18251
  _ALTERTOPICRESULT._serialized_start=18253
  _ALTERTOPICRESULT._serialized_end=18271
  _DROPTOPICREQUEST._serialized_start=18273
  _DROPTOPICREQUEST._serialized_end=18364
  _DROPTOPICRESPONSE._serialized_start=18366
  _DROPTOPICRESPONSE._serialized_end=18431
  _DROPTOPICRESULT._serialized_start=18433
  _DROPTOPICRESULT._serialized_end=18450
# @@protoc_insertion_point(module_scope)
