# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_scheme.proto',
  package='Ydb.Scheme',
  syntax='proto3',
  serialized_options=b'\n\025tech.ydb.proto.schemeB\025SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17protos/ydb_scheme.proto\x12\nYdb.Scheme\x1a\x17protos/ydb_common.proto\x1a\x1aprotos/ydb_operation.proto\"_\n\x14MakeDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15MakeDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"a\n\x16RemoveDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"G\n\x17RemoveDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x14ListDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15ListDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"8\n\x0bPermissions\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x18\n\x10permission_names\x18\x02 \x03(\t\"\xc1\x04\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12$\n\x04type\x18\x05 \x01(\x0e\x32\x16.Ydb.Scheme.Entry.Type\x12\x36\n\x15\x65\x66\x66\x65\x63tive_permissions\x18\x06 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12,\n\x0bpermissions\x18\x07 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12\x12\n\nsize_bytes\x18\x08 \x01(\x04\x12)\n\ncreated_at\x18\t \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\"\xcf\x02\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDIRECTORY\x10\x01\x12\t\n\x05TABLE\x10\x02\x12\x14\n\x10PERS_QUEUE_GROUP\x10\x03\x12\x0c\n\x08\x44\x41TABASE\x10\x04\x12\x0f\n\x0bRTMR_VOLUME\x10\x05\x12\x16\n\x12\x42LOCK_STORE_VOLUME\x10\x06\x12\x15\n\x11\x43OORDINATION_NODE\x10\x07\x12\x10\n\x0c\x43OLUMN_STORE\x10\x0c\x12\x10\n\x0c\x43OLUMN_TABLE\x10\r\x12\x0c\n\x08SEQUENCE\x10\x0f\x12\x0f\n\x0bREPLICATION\x10\x10\x12\t\n\x05TOPIC\x10\x11\x12\x12\n\x0e\x45XTERNAL_TABLE\x10\x12\x12\x18\n\x14\x45XTERNAL_DATA_SOURCE\x10\x13\x12\x08\n\x04VIEW\x10\x14\x12\x11\n\rRESOURCE_POOL\x10\x15\x12\x0c\n\x08TRANSFER\x10\x17\x12\x0c\n\x08SYS_VIEW\x10\x18\"[\n\x13ListDirectoryResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.Ydb.Scheme.Entry\"^\n\x13\x44\x65scribePathRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"D\n\x14\x44\x65scribePathResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"5\n\x12\x44\x65scribePathResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\"\xb2\x01\n\x11PermissionsAction\x12(\n\x05grant\x18\x01 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12)\n\x06revoke\x18\x02 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12&\n\x03set\x18\x03 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12\x16\n\x0c\x63hange_owner\x18\x04 \x01(\tH\x00\x42\x08\n\x06\x61\x63tion\"\xde\x01\n\x18ModifyPermissionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12.\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x1d.Ydb.Scheme.PermissionsAction\x12\x19\n\x11\x63lear_permissions\x18\x04 \x01(\x08\x12\x1f\n\x15interrupt_inheritance\x18\x05 \x01(\x08H\x00\x42\r\n\x0binheritance\"I\n\x19ModifyPermissionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBl\n\x15tech.ydb.proto.schemeB\x15SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__common__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_ENTRY_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='Ydb.Scheme.Entry.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTORY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERS_QUEUE_GROUP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATABASE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTMR_VOLUME', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_STORE_VOLUME', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COORDINATION_NODE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_STORE', index=8, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TABLE', index=9, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEQUENCE', index=10, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLICATION', index=11, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPIC', index=12, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_TABLE', index=13, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_DATA_SOURCE', index=14, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW', index=15, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_POOL', index=16, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSFER', index=17, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYS_VIEW', index=18, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=901,
  serialized_end=1236,
)
_sym_db.RegisterEnumDescriptor(_ENTRY_TYPE)


_MAKEDIRECTORYREQUEST = _descriptor.Descriptor(
  name='MakeDirectoryRequest',
  full_name='Ydb.Scheme.MakeDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scheme.MakeDirectoryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Scheme.MakeDirectoryRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=187,
)


_MAKEDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='MakeDirectoryResponse',
  full_name='Ydb.Scheme.MakeDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scheme.MakeDirectoryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=258,
)


_REMOVEDIRECTORYREQUEST = _descriptor.Descriptor(
  name='RemoveDirectoryRequest',
  full_name='Ydb.Scheme.RemoveDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scheme.RemoveDirectoryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Scheme.RemoveDirectoryRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=357,
)


_REMOVEDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='RemoveDirectoryResponse',
  full_name='Ydb.Scheme.RemoveDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scheme.RemoveDirectoryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=430,
)


_LISTDIRECTORYREQUEST = _descriptor.Descriptor(
  name='ListDirectoryRequest',
  full_name='Ydb.Scheme.ListDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scheme.ListDirectoryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Scheme.ListDirectoryRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=527,
)


_LISTDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='ListDirectoryResponse',
  full_name='Ydb.Scheme.ListDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scheme.ListDirectoryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=598,
)


_PERMISSIONS = _descriptor.Descriptor(
  name='Permissions',
  full_name='Ydb.Scheme.Permissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='Ydb.Scheme.Permissions.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission_names', full_name='Ydb.Scheme.Permissions.permission_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=656,
)


_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='Ydb.Scheme.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Scheme.Entry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='Ydb.Scheme.Entry.owner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Scheme.Entry.type', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_permissions', full_name='Ydb.Scheme.Entry.effective_permissions', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='Ydb.Scheme.Entry.permissions', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='Ydb.Scheme.Entry.size_bytes', index=5,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Ydb.Scheme.Entry.created_at', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENTRY_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=1236,
)


_LISTDIRECTORYRESULT = _descriptor.Descriptor(
  name='ListDirectoryResult',
  full_name='Ydb.Scheme.ListDirectoryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Scheme.ListDirectoryResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='children', full_name='Ydb.Scheme.ListDirectoryResult.children', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1329,
)


_DESCRIBEPATHREQUEST = _descriptor.Descriptor(
  name='DescribePathRequest',
  full_name='Ydb.Scheme.DescribePathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scheme.DescribePathRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Scheme.DescribePathRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1331,
  serialized_end=1425,
)


_DESCRIBEPATHRESPONSE = _descriptor.Descriptor(
  name='DescribePathResponse',
  full_name='Ydb.Scheme.DescribePathResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scheme.DescribePathResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1495,
)


_DESCRIBEPATHRESULT = _descriptor.Descriptor(
  name='DescribePathResult',
  full_name='Ydb.Scheme.DescribePathResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Scheme.DescribePathResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1550,
)


_PERMISSIONSACTION = _descriptor.Descriptor(
  name='PermissionsAction',
  full_name='Ydb.Scheme.PermissionsAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grant', full_name='Ydb.Scheme.PermissionsAction.grant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoke', full_name='Ydb.Scheme.PermissionsAction.revoke', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set', full_name='Ydb.Scheme.PermissionsAction.set', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_owner', full_name='Ydb.Scheme.PermissionsAction.change_owner', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='Ydb.Scheme.PermissionsAction.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1553,
  serialized_end=1731,
)


_MODIFYPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='ModifyPermissionsRequest',
  full_name='Ydb.Scheme.ModifyPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scheme.ModifyPermissionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Scheme.ModifyPermissionsRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='Ydb.Scheme.ModifyPermissionsRequest.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_permissions', full_name='Ydb.Scheme.ModifyPermissionsRequest.clear_permissions', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interrupt_inheritance', full_name='Ydb.Scheme.ModifyPermissionsRequest.interrupt_inheritance', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='inheritance', full_name='Ydb.Scheme.ModifyPermissionsRequest.inheritance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1734,
  serialized_end=1956,
)


_MODIFYPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ModifyPermissionsResponse',
  full_name='Ydb.Scheme.ModifyPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scheme.ModifyPermissionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1958,
  serialized_end=2031,
)

_MAKEDIRECTORYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MAKEDIRECTORYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_REMOVEDIRECTORYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REMOVEDIRECTORYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTDIRECTORYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTDIRECTORYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ENTRY.fields_by_name['type'].enum_type = _ENTRY_TYPE
_ENTRY.fields_by_name['effective_permissions'].message_type = _PERMISSIONS
_ENTRY.fields_by_name['permissions'].message_type = _PERMISSIONS
_ENTRY.fields_by_name['created_at'].message_type = protos_dot_ydb__common__pb2._VIRTUALTIMESTAMP
_ENTRY_TYPE.containing_type = _ENTRY
_LISTDIRECTORYRESULT.fields_by_name['self'].message_type = _ENTRY
_LISTDIRECTORYRESULT.fields_by_name['children'].message_type = _ENTRY
_DESCRIBEPATHREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEPATHRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEPATHRESULT.fields_by_name['self'].message_type = _ENTRY
_PERMISSIONSACTION.fields_by_name['grant'].message_type = _PERMISSIONS
_PERMISSIONSACTION.fields_by_name['revoke'].message_type = _PERMISSIONS
_PERMISSIONSACTION.fields_by_name['set'].message_type = _PERMISSIONS
_PERMISSIONSACTION.oneofs_by_name['action'].fields.append(
  _PERMISSIONSACTION.fields_by_name['grant'])
_PERMISSIONSACTION.fields_by_name['grant'].containing_oneof = _PERMISSIONSACTION.oneofs_by_name['action']
_PERMISSIONSACTION.oneofs_by_name['action'].fields.append(
  _PERMISSIONSACTION.fields_by_name['revoke'])
_PERMISSIONSACTION.fields_by_name['revoke'].containing_oneof = _PERMISSIONSACTION.oneofs_by_name['action']
_PERMISSIONSACTION.oneofs_by_name['action'].fields.append(
  _PERMISSIONSACTION.fields_by_name['set'])
_PERMISSIONSACTION.fields_by_name['set'].containing_oneof = _PERMISSIONSACTION.oneofs_by_name['action']
_PERMISSIONSACTION.oneofs_by_name['action'].fields.append(
  _PERMISSIONSACTION.fields_by_name['change_owner'])
_PERMISSIONSACTION.fields_by_name['change_owner'].containing_oneof = _PERMISSIONSACTION.oneofs_by_name['action']
_MODIFYPERMISSIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MODIFYPERMISSIONSREQUEST.fields_by_name['actions'].message_type = _PERMISSIONSACTION
_MODIFYPERMISSIONSREQUEST.oneofs_by_name['inheritance'].fields.append(
  _MODIFYPERMISSIONSREQUEST.fields_by_name['interrupt_inheritance'])
_MODIFYPERMISSIONSREQUEST.fields_by_name['interrupt_inheritance'].containing_oneof = _MODIFYPERMISSIONSREQUEST.oneofs_by_name['inheritance']
_MODIFYPERMISSIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['MakeDirectoryRequest'] = _MAKEDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['MakeDirectoryResponse'] = _MAKEDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['RemoveDirectoryRequest'] = _REMOVEDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['RemoveDirectoryResponse'] = _REMOVEDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['ListDirectoryRequest'] = _LISTDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['ListDirectoryResponse'] = _LISTDIRECTORYRESPONSE
DESCRIPTOR.message_types_by_name['Permissions'] = _PERMISSIONS
DESCRIPTOR.message_types_by_name['Entry'] = _ENTRY
DESCRIPTOR.message_types_by_name['ListDirectoryResult'] = _LISTDIRECTORYRESULT
DESCRIPTOR.message_types_by_name['DescribePathRequest'] = _DESCRIBEPATHREQUEST
DESCRIPTOR.message_types_by_name['DescribePathResponse'] = _DESCRIBEPATHRESPONSE
DESCRIPTOR.message_types_by_name['DescribePathResult'] = _DESCRIBEPATHRESULT
DESCRIPTOR.message_types_by_name['PermissionsAction'] = _PERMISSIONSACTION
DESCRIPTOR.message_types_by_name['ModifyPermissionsRequest'] = _MODIFYPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ModifyPermissionsResponse'] = _MODIFYPERMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MakeDirectoryRequest = _reflection.GeneratedProtocolMessageType('MakeDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAKEDIRECTORYREQUEST,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.MakeDirectoryRequest)
  })
_sym_db.RegisterMessage(MakeDirectoryRequest)

MakeDirectoryResponse = _reflection.GeneratedProtocolMessageType('MakeDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _MAKEDIRECTORYRESPONSE,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.MakeDirectoryResponse)
  })
_sym_db.RegisterMessage(MakeDirectoryResponse)

RemoveDirectoryRequest = _reflection.GeneratedProtocolMessageType('RemoveDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDIRECTORYREQUEST,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.RemoveDirectoryRequest)
  })
_sym_db.RegisterMessage(RemoveDirectoryRequest)

RemoveDirectoryResponse = _reflection.GeneratedProtocolMessageType('RemoveDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDIRECTORYRESPONSE,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.RemoveDirectoryResponse)
  })
_sym_db.RegisterMessage(RemoveDirectoryResponse)

ListDirectoryRequest = _reflection.GeneratedProtocolMessageType('ListDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDIRECTORYREQUEST,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.ListDirectoryRequest)
  })
_sym_db.RegisterMessage(ListDirectoryRequest)

ListDirectoryResponse = _reflection.GeneratedProtocolMessageType('ListDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDIRECTORYRESPONSE,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.ListDirectoryResponse)
  })
_sym_db.RegisterMessage(ListDirectoryResponse)

Permissions = _reflection.GeneratedProtocolMessageType('Permissions', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONS,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.Permissions)
  })
_sym_db.RegisterMessage(Permissions)

Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
  'DESCRIPTOR' : _ENTRY,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.Entry)
  })
_sym_db.RegisterMessage(Entry)

ListDirectoryResult = _reflection.GeneratedProtocolMessageType('ListDirectoryResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTDIRECTORYRESULT,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.ListDirectoryResult)
  })
_sym_db.RegisterMessage(ListDirectoryResult)

DescribePathRequest = _reflection.GeneratedProtocolMessageType('DescribePathRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHREQUEST,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.DescribePathRequest)
  })
_sym_db.RegisterMessage(DescribePathRequest)

DescribePathResponse = _reflection.GeneratedProtocolMessageType('DescribePathResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHRESPONSE,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.DescribePathResponse)
  })
_sym_db.RegisterMessage(DescribePathResponse)

DescribePathResult = _reflection.GeneratedProtocolMessageType('DescribePathResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPATHRESULT,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.DescribePathResult)
  })
_sym_db.RegisterMessage(DescribePathResult)

PermissionsAction = _reflection.GeneratedProtocolMessageType('PermissionsAction', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSACTION,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.PermissionsAction)
  })
_sym_db.RegisterMessage(PermissionsAction)

ModifyPermissionsRequest = _reflection.GeneratedProtocolMessageType('ModifyPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYPERMISSIONSREQUEST,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.ModifyPermissionsRequest)
  })
_sym_db.RegisterMessage(ModifyPermissionsRequest)

ModifyPermissionsResponse = _reflection.GeneratedProtocolMessageType('ModifyPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYPERMISSIONSRESPONSE,
  '__module__' : 'protos.ydb_scheme_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scheme.ModifyPermissionsResponse)
  })
_sym_db.RegisterMessage(ModifyPermissionsResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
