# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_dynamic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_dynamic_config.proto',
  package='Ydb.DynamicConfig',
  syntax='proto3',
  serialized_options=b'\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%draft/protos/ydb_dynamic_config.proto\x12\x11Ydb.DynamicConfig\x1a\x1aprotos/ydb_operation.proto\"2\n\x0e\x43onfigIdentity\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\"\x8c\x01\n\x10SetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"A\n\x11SetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x14ReplaceConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"E\n\x15ReplaceConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x83\x01\n\x11\x44ropConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"B\n\x12\x44ropConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x18\x41\x64\x64VolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"I\n\x19\x41\x64\x64VolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\",\n\x0eVolatileConfig\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"M\n\x10GetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11GetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x0fGetConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12;\n\x10volatile_configs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"6\n\x16VolatileConfigMetadata\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\t\"O\n\x12GetMetadataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"C\n\x13GetMetadataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"j\n\x11GetMetadataResult\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x43\n\x10volatile_configs\x18\x02 \x03(\x0b\x32).Ydb.DynamicConfig.VolatileConfigMetadata\"\xb7\x02\n\x1bRemoveVolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x35\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentityH\x00\x12\x0f\n\x05\x66orce\x18\x03 \x01(\x08H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDeleteH\x01\x12\r\n\x03\x61ll\x18\x05 \x01(\x08H\x01\x1a\x1a\n\x0bIdsToDelete\x12\x0b\n\x03ids\x18\x01 \x03(\x04\x42\x13\n\x11\x63onsistency_checkB\n\n\x08selector\"L\n\x1cRemoveVolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x14GetNodeLabelsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0f\n\x07node_id\x18\x02 \x01(\r\")\n\tYamlLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"E\n\x15GetNodeLabelsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"C\n\x13GetNodeLabelsResult\x12,\n\x06labels\x18\x01 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"\xcc\x01\n\x14ResolveConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12,\n\x06labels\x18\x04 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"E\n\x15ResolveConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n\x13ResolveConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\"\xbb\x01\n\x17ResolveAllConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x18\n\x10verbose_response\x18\x04 \x01(\x08\"\xb6\x01\n\x0cYamlLabelExt\x12\r\n\x05label\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).Ydb.DynamicConfig.YamlLabelExt.LabelType\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\"@\n\tLabelType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\x0b\n\x07NOT_SET\x10\x02\x12\t\n\x05\x45MPTY\x10\x03\x42\x08\n\x06_value\";\n\x08LabelSet\x12/\n\x06labels\x18\x01 \x03(\x0b\x32\x1f.Ydb.DynamicConfig.YamlLabelExt\"Q\n\x0eResolvedConfig\x12/\n\nlabel_sets\x18\x01 \x03(\x0b\x32\x1b.Ydb.DynamicConfig.LabelSet\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"H\n\x18ResolveAllConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\\\n\x16ResolveAllConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x32\n\x07\x63onfigs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.ResolvedConfigBo\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_YAMLLABELEXT_LABELTYPE = _descriptor.EnumDescriptor(
  name='LabelType',
  full_name='Ydb.DynamicConfig.YamlLabelExt.LabelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2895,
  serialized_end=2959,
)
_sym_db.RegisterEnumDescriptor(_YAMLLABELEXT_LABELTYPE)


_CONFIGIDENTITY = _descriptor.Descriptor(
  name='ConfigIdentity',
  full_name='Ydb.DynamicConfig.ConfigIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='Ydb.DynamicConfig.ConfigIdentity.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='Ydb.DynamicConfig.ConfigIdentity.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=138,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='Ydb.DynamicConfig.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.SetConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.SetConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='Ydb.DynamicConfig.SetConfigRequest.dry_run', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unknown_fields', full_name='Ydb.DynamicConfig.SetConfigRequest.allow_unknown_fields', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=281,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='Ydb.DynamicConfig.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.SetConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)


_REPLACECONFIGREQUEST = _descriptor.Descriptor(
  name='ReplaceConfigRequest',
  full_name='Ydb.DynamicConfig.ReplaceConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.dry_run', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unknown_fields', full_name='Ydb.DynamicConfig.ReplaceConfigRequest.allow_unknown_fields', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=495,
)


_REPLACECONFIGRESPONSE = _descriptor.Descriptor(
  name='ReplaceConfigResponse',
  full_name='Ydb.DynamicConfig.ReplaceConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ReplaceConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=566,
)


_DROPCONFIGREQUEST = _descriptor.Descriptor(
  name='DropConfigRequest',
  full_name='Ydb.DynamicConfig.DropConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.DropConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.DropConfigRequest.identity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=700,
)


_DROPCONFIGRESPONSE = _descriptor.Descriptor(
  name='DropConfigResponse',
  full_name='Ydb.DynamicConfig.DropConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.DropConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=768,
)


_ADDVOLATILECONFIGREQUEST = _descriptor.Descriptor(
  name='AddVolatileConfigRequest',
  full_name='Ydb.DynamicConfig.AddVolatileConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.AddVolatileConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.AddVolatileConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=871,
)


_ADDVOLATILECONFIGRESPONSE = _descriptor.Descriptor(
  name='AddVolatileConfigResponse',
  full_name='Ydb.DynamicConfig.AddVolatileConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.AddVolatileConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=946,
)


_VOLATILECONFIG = _descriptor.Descriptor(
  name='VolatileConfig',
  full_name='Ydb.DynamicConfig.VolatileConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.DynamicConfig.VolatileConfig.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.VolatileConfig.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=992,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='Ydb.DynamicConfig.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1071,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='Ydb.DynamicConfig.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1138,
)


_GETCONFIGRESULT = _descriptor.Descriptor(
  name='GetConfigResult',
  full_name='Ydb.DynamicConfig.GetConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.GetConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.GetConfigResult.volatile_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.GetConfigResult.identity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1288,
)


_VOLATILECONFIGMETADATA = _descriptor.Descriptor(
  name='VolatileConfigMetadata',
  full_name='Ydb.DynamicConfig.VolatileConfigMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.DynamicConfig.VolatileConfigMetadata.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Ydb.DynamicConfig.VolatileConfigMetadata.metadata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1344,
)


_GETMETADATAREQUEST = _descriptor.Descriptor(
  name='GetMetadataRequest',
  full_name='Ydb.DynamicConfig.GetMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetMetadataRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1425,
)


_GETMETADATARESPONSE = _descriptor.Descriptor(
  name='GetMetadataResponse',
  full_name='Ydb.DynamicConfig.GetMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetMetadataResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1494,
)


_GETMETADATARESULT = _descriptor.Descriptor(
  name='GetMetadataResult',
  full_name='Ydb.DynamicConfig.GetMetadataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Ydb.DynamicConfig.GetMetadataResult.metadata', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.GetMetadataResult.volatile_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1602,
)


_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE = _descriptor.Descriptor(
  name='IdsToDelete',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete.ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1883,
)

_REMOVEVOLATILECONFIGREQUEST = _descriptor.Descriptor(
  name='RemoveVolatileConfigRequest',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.identity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.ids', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.all', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='consistency_check', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.consistency_check',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='selector', full_name='Ydb.DynamicConfig.RemoveVolatileConfigRequest.selector',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1605,
  serialized_end=1916,
)


_REMOVEVOLATILECONFIGRESPONSE = _descriptor.Descriptor(
  name='RemoveVolatileConfigResponse',
  full_name='Ydb.DynamicConfig.RemoveVolatileConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.RemoveVolatileConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1994,
)


_GETNODELABELSREQUEST = _descriptor.Descriptor(
  name='GetNodeLabelsRequest',
  full_name='Ydb.DynamicConfig.GetNodeLabelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.GetNodeLabelsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.DynamicConfig.GetNodeLabelsRequest.node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1996,
  serialized_end=2094,
)


_YAMLLABEL = _descriptor.Descriptor(
  name='YamlLabel',
  full_name='Ydb.DynamicConfig.YamlLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='Ydb.DynamicConfig.YamlLabel.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.DynamicConfig.YamlLabel.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2137,
)


_GETNODELABELSRESPONSE = _descriptor.Descriptor(
  name='GetNodeLabelsResponse',
  full_name='Ydb.DynamicConfig.GetNodeLabelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.GetNodeLabelsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2208,
)


_GETNODELABELSRESULT = _descriptor.Descriptor(
  name='GetNodeLabelsResult',
  full_name='Ydb.DynamicConfig.GetNodeLabelsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.GetNodeLabelsResult.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2210,
  serialized_end=2277,
)


_RESOLVECONFIGREQUEST = _descriptor.Descriptor(
  name='ResolveConfigRequest',
  full_name='Ydb.DynamicConfig.ResolveConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ResolveConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.ResolveConfigRequest.volatile_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.ResolveConfigRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2280,
  serialized_end=2484,
)


_RESOLVECONFIGRESPONSE = _descriptor.Descriptor(
  name='ResolveConfigResponse',
  full_name='Ydb.DynamicConfig.ResolveConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ResolveConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2486,
  serialized_end=2555,
)


_RESOLVECONFIGRESULT = _descriptor.Descriptor(
  name='ResolveConfigResult',
  full_name='Ydb.DynamicConfig.ResolveConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2557,
  serialized_end=2594,
)


_RESOLVEALLCONFIGREQUEST = _descriptor.Descriptor(
  name='ResolveAllConfigRequest',
  full_name='Ydb.DynamicConfig.ResolveAllConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volatile_configs', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.volatile_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose_response', full_name='Ydb.DynamicConfig.ResolveAllConfigRequest.verbose_response', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2784,
)


_YAMLLABELEXT = _descriptor.Descriptor(
  name='YamlLabelExt',
  full_name='Ydb.DynamicConfig.YamlLabelExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='Ydb.DynamicConfig.YamlLabelExt.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.DynamicConfig.YamlLabelExt.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.DynamicConfig.YamlLabelExt.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _YAMLLABELEXT_LABELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_value', full_name='Ydb.DynamicConfig.YamlLabelExt._value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2787,
  serialized_end=2969,
)


_LABELSET = _descriptor.Descriptor(
  name='LabelSet',
  full_name='Ydb.DynamicConfig.LabelSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.DynamicConfig.LabelSet.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3030,
)


_RESOLVEDCONFIG = _descriptor.Descriptor(
  name='ResolvedConfig',
  full_name='Ydb.DynamicConfig.ResolvedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label_sets', full_name='Ydb.DynamicConfig.ResolvedConfig.label_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolvedConfig.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3113,
)


_RESOLVEALLCONFIGRESPONSE = _descriptor.Descriptor(
  name='ResolveAllConfigResponse',
  full_name='Ydb.DynamicConfig.ResolveAllConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.DynamicConfig.ResolveAllConfigResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3115,
  serialized_end=3187,
)


_RESOLVEALLCONFIGRESULT = _descriptor.Descriptor(
  name='ResolveAllConfigResult',
  full_name='Ydb.DynamicConfig.ResolveAllConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.DynamicConfig.ResolveAllConfigResult.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configs', full_name='Ydb.DynamicConfig.ResolveAllConfigResult.configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3189,
  serialized_end=3281,
)

_SETCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_SETCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_REPLACECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REPLACECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPCONFIGREQUEST.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_DROPCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ADDVOLATILECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ADDVOLATILECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETCONFIGRESULT.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_GETCONFIGRESULT.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_GETMETADATAREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETMETADATARESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETMETADATARESULT.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIGMETADATA
_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE.containing_type = _REMOVEVOLATILECONFIGREQUEST
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'].message_type = _CONFIGIDENTITY
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'].message_type = _REMOVEVOLATILECONFIGREQUEST_IDSTODELETE
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['identity'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['force'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['force'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['consistency_check']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['ids'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector']
_REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector'].fields.append(
  _REMOVEVOLATILECONFIGREQUEST.fields_by_name['all'])
_REMOVEVOLATILECONFIGREQUEST.fields_by_name['all'].containing_oneof = _REMOVEVOLATILECONFIGREQUEST.oneofs_by_name['selector']
_REMOVEVOLATILECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETNODELABELSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETNODELABELSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETNODELABELSRESULT.fields_by_name['labels'].message_type = _YAMLLABEL
_RESOLVECONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_RESOLVECONFIGREQUEST.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_RESOLVECONFIGREQUEST.fields_by_name['labels'].message_type = _YAMLLABEL
_RESOLVECONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_RESOLVEALLCONFIGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_RESOLVEALLCONFIGREQUEST.fields_by_name['volatile_configs'].message_type = _VOLATILECONFIG
_YAMLLABELEXT.fields_by_name['type'].enum_type = _YAMLLABELEXT_LABELTYPE
_YAMLLABELEXT_LABELTYPE.containing_type = _YAMLLABELEXT
_YAMLLABELEXT.oneofs_by_name['_value'].fields.append(
  _YAMLLABELEXT.fields_by_name['value'])
_YAMLLABELEXT.fields_by_name['value'].containing_oneof = _YAMLLABELEXT.oneofs_by_name['_value']
_LABELSET.fields_by_name['labels'].message_type = _YAMLLABELEXT
_RESOLVEDCONFIG.fields_by_name['label_sets'].message_type = _LABELSET
_RESOLVEALLCONFIGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_RESOLVEALLCONFIGRESULT.fields_by_name['configs'].message_type = _RESOLVEDCONFIG
DESCRIPTOR.message_types_by_name['ConfigIdentity'] = _CONFIGIDENTITY
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ReplaceConfigRequest'] = _REPLACECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ReplaceConfigResponse'] = _REPLACECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['DropConfigRequest'] = _DROPCONFIGREQUEST
DESCRIPTOR.message_types_by_name['DropConfigResponse'] = _DROPCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['AddVolatileConfigRequest'] = _ADDVOLATILECONFIGREQUEST
DESCRIPTOR.message_types_by_name['AddVolatileConfigResponse'] = _ADDVOLATILECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['VolatileConfig'] = _VOLATILECONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigResult'] = _GETCONFIGRESULT
DESCRIPTOR.message_types_by_name['VolatileConfigMetadata'] = _VOLATILECONFIGMETADATA
DESCRIPTOR.message_types_by_name['GetMetadataRequest'] = _GETMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetMetadataResponse'] = _GETMETADATARESPONSE
DESCRIPTOR.message_types_by_name['GetMetadataResult'] = _GETMETADATARESULT
DESCRIPTOR.message_types_by_name['RemoveVolatileConfigRequest'] = _REMOVEVOLATILECONFIGREQUEST
DESCRIPTOR.message_types_by_name['RemoveVolatileConfigResponse'] = _REMOVEVOLATILECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeLabelsRequest'] = _GETNODELABELSREQUEST
DESCRIPTOR.message_types_by_name['YamlLabel'] = _YAMLLABEL
DESCRIPTOR.message_types_by_name['GetNodeLabelsResponse'] = _GETNODELABELSRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeLabelsResult'] = _GETNODELABELSRESULT
DESCRIPTOR.message_types_by_name['ResolveConfigRequest'] = _RESOLVECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ResolveConfigResponse'] = _RESOLVECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ResolveConfigResult'] = _RESOLVECONFIGRESULT
DESCRIPTOR.message_types_by_name['ResolveAllConfigRequest'] = _RESOLVEALLCONFIGREQUEST
DESCRIPTOR.message_types_by_name['YamlLabelExt'] = _YAMLLABELEXT
DESCRIPTOR.message_types_by_name['LabelSet'] = _LABELSET
DESCRIPTOR.message_types_by_name['ResolvedConfig'] = _RESOLVEDCONFIG
DESCRIPTOR.message_types_by_name['ResolveAllConfigResponse'] = _RESOLVEALLCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ResolveAllConfigResult'] = _RESOLVEALLCONFIGRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigIdentity = _reflection.GeneratedProtocolMessageType('ConfigIdentity', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGIDENTITY,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ConfigIdentity)
  })
_sym_db.RegisterMessage(ConfigIdentity)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

ReplaceConfigRequest = _reflection.GeneratedProtocolMessageType('ReplaceConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ReplaceConfigRequest)
  })
_sym_db.RegisterMessage(ReplaceConfigRequest)

ReplaceConfigResponse = _reflection.GeneratedProtocolMessageType('ReplaceConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPLACECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ReplaceConfigResponse)
  })
_sym_db.RegisterMessage(ReplaceConfigResponse)

DropConfigRequest = _reflection.GeneratedProtocolMessageType('DropConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.DropConfigRequest)
  })
_sym_db.RegisterMessage(DropConfigRequest)

DropConfigResponse = _reflection.GeneratedProtocolMessageType('DropConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.DropConfigResponse)
  })
_sym_db.RegisterMessage(DropConfigResponse)

AddVolatileConfigRequest = _reflection.GeneratedProtocolMessageType('AddVolatileConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDVOLATILECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.AddVolatileConfigRequest)
  })
_sym_db.RegisterMessage(AddVolatileConfigRequest)

AddVolatileConfigResponse = _reflection.GeneratedProtocolMessageType('AddVolatileConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDVOLATILECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.AddVolatileConfigResponse)
  })
_sym_db.RegisterMessage(AddVolatileConfigResponse)

VolatileConfig = _reflection.GeneratedProtocolMessageType('VolatileConfig', (_message.Message,), {
  'DESCRIPTOR' : _VOLATILECONFIG,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.VolatileConfig)
  })
_sym_db.RegisterMessage(VolatileConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

GetConfigResult = _reflection.GeneratedProtocolMessageType('GetConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetConfigResult)
  })
_sym_db.RegisterMessage(GetConfigResult)

VolatileConfigMetadata = _reflection.GeneratedProtocolMessageType('VolatileConfigMetadata', (_message.Message,), {
  'DESCRIPTOR' : _VOLATILECONFIGMETADATA,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.VolatileConfigMetadata)
  })
_sym_db.RegisterMessage(VolatileConfigMetadata)

GetMetadataRequest = _reflection.GeneratedProtocolMessageType('GetMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATAREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataRequest)
  })
_sym_db.RegisterMessage(GetMetadataRequest)

GetMetadataResponse = _reflection.GeneratedProtocolMessageType('GetMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATARESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataResponse)
  })
_sym_db.RegisterMessage(GetMetadataResponse)

GetMetadataResult = _reflection.GeneratedProtocolMessageType('GetMetadataResult', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATARESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetMetadataResult)
  })
_sym_db.RegisterMessage(GetMetadataResult)

RemoveVolatileConfigRequest = _reflection.GeneratedProtocolMessageType('RemoveVolatileConfigRequest', (_message.Message,), {

  'IdsToDelete' : _reflection.GeneratedProtocolMessageType('IdsToDelete', (_message.Message,), {
    'DESCRIPTOR' : _REMOVEVOLATILECONFIGREQUEST_IDSTODELETE,
    '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDelete)
    })
  ,
  'DESCRIPTOR' : _REMOVEVOLATILECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigRequest)
  })
_sym_db.RegisterMessage(RemoveVolatileConfigRequest)
_sym_db.RegisterMessage(RemoveVolatileConfigRequest.IdsToDelete)

RemoveVolatileConfigResponse = _reflection.GeneratedProtocolMessageType('RemoveVolatileConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEVOLATILECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.RemoveVolatileConfigResponse)
  })
_sym_db.RegisterMessage(RemoveVolatileConfigResponse)

GetNodeLabelsRequest = _reflection.GeneratedProtocolMessageType('GetNodeLabelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsRequest)
  })
_sym_db.RegisterMessage(GetNodeLabelsRequest)

YamlLabel = _reflection.GeneratedProtocolMessageType('YamlLabel', (_message.Message,), {
  'DESCRIPTOR' : _YAMLLABEL,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.YamlLabel)
  })
_sym_db.RegisterMessage(YamlLabel)

GetNodeLabelsResponse = _reflection.GeneratedProtocolMessageType('GetNodeLabelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsResponse)
  })
_sym_db.RegisterMessage(GetNodeLabelsResponse)

GetNodeLabelsResult = _reflection.GeneratedProtocolMessageType('GetNodeLabelsResult', (_message.Message,), {
  'DESCRIPTOR' : _GETNODELABELSRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.GetNodeLabelsResult)
  })
_sym_db.RegisterMessage(GetNodeLabelsResult)

ResolveConfigRequest = _reflection.GeneratedProtocolMessageType('ResolveConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigRequest)
  })
_sym_db.RegisterMessage(ResolveConfigRequest)

ResolveConfigResponse = _reflection.GeneratedProtocolMessageType('ResolveConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigResponse)
  })
_sym_db.RegisterMessage(ResolveConfigResponse)

ResolveConfigResult = _reflection.GeneratedProtocolMessageType('ResolveConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVECONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveConfigResult)
  })
_sym_db.RegisterMessage(ResolveConfigResult)

ResolveAllConfigRequest = _reflection.GeneratedProtocolMessageType('ResolveAllConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGREQUEST,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigRequest)
  })
_sym_db.RegisterMessage(ResolveAllConfigRequest)

YamlLabelExt = _reflection.GeneratedProtocolMessageType('YamlLabelExt', (_message.Message,), {
  'DESCRIPTOR' : _YAMLLABELEXT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.YamlLabelExt)
  })
_sym_db.RegisterMessage(YamlLabelExt)

LabelSet = _reflection.GeneratedProtocolMessageType('LabelSet', (_message.Message,), {
  'DESCRIPTOR' : _LABELSET,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.LabelSet)
  })
_sym_db.RegisterMessage(LabelSet)

ResolvedConfig = _reflection.GeneratedProtocolMessageType('ResolvedConfig', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEDCONFIG,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolvedConfig)
  })
_sym_db.RegisterMessage(ResolvedConfig)

ResolveAllConfigResponse = _reflection.GeneratedProtocolMessageType('ResolveAllConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGRESPONSE,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigResponse)
  })
_sym_db.RegisterMessage(ResolveAllConfigResponse)

ResolveAllConfigResult = _reflection.GeneratedProtocolMessageType('ResolveAllConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEALLCONFIGRESULT,
  '__module__' : 'draft.protos.ydb_dynamic_config_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.DynamicConfig.ResolveAllConfigResult)
  })
_sym_db.RegisterMessage(ResolveAllConfigResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
