# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/ydb_rate_limiter.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protos/ydb_rate_limiter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprotos/ydb_rate_limiter.proto\x12\x0fYdb.RateLimiter\x1a\x1aprotos/ydb_operation.proto\"\x95\x01\n\x17HierarchicalDrrSettings\x12\x1c\n\x14max_units_per_second\x18\x01 \x01(\x01\x12\"\n\x1amax_burst_size_coefficient\x18\x02 \x01(\x01\x12\x1c\n\x14prefetch_coefficient\x18\x03 \x01(\x01\x12\x1a\n\x12prefetch_watermark\x18\x04 \x01(\x01\"o\n\x08Resource\x12\x15\n\rresource_path\x18\x01 \x01(\t\x12\x44\n\x10hierarchical_drr\x18\x02 \x01(\x0b\x32(.Ydb.RateLimiter.HierarchicalDrrSettingsH\x00\x42\x06\n\x04type\"\x9f\x01\n\x15\x43reateResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12+\n\x08resource\x18\x03 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"F\n\x16\x43reateResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14\x43reateResourceResult\"\x9e\x01\n\x14\x41lterResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12+\n\x08resource\x18\x03 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"E\n\x15\x41lterResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x41lterResourceResult\"\x87\x01\n\x13\x44ropResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\"D\n\x14\x44ropResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x44ropResourceResult\"\x9b\x01\n\x14ListResourcesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"E\n\x15ListResourcesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"-\n\x13ListResourcesResult\x12\x16\n\x0eresource_paths\x18\x01 \x03(\t\"\x8b\x01\n\x17\x44\x65scribeResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\"H\n\x18\x44\x65scribeResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x44\x65scribeResourceResult\x12+\n\x08resource\x18\x01 \x01(\x0b\x32\x19.Ydb.RateLimiter.Resource\"\xb7\x01\n\x16\x41\x63quireResourceRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16\x63oordination_node_path\x18\x02 \x01(\t\x12\x15\n\rresource_path\x18\x03 \x01(\t\x12\x12\n\x08required\x18\x04 \x01(\x04H\x00\x12\x0e\n\x04used\x18\x05 \x01(\x04H\x00\x42\x07\n\x05units\"G\n\x17\x41\x63quireResourceResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x17\n\x15\x41\x63quireResourceResultBu\n\x1btech.ydb.proto.rate_limiterB\x11RateLimiterProtosP\x01Z>github.com/ydb-platform/ydb-go-genproto/protos/Ydb_RateLimiter\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_rate_limiter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033tech.ydb.proto.rate_limiterB\021RateLimiterProtosP\001Z>github.com/ydb-platform/ydb-go-genproto/protos/Ydb_RateLimiter\370\001\001'
  _globals['_HIERARCHICALDRRSETTINGS']._serialized_start=79
  _globals['_HIERARCHICALDRRSETTINGS']._serialized_end=228
  _globals['_RESOURCE']._serialized_start=230
  _globals['_RESOURCE']._serialized_end=341
  _globals['_CREATERESOURCEREQUEST']._serialized_start=344
  _globals['_CREATERESOURCEREQUEST']._serialized_end=503
  _globals['_CREATERESOURCERESPONSE']._serialized_start=505
  _globals['_CREATERESOURCERESPONSE']._serialized_end=575
  _globals['_CREATERESOURCERESULT']._serialized_start=577
  _globals['_CREATERESOURCERESULT']._serialized_end=599
  _globals['_ALTERRESOURCEREQUEST']._serialized_start=602
  _globals['_ALTERRESOURCEREQUEST']._serialized_end=760
  _globals['_ALTERRESOURCERESPONSE']._serialized_start=762
  _globals['_ALTERRESOURCERESPONSE']._serialized_end=831
  _globals['_ALTERRESOURCERESULT']._serialized_start=833
  _globals['_ALTERRESOURCERESULT']._serialized_end=854
  _globals['_DROPRESOURCEREQUEST']._serialized_start=857
  _globals['_DROPRESOURCEREQUEST']._serialized_end=992
  _globals['_DROPRESOURCERESPONSE']._serialized_start=994
  _globals['_DROPRESOURCERESPONSE']._serialized_end=1062
  _globals['_DROPRESOURCERESULT']._serialized_start=1064
  _globals['_DROPRESOURCERESULT']._serialized_end=1084
  _globals['_LISTRESOURCESREQUEST']._serialized_start=1087
  _globals['_LISTRESOURCESREQUEST']._serialized_end=1242
  _globals['_LISTRESOURCESRESPONSE']._serialized_start=1244
  _globals['_LISTRESOURCESRESPONSE']._serialized_end=1313
  _globals['_LISTRESOURCESRESULT']._serialized_start=1315
  _globals['_LISTRESOURCESRESULT']._serialized_end=1360
  _globals['_DESCRIBERESOURCEREQUEST']._serialized_start=1363
  _globals['_DESCRIBERESOURCEREQUEST']._serialized_end=1502
  _globals['_DESCRIBERESOURCERESPONSE']._serialized_start=1504
  _globals['_DESCRIBERESOURCERESPONSE']._serialized_end=1576
  _globals['_DESCRIBERESOURCERESULT']._serialized_start=1578
  _globals['_DESCRIBERESOURCERESULT']._serialized_end=1647
  _globals['_ACQUIRERESOURCEREQUEST']._serialized_start=1650
  _globals['_ACQUIRERESOURCEREQUEST']._serialized_end=1833
  _globals['_ACQUIRERESOURCERESPONSE']._serialized_start=1835
  _globals['_ACQUIRERESOURCERESPONSE']._serialized_end=1906
  _globals['_ACQUIRERESOURCERESULT']._serialized_start=1908
  _globals['_ACQUIRERESOURCERESULT']._serialized_end=1931
# @@protoc_insertion_point(module_scope)
