# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_keyvalue_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.draft.protos import ydb_keyvalue_pb2 as draft_dot_protos_dot_ydb__keyvalue__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/ydb_keyvalue_v1.proto',
  package='Ydb.KeyValue.V1',
  syntax='proto3',
  serialized_options=b'\n\035tech.ydb.proto.draft.keyvalueZ=github.com/ydb-platform/ydb-go-genproto/draft/Ydb_KeyValue_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x64raft/ydb_keyvalue_v1.proto\x12\x0fYdb.KeyValue.V1\x1a\x1f\x64raft/protos/ydb_keyvalue.proto2\xe6\x07\n\x0fKeyValueService\x12U\n\x0c\x43reateVolume\x12!.Ydb.KeyValue.CreateVolumeRequest\x1a\".Ydb.KeyValue.CreateVolumeResponse\x12O\n\nDropVolume\x12\x1f.Ydb.KeyValue.DropVolumeRequest\x1a .Ydb.KeyValue.DropVolumeResponse\x12R\n\x0b\x41lterVolume\x12 .Ydb.KeyValue.AlterVolumeRequest\x1a!.Ydb.KeyValue.AlterVolumeResponse\x12[\n\x0e\x44\x65scribeVolume\x12#.Ydb.KeyValue.DescribeVolumeRequest\x1a$.Ydb.KeyValue.DescribeVolumeResponse\x12j\n\x13ListLocalPartitions\x12(.Ydb.KeyValue.ListLocalPartitionsRequest\x1a).Ydb.KeyValue.ListLocalPartitionsResponse\x12R\n\x0b\x41\x63quireLock\x12 .Ydb.KeyValue.AcquireLockRequest\x1a!.Ydb.KeyValue.AcquireLockResponse\x12g\n\x12\x45xecuteTransaction\x12\'.Ydb.KeyValue.ExecuteTransactionRequest\x1a(.Ydb.KeyValue.ExecuteTransactionResponse\x12=\n\x04Read\x12\x19.Ydb.KeyValue.ReadRequest\x1a\x1a.Ydb.KeyValue.ReadResponse\x12L\n\tReadRange\x12\x1e.Ydb.KeyValue.ReadRangeRequest\x1a\x1f.Ydb.KeyValue.ReadRangeResponse\x12L\n\tListRange\x12\x1e.Ydb.KeyValue.ListRangeRequest\x1a\x1f.Ydb.KeyValue.ListRangeResponse\x12v\n\x17GetStorageChannelStatus\x12,.Ydb.KeyValue.GetStorageChannelStatusRequest\x1a-.Ydb.KeyValue.GetStorageChannelStatusResponseB^\n\x1dtech.ydb.proto.draft.keyvalueZ=github.com/ydb-platform/ydb-go-genproto/draft/Ydb_KeyValue_V1b\x06proto3'
  ,
  dependencies=[draft_dot_protos_dot_ydb__keyvalue__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_KEYVALUESERVICE = _descriptor.ServiceDescriptor(
  name='KeyValueService',
  full_name='Ydb.KeyValue.V1.KeyValueService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=82,
  serialized_end=1080,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateVolume',
    full_name='Ydb.KeyValue.V1.KeyValueService.CreateVolume',
    index=0,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._CREATEVOLUMEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._CREATEVOLUMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropVolume',
    full_name='Ydb.KeyValue.V1.KeyValueService.DropVolume',
    index=1,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._DROPVOLUMEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._DROPVOLUMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AlterVolume',
    full_name='Ydb.KeyValue.V1.KeyValueService.AlterVolume',
    index=2,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._ALTERVOLUMEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._ALTERVOLUMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeVolume',
    full_name='Ydb.KeyValue.V1.KeyValueService.DescribeVolume',
    index=3,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._DESCRIBEVOLUMEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._DESCRIBEVOLUMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLocalPartitions',
    full_name='Ydb.KeyValue.V1.KeyValueService.ListLocalPartitions',
    index=4,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._LISTLOCALPARTITIONSREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._LISTLOCALPARTITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcquireLock',
    full_name='Ydb.KeyValue.V1.KeyValueService.AcquireLock',
    index=5,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._ACQUIRELOCKREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._ACQUIRELOCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteTransaction',
    full_name='Ydb.KeyValue.V1.KeyValueService.ExecuteTransaction',
    index=6,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._EXECUTETRANSACTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._EXECUTETRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Read',
    full_name='Ydb.KeyValue.V1.KeyValueService.Read',
    index=7,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._READREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._READRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadRange',
    full_name='Ydb.KeyValue.V1.KeyValueService.ReadRange',
    index=8,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._READRANGEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._READRANGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRange',
    full_name='Ydb.KeyValue.V1.KeyValueService.ListRange',
    index=9,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._LISTRANGEREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._LISTRANGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStorageChannelStatus',
    full_name='Ydb.KeyValue.V1.KeyValueService.GetStorageChannelStatus',
    index=10,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__keyvalue__pb2._GETSTORAGECHANNELSTATUSREQUEST,
    output_type=draft_dot_protos_dot_ydb__keyvalue__pb2._GETSTORAGECHANNELSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYVALUESERVICE)

DESCRIPTOR.services_by_name['KeyValueService'] = _KEYVALUESERVICE

# @@protoc_insertion_point(module_scope)
