# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_federation_discovery_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos import ydb_federation_discovery_pb2 as protos_dot_ydb__federation__discovery__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb_federation_discovery_v1.proto\x12\x1aYdb.FederationDiscovery.V1\x1a%protos/ydb_federation_discovery.proto2\xab\x01\n\x1a\x46\x65\x64\x65rationDiscoveryService\x12\x8c\x01\n\x17ListFederationDatabases\x12\x37.Ydb.FederationDiscovery.ListFederationDatabasesRequest\x1a\x38.Ydb.FederationDiscovery.ListFederationDatabasesResponseBl\n&tech.ydb.proto.federation.discovery.v1ZBgithub.com/ydb-platform/ydb-go-genproto/Ydb_FederationDiscovery_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb_federation_discovery_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&tech.ydb.proto.federation.discovery.v1ZBgithub.com/ydb-platform/ydb-go-genproto/Ydb_FederationDiscovery_V1'
  _FEDERATIONDISCOVERYSERVICE._serialized_start=105
  _FEDERATIONDISCOVERYSERVICE._serialized_end=276
# @@protoc_insertion_point(module_scope)
