# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_object_storage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.draft.protos import ydb_object_storage_pb2 as draft_dot_protos_dot_ydb__object__storage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/ydb_object_storage_v1.proto',
  package='Ydb.ObjectStorage.V1',
  syntax='proto3',
  serialized_options=b'\n&tech.ydb.proto.draft.object_storage.v1ZBgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_ObjectStorage_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!draft/ydb_object_storage_v1.proto\x12\x14Ydb.ObjectStorage.V1\x1a%draft/protos/ydb_object_storage.proto2e\n\x14ObjectStorageService\x12M\n\x04List\x12!.Ydb.ObjectStorage.ListingRequest\x1a\".Ydb.ObjectStorage.ListingResponseBl\n&tech.ydb.proto.draft.object_storage.v1ZBgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_ObjectStorage_V1b\x06proto3'
  ,
  dependencies=[draft_dot_protos_dot_ydb__object__storage__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_OBJECTSTORAGESERVICE = _descriptor.ServiceDescriptor(
  name='ObjectStorageService',
  full_name='Ydb.ObjectStorage.V1.ObjectStorageService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=98,
  serialized_end=199,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='Ydb.ObjectStorage.V1.ObjectStorageService.List',
    index=0,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__object__storage__pb2._LISTINGREQUEST,
    output_type=draft_dot_protos_dot_ydb__object__storage__pb2._LISTINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTSTORAGESERVICE)

DESCRIPTOR.services_by_name['ObjectStorageService'] = _OBJECTSTORAGESERVICE

# @@protoc_insertion_point(module_scope)
