# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_coordination.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v5.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v5.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v5.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprotos/ydb_coordination.proto\x12\x10Ydb.Coordination\x1a\x1aprotos/ydb_operation.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x17protos/ydb_scheme.proto\"\r\n\x0bUnsupported\"\xb2\x02\n\x06\x43onfig\x12\x0c\n\x04path\x18\x01 \x01(\t\x12 \n\x18self_check_period_millis\x18\x02 \x01(\r\x12#\n\x1bsession_grace_period_millis\x18\x03 \x01(\r\x12@\n\x15read_consistency_mode\x18\x04 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12\x42\n\x17\x61ttach_consistency_mode\x18\x05 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12M\n\x1arate_limiter_counters_mode\x18\x06 \x01(\x0e\x32).Ydb.Coordination.RateLimiterCountersMode\"g\n\x12SessionDescription\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x61ttached\x18\x04 \x01(\x08\"m\n\x10SemaphoreSession\x12\x10\n\x08order_id\x18\x05 \x01(\x04\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\xcc\x01\n\x14SemaphoreDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\r\n\x05\x63ount\x18\x07 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x11\n\tephemeral\x18\x04 \x01(\x08\x12\x32\n\x06owners\x18\x05 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\x12\x33\n\x07waiters\x18\x06 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\"\xd1\r\n\x0eSessionRequest\x12\x39\n\x04ping\x18\x01 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x39\n\x04pong\x18\x02 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x46\n\rsession_start\x18\x03 \x01(\x0b\x32-.Ydb.Coordination.SessionRequest.SessionStartH\x00\x12\x44\n\x0csession_stop\x18\x04 \x01(\x0b\x32,.Ydb.Coordination.SessionRequest.SessionStopH\x00\x12\x36\n\runsupported_5\x18\x05 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12N\n\x11\x61\x63quire_semaphore\x18\x07 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.AcquireSemaphoreH\x00\x12N\n\x11release_semaphore\x18\x08 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.ReleaseSemaphoreH\x00\x12P\n\x12\x64\x65scribe_semaphore\x18\t \x01(\x0b\x32\x32.Ydb.Coordination.SessionRequest.DescribeSemaphoreH\x00\x12L\n\x10\x63reate_semaphore\x18\n \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.CreateSemaphoreH\x00\x12L\n\x10update_semaphore\x18\x0b \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.UpdateSemaphoreH\x00\x12L\n\x10\x64\x65lete_semaphore\x18\x0c \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.DeleteSemaphoreH\x00\x12\x37\n\x0eunsupported_13\x18\r \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_14\x18\x0e \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_15\x18\x0f \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a\x85\x01\n\x0cSessionStart\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06seq_no\x18\x05 \x01(\x04\x12\x16\n\x0eprotection_key\x18\x06 \x01(\x0c\x1a\r\n\x0bSessionStop\x1ax\n\x10\x41\x63quireSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x11\n\tephemeral\x18\x06 \x01(\x08\x1a\x30\n\x10ReleaseSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x8c\x01\n\x11\x44\x65scribeSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0einclude_owners\x18\x03 \x01(\x08\x12\x17\n\x0finclude_waiters\x18\x04 \x01(\x08\x12\x12\n\nwatch_data\x18\x05 \x01(\x08\x12\x14\n\x0cwatch_owners\x18\x06 \x01(\x08\x1aL\n\x0f\x43reateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x1a=\n\x0fUpdateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x1a>\n\x0f\x44\x65leteSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x42\t\n\x07request\"\xd3\x14\n\x0fSessionResponse\x12:\n\x04ping\x18\x01 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12:\n\x04pong\x18\x02 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12<\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32).Ydb.Coordination.SessionResponse.FailureH\x00\x12K\n\x0fsession_started\x18\x04 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStartedH\x00\x12K\n\x0fsession_stopped\x18\x05 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStoppedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_7\x18\x07 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12^\n\x19\x61\x63quire_semaphore_pending\x18\x08 \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.AcquireSemaphorePendingH\x00\x12\\\n\x18\x61\x63quire_semaphore_result\x18\t \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.AcquireSemaphoreResultH\x00\x12\\\n\x18release_semaphore_result\x18\n \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.ReleaseSemaphoreResultH\x00\x12^\n\x19\x64\x65scribe_semaphore_result\x18\x0b \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.DescribeSemaphoreResultH\x00\x12`\n\x1a\x64\x65scribe_semaphore_changed\x18\x0c \x01(\x0b\x32:.Ydb.Coordination.SessionResponse.DescribeSemaphoreChangedH\x00\x12Z\n\x17\x63reate_semaphore_result\x18\r \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.CreateSemaphoreResultH\x00\x12Z\n\x17update_semaphore_result\x18\x0e \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.UpdateSemaphoreResultH\x00\x12Z\n\x17\x64\x65lete_semaphore_result\x18\x0f \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.DeleteSemaphoreResultH\x00\x12\x37\n\x0eunsupported_16\x18\x10 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_17\x18\x11 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_18\x18\x12 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a]\n\x07\x46\x61ilure\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a<\n\x0eSessionStarted\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x1a$\n\x0eSessionStopped\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x1a)\n\x17\x41\x63quireSemaphorePending\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x1a\x8e\x01\n\x16\x41\x63quireSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08\x61\x63quired\x18\x04 \x01(\x08\x1a\x8e\x01\n\x16ReleaseSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08released\x18\x04 \x01(\x08\x1a\xd9\x01\n\x17\x44\x65scribeSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x45\n\x15semaphore_description\x18\x04 \x01(\x0b\x32&.Ydb.Coordination.SemaphoreDescription\x12\x13\n\x0bwatch_added\x18\x05 \x01(\x08\x1aX\n\x18\x44\x65scribeSemaphoreChanged\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x14\n\x0c\x64\x61ta_changed\x18\x02 \x01(\x08\x12\x16\n\x0eowners_changed\x18\x03 \x01(\x08\x1a{\n\x15\x43reateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15UpdateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15\x44\x65leteSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessageB\n\n\x08response\"\x86\x01\n\x11\x43reateNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"B\n\x12\x43reateNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x01\n\x10\x41lterNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x41lterNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Z\n\x0f\x44ropNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"@\n\x10\x44ropNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"^\n\x13\x44\x65scribeNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"D\n\x14\x44\x65scribeNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x12\x44\x65scribeNodeResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config*h\n\x0f\x43onsistencyMode\x12\x1a\n\x16\x43ONSISTENCY_MODE_UNSET\x10\x00\x12\x1b\n\x17\x43ONSISTENCY_MODE_STRICT\x10\x01\x12\x1c\n\x18\x43ONSISTENCY_MODE_RELAXED\x10\x02*\x93\x01\n\x17RateLimiterCountersMode\x12$\n RATE_LIMITER_COUNTERS_MODE_UNSET\x10\x00\x12)\n%RATE_LIMITER_COUNTERS_MODE_AGGREGATED\x10\x01\x12\'\n#RATE_LIMITER_COUNTERS_MODE_DETAILED\x10\x02\x42w\n\x1btech.ydb.proto.coordinationB\x12\x43oordinationProtosP\x01Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_coordination_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033tech.ydb.proto.coordinationB\022CoordinationProtosP\001Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\370\001\001'
  _CONSISTENCYMODE._serialized_start=6137
  _CONSISTENCYMODE._serialized_end=6241
  _RATELIMITERCOUNTERSMODE._serialized_start=6244
  _RATELIMITERCOUNTERSMODE._serialized_end=6391
  _UNSUPPORTED._serialized_start=167
  _UNSUPPORTED._serialized_end=180
  _CONFIG._serialized_start=183
  _CONFIG._serialized_end=489
  _SESSIONDESCRIPTION._serialized_start=491
  _SESSIONDESCRIPTION._serialized_end=594
  _SEMAPHORESESSION._serialized_start=596
  _SEMAPHORESESSION._serialized_end=705
  _SEMAPHOREDESCRIPTION._serialized_start=708
  _SEMAPHOREDESCRIPTION._serialized_end=912
  _SESSIONREQUEST._serialized_start=915
  _SESSIONREQUEST._serialized_end=2660
  _SESSIONREQUEST_PINGPONG._serialized_start=1952
  _SESSIONREQUEST_PINGPONG._serialized_end=1978
  _SESSIONREQUEST_SESSIONSTART._serialized_start=1981
  _SESSIONREQUEST_SESSIONSTART._serialized_end=2114
  _SESSIONREQUEST_SESSIONSTOP._serialized_start=2116
  _SESSIONREQUEST_SESSIONSTOP._serialized_end=2129
  _SESSIONREQUEST_ACQUIRESEMAPHORE._serialized_start=2131
  _SESSIONREQUEST_ACQUIRESEMAPHORE._serialized_end=2251
  _SESSIONREQUEST_RELEASESEMAPHORE._serialized_start=2253
  _SESSIONREQUEST_RELEASESEMAPHORE._serialized_end=2301
  _SESSIONREQUEST_DESCRIBESEMAPHORE._serialized_start=2304
  _SESSIONREQUEST_DESCRIBESEMAPHORE._serialized_end=2444
  _SESSIONREQUEST_CREATESEMAPHORE._serialized_start=2446
  _SESSIONREQUEST_CREATESEMAPHORE._serialized_end=2522
  _SESSIONREQUEST_UPDATESEMAPHORE._serialized_start=2524
  _SESSIONREQUEST_UPDATESEMAPHORE._serialized_end=2585
  _SESSIONREQUEST_DELETESEMAPHORE._serialized_start=2587
  _SESSIONREQUEST_DELETESEMAPHORE._serialized_end=2649
  _SESSIONRESPONSE._serialized_start=2663
  _SESSIONRESPONSE._serialized_end=5306
  _SESSIONRESPONSE_PINGPONG._serialized_start=1952
  _SESSIONRESPONSE_PINGPONG._serialized_end=1978
  _SESSIONRESPONSE_FAILURE._serialized_start=4083
  _SESSIONRESPONSE_FAILURE._serialized_end=4176
  _SESSIONRESPONSE_SESSIONSTARTED._serialized_start=4178
  _SESSIONRESPONSE_SESSIONSTARTED._serialized_end=4238
  _SESSIONRESPONSE_SESSIONSTOPPED._serialized_start=4240
  _SESSIONRESPONSE_SESSIONSTOPPED._serialized_end=4276
  _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING._serialized_start=4278
  _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING._serialized_end=4319
  _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT._serialized_start=4322
  _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT._serialized_end=4464
  _SESSIONRESPONSE_RELEASESEMAPHORERESULT._serialized_start=4467
  _SESSIONRESPONSE_RELEASESEMAPHORERESULT._serialized_end=4609
  _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT._serialized_start=4612
  _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT._serialized_end=4829
  _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED._serialized_start=4831
  _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED._serialized_end=4919
  _SESSIONRESPONSE_CREATESEMAPHORERESULT._serialized_start=4921
  _SESSIONRESPONSE_CREATESEMAPHORERESULT._serialized_end=5044
  _SESSIONRESPONSE_UPDATESEMAPHORERESULT._serialized_start=5046
  _SESSIONRESPONSE_UPDATESEMAPHORERESULT._serialized_end=5169
  _SESSIONRESPONSE_DELETESEMAPHORERESULT._serialized_start=5171
  _SESSIONRESPONSE_DELETESEMAPHORERESULT._serialized_end=5294
  _CREATENODEREQUEST._serialized_start=5309
  _CREATENODEREQUEST._serialized_end=5443
  _CREATENODERESPONSE._serialized_start=5445
  _CREATENODERESPONSE._serialized_end=5511
  _ALTERNODEREQUEST._serialized_start=5514
  _ALTERNODEREQUEST._serialized_end=5647
  _ALTERNODERESPONSE._serialized_start=5649
  _ALTERNODERESPONSE._serialized_end=5714
  _DROPNODEREQUEST._serialized_start=5716
  _DROPNODEREQUEST._serialized_end=5806
  _DROPNODERESPONSE._serialized_start=5808
  _DROPNODERESPONSE._serialized_end=5872
  _DESCRIBENODEREQUEST._serialized_start=5874
  _DESCRIBENODEREQUEST._serialized_end=5968
  _DESCRIBENODERESPONSE._serialized_start=5970
  _DESCRIBENODERESPONSE._serialized_end=6038
  _DESCRIBENODERESULT._serialized_start=6040
  _DESCRIBENODERESULT._serialized_end=6135
# @@protoc_insertion_point(module_scope)
