# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/protos/ydb_dynamic_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/protos/ydb_dynamic_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%draft/protos/ydb_dynamic_config.proto\x12\x11Ydb.DynamicConfig\x1a\x1aprotos/ydb_operation.proto\"2\n\x0e\x43onfigIdentity\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\"\x8c\x01\n\x10SetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"A\n\x11SetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x14ReplaceConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"E\n\x15ReplaceConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x83\x01\n\x11\x44ropConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"B\n\x12\x44ropConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x18\x41\x64\x64VolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"I\n\x19\x41\x64\x64VolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\",\n\x0eVolatileConfig\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"M\n\x10GetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11GetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x0fGetConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12;\n\x10volatile_configs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"6\n\x16VolatileConfigMetadata\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\t\"O\n\x12GetMetadataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"C\n\x13GetMetadataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"j\n\x11GetMetadataResult\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x43\n\x10volatile_configs\x18\x02 \x03(\x0b\x32).Ydb.DynamicConfig.VolatileConfigMetadata\"\xb7\x02\n\x1bRemoveVolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x35\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentityH\x00\x12\x0f\n\x05\x66orce\x18\x03 \x01(\x08H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDeleteH\x01\x12\r\n\x03\x61ll\x18\x05 \x01(\x08H\x01\x1a\x1a\n\x0bIdsToDelete\x12\x0b\n\x03ids\x18\x01 \x03(\x04\x42\x13\n\x11\x63onsistency_checkB\n\n\x08selector\"L\n\x1cRemoveVolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x14GetNodeLabelsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0f\n\x07node_id\x18\x02 \x01(\r\")\n\tYamlLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"E\n\x15GetNodeLabelsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"C\n\x13GetNodeLabelsResult\x12,\n\x06labels\x18\x01 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"\xcc\x01\n\x14ResolveConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12,\n\x06labels\x18\x04 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"E\n\x15ResolveConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n\x13ResolveConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\"\xbb\x01\n\x17ResolveAllConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x18\n\x10verbose_response\x18\x04 \x01(\x08\"\xb6\x01\n\x0cYamlLabelExt\x12\r\n\x05label\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).Ydb.DynamicConfig.YamlLabelExt.LabelType\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\"@\n\tLabelType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\x0b\n\x07NOT_SET\x10\x02\x12\t\n\x05\x45MPTY\x10\x03\x42\x08\n\x06_value\";\n\x08LabelSet\x12/\n\x06labels\x18\x01 \x03(\x0b\x32\x1f.Ydb.DynamicConfig.YamlLabelExt\"Q\n\x0eResolvedConfig\x12/\n\nlabel_sets\x18\x01 \x03(\x0b\x32\x1b.Ydb.DynamicConfig.LabelSet\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"H\n\x18ResolveAllConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\\\n\x16ResolveAllConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x32\n\x07\x63onfigs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.ResolvedConfigBo\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_dynamic_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\370\001\001'
  _globals['_CONFIGIDENTITY']._serialized_start=88
  _globals['_CONFIGIDENTITY']._serialized_end=138
  _globals['_SETCONFIGREQUEST']._serialized_start=141
  _globals['_SETCONFIGREQUEST']._serialized_end=281
  _globals['_SETCONFIGRESPONSE']._serialized_start=283
  _globals['_SETCONFIGRESPONSE']._serialized_end=348
  _globals['_REPLACECONFIGREQUEST']._serialized_start=351
  _globals['_REPLACECONFIGREQUEST']._serialized_end=495
  _globals['_REPLACECONFIGRESPONSE']._serialized_start=497
  _globals['_REPLACECONFIGRESPONSE']._serialized_end=566
  _globals['_DROPCONFIGREQUEST']._serialized_start=569
  _globals['_DROPCONFIGREQUEST']._serialized_end=700
  _globals['_DROPCONFIGRESPONSE']._serialized_start=702
  _globals['_DROPCONFIGRESPONSE']._serialized_end=768
  _globals['_ADDVOLATILECONFIGREQUEST']._serialized_start=770
  _globals['_ADDVOLATILECONFIGREQUEST']._serialized_end=871
  _globals['_ADDVOLATILECONFIGRESPONSE']._serialized_start=873
  _globals['_ADDVOLATILECONFIGRESPONSE']._serialized_end=946
  _globals['_VOLATILECONFIG']._serialized_start=948
  _globals['_VOLATILECONFIG']._serialized_end=992
  _globals['_GETCONFIGREQUEST']._serialized_start=994
  _globals['_GETCONFIGREQUEST']._serialized_end=1071
  _globals['_GETCONFIGRESPONSE']._serialized_start=1073
  _globals['_GETCONFIGRESPONSE']._serialized_end=1138
  _globals['_GETCONFIGRESULT']._serialized_start=1141
  _globals['_GETCONFIGRESULT']._serialized_end=1288
  _globals['_VOLATILECONFIGMETADATA']._serialized_start=1290
  _globals['_VOLATILECONFIGMETADATA']._serialized_end=1344
  _globals['_GETMETADATAREQUEST']._serialized_start=1346
  _globals['_GETMETADATAREQUEST']._serialized_end=1425
  _globals['_GETMETADATARESPONSE']._serialized_start=1427
  _globals['_GETMETADATARESPONSE']._serialized_end=1494
  _globals['_GETMETADATARESULT']._serialized_start=1496
  _globals['_GETMETADATARESULT']._serialized_end=1602
  _globals['_REMOVEVOLATILECONFIGREQUEST']._serialized_start=1605
  _globals['_REMOVEVOLATILECONFIGREQUEST']._serialized_end=1916
  _globals['_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE']._serialized_start=1857
  _globals['_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE']._serialized_end=1883
  _globals['_REMOVEVOLATILECONFIGRESPONSE']._serialized_start=1918
  _globals['_REMOVEVOLATILECONFIGRESPONSE']._serialized_end=1994
  _globals['_GETNODELABELSREQUEST']._serialized_start=1996
  _globals['_GETNODELABELSREQUEST']._serialized_end=2094
  _globals['_YAMLLABEL']._serialized_start=2096
  _globals['_YAMLLABEL']._serialized_end=2137
  _globals['_GETNODELABELSRESPONSE']._serialized_start=2139
  _globals['_GETNODELABELSRESPONSE']._serialized_end=2208
  _globals['_GETNODELABELSRESULT']._serialized_start=2210
  _globals['_GETNODELABELSRESULT']._serialized_end=2277
  _globals['_RESOLVECONFIGREQUEST']._serialized_start=2280
  _globals['_RESOLVECONFIGREQUEST']._serialized_end=2484
  _globals['_RESOLVECONFIGRESPONSE']._serialized_start=2486
  _globals['_RESOLVECONFIGRESPONSE']._serialized_end=2555
  _globals['_RESOLVECONFIGRESULT']._serialized_start=2557
  _globals['_RESOLVECONFIGRESULT']._serialized_end=2594
  _globals['_RESOLVEALLCONFIGREQUEST']._serialized_start=2597
  _globals['_RESOLVEALLCONFIGREQUEST']._serialized_end=2784
  _globals['_YAMLLABELEXT']._serialized_start=2787
  _globals['_YAMLLABELEXT']._serialized_end=2969
  _globals['_YAMLLABELEXT_LABELTYPE']._serialized_start=2895
  _globals['_YAMLLABELEXT_LABELTYPE']._serialized_end=2959
  _globals['_LABELSET']._serialized_start=2971
  _globals['_LABELSET']._serialized_end=3030
  _globals['_RESOLVEDCONFIG']._serialized_start=3032
  _globals['_RESOLVEDCONFIG']._serialized_end=3113
  _globals['_RESOLVEALLCONFIGRESPONSE']._serialized_start=3115
  _globals['_RESOLVEALLCONFIGRESPONSE']._serialized_end=3187
  _globals['_RESOLVEALLCONFIGRESULT']._serialized_start=3189
  _globals['_RESOLVEALLCONFIGRESULT']._serialized_end=3281
# @@protoc_insertion_point(module_scope)
