# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb._grpc.v3.draft.protos import ydb_object_storage_pb2 as draft_dot_protos_dot_ydb__object__storage__pb2


class ObjectStorageServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/Ydb.ObjectStorage.V1.ObjectStorageService/List',
                request_serializer=draft_dot_protos_dot_ydb__object__storage__pb2.ListingRequest.SerializeToString,
                response_deserializer=draft_dot_protos_dot_ydb__object__storage__pb2.ListingResponse.FromString,
                )


class ObjectStorageServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=draft_dot_protos_dot_ydb__object__storage__pb2.ListingRequest.FromString,
                    response_serializer=draft_dot_protos_dot_ydb__object__storage__pb2.ListingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.ObjectStorage.V1.ObjectStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectStorageService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.ObjectStorage.V1.ObjectStorageService/List',
            draft_dot_protos_dot_ydb__object__storage__pb2.ListingRequest.SerializeToString,
            draft_dot_protos_dot_ydb__object__storage__pb2.ListingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
