# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_import.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_export_pb2 as protos_dot_ydb__export__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_import.proto',
  package='Ydb.Import',
  syntax='proto3',
  serialized_options=b'\n\026tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17protos/ydb_import.proto\x12\nYdb.Import\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_export.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x01\n\x0eImportProgress\"\xdb\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x16\n\x12PROGRESS_PREPARING\x10\x01\x12\x1a\n\x16PROGRESS_TRANSFER_DATA\x10\x02\x12\x1a\n\x16PROGRESS_BUILD_INDEXES\x10\x03\x12\x11\n\rPROGRESS_DONE\x10\x04\x12\x19\n\x15PROGRESS_CANCELLATION\x10\x05\x12\x16\n\x12PROGRESS_CANCELLED\x10\x06\x12\x1f\n\x1bPROGRESS_CREATE_CHANGEFEEDS\x10\x07\"\xa0\x01\n\x12ImportItemProgress\x12\x13\n\x0bparts_total\x18\x01 \x01(\r\x12\x17\n\x0fparts_completed\x18\x02 \x01(\r\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xfb\x06\n\x14ImportFromS3Settings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x06 \x03(\x0b\x32%.Ydb.Import.ImportFromS3Settings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x08 \x01(\r\x12\x0e\n\x06region\x18\t \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\n \x01(\x08\x12\x0e\n\x06no_acl\x18\x0b \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x0c \x01(\x08\x12\x15\n\rsource_prefix\x18\r \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x0e \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0f \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12M\n\x12index_filling_mode\x18\x10 \x01(\x0e\x32\x31.Ydb.Import.ImportFromS3Settings.IndexFillingMode\x12\x17\n\x0f\x65xclude_regexps\x18\x11 \x03(\t\x1aZ\n\x04Item\x12\x17\n\rsource_prefix\x18\x01 \x01(\tH\x00\x12\x15\n\x0bsource_path\x18\x03 \x01(\tH\x00\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\tB\x08\n\x06Source\".\n\x06Scheme\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\"\x90\x01\n\x10IndexFillingMode\x12\"\n\x1eINDEX_FILLING_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x18INDEX_FILLING_MODE_BUILD\x10\x01\x12\x1d\n\x19INDEX_FILLING_MODE_IMPORT\x10\x02\x12\x1b\n\x17INDEX_FILLING_MODE_AUTO\x10\x03\"\x14\n\x12ImportFromS3Result\"\xb9\x01\n\x14ImportFromS3Metadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromS3Settings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromS3Request\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromS3Response\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xf7\x02\n\x14ImportFromFsSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.Ydb.Import.ImportFromFsSettings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x04 \x01(\r\x12\x0e\n\x06no_acl\x18\x05 \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x06 \x01(\x08\x12\x18\n\x10\x64\x65stination_path\x18\x07 \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x08 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\t \x03(\t\x1a\x35\n\x04Item\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\"\x14\n\x12ImportFromFsResult\"\xb9\x01\n\x14ImportFromFsMetadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromFsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromFsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc4\x03\n\x1dListObjectsInS3ExportSettings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x06 \x03(\x0b\x32..Ydb.Import.ListObjectsInS3ExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x07 \x01(\r\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\t \x01(\x08\x12\x0e\n\x06prefix\x18\n \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0b \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x0c \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x99\x01\n\x1bListObjectsInS3ExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInS3ExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a$\n\x04Item\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInS3ExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInS3ExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInS3ExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xfe\x01\n\x1dListObjectsInFsExportSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x02 \x03(\x0b\x32..Ydb.Import.ListObjectsInFsExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x03 \x01(\r\x12;\n\x13\x65ncryption_settings\x18\x04 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x05 \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x9d\x01\n\x1bListObjectsInFsExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInFsExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a(\n\x04Item\x12\x0f\n\x07\x66s_path\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInFsExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInFsExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInFsExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\" \n\rYdbDumpFormat\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\"\x12\n\x10ImportDataResult\"\xae\x01\n\x11ImportDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\t\xa2\xe6*\x05\x18\x80\x80\x80\x08\x12-\n\x08ydb_dump\x18\x04 \x01(\x0b\x32\x19.Ydb.Import.YdbDumpFormatH\x00\x42\x08\n\x06\x66ormat\"B\n\x12ImportDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBV\n\x16tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__export__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_IMPORTPROGRESS_PROGRESS = _descriptor.EnumDescriptor(
  name='Progress',
  full_name='Ydb.Import.ImportProgress.Progress',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_PREPARING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_TRANSFER_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_BUILD_INDEXES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_DONE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_CANCELLATION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_CANCELLED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRESS_CREATE_CHANGEFEEDS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=182,
  serialized_end=401,
)
_sym_db.RegisterEnumDescriptor(_IMPORTPROGRESS_PROGRESS)

_IMPORTFROMS3SETTINGS_SCHEME = _descriptor.EnumDescriptor(
  name='Scheme',
  full_name='Ydb.Import.ImportFromS3Settings.Scheme',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1265,
  serialized_end=1311,
)
_sym_db.RegisterEnumDescriptor(_IMPORTFROMS3SETTINGS_SCHEME)

_IMPORTFROMS3SETTINGS_INDEXFILLINGMODE = _descriptor.EnumDescriptor(
  name='IndexFillingMode',
  full_name='Ydb.Import.ImportFromS3Settings.IndexFillingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDEX_FILLING_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX_FILLING_MODE_BUILD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX_FILLING_MODE_IMPORT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX_FILLING_MODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1314,
  serialized_end=1458,
)
_sym_db.RegisterEnumDescriptor(_IMPORTFROMS3SETTINGS_INDEXFILLINGMODE)


_IMPORTPROGRESS = _descriptor.Descriptor(
  name='ImportProgress',
  full_name='Ydb.Import.ImportProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMPORTPROGRESS_PROGRESS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=401,
)


_IMPORTITEMPROGRESS = _descriptor.Descriptor(
  name='ImportItemProgress',
  full_name='Ydb.Import.ImportItemProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parts_total', full_name='Ydb.Import.ImportItemProgress.parts_total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts_completed', full_name='Ydb.Import.ImportItemProgress.parts_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='Ydb.Import.ImportItemProgress.start_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='Ydb.Import.ImportItemProgress.end_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=564,
)


_IMPORTFROMS3SETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ImportFromS3Settings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_prefix', full_name='Ydb.Import.ImportFromS3Settings.Item.source_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Import.ImportFromS3Settings.Item.source_path', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Import.ImportFromS3Settings.Item.destination_path', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Source', full_name='Ydb.Import.ImportFromS3Settings.Item.Source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1173,
  serialized_end=1263,
)

_IMPORTFROMS3SETTINGS = _descriptor.Descriptor(
  name='ImportFromS3Settings',
  full_name='Ydb.Import.ImportFromS3Settings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='Ydb.Import.ImportFromS3Settings.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='Ydb.Import.ImportFromS3Settings.scheme', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='Ydb.Import.ImportFromS3Settings.bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='Ydb.Import.ImportFromS3Settings.access_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_key', full_name='Ydb.Import.ImportFromS3Settings.secret_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ImportFromS3Settings.items', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Import.ImportFromS3Settings.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Import.ImportFromS3Settings.number_of_retries', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='Ydb.Import.ImportFromS3Settings.region', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_virtual_addressing', full_name='Ydb.Import.ImportFromS3Settings.disable_virtual_addressing', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_acl', full_name='Ydb.Import.ImportFromS3Settings.no_acl', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_checksum_validation', full_name='Ydb.Import.ImportFromS3Settings.skip_checksum_validation', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_prefix', full_name='Ydb.Import.ImportFromS3Settings.source_prefix', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Import.ImportFromS3Settings.destination_path', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_settings', full_name='Ydb.Import.ImportFromS3Settings.encryption_settings', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_filling_mode', full_name='Ydb.Import.ImportFromS3Settings.index_filling_mode', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_regexps', full_name='Ydb.Import.ImportFromS3Settings.exclude_regexps', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMPORTFROMS3SETTINGS_ITEM, ],
  enum_types=[
    _IMPORTFROMS3SETTINGS_SCHEME,
    _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=1458,
)


_IMPORTFROMS3RESULT = _descriptor.Descriptor(
  name='ImportFromS3Result',
  full_name='Ydb.Import.ImportFromS3Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1460,
  serialized_end=1480,
)


_IMPORTFROMS3METADATA = _descriptor.Descriptor(
  name='ImportFromS3Metadata',
  full_name='Ydb.Import.ImportFromS3Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ImportFromS3Metadata.settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Ydb.Import.ImportFromS3Metadata.progress', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items_progress', full_name='Ydb.Import.ImportFromS3Metadata.items_progress', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1668,
)


_IMPORTFROMS3REQUEST = _descriptor.Descriptor(
  name='ImportFromS3Request',
  full_name='Ydb.Import.ImportFromS3Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Import.ImportFromS3Request.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ImportFromS3Request.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1809,
)


_IMPORTFROMS3RESPONSE = _descriptor.Descriptor(
  name='ImportFromS3Response',
  full_name='Ydb.Import.ImportFromS3Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Import.ImportFromS3Response.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1879,
)


_IMPORTFROMFSSETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ImportFromFsSettings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Import.ImportFromFsSettings.Item.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Import.ImportFromFsSettings.Item.destination_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2204,
  serialized_end=2257,
)

_IMPORTFROMFSSETTINGS = _descriptor.Descriptor(
  name='ImportFromFsSettings',
  full_name='Ydb.Import.ImportFromFsSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_path', full_name='Ydb.Import.ImportFromFsSettings.base_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ImportFromFsSettings.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Import.ImportFromFsSettings.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Import.ImportFromFsSettings.number_of_retries', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_acl', full_name='Ydb.Import.ImportFromFsSettings.no_acl', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_checksum_validation', full_name='Ydb.Import.ImportFromFsSettings.skip_checksum_validation', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Import.ImportFromFsSettings.destination_path', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_settings', full_name='Ydb.Import.ImportFromFsSettings.encryption_settings', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_regexps', full_name='Ydb.Import.ImportFromFsSettings.exclude_regexps', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMPORTFROMFSSETTINGS_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=2257,
)


_IMPORTFROMFSRESULT = _descriptor.Descriptor(
  name='ImportFromFsResult',
  full_name='Ydb.Import.ImportFromFsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2279,
)


_IMPORTFROMFSMETADATA = _descriptor.Descriptor(
  name='ImportFromFsMetadata',
  full_name='Ydb.Import.ImportFromFsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ImportFromFsMetadata.settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Ydb.Import.ImportFromFsMetadata.progress', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items_progress', full_name='Ydb.Import.ImportFromFsMetadata.items_progress', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2467,
)


_IMPORTFROMFSREQUEST = _descriptor.Descriptor(
  name='ImportFromFsRequest',
  full_name='Ydb.Import.ImportFromFsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Import.ImportFromFsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ImportFromFsRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2470,
  serialized_end=2608,
)


_IMPORTFROMFSRESPONSE = _descriptor.Descriptor(
  name='ImportFromFsResponse',
  full_name='Ydb.Import.ImportFromFsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Import.ImportFromFsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2610,
  serialized_end=2678,
)


_LISTOBJECTSINS3EXPORTSETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ListObjectsInS3ExportSettings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Import.ListObjectsInS3ExportSettings.Item.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3113,
  serialized_end=3133,
)

_LISTOBJECTSINS3EXPORTSETTINGS = _descriptor.Descriptor(
  name='ListObjectsInS3ExportSettings',
  full_name='Ydb.Import.ListObjectsInS3ExportSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='Ydb.Import.ListObjectsInS3ExportSettings.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='Ydb.Import.ListObjectsInS3ExportSettings.scheme', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='Ydb.Import.ListObjectsInS3ExportSettings.bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_key', full_name='Ydb.Import.ListObjectsInS3ExportSettings.access_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_key', full_name='Ydb.Import.ListObjectsInS3ExportSettings.secret_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ListObjectsInS3ExportSettings.items', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Import.ListObjectsInS3ExportSettings.number_of_retries', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='Ydb.Import.ListObjectsInS3ExportSettings.region', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_virtual_addressing', full_name='Ydb.Import.ListObjectsInS3ExportSettings.disable_virtual_addressing', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='Ydb.Import.ListObjectsInS3ExportSettings.prefix', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_settings', full_name='Ydb.Import.ListObjectsInS3ExportSettings.encryption_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_regexps', full_name='Ydb.Import.ListObjectsInS3ExportSettings.exclude_regexps', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTOBJECTSINS3EXPORTSETTINGS_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2681,
  serialized_end=3133,
)


_LISTOBJECTSINS3EXPORTRESULT_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ListObjectsInS3ExportResult.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='Ydb.Import.ListObjectsInS3ExportResult.Item.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Import.ListObjectsInS3ExportResult.Item.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3253,
  serialized_end=3289,
)

_LISTOBJECTSINS3EXPORTRESULT = _descriptor.Descriptor(
  name='ListObjectsInS3ExportResult',
  full_name='Ydb.Import.ListObjectsInS3ExportResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ListObjectsInS3ExportResult.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='Ydb.Import.ListObjectsInS3ExportResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTOBJECTSINS3EXPORTRESULT_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3136,
  serialized_end=3289,
)


_LISTOBJECTSINS3EXPORTREQUEST = _descriptor.Descriptor(
  name='ListObjectsInS3ExportRequest',
  full_name='Ydb.Import.ListObjectsInS3ExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Import.ListObjectsInS3ExportRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ListObjectsInS3ExportRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='Ydb.Import.ListObjectsInS3ExportRequest.page_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010<= 10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='Ydb.Import.ListObjectsInS3ExportRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3292,
  serialized_end=3501,
)


_LISTOBJECTSINS3EXPORTRESPONSE = _descriptor.Descriptor(
  name='ListObjectsInS3ExportResponse',
  full_name='Ydb.Import.ListObjectsInS3ExportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Import.ListObjectsInS3ExportResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3503,
  serialized_end=3580,
)


_LISTOBJECTSINFSEXPORTSETTINGS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ListObjectsInFsExportSettings.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Import.ListObjectsInFsExportSettings.Item.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3113,
  serialized_end=3133,
)

_LISTOBJECTSINFSEXPORTSETTINGS = _descriptor.Descriptor(
  name='ListObjectsInFsExportSettings',
  full_name='Ydb.Import.ListObjectsInFsExportSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_path', full_name='Ydb.Import.ListObjectsInFsExportSettings.base_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ListObjectsInFsExportSettings.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='Ydb.Import.ListObjectsInFsExportSettings.number_of_retries', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_settings', full_name='Ydb.Import.ListObjectsInFsExportSettings.encryption_settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_regexps', full_name='Ydb.Import.ListObjectsInFsExportSettings.exclude_regexps', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTOBJECTSINFSEXPORTSETTINGS_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3583,
  serialized_end=3837,
)


_LISTOBJECTSINFSEXPORTRESULT_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='Ydb.Import.ListObjectsInFsExportResult.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fs_path', full_name='Ydb.Import.ListObjectsInFsExportResult.Item.fs_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='db_path', full_name='Ydb.Import.ListObjectsInFsExportResult.Item.db_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3957,
  serialized_end=3997,
)

_LISTOBJECTSINFSEXPORTRESULT = _descriptor.Descriptor(
  name='ListObjectsInFsExportResult',
  full_name='Ydb.Import.ListObjectsInFsExportResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='Ydb.Import.ListObjectsInFsExportResult.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='Ydb.Import.ListObjectsInFsExportResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTOBJECTSINFSEXPORTRESULT_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3840,
  serialized_end=3997,
)


_LISTOBJECTSINFSEXPORTREQUEST = _descriptor.Descriptor(
  name='ListObjectsInFsExportRequest',
  full_name='Ydb.Import.ListObjectsInFsExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Import.ListObjectsInFsExportRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Ydb.Import.ListObjectsInFsExportRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='Ydb.Import.ListObjectsInFsExportRequest.page_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010<= 10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='Ydb.Import.ListObjectsInFsExportRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4000,
  serialized_end=4209,
)


_LISTOBJECTSINFSEXPORTRESPONSE = _descriptor.Descriptor(
  name='ListObjectsInFsExportResponse',
  full_name='Ydb.Import.ListObjectsInFsExportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Import.ListObjectsInFsExportResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4211,
  serialized_end=4288,
)


_YDBDUMPFORMAT = _descriptor.Descriptor(
  name='YdbDumpFormat',
  full_name='Ydb.Import.YdbDumpFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Import.YdbDumpFormat.columns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4290,
  serialized_end=4322,
)


_IMPORTDATARESULT = _descriptor.Descriptor(
  name='ImportDataResult',
  full_name='Ydb.Import.ImportDataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4324,
  serialized_end=4342,
)


_IMPORTDATAREQUEST = _descriptor.Descriptor(
  name='ImportDataRequest',
  full_name='Ydb.Import.ImportDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Import.ImportDataRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Import.ImportDataRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Import.ImportDataRequest.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\005\030\200\200\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ydb_dump', full_name='Ydb.Import.ImportDataRequest.ydb_dump', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='format', full_name='Ydb.Import.ImportDataRequest.format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4345,
  serialized_end=4519,
)


_IMPORTDATARESPONSE = _descriptor.Descriptor(
  name='ImportDataResponse',
  full_name='Ydb.Import.ImportDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Import.ImportDataResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4521,
  serialized_end=4587,
)

_IMPORTPROGRESS_PROGRESS.containing_type = _IMPORTPROGRESS
_IMPORTITEMPROGRESS.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_IMPORTITEMPROGRESS.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_IMPORTFROMS3SETTINGS_ITEM.containing_type = _IMPORTFROMS3SETTINGS
_IMPORTFROMS3SETTINGS_ITEM.oneofs_by_name['Source'].fields.append(
  _IMPORTFROMS3SETTINGS_ITEM.fields_by_name['source_prefix'])
_IMPORTFROMS3SETTINGS_ITEM.fields_by_name['source_prefix'].containing_oneof = _IMPORTFROMS3SETTINGS_ITEM.oneofs_by_name['Source']
_IMPORTFROMS3SETTINGS_ITEM.oneofs_by_name['Source'].fields.append(
  _IMPORTFROMS3SETTINGS_ITEM.fields_by_name['source_path'])
_IMPORTFROMS3SETTINGS_ITEM.fields_by_name['source_path'].containing_oneof = _IMPORTFROMS3SETTINGS_ITEM.oneofs_by_name['Source']
_IMPORTFROMS3SETTINGS.fields_by_name['scheme'].enum_type = _IMPORTFROMS3SETTINGS_SCHEME
_IMPORTFROMS3SETTINGS.fields_by_name['items'].message_type = _IMPORTFROMS3SETTINGS_ITEM
_IMPORTFROMS3SETTINGS.fields_by_name['encryption_settings'].message_type = protos_dot_ydb__export__pb2._ENCRYPTIONSETTINGS
_IMPORTFROMS3SETTINGS.fields_by_name['index_filling_mode'].enum_type = _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE
_IMPORTFROMS3SETTINGS_SCHEME.containing_type = _IMPORTFROMS3SETTINGS
_IMPORTFROMS3SETTINGS_INDEXFILLINGMODE.containing_type = _IMPORTFROMS3SETTINGS
_IMPORTFROMS3METADATA.fields_by_name['settings'].message_type = _IMPORTFROMS3SETTINGS
_IMPORTFROMS3METADATA.fields_by_name['progress'].enum_type = _IMPORTPROGRESS_PROGRESS
_IMPORTFROMS3METADATA.fields_by_name['items_progress'].message_type = _IMPORTITEMPROGRESS
_IMPORTFROMS3REQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_IMPORTFROMS3REQUEST.fields_by_name['settings'].message_type = _IMPORTFROMS3SETTINGS
_IMPORTFROMS3RESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_IMPORTFROMFSSETTINGS_ITEM.containing_type = _IMPORTFROMFSSETTINGS
_IMPORTFROMFSSETTINGS.fields_by_name['items'].message_type = _IMPORTFROMFSSETTINGS_ITEM
_IMPORTFROMFSSETTINGS.fields_by_name['encryption_settings'].message_type = protos_dot_ydb__export__pb2._ENCRYPTIONSETTINGS
_IMPORTFROMFSMETADATA.fields_by_name['settings'].message_type = _IMPORTFROMFSSETTINGS
_IMPORTFROMFSMETADATA.fields_by_name['progress'].enum_type = _IMPORTPROGRESS_PROGRESS
_IMPORTFROMFSMETADATA.fields_by_name['items_progress'].message_type = _IMPORTITEMPROGRESS
_IMPORTFROMFSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_IMPORTFROMFSREQUEST.fields_by_name['settings'].message_type = _IMPORTFROMFSSETTINGS
_IMPORTFROMFSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTOBJECTSINS3EXPORTSETTINGS_ITEM.containing_type = _LISTOBJECTSINS3EXPORTSETTINGS
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['scheme'].enum_type = _IMPORTFROMS3SETTINGS_SCHEME
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['items'].message_type = _LISTOBJECTSINS3EXPORTSETTINGS_ITEM
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['encryption_settings'].message_type = protos_dot_ydb__export__pb2._ENCRYPTIONSETTINGS
_LISTOBJECTSINS3EXPORTRESULT_ITEM.containing_type = _LISTOBJECTSINS3EXPORTRESULT
_LISTOBJECTSINS3EXPORTRESULT.fields_by_name['items'].message_type = _LISTOBJECTSINS3EXPORTRESULT_ITEM
_LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings'].message_type = _LISTOBJECTSINS3EXPORTSETTINGS
_LISTOBJECTSINS3EXPORTRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTOBJECTSINFSEXPORTSETTINGS_ITEM.containing_type = _LISTOBJECTSINFSEXPORTSETTINGS
_LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['items'].message_type = _LISTOBJECTSINFSEXPORTSETTINGS_ITEM
_LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['encryption_settings'].message_type = protos_dot_ydb__export__pb2._ENCRYPTIONSETTINGS
_LISTOBJECTSINFSEXPORTRESULT_ITEM.containing_type = _LISTOBJECTSINFSEXPORTRESULT
_LISTOBJECTSINFSEXPORTRESULT.fields_by_name['items'].message_type = _LISTOBJECTSINFSEXPORTRESULT_ITEM
_LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings'].message_type = _LISTOBJECTSINFSEXPORTSETTINGS
_LISTOBJECTSINFSEXPORTRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_IMPORTDATAREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_IMPORTDATAREQUEST.fields_by_name['ydb_dump'].message_type = _YDBDUMPFORMAT
_IMPORTDATAREQUEST.oneofs_by_name['format'].fields.append(
  _IMPORTDATAREQUEST.fields_by_name['ydb_dump'])
_IMPORTDATAREQUEST.fields_by_name['ydb_dump'].containing_oneof = _IMPORTDATAREQUEST.oneofs_by_name['format']
_IMPORTDATARESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['ImportProgress'] = _IMPORTPROGRESS
DESCRIPTOR.message_types_by_name['ImportItemProgress'] = _IMPORTITEMPROGRESS
DESCRIPTOR.message_types_by_name['ImportFromS3Settings'] = _IMPORTFROMS3SETTINGS
DESCRIPTOR.message_types_by_name['ImportFromS3Result'] = _IMPORTFROMS3RESULT
DESCRIPTOR.message_types_by_name['ImportFromS3Metadata'] = _IMPORTFROMS3METADATA
DESCRIPTOR.message_types_by_name['ImportFromS3Request'] = _IMPORTFROMS3REQUEST
DESCRIPTOR.message_types_by_name['ImportFromS3Response'] = _IMPORTFROMS3RESPONSE
DESCRIPTOR.message_types_by_name['ImportFromFsSettings'] = _IMPORTFROMFSSETTINGS
DESCRIPTOR.message_types_by_name['ImportFromFsResult'] = _IMPORTFROMFSRESULT
DESCRIPTOR.message_types_by_name['ImportFromFsMetadata'] = _IMPORTFROMFSMETADATA
DESCRIPTOR.message_types_by_name['ImportFromFsRequest'] = _IMPORTFROMFSREQUEST
DESCRIPTOR.message_types_by_name['ImportFromFsResponse'] = _IMPORTFROMFSRESPONSE
DESCRIPTOR.message_types_by_name['ListObjectsInS3ExportSettings'] = _LISTOBJECTSINS3EXPORTSETTINGS
DESCRIPTOR.message_types_by_name['ListObjectsInS3ExportResult'] = _LISTOBJECTSINS3EXPORTRESULT
DESCRIPTOR.message_types_by_name['ListObjectsInS3ExportRequest'] = _LISTOBJECTSINS3EXPORTREQUEST
DESCRIPTOR.message_types_by_name['ListObjectsInS3ExportResponse'] = _LISTOBJECTSINS3EXPORTRESPONSE
DESCRIPTOR.message_types_by_name['ListObjectsInFsExportSettings'] = _LISTOBJECTSINFSEXPORTSETTINGS
DESCRIPTOR.message_types_by_name['ListObjectsInFsExportResult'] = _LISTOBJECTSINFSEXPORTRESULT
DESCRIPTOR.message_types_by_name['ListObjectsInFsExportRequest'] = _LISTOBJECTSINFSEXPORTREQUEST
DESCRIPTOR.message_types_by_name['ListObjectsInFsExportResponse'] = _LISTOBJECTSINFSEXPORTRESPONSE
DESCRIPTOR.message_types_by_name['YdbDumpFormat'] = _YDBDUMPFORMAT
DESCRIPTOR.message_types_by_name['ImportDataResult'] = _IMPORTDATARESULT
DESCRIPTOR.message_types_by_name['ImportDataRequest'] = _IMPORTDATAREQUEST
DESCRIPTOR.message_types_by_name['ImportDataResponse'] = _IMPORTDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImportProgress = _reflection.GeneratedProtocolMessageType('ImportProgress', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPROGRESS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportProgress)
  })
_sym_db.RegisterMessage(ImportProgress)

ImportItemProgress = _reflection.GeneratedProtocolMessageType('ImportItemProgress', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTITEMPROGRESS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportItemProgress)
  })
_sym_db.RegisterMessage(ImportItemProgress)

ImportFromS3Settings = _reflection.GeneratedProtocolMessageType('ImportFromS3Settings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _IMPORTFROMS3SETTINGS_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Settings.Item)
    })
  ,
  'DESCRIPTOR' : _IMPORTFROMS3SETTINGS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Settings)
  })
_sym_db.RegisterMessage(ImportFromS3Settings)
_sym_db.RegisterMessage(ImportFromS3Settings.Item)

ImportFromS3Result = _reflection.GeneratedProtocolMessageType('ImportFromS3Result', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMS3RESULT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Result)
  })
_sym_db.RegisterMessage(ImportFromS3Result)

ImportFromS3Metadata = _reflection.GeneratedProtocolMessageType('ImportFromS3Metadata', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMS3METADATA,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Metadata)
  })
_sym_db.RegisterMessage(ImportFromS3Metadata)

ImportFromS3Request = _reflection.GeneratedProtocolMessageType('ImportFromS3Request', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMS3REQUEST,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Request)
  })
_sym_db.RegisterMessage(ImportFromS3Request)

ImportFromS3Response = _reflection.GeneratedProtocolMessageType('ImportFromS3Response', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMS3RESPONSE,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromS3Response)
  })
_sym_db.RegisterMessage(ImportFromS3Response)

ImportFromFsSettings = _reflection.GeneratedProtocolMessageType('ImportFromFsSettings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _IMPORTFROMFSSETTINGS_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsSettings.Item)
    })
  ,
  'DESCRIPTOR' : _IMPORTFROMFSSETTINGS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsSettings)
  })
_sym_db.RegisterMessage(ImportFromFsSettings)
_sym_db.RegisterMessage(ImportFromFsSettings.Item)

ImportFromFsResult = _reflection.GeneratedProtocolMessageType('ImportFromFsResult', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMFSRESULT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsResult)
  })
_sym_db.RegisterMessage(ImportFromFsResult)

ImportFromFsMetadata = _reflection.GeneratedProtocolMessageType('ImportFromFsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMFSMETADATA,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsMetadata)
  })
_sym_db.RegisterMessage(ImportFromFsMetadata)

ImportFromFsRequest = _reflection.GeneratedProtocolMessageType('ImportFromFsRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMFSREQUEST,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsRequest)
  })
_sym_db.RegisterMessage(ImportFromFsRequest)

ImportFromFsResponse = _reflection.GeneratedProtocolMessageType('ImportFromFsResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTFROMFSRESPONSE,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportFromFsResponse)
  })
_sym_db.RegisterMessage(ImportFromFsResponse)

ListObjectsInS3ExportSettings = _reflection.GeneratedProtocolMessageType('ListObjectsInS3ExportSettings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTSETTINGS_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportSettings.Item)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTSETTINGS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportSettings)
  })
_sym_db.RegisterMessage(ListObjectsInS3ExportSettings)
_sym_db.RegisterMessage(ListObjectsInS3ExportSettings.Item)

ListObjectsInS3ExportResult = _reflection.GeneratedProtocolMessageType('ListObjectsInS3ExportResult', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTRESULT_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportResult.Item)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTRESULT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportResult)
  })
_sym_db.RegisterMessage(ListObjectsInS3ExportResult)
_sym_db.RegisterMessage(ListObjectsInS3ExportResult.Item)

ListObjectsInS3ExportRequest = _reflection.GeneratedProtocolMessageType('ListObjectsInS3ExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTREQUEST,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportRequest)
  })
_sym_db.RegisterMessage(ListObjectsInS3ExportRequest)

ListObjectsInS3ExportResponse = _reflection.GeneratedProtocolMessageType('ListObjectsInS3ExportResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSINS3EXPORTRESPONSE,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInS3ExportResponse)
  })
_sym_db.RegisterMessage(ListObjectsInS3ExportResponse)

ListObjectsInFsExportSettings = _reflection.GeneratedProtocolMessageType('ListObjectsInFsExportSettings', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTSETTINGS_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportSettings.Item)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTSETTINGS,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportSettings)
  })
_sym_db.RegisterMessage(ListObjectsInFsExportSettings)
_sym_db.RegisterMessage(ListObjectsInFsExportSettings.Item)

ListObjectsInFsExportResult = _reflection.GeneratedProtocolMessageType('ListObjectsInFsExportResult', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTRESULT_ITEM,
    '__module__' : 'protos.ydb_import_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportResult.Item)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTRESULT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportResult)
  })
_sym_db.RegisterMessage(ListObjectsInFsExportResult)
_sym_db.RegisterMessage(ListObjectsInFsExportResult.Item)

ListObjectsInFsExportRequest = _reflection.GeneratedProtocolMessageType('ListObjectsInFsExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTREQUEST,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportRequest)
  })
_sym_db.RegisterMessage(ListObjectsInFsExportRequest)

ListObjectsInFsExportResponse = _reflection.GeneratedProtocolMessageType('ListObjectsInFsExportResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSINFSEXPORTRESPONSE,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ListObjectsInFsExportResponse)
  })
_sym_db.RegisterMessage(ListObjectsInFsExportResponse)

YdbDumpFormat = _reflection.GeneratedProtocolMessageType('YdbDumpFormat', (_message.Message,), {
  'DESCRIPTOR' : _YDBDUMPFORMAT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.YdbDumpFormat)
  })
_sym_db.RegisterMessage(YdbDumpFormat)

ImportDataResult = _reflection.GeneratedProtocolMessageType('ImportDataResult', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTDATARESULT,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportDataResult)
  })
_sym_db.RegisterMessage(ImportDataResult)

ImportDataRequest = _reflection.GeneratedProtocolMessageType('ImportDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTDATAREQUEST,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportDataRequest)
  })
_sym_db.RegisterMessage(ImportDataRequest)

ImportDataResponse = _reflection.GeneratedProtocolMessageType('ImportDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTDATARESPONSE,
  '__module__' : 'protos.ydb_import_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Import.ImportDataResponse)
  })
_sym_db.RegisterMessage(ImportDataResponse)


DESCRIPTOR._options = None
_IMPORTFROMS3SETTINGS.fields_by_name['endpoint']._options = None
_IMPORTFROMS3SETTINGS.fields_by_name['bucket']._options = None
_IMPORTFROMS3SETTINGS.fields_by_name['access_key']._options = None
_IMPORTFROMS3SETTINGS.fields_by_name['secret_key']._options = None
_IMPORTFROMS3SETTINGS.fields_by_name['description']._options = None
_IMPORTFROMS3REQUEST.fields_by_name['settings']._options = None
_IMPORTFROMFSSETTINGS.fields_by_name['base_path']._options = None
_IMPORTFROMFSSETTINGS.fields_by_name['description']._options = None
_IMPORTFROMFSREQUEST.fields_by_name['settings']._options = None
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['endpoint']._options = None
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['bucket']._options = None
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['access_key']._options = None
_LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['secret_key']._options = None
_LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings']._options = None
_LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['page_size']._options = None
_LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['base_path']._options = None
_LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings']._options = None
_LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['page_size']._options = None
_IMPORTDATAREQUEST.fields_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)
