# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/ydb_federated_query_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.draft.protos import ydb_federated_query_pb2 as draft_dot_protos_dot_ydb__federated__query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/ydb_federated_query_v1.proto',
  package='FederatedQuery.V1',
  syntax='proto3',
  serialized_options=b'\n\'tech.ydb.proto.draft.federated.query.v1ZCgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_FederatedQuery_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"draft/ydb_federated_query_v1.proto\x12\x11\x46\x65\x64\x65ratedQuery.V1\x1a&draft/protos/ydb_federated_query.proto2\xd6\x0f\n\x15\x46\x65\x64\x65ratedQueryService\x12V\n\x0b\x43reateQuery\x12\".FederatedQuery.CreateQueryRequest\x1a#.FederatedQuery.CreateQueryResponse\x12V\n\x0bListQueries\x12\".FederatedQuery.ListQueriesRequest\x1a#.FederatedQuery.ListQueriesResponse\x12\\\n\rDescribeQuery\x12$.FederatedQuery.DescribeQueryRequest\x1a%.FederatedQuery.DescribeQueryResponse\x12_\n\x0eGetQueryStatus\x12%.FederatedQuery.GetQueryStatusRequest\x1a&.FederatedQuery.GetQueryStatusResponse\x12V\n\x0bModifyQuery\x12\".FederatedQuery.ModifyQueryRequest\x1a#.FederatedQuery.ModifyQueryResponse\x12V\n\x0b\x44\x65leteQuery\x12\".FederatedQuery.DeleteQueryRequest\x1a#.FederatedQuery.DeleteQueryResponse\x12Y\n\x0c\x43ontrolQuery\x12#.FederatedQuery.ControlQueryRequest\x1a$.FederatedQuery.ControlQueryResponse\x12\\\n\rGetResultData\x12$.FederatedQuery.GetResultDataRequest\x1a%.FederatedQuery.GetResultDataResponse\x12M\n\x08ListJobs\x12\x1f.FederatedQuery.ListJobsRequest\x1a .FederatedQuery.ListJobsResponse\x12V\n\x0b\x44\x65scribeJob\x12\".FederatedQuery.DescribeJobRequest\x1a#.FederatedQuery.DescribeJobResponse\x12\x65\n\x10\x43reateConnection\x12\'.FederatedQuery.CreateConnectionRequest\x1a(.FederatedQuery.CreateConnectionResponse\x12\x62\n\x0fListConnections\x12&.FederatedQuery.ListConnectionsRequest\x1a\'.FederatedQuery.ListConnectionsResponse\x12k\n\x12\x44\x65scribeConnection\x12).FederatedQuery.DescribeConnectionRequest\x1a*.FederatedQuery.DescribeConnectionResponse\x12\x65\n\x10ModifyConnection\x12\'.FederatedQuery.ModifyConnectionRequest\x1a(.FederatedQuery.ModifyConnectionResponse\x12\x65\n\x10\x44\x65leteConnection\x12\'.FederatedQuery.DeleteConnectionRequest\x1a(.FederatedQuery.DeleteConnectionResponse\x12_\n\x0eTestConnection\x12%.FederatedQuery.TestConnectionRequest\x1a&.FederatedQuery.TestConnectionResponse\x12\\\n\rCreateBinding\x12$.FederatedQuery.CreateBindingRequest\x1a%.FederatedQuery.CreateBindingResponse\x12Y\n\x0cListBindings\x12#.FederatedQuery.ListBindingsRequest\x1a$.FederatedQuery.ListBindingsResponse\x12\x62\n\x0f\x44\x65scribeBinding\x12&.FederatedQuery.DescribeBindingRequest\x1a\'.FederatedQuery.DescribeBindingResponse\x12\\\n\rModifyBinding\x12$.FederatedQuery.ModifyBindingRequest\x1a%.FederatedQuery.ModifyBindingResponse\x12\\\n\rDeleteBinding\x12$.FederatedQuery.DeleteBindingRequest\x1a%.FederatedQuery.DeleteBindingResponseBn\n\'tech.ydb.proto.draft.federated.query.v1ZCgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_FederatedQuery_V1b\x06proto3'
  ,
  dependencies=[draft_dot_protos_dot_ydb__federated__query__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_FEDERATEDQUERYSERVICE = _descriptor.ServiceDescriptor(
  name='FederatedQueryService',
  full_name='FederatedQuery.V1.FederatedQueryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=98,
  serialized_end=2104,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateQuery',
    full_name='FederatedQuery.V1.FederatedQueryService.CreateQuery',
    index=0,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATEQUERYREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATEQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListQueries',
    full_name='FederatedQuery.V1.FederatedQueryService.ListQueries',
    index=1,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTQUERIESREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTQUERIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeQuery',
    full_name='FederatedQuery.V1.FederatedQueryService.DescribeQuery',
    index=2,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEQUERYREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetQueryStatus',
    full_name='FederatedQuery.V1.FederatedQueryService.GetQueryStatus',
    index=3,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._GETQUERYSTATUSREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._GETQUERYSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyQuery',
    full_name='FederatedQuery.V1.FederatedQueryService.ModifyQuery',
    index=4,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYQUERYREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteQuery',
    full_name='FederatedQuery.V1.FederatedQueryService.DeleteQuery',
    index=5,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETEQUERYREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETEQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ControlQuery',
    full_name='FederatedQuery.V1.FederatedQueryService.ControlQuery',
    index=6,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._CONTROLQUERYREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._CONTROLQUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResultData',
    full_name='FederatedQuery.V1.FederatedQueryService.GetResultData',
    index=7,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._GETRESULTDATAREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._GETRESULTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListJobs',
    full_name='FederatedQuery.V1.FederatedQueryService.ListJobs',
    index=8,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTJOBSREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeJob',
    full_name='FederatedQuery.V1.FederatedQueryService.DescribeJob',
    index=9,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEJOBREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateConnection',
    full_name='FederatedQuery.V1.FederatedQueryService.CreateConnection',
    index=10,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATECONNECTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATECONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListConnections',
    full_name='FederatedQuery.V1.FederatedQueryService.ListConnections',
    index=11,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTCONNECTIONSREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTCONNECTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeConnection',
    full_name='FederatedQuery.V1.FederatedQueryService.DescribeConnection',
    index=12,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBECONNECTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBECONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyConnection',
    full_name='FederatedQuery.V1.FederatedQueryService.ModifyConnection',
    index=13,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYCONNECTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYCONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteConnection',
    full_name='FederatedQuery.V1.FederatedQueryService.DeleteConnection',
    index=14,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETECONNECTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETECONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestConnection',
    full_name='FederatedQuery.V1.FederatedQueryService.TestConnection',
    index=15,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._TESTCONNECTIONREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._TESTCONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBinding',
    full_name='FederatedQuery.V1.FederatedQueryService.CreateBinding',
    index=16,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATEBINDINGREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._CREATEBINDINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBindings',
    full_name='FederatedQuery.V1.FederatedQueryService.ListBindings',
    index=17,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTBINDINGSREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._LISTBINDINGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeBinding',
    full_name='FederatedQuery.V1.FederatedQueryService.DescribeBinding',
    index=18,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEBINDINGREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DESCRIBEBINDINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyBinding',
    full_name='FederatedQuery.V1.FederatedQueryService.ModifyBinding',
    index=19,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYBINDINGREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._MODIFYBINDINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBinding',
    full_name='FederatedQuery.V1.FederatedQueryService.DeleteBinding',
    index=20,
    containing_service=None,
    input_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETEBINDINGREQUEST,
    output_type=draft_dot_protos_dot_ydb__federated__query__pb2._DELETEBINDINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEDERATEDQUERYSERVICE)

DESCRIPTOR.services_by_name['FederatedQueryService'] = _FEDERATEDQUERYSERVICE

# @@protoc_insertion_point(module_scope)
