from protos import ydb_rate_limiter_pb2 as _ydb_rate_limiter_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
