# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v3.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v3.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v3.protos import ydb_topic_pb2 as protos_dot_ydb__topic__pb2
from ydb._grpc.v3.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_table.proto',
  package='Ydb.Table',
  syntax='proto3',
  serialized_options=b'\n\024tech.ydb.proto.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16protos/ydb_table.proto\x12\tYdb.Table\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_common.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x16protos/ydb_value.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x16protos/ydb_topic.proto\x1a\x18protos/ydb_formats.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Q\n\x14\x43reateSessionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x43reateSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\")\n\x13\x43reateSessionResult\x12\x12\n\nsession_id\x18\x01 \x01(\t\"e\n\x14\x44\x65leteSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15\x44\x65leteSessionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\r\n\x0bGlobalIndex\"\x12\n\x10GlobalAsyncIndex\"\x13\n\x11GlobalUniqueIndex\"\xf7\x01\n\nTableIndex\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x04 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12;\n\x13global_unique_index\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.GlobalUniqueIndexH\x00\x12\x14\n\x0c\x64\x61ta_columns\x18\x05 \x03(\tB\x06\n\x04type\"\x98\x03\n\x15TableIndexDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rindex_columns\x18\x02 \x03(\t\x12.\n\x0cglobal_index\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.GlobalIndexH\x00\x12\x39\n\x12global_async_index\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.GlobalAsyncIndexH\x00\x12;\n\x13global_unique_index\x18\x08 \x01(\x0b\x32\x1c.Ydb.Table.GlobalUniqueIndexH\x00\x12\x37\n\x06status\x18\x04 \x01(\x0e\x32\'.Ydb.Table.TableIndexDescription.Status\x12\x14\n\x0c\x64\x61ta_columns\x18\x06 \x03(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x04\"G\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x13\n\x0fSTATUS_BUILDING\x10\x02\x42\x06\n\x04type\"\xdd\x01\n\x0fIndexBuildState\"\xc9\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_PREPARING\x10\x01\x12\x1a\n\x16STATE_TRANSFERING_DATA\x10\x02\x12\x12\n\x0eSTATE_APPLYING\x10\x03\x12\x0e\n\nSTATE_DONE\x10\x04\x12\x16\n\x12STATE_CANCELLATION\x10\x05\x12\x13\n\x0fSTATE_CANCELLED\x10\x06\x12\x13\n\x0fSTATE_REJECTION\x10\x07\x12\x12\n\x0eSTATE_REJECTED\x10\x08\"K\n\x15IndexBuildDescription\x12\x0c\n\x04path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\"\x8e\x01\n\x12IndexBuildMetadata\x12\x35\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32 .Ydb.Table.IndexBuildDescription\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12\x10\n\x08progress\x18\x03 \x01(\x02\"\x9a\x01\n\x0e\x43hangefeedMode\"\x87\x01\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_KEYS_ONLY\x10\x01\x12\x10\n\x0cMODE_UPDATES\x10\x02\x12\x12\n\x0eMODE_NEW_IMAGE\x10\x03\x12\x12\n\x0eMODE_OLD_IMAGE\x10\x04\x12\x1b\n\x17MODE_NEW_AND_OLD_IMAGES\x10\x05\"\x81\x01\n\x10\x43hangefeedFormat\"m\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\x12 \n\x1c\x46ORMAT_DYNAMODB_STREAMS_JSON\x10\x02\x12\x18\n\x14\x46ORMAT_DEBEZIUM_JSON\x10\x03\"\x8e\x04\n\nChangefeed\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\x12\x14\n\x0cinitial_scan\x18\x06 \x01(\x08\x12R\n\nattributes\x18\x07 \x03(\x0b\x32%.Ydb.Table.Changefeed.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x1b\n\naws_region\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12?\n\x1cresolved_timestamps_interval\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x1btopic_partitioning_settings\x18\n \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x04\n\x15\x43hangefeedDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.Ydb.Table.ChangefeedMode.Mode\x12\x32\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\".Ydb.Table.ChangefeedFormat.Format\x12\x35\n\x05state\x18\x04 \x01(\x0e\x32&.Ydb.Table.ChangefeedDescription.State\x12\x1a\n\x12virtual_timestamps\x18\x05 \x01(\x08\x12\x44\n\nattributes\x18\x06 \x03(\x0b\x32\x30.Ydb.Table.ChangefeedDescription.AttributesEntry\x12\x12\n\naws_region\x18\x07 \x01(\t\x12?\n\x1cresolved_timestamps_interval\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_ENABLED\x10\x01\x12\x12\n\x0eSTATE_DISABLED\x10\x02\x12\x16\n\x12STATE_INITIAL_SCAN\x10\x03\"\x1c\n\x0bStoragePool\x12\r\n\x05media\x18\x01 \x01(\t\"\xaa\x02\n\rStoragePolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12&\n\x06syslog\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12#\n\x03log\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12$\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x06 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x36\n\x0f\x63olumn_families\x18\x07 \x03(\x0b\x32\x1d.Ydb.Table.ColumnFamilyPolicy\"\xb1\x02\n\x12\x43olumnFamilyPolicy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x03 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12>\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32).Ydb.Table.ColumnFamilyPolicy.Compression\"L\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x0e\n\nCOMPRESSED\x10\x02\"\'\n\x10\x43ompactionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\";\n\x12\x45xplicitPartitions\x12%\n\x0csplit_points\x18\x01 \x03(\x0b\x32\x0f.Ydb.TypedValue\"S\n\x0ePartitionStats\x12\x15\n\rrows_estimate\x18\x01 \x01(\x04\x12\x12\n\nstore_size\x18\x02 \x01(\x04\x12\x16\n\x0eleader_node_id\x18\x03 \x01(\r\"\xe9\x01\n\nTableStats\x12\x32\n\x0fpartition_stats\x18\x01 \x03(\x0b\x32\x19.Ydb.Table.PartitionStats\x12\x15\n\rrows_estimate\x18\x02 \x01(\x04\x12\x12\n\nstore_size\x18\x03 \x01(\x04\x12\x12\n\npartitions\x18\x04 \x01(\x04\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11modification_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdc\x02\n\x12PartitioningPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12O\n\x11\x61uto_partitioning\x18\x02 \x01(\x0e\x32\x34.Ydb.Table.PartitioningPolicy.AutoPartitioningPolicy\x12\x1c\n\x12uniform_partitions\x18\x03 \x01(\x04H\x00\x12<\n\x13\x65xplicit_partitions\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\"v\n\x16\x41utoPartitioningPolicy\x12(\n$AUTO_PARTITIONING_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0e\n\nAUTO_SPLIT\x10\x02\x12\x14\n\x10\x41UTO_SPLIT_MERGE\x10\x03\x42\x0c\n\npartitions\"&\n\x0f\x45xecutionPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xb1\x01\n\x11ReplicationPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x16\n\x0ereplicas_count\x18\x02 \x01(\r\x12=\n\x1c\x63reate_per_availability_zone\x18\x03 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x30\n\x0f\x61llow_promotion\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"$\n\rCachingPolicy\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\"\xeb\x02\n\x0cTableProfile\x12\x13\n\x0bpreset_name\x18\x01 \x01(\t\x12\x30\n\x0estorage_policy\x18\x02 \x01(\x0b\x32\x18.Ydb.Table.StoragePolicy\x12\x36\n\x11\x63ompaction_policy\x18\x03 \x01(\x0b\x32\x1b.Ydb.Table.CompactionPolicy\x12:\n\x13partitioning_policy\x18\x04 \x01(\x0b\x32\x1d.Ydb.Table.PartitioningPolicy\x12\x34\n\x10\x65xecution_policy\x18\x05 \x01(\x0b\x32\x1a.Ydb.Table.ExecutionPolicy\x12\x38\n\x12replication_policy\x18\x06 \x01(\x0b\x32\x1c.Ydb.Table.ReplicationPolicy\x12\x30\n\x0e\x63\x61\x63hing_policy\x18\x07 \x01(\x0b\x32\x18.Ydb.Table.CachingPolicy\"\xaa\x03\n\x13SequenceDescription\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmin_value\x18\x02 \x01(\x12H\x01\x88\x01\x01\x12\x16\n\tmax_value\x18\x03 \x01(\x12H\x02\x88\x01\x01\x12\x18\n\x0bstart_value\x18\x04 \x01(\x12H\x03\x88\x01\x01\x12\x12\n\x05\x63\x61\x63he\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tincrement\x18\x06 \x01(\x12H\x05\x88\x01\x01\x12\x12\n\x05\x63ycle\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12;\n\x07set_val\x18\x08 \x01(\x0b\x32%.Ydb.Table.SequenceDescription.SetValH\x07\x88\x01\x01\x1aV\n\x06SetVal\x12\x17\n\nnext_value\x18\x01 \x01(\x12H\x00\x88\x01\x01\x12\x16\n\tnext_used\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\r\n\x0b_next_valueB\x0c\n\n_next_usedB\x07\n\x05_nameB\x0c\n\n_min_valueB\x0c\n\n_max_valueB\x0e\n\x0c_start_valueB\x08\n\x06_cacheB\x0c\n\n_incrementB\x08\n\x06_cycleB\n\n\x08_set_val\"\xda\x01\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12\x15\n\x08not_null\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\'\n\x0c\x66rom_literal\x18\x05 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x37\n\rfrom_sequence\x18\x06 \x01(\x0b\x32\x1e.Ydb.Table.SequenceDescriptionH\x00\x42\x0f\n\rdefault_valueB\x0b\n\t_not_null\"O\n\x1a\x44\x61teTypeColumnModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpire_after_seconds\x18\x02 \x01(\r\"\x8e\x02\n\x1fValueSinceUnixEpochModeSettings\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x44\n\x0b\x63olumn_unit\x18\x02 \x01(\x0e\x32/.Ydb.Table.ValueSinceUnixEpochModeSettings.Unit\x12\x1c\n\x14\x65xpire_after_seconds\x18\x03 \x01(\r\"r\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNIT_SECONDS\x10\x01\x12\x15\n\x11UNIT_MILLISECONDS\x10\x02\x12\x15\n\x11UNIT_MICROSECONDS\x10\x03\x12\x14\n\x10UNIT_NANOSECONDS\x10\x04\"\xc4\x01\n\x0bTtlSettings\x12\x41\n\x10\x64\x61te_type_column\x18\x01 \x01(\x0b\x32%.Ydb.Table.DateTypeColumnModeSettingsH\x00\x12L\n\x16value_since_unix_epoch\x18\x02 \x01(\x0b\x32*.Ydb.Table.ValueSinceUnixEpochModeSettingsH\x00\x12\x1c\n\x14run_interval_seconds\x18\x03 \x01(\rB\x06\n\x04mode\"\xda\x01\n\x0fStorageSettings\x12\x32\n\x12tablet_commit_log0\x18\x01 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x32\n\x12tablet_commit_log1\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12(\n\x08\x65xternal\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x35\n\x14store_external_blobs\x18\x05 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\x84\x02\n\x0c\x43olumnFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.StoragePool\x12\x38\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32#.Ydb.Table.ColumnFamily.Compression\x12/\n\x0ekeep_in_memory\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"U\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPRESSION_NONE\x10\x01\x12\x13\n\x0f\x43OMPRESSION_LZ4\x10\x02\"\xf7\x01\n\x14PartitioningSettings\x12\x14\n\x0cpartition_by\x18\x01 \x03(\t\x12\x35\n\x14partitioning_by_size\x18\x02 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11partition_size_mb\x18\x03 \x01(\x04\x12\x35\n\x14partitioning_by_load\x18\x04 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x1c\n\x14min_partitions_count\x18\x06 \x01(\x04\x12\x1c\n\x14max_partitions_count\x18\x07 \x01(\x04J\x04\x08\x05\x10\x06\"C\n\x16\x41zReadReplicasSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13read_replicas_count\x18\x02 \x01(\x04\"_\n\x17\x43lusterReplicasSettings\x12\x44\n\x19\x61z_read_replicas_settings\x18\x02 \x03(\x0b\x32!.Ydb.Table.AzReadReplicasSettings\"t\n\x14ReadReplicasSettings\x12$\n\x1aper_az_read_replicas_count\x18\x01 \x01(\x04H\x00\x12$\n\x1a\x61ny_az_read_replicas_count\x18\x02 \x01(\x04H\x00\x42\n\n\x08settingsJ\x04\x08\x03\x10\x04\"\xaa\x07\n\x12\x43reateTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x04 \x03(\t\x12(\n\x07profile\x18\x05 \x01(\x0b\x32\x17.Ydb.Table.TableProfile\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\x07indexes\x18\x07 \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12,\n\x0cttl_settings\x18\x08 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\t \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\n \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12Z\n\nattributes\x18\x0b \x03(\x0b\x32-.Ydb.Table.CreateTableRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x19\n\x11\x63ompaction_policy\x18\x0c \x01(\t\x12\x1c\n\x12uniform_partitions\x18\r \x01(\x04H\x00\x12:\n\x11partition_at_keys\x18\x0e \x01(\x0b\x32\x1d.Ydb.Table.ExplicitPartitionsH\x00\x12>\n\x15partitioning_settings\x18\x0f \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\x10 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x11 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x0f\n\x07tiering\x18\x12 \x01(\t\x12\x11\n\ttemporary\x18\x13 \x01(\x08\x12(\n\nstore_type\x18\x14 \x01(\x0e\x32\x14.Ydb.Table.StoreType\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\npartitions\"C\n\x13\x43reateTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"u\n\x10\x44ropTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParamsJ\x04\x08\x03\x10\x04\"A\n\x11\x44ropTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameIndexItem\x12\x13\n\x0bsource_name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_name\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x95\t\n\x11\x41lterTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12*\n\x0b\x61\x64\x64_columns\x18\x03 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x14\n\x0c\x64rop_columns\x18\x04 \x03(\t\x12\x39\n\x10operation_params\x18\x05 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\ralter_columns\x18\x06 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x32\n\x10set_ttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12\x33\n\x11\x64rop_ttl_settings\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x0b\x61\x64\x64_indexes\x18\t \x03(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x14\n\x0c\x64rop_indexes\x18\n \x03(\t\x12:\n\x16\x61lter_storage_settings\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x34\n\x13\x61\x64\x64_column_families\x18\x0c \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x36\n\x15\x61lter_column_families\x18\r \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12`\n\x10\x61lter_attributes\x18\x0e \x03(\x0b\x32\x31.Ydb.Table.AlterTableRequest.AlterAttributesEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x1d\n\x15set_compaction_policy\x18\x0f \x01(\t\x12\x44\n\x1b\x61lter_partitioning_settings\x18\x10 \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x35\n\x14set_key_bloom_filter\x18\x11 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x43\n\x1aset_read_replicas_settings\x18\x12 \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12.\n\x0f\x61\x64\x64_changefeeds\x18\x13 \x03(\x0b\x32\x15.Ydb.Table.Changefeed\x12\x18\n\x10\x64rop_changefeeds\x18\x14 \x03(\t\x12\x32\n\x0erename_indexes\x18\x15 \x03(\x0b\x32\x1a.Ydb.Table.RenameIndexItem\x12\x15\n\x0bset_tiering\x18\x16 \x01(\tH\x01\x12.\n\x0c\x64rop_tiering\x18\x17 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nttl_actionB\x10\n\x0etiering_action\"B\n\x12\x41lterTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x10\x43opyTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x43opyTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"T\n\rCopyTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x14\n\x0comit_indexes\x18\x03 \x01(\x08\"\x8c\x01\n\x11\x43opyTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12(\n\x06tables\x18\x03 \x03(\x0b\x32\x18.Ydb.Table.CopyTableItem\"B\n\x12\x43opyTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x0fRenameTableItem\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1b\n\x13replace_destination\x18\x03 \x01(\x08\"\x90\x01\n\x13RenameTablesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12*\n\x06tables\x18\x03 \x03(\x0b\x32\x1a.Ydb.Table.RenameTableItem\"D\n\x14RenameTablesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xf5\x01\n\x14\x44\x65scribeTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x04 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18include_shard_key_bounds\x18\x05 \x01(\x08\x12\x1b\n\x13include_table_stats\x18\x06 \x01(\x08\x12\x1f\n\x17include_partition_stats\x18\x07 \x01(\x08\x12 \n\x18include_shard_nodes_info\x18\t \x01(\x08\"E\n\x15\x44\x65scribeTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc9\x06\n\x13\x44\x65scribeTableResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12&\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x03 \x03(\t\x12)\n\x10shard_key_bounds\x18\x04 \x03(\x0b\x32\x0f.Ydb.TypedValue\x12\x31\n\x07indexes\x18\x05 \x03(\x0b\x32 .Ydb.Table.TableIndexDescription\x12*\n\x0btable_stats\x18\x06 \x01(\x0b\x32\x15.Ydb.Table.TableStats\x12,\n\x0cttl_settings\x18\x07 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\x12\x34\n\x10storage_settings\x18\x08 \x01(\x0b\x32\x1a.Ydb.Table.StorageSettings\x12\x30\n\x0f\x63olumn_families\x18\t \x03(\x0b\x32\x17.Ydb.Table.ColumnFamily\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Table.DescribeTableResult.AttributesEntry\x12>\n\x15partitioning_settings\x18\x0c \x01(\x0b\x32\x1f.Ydb.Table.PartitioningSettings\x12\x31\n\x10key_bloom_filter\x18\r \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12?\n\x16read_replicas_settings\x18\x0e \x01(\x0b\x32\x1f.Ydb.Table.ReadReplicasSettings\x12\x35\n\x0b\x63hangefeeds\x18\x0f \x03(\x0b\x32 .Ydb.Table.ChangefeedDescription\x12\x0f\n\x07tiering\x18\x10 \x01(\t\x12\x11\n\ttemporary\x18\x11 \x01(\x08\x12(\n\nstore_type\x18\x12 \x01(\x0e\x32\x14.Ydb.Table.StoreType\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0c\"2\n\x05Query\x12\x12\n\x08yql_text\x18\x01 \x01(\tH\x00\x12\x0c\n\x02id\x18\x02 \x01(\tH\x00\x42\x07\n\x05query\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x18\n\x16SnapshotRWModeSettings\"\xdd\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Table.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Table.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Table.SnapshotModeSettingsH\x00\x12@\n\x13snapshot_read_write\x18\x05 \x01(\x0b\x32!.Ydb.Table.SnapshotRWModeSettingsH\x00\x42\t\n\x07tx_mode\"{\n\x12TransactionControl\x12\x0f\n\x05tx_id\x18\x01 \x01(\tH\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\")\n\x10QueryCachePolicy\x12\x15\n\rkeep_in_cache\x18\x01 \x01(\x08\"\xb1\x01\n\x14QueryStatsCollection\"\x98\x01\n\x04Mode\x12 \n\x1cSTATS_COLLECTION_UNSPECIFIED\x10\x00\x12\x19\n\x15STATS_COLLECTION_NONE\x10\x01\x12\x1a\n\x16STATS_COLLECTION_BASIC\x10\x02\x12\x19\n\x15STATS_COLLECTION_FULL\x10\x03\x12\x1c\n\x18STATS_COLLECTION_PROFILE\x10\x04\"\xbe\x03\n\x17\x45xecuteDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x31\n\ntx_control\x18\x02 \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteDataQueryRequest.ParametersEntry\x12\x37\n\x12query_cache_policy\x18\x05 \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x39\n\x10operation_params\x18\x06 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x07 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"H\n\x18\x45xecuteDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"|\n\x19\x45xecuteSchemeQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"J\n\x1a\x45xecuteSchemeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1d\n\x0fTransactionMeta\x12\n\n\x02id\x18\x01 \x01(\t\"\x9f\x01\n\tQueryMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x43\n\x10parameters_types\x18\x02 \x03(\x0b\x32).Ydb.Table.QueryMeta.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"\xc1\x01\n\x12\x45xecuteQueryResult\x12#\n\x0bresult_sets\x18\x01 \x03(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x02 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12(\n\nquery_meta\x18\x03 \x01(\x0b\x32\x14.Ydb.Table.QueryMeta\x12/\n\x0bquery_stats\x18\x04 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"\x9c\x01\n\x17\x45xplainDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18\x63ollect_full_diagnostics\x18\x04 \x01(\x08\"H\n\x18\x45xplainDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"[\n\x12\x45xplainQueryResult\x12\x11\n\tquery_ast\x18\x01 \x01(\t\x12\x12\n\nquery_plan\x18\x02 \x01(\t\x12\x1e\n\x16query_full_diagnostics\x18\x03 \x01(\t\"z\n\x17PrepareDataQueryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08yql_text\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18PrepareDataQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x12PrepareQueryResult\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12L\n\x10parameters_types\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.PrepareQueryResult.ParametersTypesEntry\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\"a\n\x10KeepAliveRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11KeepAliveResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb7\x01\n\x0fKeepAliveResult\x12@\n\x0esession_status\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\"b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02\"\x9d\x01\n\x17\x42\x65ginTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Table.TransactionSettings\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"H\n\x18\x42\x65ginTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x16\x42\x65ginTransactionResult\x12+\n\x07tx_meta\x18\x01 \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\"\xb5\x01\n\x18\x43ommitTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\rcollect_stats\x18\x04 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\"I\n\x19\x43ommitTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x17\x43ommitTransactionResult\x12/\n\x0bquery_stats\x18\x01 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"z\n\x1aRollbackTransactionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"K\n\x1bRollbackTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x98\x01\n\x18StoragePolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.StoragePolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1b\x43ompactionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06labels\x18\x02 \x03(\x0b\x32\x32.Ydb.Table.CompactionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x1dPartitioningPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x06labels\x18\x02 \x03(\x0b\x32\x34.Ydb.Table.PartitioningPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1a\x45xecutionPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Table.ExecutionPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x1cReplicationPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x06labels\x18\x02 \x03(\x0b\x32\x33.Ydb.Table.ReplicationPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x18\x43\x61\x63hingPolicyDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06labels\x18\x02 \x03(\x0b\x32/.Ydb.Table.CachingPolicyDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x04\n\x17TableProfileDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x06labels\x18\x02 \x03(\x0b\x32..Ydb.Table.TableProfileDescription.LabelsEntry\x12\x1e\n\x16\x64\x65\x66\x61ult_storage_policy\x18\x03 \x01(\t\x12 \n\x18\x61llowed_storage_policies\x18\x04 \x03(\t\x12!\n\x19\x64\x65\x66\x61ult_compaction_policy\x18\x05 \x01(\t\x12#\n\x1b\x61llowed_compaction_policies\x18\x06 \x03(\t\x12#\n\x1b\x64\x65\x66\x61ult_partitioning_policy\x18\x07 \x01(\t\x12%\n\x1d\x61llowed_partitioning_policies\x18\x08 \x03(\t\x12 \n\x18\x64\x65\x66\x61ult_execution_policy\x18\t \x01(\t\x12\"\n\x1a\x61llowed_execution_policies\x18\n \x03(\t\x12\"\n\x1a\x64\x65\x66\x61ult_replication_policy\x18\x0b \x01(\t\x12$\n\x1c\x61llowed_replication_policies\x18\x0c \x03(\t\x12\x1e\n\x16\x64\x65\x66\x61ult_caching_policy\x18\r \x01(\t\x12 \n\x18\x61llowed_caching_policies\x18\x0e \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"X\n\x1b\x44\x65scribeTableOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"L\n\x1c\x44\x65scribeTableOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x99\x04\n\x1a\x44\x65scribeTableOptionsResult\x12\x41\n\x15table_profile_presets\x18\x01 \x03(\x0b\x32\".Ydb.Table.TableProfileDescription\x12\x43\n\x16storage_policy_presets\x18\x02 \x03(\x0b\x32#.Ydb.Table.StoragePolicyDescription\x12I\n\x19\x63ompaction_policy_presets\x18\x03 \x03(\x0b\x32&.Ydb.Table.CompactionPolicyDescription\x12M\n\x1bpartitioning_policy_presets\x18\x04 \x03(\x0b\x32(.Ydb.Table.PartitioningPolicyDescription\x12G\n\x18\x65xecution_policy_presets\x18\x05 \x03(\x0b\x32%.Ydb.Table.ExecutionPolicyDescription\x12K\n\x1areplication_policy_presets\x18\x06 \x03(\x0b\x32\'.Ydb.Table.ReplicationPolicyDescription\x12\x43\n\x16\x63\x61\x63hing_policy_presets\x18\x07 \x03(\x0b\x32#.Ydb.Table.CachingPolicyDescription\"\xc0\x01\n\x08KeyRange\x12\"\n\x07greater\x18\x01 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12+\n\x10greater_or_equal\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x00\x12\x1f\n\x04less\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x12(\n\rless_or_equal\x18\x04 \x01(\x0b\x32\x0f.Ydb.TypedValueH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"\xb8\x02\n\x10ReadTableRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12&\n\tkey_range\x18\x03 \x01(\x0b\x32\x13.Ydb.Table.KeyRange\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12\x0f\n\x07ordered\x18\x05 \x01(\x08\x12\x11\n\trow_limit\x18\x06 \x01(\x04\x12-\n\x0cuse_snapshot\x18\x07 \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\x12\x19\n\x11\x62\x61tch_limit_bytes\x18\x08 \x01(\x04\x12\x18\n\x10\x62\x61tch_limit_rows\x18\t \x01(\x04\x12\x41\n return_not_null_data_as_optional\x18\n \x01(\x0e\x32\x17.Ydb.FeatureFlag.Status\"\xbc\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x08snapshot\x18\x04 \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\x12*\n\x06result\x18\x03 \x01(\x0b\x32\x1a.Ydb.Table.ReadTableResult\"5\n\x0fReadTableResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"c\n\x0fReadRowsRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1d\n\x04keys\x18\x03 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\"\x8a\x01\n\x10ReadRowsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\nresult_set\x18\x03 \x01(\x0b\x32\x0e.Ydb.ResultSet\"\x8d\x02\n\x11\x42ulkUpsertRequest\x12\r\n\x05table\x18\x01 \x01(\t\x12\x1d\n\x04rows\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12?\n\x14\x61rrow_batch_settings\x18\x07 \x01(\x0b\x32\x1f.Ydb.Formats.ArrowBatchSettingsH\x00\x12\x30\n\x0c\x63sv_settings\x18\x08 \x01(\x0b\x32\x18.Ydb.Formats.CsvSettingsH\x00\x12\r\n\x04\x64\x61ta\x18\xe8\x07 \x01(\x0c\x42\r\n\x0b\x64\x61ta_format\"B\n\x12\x42ulkUpsertResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x42ulkUpsertResult\"\xb3\x03\n\x17\x45xecuteScanQueryRequest\x12\x1f\n\x05query\x18\x03 \x01(\x0b\x32\x10.Ydb.Table.Query\x12\x46\n\nparameters\x18\x04 \x03(\x0b\x32\x32.Ydb.Table.ExecuteScanQueryRequest.ParametersEntry\x12\x35\n\x04mode\x18\x06 \x01(\x0e\x32\'.Ydb.Table.ExecuteScanQueryRequest.Mode\x12;\n\rcollect_stats\x18\x08 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x12 \n\x18\x63ollect_full_diagnostics\x18\t \x01(\x08\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"=\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0cMODE_EXPLAIN\x10\x01\x12\r\n\tMODE_EXEC\x10\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\xaf\x01\n\x1f\x45xecuteScanQueryPartialResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x38\n\x06result\x18\x03 \x01(\x0b\x32(.Ydb.Table.ExecuteScanQueryPartialResult\"\xac\x01\n\x1d\x45xecuteScanQueryPartialResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x06 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\x12\x1e\n\x16query_full_diagnostics\x18\x07 \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06*R\n\tStoreType\x12\x1a\n\x16STORE_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTORE_TYPE_ROW\x10\x01\x12\x15\n\x11STORE_TYPE_COLUMN\x10\x02\x42S\n\x14tech.ydb.proto.tableZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Table\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__common__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__query__stats__pb2.DESCRIPTOR,protos_dot_ydb__value__pb2.DESCRIPTOR,protos_dot_ydb__scheme__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,protos_dot_ydb__topic__pb2.DESCRIPTOR,protos_dot_ydb__formats__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_STORETYPE = _descriptor.EnumDescriptor(
  name='StoreType',
  full_name='Ydb.Table.StoreType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STORE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORE_TYPE_ROW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORE_TYPE_COLUMN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20382,
  serialized_end=20464,
)
_sym_db.RegisterEnumDescriptor(_STORETYPE)

StoreType = enum_type_wrapper.EnumTypeWrapper(_STORETYPE)
STORE_TYPE_UNSPECIFIED = 0
STORE_TYPE_ROW = 1
STORE_TYPE_COLUMN = 2


_TABLEINDEXDESCRIPTION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='Ydb.Table.TableIndexDescription.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_BUILDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1420,
  serialized_end=1491,
)
_sym_db.RegisterEnumDescriptor(_TABLEINDEXDESCRIPTION_STATUS)

_INDEXBUILDSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='Ydb.Table.IndexBuildState.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_PREPARING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_TRANSFERING_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_APPLYING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_DONE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_CANCELLATION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_CANCELLED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_REJECTION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_REJECTED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1522,
  serialized_end=1723,
)
_sym_db.RegisterEnumDescriptor(_INDEXBUILDSTATE_STATE)

_CHANGEFEEDMODE_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='Ydb.Table.ChangefeedMode.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_KEYS_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_UPDATES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_NEW_IMAGE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_OLD_IMAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_NEW_AND_OLD_IMAGES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1967,
  serialized_end=2102,
)
_sym_db.RegisterEnumDescriptor(_CHANGEFEEDMODE_MODE)

_CHANGEFEEDFORMAT_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='Ydb.Table.ChangefeedFormat.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMAT_JSON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMAT_DYNAMODB_STREAMS_JSON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMAT_DEBEZIUM_JSON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2125,
  serialized_end=2234,
)
_sym_db.RegisterEnumDescriptor(_CHANGEFEEDFORMAT_FORMAT)

_CHANGEFEEDDESCRIPTION_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='Ydb.Table.ChangefeedDescription.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_INITIAL_SCAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3192,
  serialized_end=3285,
)
_sym_db.RegisterEnumDescriptor(_CHANGEFEEDDESCRIPTION_STATE)

_COLUMNFAMILYPOLICY_COMPRESSION = _descriptor.EnumDescriptor(
  name='Compression',
  full_name='Ydb.Table.ColumnFamilyPolicy.Compression',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNCOMPRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3848,
  serialized_end=3924,
)
_sym_db.RegisterEnumDescriptor(_COLUMNFAMILYPOLICY_COMPRESSION)

_PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY = _descriptor.EnumDescriptor(
  name='AutoPartitioningPolicy',
  full_name='Ydb.Table.PartitioningPolicy.AutoPartitioningPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_PARTITIONING_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SPLIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO_SPLIT_MERGE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4566,
  serialized_end=4684,
)
_sym_db.RegisterEnumDescriptor(_PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY)

_VALUESINCEUNIXEPOCHMODESETTINGS_UNIT = _descriptor.EnumDescriptor(
  name='Unit',
  full_name='Ydb.Table.ValueSinceUnixEpochModeSettings.Unit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_SECONDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILLISECONDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MICROSECONDS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_NANOSECONDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6212,
  serialized_end=6326,
)
_sym_db.RegisterEnumDescriptor(_VALUESINCEUNIXEPOCHMODESETTINGS_UNIT)

_COLUMNFAMILY_COMPRESSION = _descriptor.EnumDescriptor(
  name='Compression',
  full_name='Ydb.Table.ColumnFamily.Compression',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LZ4', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6924,
  serialized_end=7009,
)
_sym_db.RegisterEnumDescriptor(_COLUMNFAMILY_COMPRESSION)

_QUERYSTATSCOLLECTION_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='Ydb.Table.QueryStatsCollection.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATS_COLLECTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_COLLECTION_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_COLLECTION_BASIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_COLLECTION_FULL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_COLLECTION_PROFILE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12819,
  serialized_end=12971,
)
_sym_db.RegisterEnumDescriptor(_QUERYSTATSCOLLECTION_MODE)

_KEEPALIVERESULT_SESSIONSTATUS = _descriptor.EnumDescriptor(
  name='SessionStatus',
  full_name='Ydb.Table.KeepAliveResult.SessionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATUS_READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATUS_BUSY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15049,
  serialized_end=15147,
)
_sym_db.RegisterEnumDescriptor(_KEEPALIVERESULT_SESSIONSTATUS)

_EXECUTESCANQUERYREQUEST_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='Ydb.Table.ExecuteScanQueryRequest.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_EXPLAIN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_EXEC', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19942,
  serialized_end=20003,
)
_sym_db.RegisterEnumDescriptor(_EXECUTESCANQUERYREQUEST_MODE)


_CREATESESSIONREQUEST = _descriptor.Descriptor(
  name='CreateSessionRequest',
  full_name='Ydb.Table.CreateSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.CreateSessionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=494,
)


_CREATESESSIONRESPONSE = _descriptor.Descriptor(
  name='CreateSessionResponse',
  full_name='Ydb.Table.CreateSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.CreateSessionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=565,
)


_CREATESESSIONRESULT = _descriptor.Descriptor(
  name='CreateSessionResult',
  full_name='Ydb.Table.CreateSessionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.CreateSessionResult.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=608,
)


_DELETESESSIONREQUEST = _descriptor.Descriptor(
  name='DeleteSessionRequest',
  full_name='Ydb.Table.DeleteSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.DeleteSessionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.DeleteSessionRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=711,
)


_DELETESESSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteSessionResponse',
  full_name='Ydb.Table.DeleteSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.DeleteSessionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=782,
)


_GLOBALINDEX = _descriptor.Descriptor(
  name='GlobalIndex',
  full_name='Ydb.Table.GlobalIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=797,
)


_GLOBALASYNCINDEX = _descriptor.Descriptor(
  name='GlobalAsyncIndex',
  full_name='Ydb.Table.GlobalAsyncIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=817,
)


_GLOBALUNIQUEINDEX = _descriptor.Descriptor(
  name='GlobalUniqueIndex',
  full_name='Ydb.Table.GlobalUniqueIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=838,
)


_TABLEINDEX = _descriptor.Descriptor(
  name='TableIndex',
  full_name='Ydb.Table.TableIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.TableIndex.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_columns', full_name='Ydb.Table.TableIndex.index_columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_index', full_name='Ydb.Table.TableIndex.global_index', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_async_index', full_name='Ydb.Table.TableIndex.global_async_index', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_unique_index', full_name='Ydb.Table.TableIndex.global_unique_index', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_columns', full_name='Ydb.Table.TableIndex.data_columns', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='Ydb.Table.TableIndex.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=841,
  serialized_end=1088,
)


_TABLEINDEXDESCRIPTION = _descriptor.Descriptor(
  name='TableIndexDescription',
  full_name='Ydb.Table.TableIndexDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.TableIndexDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_columns', full_name='Ydb.Table.TableIndexDescription.index_columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_index', full_name='Ydb.Table.TableIndexDescription.global_index', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_async_index', full_name='Ydb.Table.TableIndexDescription.global_async_index', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_unique_index', full_name='Ydb.Table.TableIndexDescription.global_unique_index', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Table.TableIndexDescription.status', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_columns', full_name='Ydb.Table.TableIndexDescription.data_columns', index=6,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='Ydb.Table.TableIndexDescription.size_bytes', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TABLEINDEXDESCRIPTION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='Ydb.Table.TableIndexDescription.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1091,
  serialized_end=1499,
)


_INDEXBUILDSTATE = _descriptor.Descriptor(
  name='IndexBuildState',
  full_name='Ydb.Table.IndexBuildState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INDEXBUILDSTATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1723,
)


_INDEXBUILDDESCRIPTION = _descriptor.Descriptor(
  name='IndexBuildDescription',
  full_name='Ydb.Table.IndexBuildDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.IndexBuildDescription.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='Ydb.Table.IndexBuildDescription.index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1800,
)


_INDEXBUILDMETADATA = _descriptor.Descriptor(
  name='IndexBuildMetadata',
  full_name='Ydb.Table.IndexBuildMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Table.IndexBuildMetadata.description', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Table.IndexBuildMetadata.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Ydb.Table.IndexBuildMetadata.progress', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1945,
)


_CHANGEFEEDMODE = _descriptor.Descriptor(
  name='ChangefeedMode',
  full_name='Ydb.Table.ChangefeedMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEFEEDMODE_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1948,
  serialized_end=2102,
)


_CHANGEFEEDFORMAT = _descriptor.Descriptor(
  name='ChangefeedFormat',
  full_name='Ydb.Table.ChangefeedFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEFEEDFORMAT_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2105,
  serialized_end=2234,
)


_CHANGEFEED_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Table.Changefeed.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.Changefeed.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.Changefeed.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2763,
)

_CHANGEFEED = _descriptor.Descriptor(
  name='Changefeed',
  full_name='Ydb.Table.Changefeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.Changefeed.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='Ydb.Table.Changefeed.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='Ydb.Table.Changefeed.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='Ydb.Table.Changefeed.retention_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_timestamps', full_name='Ydb.Table.Changefeed.virtual_timestamps', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_scan', full_name='Ydb.Table.Changefeed.initial_scan', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Table.Changefeed.attributes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_region', full_name='Ydb.Table.Changefeed.aws_region', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolved_timestamps_interval', full_name='Ydb.Table.Changefeed.resolved_timestamps_interval', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_partitioning_settings', full_name='Ydb.Table.Changefeed.topic_partitioning_settings', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHANGEFEED_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2237,
  serialized_end=2763,
)


_CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Table.ChangefeedDescription.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.ChangefeedDescription.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.ChangefeedDescription.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2763,
)

_CHANGEFEEDDESCRIPTION = _descriptor.Descriptor(
  name='ChangefeedDescription',
  full_name='Ydb.Table.ChangefeedDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ChangefeedDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='Ydb.Table.ChangefeedDescription.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='Ydb.Table.ChangefeedDescription.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Table.ChangefeedDescription.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_timestamps', full_name='Ydb.Table.ChangefeedDescription.virtual_timestamps', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Table.ChangefeedDescription.attributes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_region', full_name='Ydb.Table.ChangefeedDescription.aws_region', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolved_timestamps_interval', full_name='Ydb.Table.ChangefeedDescription.resolved_timestamps_interval', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY, ],
  enum_types=[
    _CHANGEFEEDDESCRIPTION_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=3285,
)


_STORAGEPOOL = _descriptor.Descriptor(
  name='StoragePool',
  full_name='Ydb.Table.StoragePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='media', full_name='Ydb.Table.StoragePool.media', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3287,
  serialized_end=3315,
)


_STORAGEPOLICY = _descriptor.Descriptor(
  name='StoragePolicy',
  full_name='Ydb.Table.StoragePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.StoragePolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syslog', full_name='Ydb.Table.StoragePolicy.syslog', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='Ydb.Table.StoragePolicy.log', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Table.StoragePolicy.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='Ydb.Table.StoragePolicy.external', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_in_memory', full_name='Ydb.Table.StoragePolicy.keep_in_memory', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_families', full_name='Ydb.Table.StoragePolicy.column_families', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3318,
  serialized_end=3616,
)


_COLUMNFAMILYPOLICY = _descriptor.Descriptor(
  name='ColumnFamilyPolicy',
  full_name='Ydb.Table.ColumnFamilyPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ColumnFamilyPolicy.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Table.ColumnFamilyPolicy.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='Ydb.Table.ColumnFamilyPolicy.external', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_in_memory', full_name='Ydb.Table.ColumnFamilyPolicy.keep_in_memory', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='Ydb.Table.ColumnFamilyPolicy.compression', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLUMNFAMILYPOLICY_COMPRESSION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3619,
  serialized_end=3924,
)


_COMPACTIONPOLICY = _descriptor.Descriptor(
  name='CompactionPolicy',
  full_name='Ydb.Table.CompactionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.CompactionPolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3926,
  serialized_end=3965,
)


_EXPLICITPARTITIONS = _descriptor.Descriptor(
  name='ExplicitPartitions',
  full_name='Ydb.Table.ExplicitPartitions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='split_points', full_name='Ydb.Table.ExplicitPartitions.split_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3967,
  serialized_end=4026,
)


_PARTITIONSTATS = _descriptor.Descriptor(
  name='PartitionStats',
  full_name='Ydb.Table.PartitionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows_estimate', full_name='Ydb.Table.PartitionStats.rows_estimate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_size', full_name='Ydb.Table.PartitionStats.store_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leader_node_id', full_name='Ydb.Table.PartitionStats.leader_node_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4111,
)


_TABLESTATS = _descriptor.Descriptor(
  name='TableStats',
  full_name='Ydb.Table.TableStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_stats', full_name='Ydb.Table.TableStats.partition_stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows_estimate', full_name='Ydb.Table.TableStats.rows_estimate', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_size', full_name='Ydb.Table.TableStats.store_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='Ydb.Table.TableStats.partitions', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_time', full_name='Ydb.Table.TableStats.creation_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modification_time', full_name='Ydb.Table.TableStats.modification_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4114,
  serialized_end=4347,
)


_PARTITIONINGPOLICY = _descriptor.Descriptor(
  name='PartitioningPolicy',
  full_name='Ydb.Table.PartitioningPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.PartitioningPolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_partitioning', full_name='Ydb.Table.PartitioningPolicy.auto_partitioning', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniform_partitions', full_name='Ydb.Table.PartitioningPolicy.uniform_partitions', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_partitions', full_name='Ydb.Table.PartitioningPolicy.explicit_partitions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='partitions', full_name='Ydb.Table.PartitioningPolicy.partitions',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4350,
  serialized_end=4698,
)


_EXECUTIONPOLICY = _descriptor.Descriptor(
  name='ExecutionPolicy',
  full_name='Ydb.Table.ExecutionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.ExecutionPolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4700,
  serialized_end=4738,
)


_REPLICATIONPOLICY = _descriptor.Descriptor(
  name='ReplicationPolicy',
  full_name='Ydb.Table.ReplicationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.ReplicationPolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicas_count', full_name='Ydb.Table.ReplicationPolicy.replicas_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_per_availability_zone', full_name='Ydb.Table.ReplicationPolicy.create_per_availability_zone', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_promotion', full_name='Ydb.Table.ReplicationPolicy.allow_promotion', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4741,
  serialized_end=4918,
)


_CACHINGPOLICY = _descriptor.Descriptor(
  name='CachingPolicy',
  full_name='Ydb.Table.CachingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.CachingPolicy.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4920,
  serialized_end=4956,
)


_TABLEPROFILE = _descriptor.Descriptor(
  name='TableProfile',
  full_name='Ydb.Table.TableProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_name', full_name='Ydb.Table.TableProfile.preset_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_policy', full_name='Ydb.Table.TableProfile.storage_policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compaction_policy', full_name='Ydb.Table.TableProfile.compaction_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_policy', full_name='Ydb.Table.TableProfile.partitioning_policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_policy', full_name='Ydb.Table.TableProfile.execution_policy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_policy', full_name='Ydb.Table.TableProfile.replication_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caching_policy', full_name='Ydb.Table.TableProfile.caching_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4959,
  serialized_end=5322,
)


_SEQUENCEDESCRIPTION_SETVAL = _descriptor.Descriptor(
  name='SetVal',
  full_name='Ydb.Table.SequenceDescription.SetVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_value', full_name='Ydb.Table.SequenceDescription.SetVal.next_value', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_used', full_name='Ydb.Table.SequenceDescription.SetVal.next_used', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_next_value', full_name='Ydb.Table.SequenceDescription.SetVal._next_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_next_used', full_name='Ydb.Table.SequenceDescription.SetVal._next_used',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5566,
  serialized_end=5652,
)

_SEQUENCEDESCRIPTION = _descriptor.Descriptor(
  name='SequenceDescription',
  full_name='Ydb.Table.SequenceDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.SequenceDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='Ydb.Table.SequenceDescription.min_value', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='Ydb.Table.SequenceDescription.max_value', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_value', full_name='Ydb.Table.SequenceDescription.start_value', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache', full_name='Ydb.Table.SequenceDescription.cache', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='increment', full_name='Ydb.Table.SequenceDescription.increment', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='Ydb.Table.SequenceDescription.cycle', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_val', full_name='Ydb.Table.SequenceDescription.set_val', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SEQUENCEDESCRIPTION_SETVAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='Ydb.Table.SequenceDescription._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_min_value', full_name='Ydb.Table.SequenceDescription._min_value',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_value', full_name='Ydb.Table.SequenceDescription._max_value',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_start_value', full_name='Ydb.Table.SequenceDescription._start_value',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cache', full_name='Ydb.Table.SequenceDescription._cache',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_increment', full_name='Ydb.Table.SequenceDescription._increment',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_cycle', full_name='Ydb.Table.SequenceDescription._cycle',
      index=6, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_set_val', full_name='Ydb.Table.SequenceDescription._set_val',
      index=7, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5325,
  serialized_end=5751,
)


_COLUMNMETA = _descriptor.Descriptor(
  name='ColumnMeta',
  full_name='Ydb.Table.ColumnMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ColumnMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Table.ColumnMeta.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family', full_name='Ydb.Table.ColumnMeta.family', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_null', full_name='Ydb.Table.ColumnMeta.not_null', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_literal', full_name='Ydb.Table.ColumnMeta.from_literal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_sequence', full_name='Ydb.Table.ColumnMeta.from_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='default_value', full_name='Ydb.Table.ColumnMeta.default_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_not_null', full_name='Ydb.Table.ColumnMeta._not_null',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5754,
  serialized_end=5972,
)


_DATETYPECOLUMNMODESETTINGS = _descriptor.Descriptor(
  name='DateTypeColumnModeSettings',
  full_name='Ydb.Table.DateTypeColumnModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='Ydb.Table.DateTypeColumnModeSettings.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_after_seconds', full_name='Ydb.Table.DateTypeColumnModeSettings.expire_after_seconds', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5974,
  serialized_end=6053,
)


_VALUESINCEUNIXEPOCHMODESETTINGS = _descriptor.Descriptor(
  name='ValueSinceUnixEpochModeSettings',
  full_name='Ydb.Table.ValueSinceUnixEpochModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='Ydb.Table.ValueSinceUnixEpochModeSettings.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_unit', full_name='Ydb.Table.ValueSinceUnixEpochModeSettings.column_unit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_after_seconds', full_name='Ydb.Table.ValueSinceUnixEpochModeSettings.expire_after_seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6056,
  serialized_end=6326,
)


_TTLSETTINGS = _descriptor.Descriptor(
  name='TtlSettings',
  full_name='Ydb.Table.TtlSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_type_column', full_name='Ydb.Table.TtlSettings.date_type_column', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_since_unix_epoch', full_name='Ydb.Table.TtlSettings.value_since_unix_epoch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_interval_seconds', full_name='Ydb.Table.TtlSettings.run_interval_seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='Ydb.Table.TtlSettings.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6329,
  serialized_end=6525,
)


_STORAGESETTINGS = _descriptor.Descriptor(
  name='StorageSettings',
  full_name='Ydb.Table.StorageSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablet_commit_log0', full_name='Ydb.Table.StorageSettings.tablet_commit_log0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablet_commit_log1', full_name='Ydb.Table.StorageSettings.tablet_commit_log1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='Ydb.Table.StorageSettings.external', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_external_blobs', full_name='Ydb.Table.StorageSettings.store_external_blobs', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6528,
  serialized_end=6746,
)


_COLUMNFAMILY = _descriptor.Descriptor(
  name='ColumnFamily',
  full_name='Ydb.Table.ColumnFamily',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ColumnFamily.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Table.ColumnFamily.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='Ydb.Table.ColumnFamily.compression', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_in_memory', full_name='Ydb.Table.ColumnFamily.keep_in_memory', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLUMNFAMILY_COMPRESSION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6749,
  serialized_end=7009,
)


_PARTITIONINGSETTINGS = _descriptor.Descriptor(
  name='PartitioningSettings',
  full_name='Ydb.Table.PartitioningSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='Ydb.Table.PartitioningSettings.partition_by', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_by_size', full_name='Ydb.Table.PartitioningSettings.partitioning_by_size', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_size_mb', full_name='Ydb.Table.PartitioningSettings.partition_size_mb', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_by_load', full_name='Ydb.Table.PartitioningSettings.partitioning_by_load', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_partitions_count', full_name='Ydb.Table.PartitioningSettings.min_partitions_count', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_partitions_count', full_name='Ydb.Table.PartitioningSettings.max_partitions_count', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7012,
  serialized_end=7259,
)


_AZREADREPLICASSETTINGS = _descriptor.Descriptor(
  name='AzReadReplicasSettings',
  full_name='Ydb.Table.AzReadReplicasSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.AzReadReplicasSettings.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_replicas_count', full_name='Ydb.Table.AzReadReplicasSettings.read_replicas_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7261,
  serialized_end=7328,
)


_CLUSTERREPLICASSETTINGS = _descriptor.Descriptor(
  name='ClusterReplicasSettings',
  full_name='Ydb.Table.ClusterReplicasSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='az_read_replicas_settings', full_name='Ydb.Table.ClusterReplicasSettings.az_read_replicas_settings', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7330,
  serialized_end=7425,
)


_READREPLICASSETTINGS = _descriptor.Descriptor(
  name='ReadReplicasSettings',
  full_name='Ydb.Table.ReadReplicasSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='per_az_read_replicas_count', full_name='Ydb.Table.ReadReplicasSettings.per_az_read_replicas_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_az_read_replicas_count', full_name='Ydb.Table.ReadReplicasSettings.any_az_read_replicas_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='settings', full_name='Ydb.Table.ReadReplicasSettings.settings',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7427,
  serialized_end=7543,
)


_CREATETABLEREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Table.CreateTableRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.CreateTableRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.CreateTableRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2763,
)

_CREATETABLEREQUEST = _descriptor.Descriptor(
  name='CreateTableRequest',
  full_name='Ydb.Table.CreateTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.CreateTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.CreateTableRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Table.CreateTableRequest.columns', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='Ydb.Table.CreateTableRequest.primary_key', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='Ydb.Table.CreateTableRequest.profile', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.CreateTableRequest.operation_params', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexes', full_name='Ydb.Table.CreateTableRequest.indexes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_settings', full_name='Ydb.Table.CreateTableRequest.ttl_settings', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_settings', full_name='Ydb.Table.CreateTableRequest.storage_settings', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_families', full_name='Ydb.Table.CreateTableRequest.column_families', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Table.CreateTableRequest.attributes', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compaction_policy', full_name='Ydb.Table.CreateTableRequest.compaction_policy', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniform_partitions', full_name='Ydb.Table.CreateTableRequest.uniform_partitions', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_at_keys', full_name='Ydb.Table.CreateTableRequest.partition_at_keys', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_settings', full_name='Ydb.Table.CreateTableRequest.partitioning_settings', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_bloom_filter', full_name='Ydb.Table.CreateTableRequest.key_bloom_filter', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_replicas_settings', full_name='Ydb.Table.CreateTableRequest.read_replicas_settings', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tiering', full_name='Ydb.Table.CreateTableRequest.tiering', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporary', full_name='Ydb.Table.CreateTableRequest.temporary', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_type', full_name='Ydb.Table.CreateTableRequest.store_type', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETABLEREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='partitions', full_name='Ydb.Table.CreateTableRequest.partitions',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7546,
  serialized_end=8484,
)


_CREATETABLERESPONSE = _descriptor.Descriptor(
  name='CreateTableResponse',
  full_name='Ydb.Table.CreateTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.CreateTableResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8486,
  serialized_end=8553,
)


_DROPTABLEREQUEST = _descriptor.Descriptor(
  name='DropTableRequest',
  full_name='Ydb.Table.DropTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.DropTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.DropTableRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.DropTableRequest.operation_params', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8555,
  serialized_end=8672,
)


_DROPTABLERESPONSE = _descriptor.Descriptor(
  name='DropTableResponse',
  full_name='Ydb.Table.DropTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.DropTableResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8674,
  serialized_end=8739,
)


_RENAMEINDEXITEM = _descriptor.Descriptor(
  name='RenameIndexItem',
  full_name='Ydb.Table.RenameIndexItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_name', full_name='Ydb.Table.RenameIndexItem.source_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_name', full_name='Ydb.Table.RenameIndexItem.destination_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replace_destination', full_name='Ydb.Table.RenameIndexItem.replace_destination', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8741,
  serialized_end=8834,
)


_ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AlterAttributesEntry',
  full_name='Ydb.Table.AlterTableRequest.AlterAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.AlterTableRequest.AlterAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.AlterTableRequest.AlterAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9924,
  serialized_end=9978,
)

_ALTERTABLEREQUEST = _descriptor.Descriptor(
  name='AlterTableRequest',
  full_name='Ydb.Table.AlterTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.AlterTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.AlterTableRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_columns', full_name='Ydb.Table.AlterTableRequest.add_columns', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_columns', full_name='Ydb.Table.AlterTableRequest.drop_columns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.AlterTableRequest.operation_params', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_columns', full_name='Ydb.Table.AlterTableRequest.alter_columns', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_ttl_settings', full_name='Ydb.Table.AlterTableRequest.set_ttl_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_ttl_settings', full_name='Ydb.Table.AlterTableRequest.drop_ttl_settings', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_indexes', full_name='Ydb.Table.AlterTableRequest.add_indexes', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_indexes', full_name='Ydb.Table.AlterTableRequest.drop_indexes', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_storage_settings', full_name='Ydb.Table.AlterTableRequest.alter_storage_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_column_families', full_name='Ydb.Table.AlterTableRequest.add_column_families', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_column_families', full_name='Ydb.Table.AlterTableRequest.alter_column_families', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_attributes', full_name='Ydb.Table.AlterTableRequest.alter_attributes', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_compaction_policy', full_name='Ydb.Table.AlterTableRequest.set_compaction_policy', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_partitioning_settings', full_name='Ydb.Table.AlterTableRequest.alter_partitioning_settings', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_key_bloom_filter', full_name='Ydb.Table.AlterTableRequest.set_key_bloom_filter', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_read_replicas_settings', full_name='Ydb.Table.AlterTableRequest.set_read_replicas_settings', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_changefeeds', full_name='Ydb.Table.AlterTableRequest.add_changefeeds', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_changefeeds', full_name='Ydb.Table.AlterTableRequest.drop_changefeeds', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rename_indexes', full_name='Ydb.Table.AlterTableRequest.rename_indexes', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_tiering', full_name='Ydb.Table.AlterTableRequest.set_tiering', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_tiering', full_name='Ydb.Table.AlterTableRequest.drop_tiering', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ttl_action', full_name='Ydb.Table.AlterTableRequest.ttl_action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='tiering_action', full_name='Ydb.Table.AlterTableRequest.tiering_action',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8837,
  serialized_end=10010,
)


_ALTERTABLERESPONSE = _descriptor.Descriptor(
  name='AlterTableResponse',
  full_name='Ydb.Table.AlterTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.AlterTableResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10012,
  serialized_end=10078,
)


_COPYTABLEREQUEST = _descriptor.Descriptor(
  name='CopyTableRequest',
  full_name='Ydb.Table.CopyTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.CopyTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Table.CopyTableRequest.source_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Table.CopyTableRequest.destination_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.CopyTableRequest.operation_params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10081,
  serialized_end=10225,
)


_COPYTABLERESPONSE = _descriptor.Descriptor(
  name='CopyTableResponse',
  full_name='Ydb.Table.CopyTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.CopyTableResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10227,
  serialized_end=10292,
)


_COPYTABLEITEM = _descriptor.Descriptor(
  name='CopyTableItem',
  full_name='Ydb.Table.CopyTableItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Table.CopyTableItem.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Table.CopyTableItem.destination_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omit_indexes', full_name='Ydb.Table.CopyTableItem.omit_indexes', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10294,
  serialized_end=10378,
)


_COPYTABLESREQUEST = _descriptor.Descriptor(
  name='CopyTablesRequest',
  full_name='Ydb.Table.CopyTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.CopyTablesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.CopyTablesRequest.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tables', full_name='Ydb.Table.CopyTablesRequest.tables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10381,
  serialized_end=10521,
)


_COPYTABLESRESPONSE = _descriptor.Descriptor(
  name='CopyTablesResponse',
  full_name='Ydb.Table.CopyTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.CopyTablesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10523,
  serialized_end=10589,
)


_RENAMETABLEITEM = _descriptor.Descriptor(
  name='RenameTableItem',
  full_name='Ydb.Table.RenameTableItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_path', full_name='Ydb.Table.RenameTableItem.source_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_path', full_name='Ydb.Table.RenameTableItem.destination_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replace_destination', full_name='Ydb.Table.RenameTableItem.replace_destination', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10591,
  serialized_end=10684,
)


_RENAMETABLESREQUEST = _descriptor.Descriptor(
  name='RenameTablesRequest',
  full_name='Ydb.Table.RenameTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.RenameTablesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.RenameTablesRequest.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tables', full_name='Ydb.Table.RenameTablesRequest.tables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10687,
  serialized_end=10831,
)


_RENAMETABLESRESPONSE = _descriptor.Descriptor(
  name='RenameTablesResponse',
  full_name='Ydb.Table.RenameTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.RenameTablesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10833,
  serialized_end=10901,
)


_DESCRIBETABLEREQUEST = _descriptor.Descriptor(
  name='DescribeTableRequest',
  full_name='Ydb.Table.DescribeTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.DescribeTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.DescribeTableRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.DescribeTableRequest.operation_params', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_shard_key_bounds', full_name='Ydb.Table.DescribeTableRequest.include_shard_key_bounds', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_table_stats', full_name='Ydb.Table.DescribeTableRequest.include_table_stats', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_partition_stats', full_name='Ydb.Table.DescribeTableRequest.include_partition_stats', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_shard_nodes_info', full_name='Ydb.Table.DescribeTableRequest.include_shard_nodes_info', index=6,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10904,
  serialized_end=11149,
)


_DESCRIBETABLERESPONSE = _descriptor.Descriptor(
  name='DescribeTableResponse',
  full_name='Ydb.Table.DescribeTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.DescribeTableResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11151,
  serialized_end=11220,
)


_DESCRIBETABLERESULT_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Table.DescribeTableResult.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.DescribeTableResult.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.DescribeTableResult.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2763,
)

_DESCRIBETABLERESULT = _descriptor.Descriptor(
  name='DescribeTableResult',
  full_name='Ydb.Table.DescribeTableResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Table.DescribeTableResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Table.DescribeTableResult.columns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='Ydb.Table.DescribeTableResult.primary_key', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_key_bounds', full_name='Ydb.Table.DescribeTableResult.shard_key_bounds', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexes', full_name='Ydb.Table.DescribeTableResult.indexes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_stats', full_name='Ydb.Table.DescribeTableResult.table_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_settings', full_name='Ydb.Table.DescribeTableResult.ttl_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_settings', full_name='Ydb.Table.DescribeTableResult.storage_settings', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column_families', full_name='Ydb.Table.DescribeTableResult.column_families', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Table.DescribeTableResult.attributes', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_settings', full_name='Ydb.Table.DescribeTableResult.partitioning_settings', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_bloom_filter', full_name='Ydb.Table.DescribeTableResult.key_bloom_filter', index=11,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_replicas_settings', full_name='Ydb.Table.DescribeTableResult.read_replicas_settings', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changefeeds', full_name='Ydb.Table.DescribeTableResult.changefeeds', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tiering', full_name='Ydb.Table.DescribeTableResult.tiering', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporary', full_name='Ydb.Table.DescribeTableResult.temporary', index=15,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_type', full_name='Ydb.Table.DescribeTableResult.store_type', index=16,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DESCRIBETABLERESULT_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11223,
  serialized_end=12064,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='Ydb.Table.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yql_text', full_name='Ydb.Table.Query.yql_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Table.Query.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='Ydb.Table.Query.query',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12066,
  serialized_end=12116,
)


_SERIALIZABLEMODESETTINGS = _descriptor.Descriptor(
  name='SerializableModeSettings',
  full_name='Ydb.Table.SerializableModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12118,
  serialized_end=12144,
)


_ONLINEMODESETTINGS = _descriptor.Descriptor(
  name='OnlineModeSettings',
  full_name='Ydb.Table.OnlineModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_inconsistent_reads', full_name='Ydb.Table.OnlineModeSettings.allow_inconsistent_reads', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12146,
  serialized_end=12200,
)


_STALEMODESETTINGS = _descriptor.Descriptor(
  name='StaleModeSettings',
  full_name='Ydb.Table.StaleModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12202,
  serialized_end=12221,
)


_SNAPSHOTMODESETTINGS = _descriptor.Descriptor(
  name='SnapshotModeSettings',
  full_name='Ydb.Table.SnapshotModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12223,
  serialized_end=12245,
)


_SNAPSHOTRWMODESETTINGS = _descriptor.Descriptor(
  name='SnapshotRWModeSettings',
  full_name='Ydb.Table.SnapshotRWModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12247,
  serialized_end=12271,
)


_TRANSACTIONSETTINGS = _descriptor.Descriptor(
  name='TransactionSettings',
  full_name='Ydb.Table.TransactionSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serializable_read_write', full_name='Ydb.Table.TransactionSettings.serializable_read_write', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_read_only', full_name='Ydb.Table.TransactionSettings.online_read_only', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stale_read_only', full_name='Ydb.Table.TransactionSettings.stale_read_only', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_read_only', full_name='Ydb.Table.TransactionSettings.snapshot_read_only', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_read_write', full_name='Ydb.Table.TransactionSettings.snapshot_read_write', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tx_mode', full_name='Ydb.Table.TransactionSettings.tx_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12274,
  serialized_end=12623,
)


_TRANSACTIONCONTROL = _descriptor.Descriptor(
  name='TransactionControl',
  full_name='Ydb.Table.TransactionControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Table.TransactionControl.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='begin_tx', full_name='Ydb.Table.TransactionControl.begin_tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_tx', full_name='Ydb.Table.TransactionControl.commit_tx', index=2,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tx_selector', full_name='Ydb.Table.TransactionControl.tx_selector',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12625,
  serialized_end=12748,
)


_QUERYCACHEPOLICY = _descriptor.Descriptor(
  name='QueryCachePolicy',
  full_name='Ydb.Table.QueryCachePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keep_in_cache', full_name='Ydb.Table.QueryCachePolicy.keep_in_cache', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12750,
  serialized_end=12791,
)


_QUERYSTATSCOLLECTION = _descriptor.Descriptor(
  name='QueryStatsCollection',
  full_name='Ydb.Table.QueryStatsCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUERYSTATSCOLLECTION_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12794,
  serialized_end=12971,
)


_EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='Ydb.Table.ExecuteDataQueryRequest.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.ExecuteDataQueryRequest.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.ExecuteDataQueryRequest.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13354,
  serialized_end=13420,
)

_EXECUTEDATAQUERYREQUEST = _descriptor.Descriptor(
  name='ExecuteDataQueryRequest',
  full_name='Ydb.Table.ExecuteDataQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.ExecuteDataQueryRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_control', full_name='Ydb.Table.ExecuteDataQueryRequest.tx_control', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='Ydb.Table.ExecuteDataQueryRequest.query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Ydb.Table.ExecuteDataQueryRequest.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_cache_policy', full_name='Ydb.Table.ExecuteDataQueryRequest.query_cache_policy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.ExecuteDataQueryRequest.operation_params', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_stats', full_name='Ydb.Table.ExecuteDataQueryRequest.collect_stats', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12974,
  serialized_end=13420,
)


_EXECUTEDATAQUERYRESPONSE = _descriptor.Descriptor(
  name='ExecuteDataQueryResponse',
  full_name='Ydb.Table.ExecuteDataQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.ExecuteDataQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13422,
  serialized_end=13494,
)


_EXECUTESCHEMEQUERYREQUEST = _descriptor.Descriptor(
  name='ExecuteSchemeQueryRequest',
  full_name='Ydb.Table.ExecuteSchemeQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.ExecuteSchemeQueryRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yql_text', full_name='Ydb.Table.ExecuteSchemeQueryRequest.yql_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.ExecuteSchemeQueryRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13496,
  serialized_end=13620,
)


_EXECUTESCHEMEQUERYRESPONSE = _descriptor.Descriptor(
  name='ExecuteSchemeQueryResponse',
  full_name='Ydb.Table.ExecuteSchemeQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.ExecuteSchemeQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13622,
  serialized_end=13696,
)


_TRANSACTIONMETA = _descriptor.Descriptor(
  name='TransactionMeta',
  full_name='Ydb.Table.TransactionMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Table.TransactionMeta.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13698,
  serialized_end=13727,
)


_QUERYMETA_PARAMETERSTYPESENTRY = _descriptor.Descriptor(
  name='ParametersTypesEntry',
  full_name='Ydb.Table.QueryMeta.ParametersTypesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.QueryMeta.ParametersTypesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.QueryMeta.ParametersTypesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13824,
  serialized_end=13889,
)

_QUERYMETA = _descriptor.Descriptor(
  name='QueryMeta',
  full_name='Ydb.Table.QueryMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Table.QueryMeta.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters_types', full_name='Ydb.Table.QueryMeta.parameters_types', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYMETA_PARAMETERSTYPESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13730,
  serialized_end=13889,
)


_EXECUTEQUERYRESULT = _descriptor.Descriptor(
  name='ExecuteQueryResult',
  full_name='Ydb.Table.ExecuteQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_sets', full_name='Ydb.Table.ExecuteQueryResult.result_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_meta', full_name='Ydb.Table.ExecuteQueryResult.tx_meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_meta', full_name='Ydb.Table.ExecuteQueryResult.query_meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_stats', full_name='Ydb.Table.ExecuteQueryResult.query_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13892,
  serialized_end=14085,
)


_EXPLAINDATAQUERYREQUEST = _descriptor.Descriptor(
  name='ExplainDataQueryRequest',
  full_name='Ydb.Table.ExplainDataQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.ExplainDataQueryRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yql_text', full_name='Ydb.Table.ExplainDataQueryRequest.yql_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.ExplainDataQueryRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_full_diagnostics', full_name='Ydb.Table.ExplainDataQueryRequest.collect_full_diagnostics', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14088,
  serialized_end=14244,
)


_EXPLAINDATAQUERYRESPONSE = _descriptor.Descriptor(
  name='ExplainDataQueryResponse',
  full_name='Ydb.Table.ExplainDataQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.ExplainDataQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14246,
  serialized_end=14318,
)


_EXPLAINQUERYRESULT = _descriptor.Descriptor(
  name='ExplainQueryResult',
  full_name='Ydb.Table.ExplainQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_ast', full_name='Ydb.Table.ExplainQueryResult.query_ast', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_plan', full_name='Ydb.Table.ExplainQueryResult.query_plan', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_full_diagnostics', full_name='Ydb.Table.ExplainQueryResult.query_full_diagnostics', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14320,
  serialized_end=14411,
)


_PREPAREDATAQUERYREQUEST = _descriptor.Descriptor(
  name='PrepareDataQueryRequest',
  full_name='Ydb.Table.PrepareDataQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.PrepareDataQueryRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yql_text', full_name='Ydb.Table.PrepareDataQueryRequest.yql_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.PrepareDataQueryRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14413,
  serialized_end=14535,
)


_PREPAREDATAQUERYRESPONSE = _descriptor.Descriptor(
  name='PrepareDataQueryResponse',
  full_name='Ydb.Table.PrepareDataQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.PrepareDataQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14537,
  serialized_end=14609,
)


_PREPAREQUERYRESULT_PARAMETERSTYPESENTRY = _descriptor.Descriptor(
  name='ParametersTypesEntry',
  full_name='Ydb.Table.PrepareQueryResult.ParametersTypesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.PrepareQueryResult.ParametersTypesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.PrepareQueryResult.ParametersTypesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13824,
  serialized_end=13889,
)

_PREPAREQUERYRESULT = _descriptor.Descriptor(
  name='PrepareQueryResult',
  full_name='Ydb.Table.PrepareQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='Ydb.Table.PrepareQueryResult.query_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters_types', full_name='Ydb.Table.PrepareQueryResult.parameters_types', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PREPAREQUERYRESULT_PARAMETERSTYPESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14612,
  serialized_end=14795,
)


_KEEPALIVEREQUEST = _descriptor.Descriptor(
  name='KeepAliveRequest',
  full_name='Ydb.Table.KeepAliveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.KeepAliveRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.KeepAliveRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14797,
  serialized_end=14894,
)


_KEEPALIVERESPONSE = _descriptor.Descriptor(
  name='KeepAliveResponse',
  full_name='Ydb.Table.KeepAliveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.KeepAliveResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14896,
  serialized_end=14961,
)


_KEEPALIVERESULT = _descriptor.Descriptor(
  name='KeepAliveResult',
  full_name='Ydb.Table.KeepAliveResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_status', full_name='Ydb.Table.KeepAliveResult.session_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEEPALIVERESULT_SESSIONSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14964,
  serialized_end=15147,
)


_BEGINTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='BeginTransactionRequest',
  full_name='Ydb.Table.BeginTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.BeginTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_settings', full_name='Ydb.Table.BeginTransactionRequest.tx_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.BeginTransactionRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15150,
  serialized_end=15307,
)


_BEGINTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='BeginTransactionResponse',
  full_name='Ydb.Table.BeginTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.BeginTransactionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15309,
  serialized_end=15381,
)


_BEGINTRANSACTIONRESULT = _descriptor.Descriptor(
  name='BeginTransactionResult',
  full_name='Ydb.Table.BeginTransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_meta', full_name='Ydb.Table.BeginTransactionResult.tx_meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15383,
  serialized_end=15452,
)


_COMMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='CommitTransactionRequest',
  full_name='Ydb.Table.CommitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.CommitTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Table.CommitTransactionRequest.tx_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.CommitTransactionRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_stats', full_name='Ydb.Table.CommitTransactionRequest.collect_stats', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15455,
  serialized_end=15636,
)


_COMMITTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='CommitTransactionResponse',
  full_name='Ydb.Table.CommitTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.CommitTransactionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15638,
  serialized_end=15711,
)


_COMMITTRANSACTIONRESULT = _descriptor.Descriptor(
  name='CommitTransactionResult',
  full_name='Ydb.Table.CommitTransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_stats', full_name='Ydb.Table.CommitTransactionResult.query_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15713,
  serialized_end=15787,
)


_ROLLBACKTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='RollbackTransactionRequest',
  full_name='Ydb.Table.RollbackTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.RollbackTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Table.RollbackTransactionRequest.tx_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.RollbackTransactionRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15789,
  serialized_end=15911,
)


_ROLLBACKTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='RollbackTransactionResponse',
  full_name='Ydb.Table.RollbackTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.RollbackTransactionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15913,
  serialized_end=15988,
)


_STORAGEPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.StoragePolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.StoragePolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.StoragePolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_STORAGEPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='StoragePolicyDescription',
  full_name='Ydb.Table.StoragePolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.StoragePolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.StoragePolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STORAGEPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15991,
  serialized_end=16143,
)


_COMPACTIONPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.CompactionPolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.CompactionPolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.CompactionPolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_COMPACTIONPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='CompactionPolicyDescription',
  full_name='Ydb.Table.CompactionPolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.CompactionPolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.CompactionPolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPACTIONPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16146,
  serialized_end=16304,
)


_PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.PartitioningPolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.PartitioningPolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.PartitioningPolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_PARTITIONINGPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='PartitioningPolicyDescription',
  full_name='Ydb.Table.PartitioningPolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.PartitioningPolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.PartitioningPolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16307,
  serialized_end=16469,
)


_EXECUTIONPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.ExecutionPolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.ExecutionPolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.ExecutionPolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_EXECUTIONPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='ExecutionPolicyDescription',
  full_name='Ydb.Table.ExecutionPolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ExecutionPolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.ExecutionPolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTIONPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16472,
  serialized_end=16628,
)


_REPLICATIONPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.ReplicationPolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.ReplicationPolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.ReplicationPolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_REPLICATIONPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='ReplicationPolicyDescription',
  full_name='Ydb.Table.ReplicationPolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.ReplicationPolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.ReplicationPolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REPLICATIONPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16631,
  serialized_end=16791,
)


_CACHINGPOLICYDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.CachingPolicyDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.CachingPolicyDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.CachingPolicyDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_CACHINGPOLICYDESCRIPTION = _descriptor.Descriptor(
  name='CachingPolicyDescription',
  full_name='Ydb.Table.CachingPolicyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.CachingPolicyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.CachingPolicyDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CACHINGPOLICYDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16794,
  serialized_end=16946,
)


_TABLEPROFILEDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Table.TableProfileDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.TableProfileDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.TableProfileDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16143,
)

_TABLEPROFILEDESCRIPTION = _descriptor.Descriptor(
  name='TableProfileDescription',
  full_name='Ydb.Table.TableProfileDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Table.TableProfileDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Table.TableProfileDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_storage_policy', full_name='Ydb.Table.TableProfileDescription.default_storage_policy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_storage_policies', full_name='Ydb.Table.TableProfileDescription.allowed_storage_policies', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_compaction_policy', full_name='Ydb.Table.TableProfileDescription.default_compaction_policy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_compaction_policies', full_name='Ydb.Table.TableProfileDescription.allowed_compaction_policies', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_partitioning_policy', full_name='Ydb.Table.TableProfileDescription.default_partitioning_policy', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_partitioning_policies', full_name='Ydb.Table.TableProfileDescription.allowed_partitioning_policies', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_execution_policy', full_name='Ydb.Table.TableProfileDescription.default_execution_policy', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_execution_policies', full_name='Ydb.Table.TableProfileDescription.allowed_execution_policies', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_replication_policy', full_name='Ydb.Table.TableProfileDescription.default_replication_policy', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_replication_policies', full_name='Ydb.Table.TableProfileDescription.allowed_replication_policies', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_caching_policy', full_name='Ydb.Table.TableProfileDescription.default_caching_policy', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_caching_policies', full_name='Ydb.Table.TableProfileDescription.allowed_caching_policies', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TABLEPROFILEDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16949,
  serialized_end=17523,
)


_DESCRIBETABLEOPTIONSREQUEST = _descriptor.Descriptor(
  name='DescribeTableOptionsRequest',
  full_name='Ydb.Table.DescribeTableOptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.DescribeTableOptionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17525,
  serialized_end=17613,
)


_DESCRIBETABLEOPTIONSRESPONSE = _descriptor.Descriptor(
  name='DescribeTableOptionsResponse',
  full_name='Ydb.Table.DescribeTableOptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.DescribeTableOptionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17615,
  serialized_end=17691,
)


_DESCRIBETABLEOPTIONSRESULT = _descriptor.Descriptor(
  name='DescribeTableOptionsResult',
  full_name='Ydb.Table.DescribeTableOptionsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_profile_presets', full_name='Ydb.Table.DescribeTableOptionsResult.table_profile_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.storage_policy_presets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compaction_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.compaction_policy_presets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.partitioning_policy_presets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.execution_policy_presets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.replication_policy_presets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caching_policy_presets', full_name='Ydb.Table.DescribeTableOptionsResult.caching_policy_presets', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17694,
  serialized_end=18231,
)


_KEYRANGE = _descriptor.Descriptor(
  name='KeyRange',
  full_name='Ydb.Table.KeyRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='greater', full_name='Ydb.Table.KeyRange.greater', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='greater_or_equal', full_name='Ydb.Table.KeyRange.greater_or_equal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='less', full_name='Ydb.Table.KeyRange.less', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='less_or_equal', full_name='Ydb.Table.KeyRange.less_or_equal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='from_bound', full_name='Ydb.Table.KeyRange.from_bound',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='to_bound', full_name='Ydb.Table.KeyRange.to_bound',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=18234,
  serialized_end=18426,
)


_READTABLEREQUEST = _descriptor.Descriptor(
  name='ReadTableRequest',
  full_name='Ydb.Table.ReadTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.ReadTableRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.ReadTableRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_range', full_name='Ydb.Table.ReadTableRequest.key_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Table.ReadTableRequest.columns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordered', full_name='Ydb.Table.ReadTableRequest.ordered', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='row_limit', full_name='Ydb.Table.ReadTableRequest.row_limit', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_snapshot', full_name='Ydb.Table.ReadTableRequest.use_snapshot', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_limit_bytes', full_name='Ydb.Table.ReadTableRequest.batch_limit_bytes', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_limit_rows', full_name='Ydb.Table.ReadTableRequest.batch_limit_rows', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_not_null_data_as_optional', full_name='Ydb.Table.ReadTableRequest.return_not_null_data_as_optional', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18429,
  serialized_end=18741,
)


_READTABLERESPONSE = _descriptor.Descriptor(
  name='ReadTableResponse',
  full_name='Ydb.Table.ReadTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Table.ReadTableResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Table.ReadTableResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='Ydb.Table.ReadTableResponse.snapshot', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Ydb.Table.ReadTableResponse.result', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18744,
  serialized_end=18932,
)


_READTABLERESULT = _descriptor.Descriptor(
  name='ReadTableResult',
  full_name='Ydb.Table.ReadTableResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Table.ReadTableResult.result_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18934,
  serialized_end=18987,
)


_READROWSREQUEST = _descriptor.Descriptor(
  name='ReadRowsRequest',
  full_name='Ydb.Table.ReadRowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Table.ReadRowsRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Table.ReadRowsRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys', full_name='Ydb.Table.ReadRowsRequest.keys', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Table.ReadRowsRequest.columns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18989,
  serialized_end=19088,
)


_READROWSRESPONSE = _descriptor.Descriptor(
  name='ReadRowsResponse',
  full_name='Ydb.Table.ReadRowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Table.ReadRowsResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Table.ReadRowsResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Table.ReadRowsResponse.result_set', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19091,
  serialized_end=19229,
)


_BULKUPSERTREQUEST = _descriptor.Descriptor(
  name='BulkUpsertRequest',
  full_name='Ydb.Table.BulkUpsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='Ydb.Table.BulkUpsertRequest.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='Ydb.Table.BulkUpsertRequest.rows', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Table.BulkUpsertRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_batch_settings', full_name='Ydb.Table.BulkUpsertRequest.arrow_batch_settings', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csv_settings', full_name='Ydb.Table.BulkUpsertRequest.csv_settings', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Table.BulkUpsertRequest.data', index=5,
      number=1000, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data_format', full_name='Ydb.Table.BulkUpsertRequest.data_format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=19232,
  serialized_end=19501,
)


_BULKUPSERTRESPONSE = _descriptor.Descriptor(
  name='BulkUpsertResponse',
  full_name='Ydb.Table.BulkUpsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Table.BulkUpsertResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19503,
  serialized_end=19569,
)


_BULKUPSERTRESULT = _descriptor.Descriptor(
  name='BulkUpsertResult',
  full_name='Ydb.Table.BulkUpsertResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19571,
  serialized_end=19589,
)


_EXECUTESCANQUERYREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='Ydb.Table.ExecuteScanQueryRequest.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Table.ExecuteScanQueryRequest.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Table.ExecuteScanQueryRequest.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13354,
  serialized_end=13420,
)

_EXECUTESCANQUERYREQUEST = _descriptor.Descriptor(
  name='ExecuteScanQueryRequest',
  full_name='Ydb.Table.ExecuteScanQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='Ydb.Table.ExecuteScanQueryRequest.query', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Ydb.Table.ExecuteScanQueryRequest.parameters', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='Ydb.Table.ExecuteScanQueryRequest.mode', index=2,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_stats', full_name='Ydb.Table.ExecuteScanQueryRequest.collect_stats', index=3,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_full_diagnostics', full_name='Ydb.Table.ExecuteScanQueryRequest.collect_full_diagnostics', index=4,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTESCANQUERYREQUEST_PARAMETERSENTRY, ],
  enum_types=[
    _EXECUTESCANQUERYREQUEST_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19592,
  serialized_end=20027,
)


_EXECUTESCANQUERYPARTIALRESPONSE = _descriptor.Descriptor(
  name='ExecuteScanQueryPartialResponse',
  full_name='Ydb.Table.ExecuteScanQueryPartialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Table.ExecuteScanQueryPartialResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Table.ExecuteScanQueryPartialResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Ydb.Table.ExecuteScanQueryPartialResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20030,
  serialized_end=20205,
)


_EXECUTESCANQUERYPARTIALRESULT = _descriptor.Descriptor(
  name='ExecuteScanQueryPartialResult',
  full_name='Ydb.Table.ExecuteScanQueryPartialResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Table.ExecuteScanQueryPartialResult.result_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_stats', full_name='Ydb.Table.ExecuteScanQueryPartialResult.query_stats', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_full_diagnostics', full_name='Ydb.Table.ExecuteScanQueryPartialResult.query_full_diagnostics', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20208,
  serialized_end=20380,
)

_CREATESESSIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATESESSIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DELETESESSIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DELETESESSIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_TABLEINDEX.fields_by_name['global_index'].message_type = _GLOBALINDEX
_TABLEINDEX.fields_by_name['global_async_index'].message_type = _GLOBALASYNCINDEX
_TABLEINDEX.fields_by_name['global_unique_index'].message_type = _GLOBALUNIQUEINDEX
_TABLEINDEX.oneofs_by_name['type'].fields.append(
  _TABLEINDEX.fields_by_name['global_index'])
_TABLEINDEX.fields_by_name['global_index'].containing_oneof = _TABLEINDEX.oneofs_by_name['type']
_TABLEINDEX.oneofs_by_name['type'].fields.append(
  _TABLEINDEX.fields_by_name['global_async_index'])
_TABLEINDEX.fields_by_name['global_async_index'].containing_oneof = _TABLEINDEX.oneofs_by_name['type']
_TABLEINDEX.oneofs_by_name['type'].fields.append(
  _TABLEINDEX.fields_by_name['global_unique_index'])
_TABLEINDEX.fields_by_name['global_unique_index'].containing_oneof = _TABLEINDEX.oneofs_by_name['type']
_TABLEINDEXDESCRIPTION.fields_by_name['global_index'].message_type = _GLOBALINDEX
_TABLEINDEXDESCRIPTION.fields_by_name['global_async_index'].message_type = _GLOBALASYNCINDEX
_TABLEINDEXDESCRIPTION.fields_by_name['global_unique_index'].message_type = _GLOBALUNIQUEINDEX
_TABLEINDEXDESCRIPTION.fields_by_name['status'].enum_type = _TABLEINDEXDESCRIPTION_STATUS
_TABLEINDEXDESCRIPTION_STATUS.containing_type = _TABLEINDEXDESCRIPTION
_TABLEINDEXDESCRIPTION.oneofs_by_name['type'].fields.append(
  _TABLEINDEXDESCRIPTION.fields_by_name['global_index'])
_TABLEINDEXDESCRIPTION.fields_by_name['global_index'].containing_oneof = _TABLEINDEXDESCRIPTION.oneofs_by_name['type']
_TABLEINDEXDESCRIPTION.oneofs_by_name['type'].fields.append(
  _TABLEINDEXDESCRIPTION.fields_by_name['global_async_index'])
_TABLEINDEXDESCRIPTION.fields_by_name['global_async_index'].containing_oneof = _TABLEINDEXDESCRIPTION.oneofs_by_name['type']
_TABLEINDEXDESCRIPTION.oneofs_by_name['type'].fields.append(
  _TABLEINDEXDESCRIPTION.fields_by_name['global_unique_index'])
_TABLEINDEXDESCRIPTION.fields_by_name['global_unique_index'].containing_oneof = _TABLEINDEXDESCRIPTION.oneofs_by_name['type']
_INDEXBUILDSTATE_STATE.containing_type = _INDEXBUILDSTATE
_INDEXBUILDDESCRIPTION.fields_by_name['index'].message_type = _TABLEINDEX
_INDEXBUILDMETADATA.fields_by_name['description'].message_type = _INDEXBUILDDESCRIPTION
_INDEXBUILDMETADATA.fields_by_name['state'].enum_type = _INDEXBUILDSTATE_STATE
_CHANGEFEEDMODE_MODE.containing_type = _CHANGEFEEDMODE
_CHANGEFEEDFORMAT_FORMAT.containing_type = _CHANGEFEEDFORMAT
_CHANGEFEED_ATTRIBUTESENTRY.containing_type = _CHANGEFEED
_CHANGEFEED.fields_by_name['mode'].enum_type = _CHANGEFEEDMODE_MODE
_CHANGEFEED.fields_by_name['format'].enum_type = _CHANGEFEEDFORMAT_FORMAT
_CHANGEFEED.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CHANGEFEED.fields_by_name['attributes'].message_type = _CHANGEFEED_ATTRIBUTESENTRY
_CHANGEFEED.fields_by_name['resolved_timestamps_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CHANGEFEED.fields_by_name['topic_partitioning_settings'].message_type = protos_dot_ydb__topic__pb2._PARTITIONINGSETTINGS
_CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY.containing_type = _CHANGEFEEDDESCRIPTION
_CHANGEFEEDDESCRIPTION.fields_by_name['mode'].enum_type = _CHANGEFEEDMODE_MODE
_CHANGEFEEDDESCRIPTION.fields_by_name['format'].enum_type = _CHANGEFEEDFORMAT_FORMAT
_CHANGEFEEDDESCRIPTION.fields_by_name['state'].enum_type = _CHANGEFEEDDESCRIPTION_STATE
_CHANGEFEEDDESCRIPTION.fields_by_name['attributes'].message_type = _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY
_CHANGEFEEDDESCRIPTION.fields_by_name['resolved_timestamps_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CHANGEFEEDDESCRIPTION_STATE.containing_type = _CHANGEFEEDDESCRIPTION
_STORAGEPOLICY.fields_by_name['syslog'].message_type = _STORAGEPOOL
_STORAGEPOLICY.fields_by_name['log'].message_type = _STORAGEPOOL
_STORAGEPOLICY.fields_by_name['data'].message_type = _STORAGEPOOL
_STORAGEPOLICY.fields_by_name['external'].message_type = _STORAGEPOOL
_STORAGEPOLICY.fields_by_name['keep_in_memory'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_STORAGEPOLICY.fields_by_name['column_families'].message_type = _COLUMNFAMILYPOLICY
_COLUMNFAMILYPOLICY.fields_by_name['data'].message_type = _STORAGEPOOL
_COLUMNFAMILYPOLICY.fields_by_name['external'].message_type = _STORAGEPOOL
_COLUMNFAMILYPOLICY.fields_by_name['keep_in_memory'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_COLUMNFAMILYPOLICY.fields_by_name['compression'].enum_type = _COLUMNFAMILYPOLICY_COMPRESSION
_COLUMNFAMILYPOLICY_COMPRESSION.containing_type = _COLUMNFAMILYPOLICY
_EXPLICITPARTITIONS.fields_by_name['split_points'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_TABLESTATS.fields_by_name['partition_stats'].message_type = _PARTITIONSTATS
_TABLESTATS.fields_by_name['creation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLESTATS.fields_by_name['modification_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTITIONINGPOLICY.fields_by_name['auto_partitioning'].enum_type = _PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY
_PARTITIONINGPOLICY.fields_by_name['explicit_partitions'].message_type = _EXPLICITPARTITIONS
_PARTITIONINGPOLICY_AUTOPARTITIONINGPOLICY.containing_type = _PARTITIONINGPOLICY
_PARTITIONINGPOLICY.oneofs_by_name['partitions'].fields.append(
  _PARTITIONINGPOLICY.fields_by_name['uniform_partitions'])
_PARTITIONINGPOLICY.fields_by_name['uniform_partitions'].containing_oneof = _PARTITIONINGPOLICY.oneofs_by_name['partitions']
_PARTITIONINGPOLICY.oneofs_by_name['partitions'].fields.append(
  _PARTITIONINGPOLICY.fields_by_name['explicit_partitions'])
_PARTITIONINGPOLICY.fields_by_name['explicit_partitions'].containing_oneof = _PARTITIONINGPOLICY.oneofs_by_name['partitions']
_REPLICATIONPOLICY.fields_by_name['create_per_availability_zone'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_REPLICATIONPOLICY.fields_by_name['allow_promotion'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_TABLEPROFILE.fields_by_name['storage_policy'].message_type = _STORAGEPOLICY
_TABLEPROFILE.fields_by_name['compaction_policy'].message_type = _COMPACTIONPOLICY
_TABLEPROFILE.fields_by_name['partitioning_policy'].message_type = _PARTITIONINGPOLICY
_TABLEPROFILE.fields_by_name['execution_policy'].message_type = _EXECUTIONPOLICY
_TABLEPROFILE.fields_by_name['replication_policy'].message_type = _REPLICATIONPOLICY
_TABLEPROFILE.fields_by_name['caching_policy'].message_type = _CACHINGPOLICY
_SEQUENCEDESCRIPTION_SETVAL.containing_type = _SEQUENCEDESCRIPTION
_SEQUENCEDESCRIPTION_SETVAL.oneofs_by_name['_next_value'].fields.append(
  _SEQUENCEDESCRIPTION_SETVAL.fields_by_name['next_value'])
_SEQUENCEDESCRIPTION_SETVAL.fields_by_name['next_value'].containing_oneof = _SEQUENCEDESCRIPTION_SETVAL.oneofs_by_name['_next_value']
_SEQUENCEDESCRIPTION_SETVAL.oneofs_by_name['_next_used'].fields.append(
  _SEQUENCEDESCRIPTION_SETVAL.fields_by_name['next_used'])
_SEQUENCEDESCRIPTION_SETVAL.fields_by_name['next_used'].containing_oneof = _SEQUENCEDESCRIPTION_SETVAL.oneofs_by_name['_next_used']
_SEQUENCEDESCRIPTION.fields_by_name['set_val'].message_type = _SEQUENCEDESCRIPTION_SETVAL
_SEQUENCEDESCRIPTION.oneofs_by_name['_name'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['name'])
_SEQUENCEDESCRIPTION.fields_by_name['name'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_name']
_SEQUENCEDESCRIPTION.oneofs_by_name['_min_value'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['min_value'])
_SEQUENCEDESCRIPTION.fields_by_name['min_value'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_min_value']
_SEQUENCEDESCRIPTION.oneofs_by_name['_max_value'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['max_value'])
_SEQUENCEDESCRIPTION.fields_by_name['max_value'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_max_value']
_SEQUENCEDESCRIPTION.oneofs_by_name['_start_value'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['start_value'])
_SEQUENCEDESCRIPTION.fields_by_name['start_value'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_start_value']
_SEQUENCEDESCRIPTION.oneofs_by_name['_cache'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['cache'])
_SEQUENCEDESCRIPTION.fields_by_name['cache'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_cache']
_SEQUENCEDESCRIPTION.oneofs_by_name['_increment'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['increment'])
_SEQUENCEDESCRIPTION.fields_by_name['increment'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_increment']
_SEQUENCEDESCRIPTION.oneofs_by_name['_cycle'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['cycle'])
_SEQUENCEDESCRIPTION.fields_by_name['cycle'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_cycle']
_SEQUENCEDESCRIPTION.oneofs_by_name['_set_val'].fields.append(
  _SEQUENCEDESCRIPTION.fields_by_name['set_val'])
_SEQUENCEDESCRIPTION.fields_by_name['set_val'].containing_oneof = _SEQUENCEDESCRIPTION.oneofs_by_name['_set_val']
_COLUMNMETA.fields_by_name['type'].message_type = protos_dot_ydb__value__pb2._TYPE
_COLUMNMETA.fields_by_name['from_literal'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_COLUMNMETA.fields_by_name['from_sequence'].message_type = _SEQUENCEDESCRIPTION
_COLUMNMETA.oneofs_by_name['default_value'].fields.append(
  _COLUMNMETA.fields_by_name['from_literal'])
_COLUMNMETA.fields_by_name['from_literal'].containing_oneof = _COLUMNMETA.oneofs_by_name['default_value']
_COLUMNMETA.oneofs_by_name['default_value'].fields.append(
  _COLUMNMETA.fields_by_name['from_sequence'])
_COLUMNMETA.fields_by_name['from_sequence'].containing_oneof = _COLUMNMETA.oneofs_by_name['default_value']
_COLUMNMETA.oneofs_by_name['_not_null'].fields.append(
  _COLUMNMETA.fields_by_name['not_null'])
_COLUMNMETA.fields_by_name['not_null'].containing_oneof = _COLUMNMETA.oneofs_by_name['_not_null']
_VALUESINCEUNIXEPOCHMODESETTINGS.fields_by_name['column_unit'].enum_type = _VALUESINCEUNIXEPOCHMODESETTINGS_UNIT
_VALUESINCEUNIXEPOCHMODESETTINGS_UNIT.containing_type = _VALUESINCEUNIXEPOCHMODESETTINGS
_TTLSETTINGS.fields_by_name['date_type_column'].message_type = _DATETYPECOLUMNMODESETTINGS
_TTLSETTINGS.fields_by_name['value_since_unix_epoch'].message_type = _VALUESINCEUNIXEPOCHMODESETTINGS
_TTLSETTINGS.oneofs_by_name['mode'].fields.append(
  _TTLSETTINGS.fields_by_name['date_type_column'])
_TTLSETTINGS.fields_by_name['date_type_column'].containing_oneof = _TTLSETTINGS.oneofs_by_name['mode']
_TTLSETTINGS.oneofs_by_name['mode'].fields.append(
  _TTLSETTINGS.fields_by_name['value_since_unix_epoch'])
_TTLSETTINGS.fields_by_name['value_since_unix_epoch'].containing_oneof = _TTLSETTINGS.oneofs_by_name['mode']
_STORAGESETTINGS.fields_by_name['tablet_commit_log0'].message_type = _STORAGEPOOL
_STORAGESETTINGS.fields_by_name['tablet_commit_log1'].message_type = _STORAGEPOOL
_STORAGESETTINGS.fields_by_name['external'].message_type = _STORAGEPOOL
_STORAGESETTINGS.fields_by_name['store_external_blobs'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_COLUMNFAMILY.fields_by_name['data'].message_type = _STORAGEPOOL
_COLUMNFAMILY.fields_by_name['compression'].enum_type = _COLUMNFAMILY_COMPRESSION
_COLUMNFAMILY.fields_by_name['keep_in_memory'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_COLUMNFAMILY_COMPRESSION.containing_type = _COLUMNFAMILY
_PARTITIONINGSETTINGS.fields_by_name['partitioning_by_size'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_PARTITIONINGSETTINGS.fields_by_name['partitioning_by_load'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_CLUSTERREPLICASSETTINGS.fields_by_name['az_read_replicas_settings'].message_type = _AZREADREPLICASSETTINGS
_READREPLICASSETTINGS.oneofs_by_name['settings'].fields.append(
  _READREPLICASSETTINGS.fields_by_name['per_az_read_replicas_count'])
_READREPLICASSETTINGS.fields_by_name['per_az_read_replicas_count'].containing_oneof = _READREPLICASSETTINGS.oneofs_by_name['settings']
_READREPLICASSETTINGS.oneofs_by_name['settings'].fields.append(
  _READREPLICASSETTINGS.fields_by_name['any_az_read_replicas_count'])
_READREPLICASSETTINGS.fields_by_name['any_az_read_replicas_count'].containing_oneof = _READREPLICASSETTINGS.oneofs_by_name['settings']
_CREATETABLEREQUEST_ATTRIBUTESENTRY.containing_type = _CREATETABLEREQUEST
_CREATETABLEREQUEST.fields_by_name['columns'].message_type = _COLUMNMETA
_CREATETABLEREQUEST.fields_by_name['profile'].message_type = _TABLEPROFILE
_CREATETABLEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATETABLEREQUEST.fields_by_name['indexes'].message_type = _TABLEINDEX
_CREATETABLEREQUEST.fields_by_name['ttl_settings'].message_type = _TTLSETTINGS
_CREATETABLEREQUEST.fields_by_name['storage_settings'].message_type = _STORAGESETTINGS
_CREATETABLEREQUEST.fields_by_name['column_families'].message_type = _COLUMNFAMILY
_CREATETABLEREQUEST.fields_by_name['attributes'].message_type = _CREATETABLEREQUEST_ATTRIBUTESENTRY
_CREATETABLEREQUEST.fields_by_name['partition_at_keys'].message_type = _EXPLICITPARTITIONS
_CREATETABLEREQUEST.fields_by_name['partitioning_settings'].message_type = _PARTITIONINGSETTINGS
_CREATETABLEREQUEST.fields_by_name['key_bloom_filter'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_CREATETABLEREQUEST.fields_by_name['read_replicas_settings'].message_type = _READREPLICASSETTINGS
_CREATETABLEREQUEST.fields_by_name['store_type'].enum_type = _STORETYPE
_CREATETABLEREQUEST.oneofs_by_name['partitions'].fields.append(
  _CREATETABLEREQUEST.fields_by_name['uniform_partitions'])
_CREATETABLEREQUEST.fields_by_name['uniform_partitions'].containing_oneof = _CREATETABLEREQUEST.oneofs_by_name['partitions']
_CREATETABLEREQUEST.oneofs_by_name['partitions'].fields.append(
  _CREATETABLEREQUEST.fields_by_name['partition_at_keys'])
_CREATETABLEREQUEST.fields_by_name['partition_at_keys'].containing_oneof = _CREATETABLEREQUEST.oneofs_by_name['partitions']
_CREATETABLERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPTABLEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPTABLERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY.containing_type = _ALTERTABLEREQUEST
_ALTERTABLEREQUEST.fields_by_name['add_columns'].message_type = _COLUMNMETA
_ALTERTABLEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERTABLEREQUEST.fields_by_name['alter_columns'].message_type = _COLUMNMETA
_ALTERTABLEREQUEST.fields_by_name['set_ttl_settings'].message_type = _TTLSETTINGS
_ALTERTABLEREQUEST.fields_by_name['drop_ttl_settings'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ALTERTABLEREQUEST.fields_by_name['add_indexes'].message_type = _TABLEINDEX
_ALTERTABLEREQUEST.fields_by_name['alter_storage_settings'].message_type = _STORAGESETTINGS
_ALTERTABLEREQUEST.fields_by_name['add_column_families'].message_type = _COLUMNFAMILY
_ALTERTABLEREQUEST.fields_by_name['alter_column_families'].message_type = _COLUMNFAMILY
_ALTERTABLEREQUEST.fields_by_name['alter_attributes'].message_type = _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY
_ALTERTABLEREQUEST.fields_by_name['alter_partitioning_settings'].message_type = _PARTITIONINGSETTINGS
_ALTERTABLEREQUEST.fields_by_name['set_key_bloom_filter'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_ALTERTABLEREQUEST.fields_by_name['set_read_replicas_settings'].message_type = _READREPLICASSETTINGS
_ALTERTABLEREQUEST.fields_by_name['add_changefeeds'].message_type = _CHANGEFEED
_ALTERTABLEREQUEST.fields_by_name['rename_indexes'].message_type = _RENAMEINDEXITEM
_ALTERTABLEREQUEST.fields_by_name['drop_tiering'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ALTERTABLEREQUEST.oneofs_by_name['ttl_action'].fields.append(
  _ALTERTABLEREQUEST.fields_by_name['set_ttl_settings'])
_ALTERTABLEREQUEST.fields_by_name['set_ttl_settings'].containing_oneof = _ALTERTABLEREQUEST.oneofs_by_name['ttl_action']
_ALTERTABLEREQUEST.oneofs_by_name['ttl_action'].fields.append(
  _ALTERTABLEREQUEST.fields_by_name['drop_ttl_settings'])
_ALTERTABLEREQUEST.fields_by_name['drop_ttl_settings'].containing_oneof = _ALTERTABLEREQUEST.oneofs_by_name['ttl_action']
_ALTERTABLEREQUEST.oneofs_by_name['tiering_action'].fields.append(
  _ALTERTABLEREQUEST.fields_by_name['set_tiering'])
_ALTERTABLEREQUEST.fields_by_name['set_tiering'].containing_oneof = _ALTERTABLEREQUEST.oneofs_by_name['tiering_action']
_ALTERTABLEREQUEST.oneofs_by_name['tiering_action'].fields.append(
  _ALTERTABLEREQUEST.fields_by_name['drop_tiering'])
_ALTERTABLEREQUEST.fields_by_name['drop_tiering'].containing_oneof = _ALTERTABLEREQUEST.oneofs_by_name['tiering_action']
_ALTERTABLERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_COPYTABLEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_COPYTABLERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_COPYTABLESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_COPYTABLESREQUEST.fields_by_name['tables'].message_type = _COPYTABLEITEM
_COPYTABLESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_RENAMETABLESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_RENAMETABLESREQUEST.fields_by_name['tables'].message_type = _RENAMETABLEITEM
_RENAMETABLESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBETABLEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBETABLERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBETABLERESULT_ATTRIBUTESENTRY.containing_type = _DESCRIBETABLERESULT
_DESCRIBETABLERESULT.fields_by_name['self'].message_type = protos_dot_ydb__scheme__pb2._ENTRY
_DESCRIBETABLERESULT.fields_by_name['columns'].message_type = _COLUMNMETA
_DESCRIBETABLERESULT.fields_by_name['shard_key_bounds'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_DESCRIBETABLERESULT.fields_by_name['indexes'].message_type = _TABLEINDEXDESCRIPTION
_DESCRIBETABLERESULT.fields_by_name['table_stats'].message_type = _TABLESTATS
_DESCRIBETABLERESULT.fields_by_name['ttl_settings'].message_type = _TTLSETTINGS
_DESCRIBETABLERESULT.fields_by_name['storage_settings'].message_type = _STORAGESETTINGS
_DESCRIBETABLERESULT.fields_by_name['column_families'].message_type = _COLUMNFAMILY
_DESCRIBETABLERESULT.fields_by_name['attributes'].message_type = _DESCRIBETABLERESULT_ATTRIBUTESENTRY
_DESCRIBETABLERESULT.fields_by_name['partitioning_settings'].message_type = _PARTITIONINGSETTINGS
_DESCRIBETABLERESULT.fields_by_name['key_bloom_filter'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_DESCRIBETABLERESULT.fields_by_name['read_replicas_settings'].message_type = _READREPLICASSETTINGS
_DESCRIBETABLERESULT.fields_by_name['changefeeds'].message_type = _CHANGEFEEDDESCRIPTION
_DESCRIBETABLERESULT.fields_by_name['store_type'].enum_type = _STORETYPE
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['yql_text'])
_QUERY.fields_by_name['yql_text'].containing_oneof = _QUERY.oneofs_by_name['query']
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['id'])
_QUERY.fields_by_name['id'].containing_oneof = _QUERY.oneofs_by_name['query']
_TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'].message_type = _SERIALIZABLEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['online_read_only'].message_type = _ONLINEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['stale_read_only'].message_type = _STALEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'].message_type = _SNAPSHOTMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'].message_type = _SNAPSHOTRWMODESETTINGS
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'])
_TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['online_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['online_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['stale_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['stale_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'])
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONCONTROL.fields_by_name['begin_tx'].message_type = _TRANSACTIONSETTINGS
_TRANSACTIONCONTROL.oneofs_by_name['tx_selector'].fields.append(
  _TRANSACTIONCONTROL.fields_by_name['tx_id'])
_TRANSACTIONCONTROL.fields_by_name['tx_id'].containing_oneof = _TRANSACTIONCONTROL.oneofs_by_name['tx_selector']
_TRANSACTIONCONTROL.oneofs_by_name['tx_selector'].fields.append(
  _TRANSACTIONCONTROL.fields_by_name['begin_tx'])
_TRANSACTIONCONTROL.fields_by_name['begin_tx'].containing_oneof = _TRANSACTIONCONTROL.oneofs_by_name['tx_selector']
_QUERYSTATSCOLLECTION_MODE.containing_type = _QUERYSTATSCOLLECTION
_EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY.containing_type = _EXECUTEDATAQUERYREQUEST
_EXECUTEDATAQUERYREQUEST.fields_by_name['tx_control'].message_type = _TRANSACTIONCONTROL
_EXECUTEDATAQUERYREQUEST.fields_by_name['query'].message_type = _QUERY
_EXECUTEDATAQUERYREQUEST.fields_by_name['parameters'].message_type = _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY
_EXECUTEDATAQUERYREQUEST.fields_by_name['query_cache_policy'].message_type = _QUERYCACHEPOLICY
_EXECUTEDATAQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXECUTEDATAQUERYREQUEST.fields_by_name['collect_stats'].enum_type = _QUERYSTATSCOLLECTION_MODE
_EXECUTEDATAQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXECUTESCHEMEQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXECUTESCHEMEQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_QUERYMETA_PARAMETERSTYPESENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPE
_QUERYMETA_PARAMETERSTYPESENTRY.containing_type = _QUERYMETA
_QUERYMETA.fields_by_name['parameters_types'].message_type = _QUERYMETA_PARAMETERSTYPESENTRY
_EXECUTEQUERYRESULT.fields_by_name['result_sets'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_EXECUTEQUERYRESULT.fields_by_name['tx_meta'].message_type = _TRANSACTIONMETA
_EXECUTEQUERYRESULT.fields_by_name['query_meta'].message_type = _QUERYMETA
_EXECUTEQUERYRESULT.fields_by_name['query_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_EXPLAINDATAQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXPLAINDATAQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_PREPAREDATAQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_PREPAREDATAQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_PREPAREQUERYRESULT_PARAMETERSTYPESENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPE
_PREPAREQUERYRESULT_PARAMETERSTYPESENTRY.containing_type = _PREPAREQUERYRESULT
_PREPAREQUERYRESULT.fields_by_name['parameters_types'].message_type = _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY
_KEEPALIVEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_KEEPALIVERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_KEEPALIVERESULT.fields_by_name['session_status'].enum_type = _KEEPALIVERESULT_SESSIONSTATUS
_KEEPALIVERESULT_SESSIONSTATUS.containing_type = _KEEPALIVERESULT
_BEGINTRANSACTIONREQUEST.fields_by_name['tx_settings'].message_type = _TRANSACTIONSETTINGS
_BEGINTRANSACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_BEGINTRANSACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_BEGINTRANSACTIONRESULT.fields_by_name['tx_meta'].message_type = _TRANSACTIONMETA
_COMMITTRANSACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_COMMITTRANSACTIONREQUEST.fields_by_name['collect_stats'].enum_type = _QUERYSTATSCOLLECTION_MODE
_COMMITTRANSACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_COMMITTRANSACTIONRESULT.fields_by_name['query_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_ROLLBACKTRANSACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ROLLBACKTRANSACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_STORAGEPOLICYDESCRIPTION_LABELSENTRY.containing_type = _STORAGEPOLICYDESCRIPTION
_STORAGEPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _STORAGEPOLICYDESCRIPTION_LABELSENTRY
_COMPACTIONPOLICYDESCRIPTION_LABELSENTRY.containing_type = _COMPACTIONPOLICYDESCRIPTION
_COMPACTIONPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY
_PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY.containing_type = _PARTITIONINGPOLICYDESCRIPTION
_PARTITIONINGPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY
_EXECUTIONPOLICYDESCRIPTION_LABELSENTRY.containing_type = _EXECUTIONPOLICYDESCRIPTION
_EXECUTIONPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY
_REPLICATIONPOLICYDESCRIPTION_LABELSENTRY.containing_type = _REPLICATIONPOLICYDESCRIPTION
_REPLICATIONPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY
_CACHINGPOLICYDESCRIPTION_LABELSENTRY.containing_type = _CACHINGPOLICYDESCRIPTION
_CACHINGPOLICYDESCRIPTION.fields_by_name['labels'].message_type = _CACHINGPOLICYDESCRIPTION_LABELSENTRY
_TABLEPROFILEDESCRIPTION_LABELSENTRY.containing_type = _TABLEPROFILEDESCRIPTION
_TABLEPROFILEDESCRIPTION.fields_by_name['labels'].message_type = _TABLEPROFILEDESCRIPTION_LABELSENTRY
_DESCRIBETABLEOPTIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBETABLEOPTIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['table_profile_presets'].message_type = _TABLEPROFILEDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['storage_policy_presets'].message_type = _STORAGEPOLICYDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['compaction_policy_presets'].message_type = _COMPACTIONPOLICYDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['partitioning_policy_presets'].message_type = _PARTITIONINGPOLICYDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['execution_policy_presets'].message_type = _EXECUTIONPOLICYDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['replication_policy_presets'].message_type = _REPLICATIONPOLICYDESCRIPTION
_DESCRIBETABLEOPTIONSRESULT.fields_by_name['caching_policy_presets'].message_type = _CACHINGPOLICYDESCRIPTION
_KEYRANGE.fields_by_name['greater'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_KEYRANGE.fields_by_name['greater_or_equal'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_KEYRANGE.fields_by_name['less'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_KEYRANGE.fields_by_name['less_or_equal'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_KEYRANGE.oneofs_by_name['from_bound'].fields.append(
  _KEYRANGE.fields_by_name['greater'])
_KEYRANGE.fields_by_name['greater'].containing_oneof = _KEYRANGE.oneofs_by_name['from_bound']
_KEYRANGE.oneofs_by_name['from_bound'].fields.append(
  _KEYRANGE.fields_by_name['greater_or_equal'])
_KEYRANGE.fields_by_name['greater_or_equal'].containing_oneof = _KEYRANGE.oneofs_by_name['from_bound']
_KEYRANGE.oneofs_by_name['to_bound'].fields.append(
  _KEYRANGE.fields_by_name['less'])
_KEYRANGE.fields_by_name['less'].containing_oneof = _KEYRANGE.oneofs_by_name['to_bound']
_KEYRANGE.oneofs_by_name['to_bound'].fields.append(
  _KEYRANGE.fields_by_name['less_or_equal'])
_KEYRANGE.fields_by_name['less_or_equal'].containing_oneof = _KEYRANGE.oneofs_by_name['to_bound']
_READTABLEREQUEST.fields_by_name['key_range'].message_type = _KEYRANGE
_READTABLEREQUEST.fields_by_name['use_snapshot'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_READTABLEREQUEST.fields_by_name['return_not_null_data_as_optional'].enum_type = protos_dot_ydb__common__pb2._FEATUREFLAG_STATUS
_READTABLERESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_READTABLERESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_READTABLERESPONSE.fields_by_name['snapshot'].message_type = protos_dot_ydb__common__pb2._VIRTUALTIMESTAMP
_READTABLERESPONSE.fields_by_name['result'].message_type = _READTABLERESULT
_READTABLERESULT.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_READROWSREQUEST.fields_by_name['keys'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_READROWSRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_READROWSRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_READROWSRESPONSE.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_BULKUPSERTREQUEST.fields_by_name['rows'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_BULKUPSERTREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_BULKUPSERTREQUEST.fields_by_name['arrow_batch_settings'].message_type = protos_dot_ydb__formats__pb2._ARROWBATCHSETTINGS
_BULKUPSERTREQUEST.fields_by_name['csv_settings'].message_type = protos_dot_ydb__formats__pb2._CSVSETTINGS
_BULKUPSERTREQUEST.oneofs_by_name['data_format'].fields.append(
  _BULKUPSERTREQUEST.fields_by_name['arrow_batch_settings'])
_BULKUPSERTREQUEST.fields_by_name['arrow_batch_settings'].containing_oneof = _BULKUPSERTREQUEST.oneofs_by_name['data_format']
_BULKUPSERTREQUEST.oneofs_by_name['data_format'].fields.append(
  _BULKUPSERTREQUEST.fields_by_name['csv_settings'])
_BULKUPSERTREQUEST.fields_by_name['csv_settings'].containing_oneof = _BULKUPSERTREQUEST.oneofs_by_name['data_format']
_BULKUPSERTRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXECUTESCANQUERYREQUEST_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_EXECUTESCANQUERYREQUEST_PARAMETERSENTRY.containing_type = _EXECUTESCANQUERYREQUEST
_EXECUTESCANQUERYREQUEST.fields_by_name['query'].message_type = _QUERY
_EXECUTESCANQUERYREQUEST.fields_by_name['parameters'].message_type = _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY
_EXECUTESCANQUERYREQUEST.fields_by_name['mode'].enum_type = _EXECUTESCANQUERYREQUEST_MODE
_EXECUTESCANQUERYREQUEST.fields_by_name['collect_stats'].enum_type = _QUERYSTATSCOLLECTION_MODE
_EXECUTESCANQUERYREQUEST_MODE.containing_type = _EXECUTESCANQUERYREQUEST
_EXECUTESCANQUERYPARTIALRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_EXECUTESCANQUERYPARTIALRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_EXECUTESCANQUERYPARTIALRESPONSE.fields_by_name['result'].message_type = _EXECUTESCANQUERYPARTIALRESULT
_EXECUTESCANQUERYPARTIALRESULT.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_EXECUTESCANQUERYPARTIALRESULT.fields_by_name['query_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateSessionResult'] = _CREATESESSIONRESULT
DESCRIPTOR.message_types_by_name['DeleteSessionRequest'] = _DELETESESSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteSessionResponse'] = _DELETESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['GlobalIndex'] = _GLOBALINDEX
DESCRIPTOR.message_types_by_name['GlobalAsyncIndex'] = _GLOBALASYNCINDEX
DESCRIPTOR.message_types_by_name['GlobalUniqueIndex'] = _GLOBALUNIQUEINDEX
DESCRIPTOR.message_types_by_name['TableIndex'] = _TABLEINDEX
DESCRIPTOR.message_types_by_name['TableIndexDescription'] = _TABLEINDEXDESCRIPTION
DESCRIPTOR.message_types_by_name['IndexBuildState'] = _INDEXBUILDSTATE
DESCRIPTOR.message_types_by_name['IndexBuildDescription'] = _INDEXBUILDDESCRIPTION
DESCRIPTOR.message_types_by_name['IndexBuildMetadata'] = _INDEXBUILDMETADATA
DESCRIPTOR.message_types_by_name['ChangefeedMode'] = _CHANGEFEEDMODE
DESCRIPTOR.message_types_by_name['ChangefeedFormat'] = _CHANGEFEEDFORMAT
DESCRIPTOR.message_types_by_name['Changefeed'] = _CHANGEFEED
DESCRIPTOR.message_types_by_name['ChangefeedDescription'] = _CHANGEFEEDDESCRIPTION
DESCRIPTOR.message_types_by_name['StoragePool'] = _STORAGEPOOL
DESCRIPTOR.message_types_by_name['StoragePolicy'] = _STORAGEPOLICY
DESCRIPTOR.message_types_by_name['ColumnFamilyPolicy'] = _COLUMNFAMILYPOLICY
DESCRIPTOR.message_types_by_name['CompactionPolicy'] = _COMPACTIONPOLICY
DESCRIPTOR.message_types_by_name['ExplicitPartitions'] = _EXPLICITPARTITIONS
DESCRIPTOR.message_types_by_name['PartitionStats'] = _PARTITIONSTATS
DESCRIPTOR.message_types_by_name['TableStats'] = _TABLESTATS
DESCRIPTOR.message_types_by_name['PartitioningPolicy'] = _PARTITIONINGPOLICY
DESCRIPTOR.message_types_by_name['ExecutionPolicy'] = _EXECUTIONPOLICY
DESCRIPTOR.message_types_by_name['ReplicationPolicy'] = _REPLICATIONPOLICY
DESCRIPTOR.message_types_by_name['CachingPolicy'] = _CACHINGPOLICY
DESCRIPTOR.message_types_by_name['TableProfile'] = _TABLEPROFILE
DESCRIPTOR.message_types_by_name['SequenceDescription'] = _SEQUENCEDESCRIPTION
DESCRIPTOR.message_types_by_name['ColumnMeta'] = _COLUMNMETA
DESCRIPTOR.message_types_by_name['DateTypeColumnModeSettings'] = _DATETYPECOLUMNMODESETTINGS
DESCRIPTOR.message_types_by_name['ValueSinceUnixEpochModeSettings'] = _VALUESINCEUNIXEPOCHMODESETTINGS
DESCRIPTOR.message_types_by_name['TtlSettings'] = _TTLSETTINGS
DESCRIPTOR.message_types_by_name['StorageSettings'] = _STORAGESETTINGS
DESCRIPTOR.message_types_by_name['ColumnFamily'] = _COLUMNFAMILY
DESCRIPTOR.message_types_by_name['PartitioningSettings'] = _PARTITIONINGSETTINGS
DESCRIPTOR.message_types_by_name['AzReadReplicasSettings'] = _AZREADREPLICASSETTINGS
DESCRIPTOR.message_types_by_name['ClusterReplicasSettings'] = _CLUSTERREPLICASSETTINGS
DESCRIPTOR.message_types_by_name['ReadReplicasSettings'] = _READREPLICASSETTINGS
DESCRIPTOR.message_types_by_name['CreateTableRequest'] = _CREATETABLEREQUEST
DESCRIPTOR.message_types_by_name['CreateTableResponse'] = _CREATETABLERESPONSE
DESCRIPTOR.message_types_by_name['DropTableRequest'] = _DROPTABLEREQUEST
DESCRIPTOR.message_types_by_name['DropTableResponse'] = _DROPTABLERESPONSE
DESCRIPTOR.message_types_by_name['RenameIndexItem'] = _RENAMEINDEXITEM
DESCRIPTOR.message_types_by_name['AlterTableRequest'] = _ALTERTABLEREQUEST
DESCRIPTOR.message_types_by_name['AlterTableResponse'] = _ALTERTABLERESPONSE
DESCRIPTOR.message_types_by_name['CopyTableRequest'] = _COPYTABLEREQUEST
DESCRIPTOR.message_types_by_name['CopyTableResponse'] = _COPYTABLERESPONSE
DESCRIPTOR.message_types_by_name['CopyTableItem'] = _COPYTABLEITEM
DESCRIPTOR.message_types_by_name['CopyTablesRequest'] = _COPYTABLESREQUEST
DESCRIPTOR.message_types_by_name['CopyTablesResponse'] = _COPYTABLESRESPONSE
DESCRIPTOR.message_types_by_name['RenameTableItem'] = _RENAMETABLEITEM
DESCRIPTOR.message_types_by_name['RenameTablesRequest'] = _RENAMETABLESREQUEST
DESCRIPTOR.message_types_by_name['RenameTablesResponse'] = _RENAMETABLESRESPONSE
DESCRIPTOR.message_types_by_name['DescribeTableRequest'] = _DESCRIBETABLEREQUEST
DESCRIPTOR.message_types_by_name['DescribeTableResponse'] = _DESCRIBETABLERESPONSE
DESCRIPTOR.message_types_by_name['DescribeTableResult'] = _DESCRIBETABLERESULT
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['SerializableModeSettings'] = _SERIALIZABLEMODESETTINGS
DESCRIPTOR.message_types_by_name['OnlineModeSettings'] = _ONLINEMODESETTINGS
DESCRIPTOR.message_types_by_name['StaleModeSettings'] = _STALEMODESETTINGS
DESCRIPTOR.message_types_by_name['SnapshotModeSettings'] = _SNAPSHOTMODESETTINGS
DESCRIPTOR.message_types_by_name['SnapshotRWModeSettings'] = _SNAPSHOTRWMODESETTINGS
DESCRIPTOR.message_types_by_name['TransactionSettings'] = _TRANSACTIONSETTINGS
DESCRIPTOR.message_types_by_name['TransactionControl'] = _TRANSACTIONCONTROL
DESCRIPTOR.message_types_by_name['QueryCachePolicy'] = _QUERYCACHEPOLICY
DESCRIPTOR.message_types_by_name['QueryStatsCollection'] = _QUERYSTATSCOLLECTION
DESCRIPTOR.message_types_by_name['ExecuteDataQueryRequest'] = _EXECUTEDATAQUERYREQUEST
DESCRIPTOR.message_types_by_name['ExecuteDataQueryResponse'] = _EXECUTEDATAQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteSchemeQueryRequest'] = _EXECUTESCHEMEQUERYREQUEST
DESCRIPTOR.message_types_by_name['ExecuteSchemeQueryResponse'] = _EXECUTESCHEMEQUERYRESPONSE
DESCRIPTOR.message_types_by_name['TransactionMeta'] = _TRANSACTIONMETA
DESCRIPTOR.message_types_by_name['QueryMeta'] = _QUERYMETA
DESCRIPTOR.message_types_by_name['ExecuteQueryResult'] = _EXECUTEQUERYRESULT
DESCRIPTOR.message_types_by_name['ExplainDataQueryRequest'] = _EXPLAINDATAQUERYREQUEST
DESCRIPTOR.message_types_by_name['ExplainDataQueryResponse'] = _EXPLAINDATAQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ExplainQueryResult'] = _EXPLAINQUERYRESULT
DESCRIPTOR.message_types_by_name['PrepareDataQueryRequest'] = _PREPAREDATAQUERYREQUEST
DESCRIPTOR.message_types_by_name['PrepareDataQueryResponse'] = _PREPAREDATAQUERYRESPONSE
DESCRIPTOR.message_types_by_name['PrepareQueryResult'] = _PREPAREQUERYRESULT
DESCRIPTOR.message_types_by_name['KeepAliveRequest'] = _KEEPALIVEREQUEST
DESCRIPTOR.message_types_by_name['KeepAliveResponse'] = _KEEPALIVERESPONSE
DESCRIPTOR.message_types_by_name['KeepAliveResult'] = _KEEPALIVERESULT
DESCRIPTOR.message_types_by_name['BeginTransactionRequest'] = _BEGINTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['BeginTransactionResponse'] = _BEGINTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['BeginTransactionResult'] = _BEGINTRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['CommitTransactionRequest'] = _COMMITTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['CommitTransactionResponse'] = _COMMITTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['CommitTransactionResult'] = _COMMITTRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['RollbackTransactionRequest'] = _ROLLBACKTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['RollbackTransactionResponse'] = _ROLLBACKTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['StoragePolicyDescription'] = _STORAGEPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['CompactionPolicyDescription'] = _COMPACTIONPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['PartitioningPolicyDescription'] = _PARTITIONINGPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['ExecutionPolicyDescription'] = _EXECUTIONPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['ReplicationPolicyDescription'] = _REPLICATIONPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['CachingPolicyDescription'] = _CACHINGPOLICYDESCRIPTION
DESCRIPTOR.message_types_by_name['TableProfileDescription'] = _TABLEPROFILEDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeTableOptionsRequest'] = _DESCRIBETABLEOPTIONSREQUEST
DESCRIPTOR.message_types_by_name['DescribeTableOptionsResponse'] = _DESCRIBETABLEOPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['DescribeTableOptionsResult'] = _DESCRIBETABLEOPTIONSRESULT
DESCRIPTOR.message_types_by_name['KeyRange'] = _KEYRANGE
DESCRIPTOR.message_types_by_name['ReadTableRequest'] = _READTABLEREQUEST
DESCRIPTOR.message_types_by_name['ReadTableResponse'] = _READTABLERESPONSE
DESCRIPTOR.message_types_by_name['ReadTableResult'] = _READTABLERESULT
DESCRIPTOR.message_types_by_name['ReadRowsRequest'] = _READROWSREQUEST
DESCRIPTOR.message_types_by_name['ReadRowsResponse'] = _READROWSRESPONSE
DESCRIPTOR.message_types_by_name['BulkUpsertRequest'] = _BULKUPSERTREQUEST
DESCRIPTOR.message_types_by_name['BulkUpsertResponse'] = _BULKUPSERTRESPONSE
DESCRIPTOR.message_types_by_name['BulkUpsertResult'] = _BULKUPSERTRESULT
DESCRIPTOR.message_types_by_name['ExecuteScanQueryRequest'] = _EXECUTESCANQUERYREQUEST
DESCRIPTOR.message_types_by_name['ExecuteScanQueryPartialResponse'] = _EXECUTESCANQUERYPARTIALRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteScanQueryPartialResult'] = _EXECUTESCANQUERYPARTIALRESULT
DESCRIPTOR.enum_types_by_name['StoreType'] = _STORETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSessionRequest = _reflection.GeneratedProtocolMessageType('CreateSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CreateSessionRequest)
  })
_sym_db.RegisterMessage(CreateSessionRequest)

CreateSessionResponse = _reflection.GeneratedProtocolMessageType('CreateSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CreateSessionResponse)
  })
_sym_db.RegisterMessage(CreateSessionResponse)

CreateSessionResult = _reflection.GeneratedProtocolMessageType('CreateSessionResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CreateSessionResult)
  })
_sym_db.RegisterMessage(CreateSessionResult)

DeleteSessionRequest = _reflection.GeneratedProtocolMessageType('DeleteSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DeleteSessionRequest)
  })
_sym_db.RegisterMessage(DeleteSessionRequest)

DeleteSessionResponse = _reflection.GeneratedProtocolMessageType('DeleteSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DeleteSessionResponse)
  })
_sym_db.RegisterMessage(DeleteSessionResponse)

GlobalIndex = _reflection.GeneratedProtocolMessageType('GlobalIndex', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALINDEX,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.GlobalIndex)
  })
_sym_db.RegisterMessage(GlobalIndex)

GlobalAsyncIndex = _reflection.GeneratedProtocolMessageType('GlobalAsyncIndex', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALASYNCINDEX,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.GlobalAsyncIndex)
  })
_sym_db.RegisterMessage(GlobalAsyncIndex)

GlobalUniqueIndex = _reflection.GeneratedProtocolMessageType('GlobalUniqueIndex', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALUNIQUEINDEX,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.GlobalUniqueIndex)
  })
_sym_db.RegisterMessage(GlobalUniqueIndex)

TableIndex = _reflection.GeneratedProtocolMessageType('TableIndex', (_message.Message,), {
  'DESCRIPTOR' : _TABLEINDEX,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TableIndex)
  })
_sym_db.RegisterMessage(TableIndex)

TableIndexDescription = _reflection.GeneratedProtocolMessageType('TableIndexDescription', (_message.Message,), {
  'DESCRIPTOR' : _TABLEINDEXDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TableIndexDescription)
  })
_sym_db.RegisterMessage(TableIndexDescription)

IndexBuildState = _reflection.GeneratedProtocolMessageType('IndexBuildState', (_message.Message,), {
  'DESCRIPTOR' : _INDEXBUILDSTATE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.IndexBuildState)
  })
_sym_db.RegisterMessage(IndexBuildState)

IndexBuildDescription = _reflection.GeneratedProtocolMessageType('IndexBuildDescription', (_message.Message,), {
  'DESCRIPTOR' : _INDEXBUILDDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.IndexBuildDescription)
  })
_sym_db.RegisterMessage(IndexBuildDescription)

IndexBuildMetadata = _reflection.GeneratedProtocolMessageType('IndexBuildMetadata', (_message.Message,), {
  'DESCRIPTOR' : _INDEXBUILDMETADATA,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.IndexBuildMetadata)
  })
_sym_db.RegisterMessage(IndexBuildMetadata)

ChangefeedMode = _reflection.GeneratedProtocolMessageType('ChangefeedMode', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEFEEDMODE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ChangefeedMode)
  })
_sym_db.RegisterMessage(ChangefeedMode)

ChangefeedFormat = _reflection.GeneratedProtocolMessageType('ChangefeedFormat', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEFEEDFORMAT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ChangefeedFormat)
  })
_sym_db.RegisterMessage(ChangefeedFormat)

Changefeed = _reflection.GeneratedProtocolMessageType('Changefeed', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHANGEFEED_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.Changefeed.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CHANGEFEED,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.Changefeed)
  })
_sym_db.RegisterMessage(Changefeed)
_sym_db.RegisterMessage(Changefeed.AttributesEntry)

ChangefeedDescription = _reflection.GeneratedProtocolMessageType('ChangefeedDescription', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.ChangefeedDescription.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CHANGEFEEDDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ChangefeedDescription)
  })
_sym_db.RegisterMessage(ChangefeedDescription)
_sym_db.RegisterMessage(ChangefeedDescription.AttributesEntry)

StoragePool = _reflection.GeneratedProtocolMessageType('StoragePool', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPOOL,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.StoragePool)
  })
_sym_db.RegisterMessage(StoragePool)

StoragePolicy = _reflection.GeneratedProtocolMessageType('StoragePolicy', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.StoragePolicy)
  })
_sym_db.RegisterMessage(StoragePolicy)

ColumnFamilyPolicy = _reflection.GeneratedProtocolMessageType('ColumnFamilyPolicy', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNFAMILYPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ColumnFamilyPolicy)
  })
_sym_db.RegisterMessage(ColumnFamilyPolicy)

CompactionPolicy = _reflection.GeneratedProtocolMessageType('CompactionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTIONPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CompactionPolicy)
  })
_sym_db.RegisterMessage(CompactionPolicy)

ExplicitPartitions = _reflection.GeneratedProtocolMessageType('ExplicitPartitions', (_message.Message,), {
  'DESCRIPTOR' : _EXPLICITPARTITIONS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExplicitPartitions)
  })
_sym_db.RegisterMessage(ExplicitPartitions)

PartitionStats = _reflection.GeneratedProtocolMessageType('PartitionStats', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONSTATS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PartitionStats)
  })
_sym_db.RegisterMessage(PartitionStats)

TableStats = _reflection.GeneratedProtocolMessageType('TableStats', (_message.Message,), {
  'DESCRIPTOR' : _TABLESTATS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TableStats)
  })
_sym_db.RegisterMessage(TableStats)

PartitioningPolicy = _reflection.GeneratedProtocolMessageType('PartitioningPolicy', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONINGPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PartitioningPolicy)
  })
_sym_db.RegisterMessage(PartitioningPolicy)

ExecutionPolicy = _reflection.GeneratedProtocolMessageType('ExecutionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecutionPolicy)
  })
_sym_db.RegisterMessage(ExecutionPolicy)

ReplicationPolicy = _reflection.GeneratedProtocolMessageType('ReplicationPolicy', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReplicationPolicy)
  })
_sym_db.RegisterMessage(ReplicationPolicy)

CachingPolicy = _reflection.GeneratedProtocolMessageType('CachingPolicy', (_message.Message,), {
  'DESCRIPTOR' : _CACHINGPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CachingPolicy)
  })
_sym_db.RegisterMessage(CachingPolicy)

TableProfile = _reflection.GeneratedProtocolMessageType('TableProfile', (_message.Message,), {
  'DESCRIPTOR' : _TABLEPROFILE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TableProfile)
  })
_sym_db.RegisterMessage(TableProfile)

SequenceDescription = _reflection.GeneratedProtocolMessageType('SequenceDescription', (_message.Message,), {

  'SetVal' : _reflection.GeneratedProtocolMessageType('SetVal', (_message.Message,), {
    'DESCRIPTOR' : _SEQUENCEDESCRIPTION_SETVAL,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.SequenceDescription.SetVal)
    })
  ,
  'DESCRIPTOR' : _SEQUENCEDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.SequenceDescription)
  })
_sym_db.RegisterMessage(SequenceDescription)
_sym_db.RegisterMessage(SequenceDescription.SetVal)

ColumnMeta = _reflection.GeneratedProtocolMessageType('ColumnMeta', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNMETA,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ColumnMeta)
  })
_sym_db.RegisterMessage(ColumnMeta)

DateTypeColumnModeSettings = _reflection.GeneratedProtocolMessageType('DateTypeColumnModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _DATETYPECOLUMNMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DateTypeColumnModeSettings)
  })
_sym_db.RegisterMessage(DateTypeColumnModeSettings)

ValueSinceUnixEpochModeSettings = _reflection.GeneratedProtocolMessageType('ValueSinceUnixEpochModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _VALUESINCEUNIXEPOCHMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ValueSinceUnixEpochModeSettings)
  })
_sym_db.RegisterMessage(ValueSinceUnixEpochModeSettings)

TtlSettings = _reflection.GeneratedProtocolMessageType('TtlSettings', (_message.Message,), {
  'DESCRIPTOR' : _TTLSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TtlSettings)
  })
_sym_db.RegisterMessage(TtlSettings)

StorageSettings = _reflection.GeneratedProtocolMessageType('StorageSettings', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.StorageSettings)
  })
_sym_db.RegisterMessage(StorageSettings)

ColumnFamily = _reflection.GeneratedProtocolMessageType('ColumnFamily', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNFAMILY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ColumnFamily)
  })
_sym_db.RegisterMessage(ColumnFamily)

PartitioningSettings = _reflection.GeneratedProtocolMessageType('PartitioningSettings', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONINGSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PartitioningSettings)
  })
_sym_db.RegisterMessage(PartitioningSettings)

AzReadReplicasSettings = _reflection.GeneratedProtocolMessageType('AzReadReplicasSettings', (_message.Message,), {
  'DESCRIPTOR' : _AZREADREPLICASSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.AzReadReplicasSettings)
  })
_sym_db.RegisterMessage(AzReadReplicasSettings)

ClusterReplicasSettings = _reflection.GeneratedProtocolMessageType('ClusterReplicasSettings', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERREPLICASSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ClusterReplicasSettings)
  })
_sym_db.RegisterMessage(ClusterReplicasSettings)

ReadReplicasSettings = _reflection.GeneratedProtocolMessageType('ReadReplicasSettings', (_message.Message,), {
  'DESCRIPTOR' : _READREPLICASSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadReplicasSettings)
  })
_sym_db.RegisterMessage(ReadReplicasSettings)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETABLEREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.CreateTableRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)
_sym_db.RegisterMessage(CreateTableRequest.AttributesEntry)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DropTableRequest = _reflection.GeneratedProtocolMessageType('DropTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPTABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DropTableRequest)
  })
_sym_db.RegisterMessage(DropTableRequest)

DropTableResponse = _reflection.GeneratedProtocolMessageType('DropTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPTABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DropTableResponse)
  })
_sym_db.RegisterMessage(DropTableResponse)

RenameIndexItem = _reflection.GeneratedProtocolMessageType('RenameIndexItem', (_message.Message,), {
  'DESCRIPTOR' : _RENAMEINDEXITEM,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RenameIndexItem)
  })
_sym_db.RegisterMessage(RenameIndexItem)

AlterTableRequest = _reflection.GeneratedProtocolMessageType('AlterTableRequest', (_message.Message,), {

  'AlterAttributesEntry' : _reflection.GeneratedProtocolMessageType('AlterAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.AlterTableRequest.AlterAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _ALTERTABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.AlterTableRequest)
  })
_sym_db.RegisterMessage(AlterTableRequest)
_sym_db.RegisterMessage(AlterTableRequest.AlterAttributesEntry)

AlterTableResponse = _reflection.GeneratedProtocolMessageType('AlterTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERTABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.AlterTableResponse)
  })
_sym_db.RegisterMessage(AlterTableResponse)

CopyTableRequest = _reflection.GeneratedProtocolMessageType('CopyTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYTABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CopyTableRequest)
  })
_sym_db.RegisterMessage(CopyTableRequest)

CopyTableResponse = _reflection.GeneratedProtocolMessageType('CopyTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _COPYTABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CopyTableResponse)
  })
_sym_db.RegisterMessage(CopyTableResponse)

CopyTableItem = _reflection.GeneratedProtocolMessageType('CopyTableItem', (_message.Message,), {
  'DESCRIPTOR' : _COPYTABLEITEM,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CopyTableItem)
  })
_sym_db.RegisterMessage(CopyTableItem)

CopyTablesRequest = _reflection.GeneratedProtocolMessageType('CopyTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYTABLESREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CopyTablesRequest)
  })
_sym_db.RegisterMessage(CopyTablesRequest)

CopyTablesResponse = _reflection.GeneratedProtocolMessageType('CopyTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _COPYTABLESRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CopyTablesResponse)
  })
_sym_db.RegisterMessage(CopyTablesResponse)

RenameTableItem = _reflection.GeneratedProtocolMessageType('RenameTableItem', (_message.Message,), {
  'DESCRIPTOR' : _RENAMETABLEITEM,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RenameTableItem)
  })
_sym_db.RegisterMessage(RenameTableItem)

RenameTablesRequest = _reflection.GeneratedProtocolMessageType('RenameTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _RENAMETABLESREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RenameTablesRequest)
  })
_sym_db.RegisterMessage(RenameTablesRequest)

RenameTablesResponse = _reflection.GeneratedProtocolMessageType('RenameTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _RENAMETABLESRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RenameTablesResponse)
  })
_sym_db.RegisterMessage(RenameTablesResponse)

DescribeTableRequest = _reflection.GeneratedProtocolMessageType('DescribeTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableRequest)
  })
_sym_db.RegisterMessage(DescribeTableRequest)

DescribeTableResponse = _reflection.GeneratedProtocolMessageType('DescribeTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableResponse)
  })
_sym_db.RegisterMessage(DescribeTableResponse)

DescribeTableResult = _reflection.GeneratedProtocolMessageType('DescribeTableResult', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBETABLERESULT_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableResult.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _DESCRIBETABLERESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableResult)
  })
_sym_db.RegisterMessage(DescribeTableResult)
_sym_db.RegisterMessage(DescribeTableResult.AttributesEntry)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.Query)
  })
_sym_db.RegisterMessage(Query)

SerializableModeSettings = _reflection.GeneratedProtocolMessageType('SerializableModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZABLEMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.SerializableModeSettings)
  })
_sym_db.RegisterMessage(SerializableModeSettings)

OnlineModeSettings = _reflection.GeneratedProtocolMessageType('OnlineModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.OnlineModeSettings)
  })
_sym_db.RegisterMessage(OnlineModeSettings)

StaleModeSettings = _reflection.GeneratedProtocolMessageType('StaleModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _STALEMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.StaleModeSettings)
  })
_sym_db.RegisterMessage(StaleModeSettings)

SnapshotModeSettings = _reflection.GeneratedProtocolMessageType('SnapshotModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.SnapshotModeSettings)
  })
_sym_db.RegisterMessage(SnapshotModeSettings)

SnapshotRWModeSettings = _reflection.GeneratedProtocolMessageType('SnapshotRWModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTRWMODESETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.SnapshotRWModeSettings)
  })
_sym_db.RegisterMessage(SnapshotRWModeSettings)

TransactionSettings = _reflection.GeneratedProtocolMessageType('TransactionSettings', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSETTINGS,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TransactionSettings)
  })
_sym_db.RegisterMessage(TransactionSettings)

TransactionControl = _reflection.GeneratedProtocolMessageType('TransactionControl', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONCONTROL,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TransactionControl)
  })
_sym_db.RegisterMessage(TransactionControl)

QueryCachePolicy = _reflection.GeneratedProtocolMessageType('QueryCachePolicy', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCACHEPOLICY,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.QueryCachePolicy)
  })
_sym_db.RegisterMessage(QueryCachePolicy)

QueryStatsCollection = _reflection.GeneratedProtocolMessageType('QueryStatsCollection', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATSCOLLECTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.QueryStatsCollection)
  })
_sym_db.RegisterMessage(QueryStatsCollection)

ExecuteDataQueryRequest = _reflection.GeneratedProtocolMessageType('ExecuteDataQueryRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteDataQueryRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEDATAQUERYREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteDataQueryRequest)
  })
_sym_db.RegisterMessage(ExecuteDataQueryRequest)
_sym_db.RegisterMessage(ExecuteDataQueryRequest.ParametersEntry)

ExecuteDataQueryResponse = _reflection.GeneratedProtocolMessageType('ExecuteDataQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEDATAQUERYRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteDataQueryResponse)
  })
_sym_db.RegisterMessage(ExecuteDataQueryResponse)

ExecuteSchemeQueryRequest = _reflection.GeneratedProtocolMessageType('ExecuteSchemeQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESCHEMEQUERYREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteSchemeQueryRequest)
  })
_sym_db.RegisterMessage(ExecuteSchemeQueryRequest)

ExecuteSchemeQueryResponse = _reflection.GeneratedProtocolMessageType('ExecuteSchemeQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESCHEMEQUERYRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteSchemeQueryResponse)
  })
_sym_db.RegisterMessage(ExecuteSchemeQueryResponse)

TransactionMeta = _reflection.GeneratedProtocolMessageType('TransactionMeta', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONMETA,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TransactionMeta)
  })
_sym_db.RegisterMessage(TransactionMeta)

QueryMeta = _reflection.GeneratedProtocolMessageType('QueryMeta', (_message.Message,), {

  'ParametersTypesEntry' : _reflection.GeneratedProtocolMessageType('ParametersTypesEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYMETA_PARAMETERSTYPESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.QueryMeta.ParametersTypesEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYMETA,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.QueryMeta)
  })
_sym_db.RegisterMessage(QueryMeta)
_sym_db.RegisterMessage(QueryMeta.ParametersTypesEntry)

ExecuteQueryResult = _reflection.GeneratedProtocolMessageType('ExecuteQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEQUERYRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteQueryResult)
  })
_sym_db.RegisterMessage(ExecuteQueryResult)

ExplainDataQueryRequest = _reflection.GeneratedProtocolMessageType('ExplainDataQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPLAINDATAQUERYREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExplainDataQueryRequest)
  })
_sym_db.RegisterMessage(ExplainDataQueryRequest)

ExplainDataQueryResponse = _reflection.GeneratedProtocolMessageType('ExplainDataQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXPLAINDATAQUERYRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExplainDataQueryResponse)
  })
_sym_db.RegisterMessage(ExplainDataQueryResponse)

ExplainQueryResult = _reflection.GeneratedProtocolMessageType('ExplainQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _EXPLAINQUERYRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExplainQueryResult)
  })
_sym_db.RegisterMessage(ExplainQueryResult)

PrepareDataQueryRequest = _reflection.GeneratedProtocolMessageType('PrepareDataQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDATAQUERYREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PrepareDataQueryRequest)
  })
_sym_db.RegisterMessage(PrepareDataQueryRequest)

PrepareDataQueryResponse = _reflection.GeneratedProtocolMessageType('PrepareDataQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDATAQUERYRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PrepareDataQueryResponse)
  })
_sym_db.RegisterMessage(PrepareDataQueryResponse)

PrepareQueryResult = _reflection.GeneratedProtocolMessageType('PrepareQueryResult', (_message.Message,), {

  'ParametersTypesEntry' : _reflection.GeneratedProtocolMessageType('ParametersTypesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREPAREQUERYRESULT_PARAMETERSTYPESENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.PrepareQueryResult.ParametersTypesEntry)
    })
  ,
  'DESCRIPTOR' : _PREPAREQUERYRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PrepareQueryResult)
  })
_sym_db.RegisterMessage(PrepareQueryResult)
_sym_db.RegisterMessage(PrepareQueryResult.ParametersTypesEntry)

KeepAliveRequest = _reflection.GeneratedProtocolMessageType('KeepAliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _KEEPALIVEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.KeepAliveRequest)
  })
_sym_db.RegisterMessage(KeepAliveRequest)

KeepAliveResponse = _reflection.GeneratedProtocolMessageType('KeepAliveResponse', (_message.Message,), {
  'DESCRIPTOR' : _KEEPALIVERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.KeepAliveResponse)
  })
_sym_db.RegisterMessage(KeepAliveResponse)

KeepAliveResult = _reflection.GeneratedProtocolMessageType('KeepAliveResult', (_message.Message,), {
  'DESCRIPTOR' : _KEEPALIVERESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.KeepAliveResult)
  })
_sym_db.RegisterMessage(KeepAliveResult)

BeginTransactionRequest = _reflection.GeneratedProtocolMessageType('BeginTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _BEGINTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BeginTransactionRequest)
  })
_sym_db.RegisterMessage(BeginTransactionRequest)

BeginTransactionResponse = _reflection.GeneratedProtocolMessageType('BeginTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _BEGINTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BeginTransactionResponse)
  })
_sym_db.RegisterMessage(BeginTransactionResponse)

BeginTransactionResult = _reflection.GeneratedProtocolMessageType('BeginTransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _BEGINTRANSACTIONRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BeginTransactionResult)
  })
_sym_db.RegisterMessage(BeginTransactionResult)

CommitTransactionRequest = _reflection.GeneratedProtocolMessageType('CommitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CommitTransactionRequest)
  })
_sym_db.RegisterMessage(CommitTransactionRequest)

CommitTransactionResponse = _reflection.GeneratedProtocolMessageType('CommitTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CommitTransactionResponse)
  })
_sym_db.RegisterMessage(CommitTransactionResponse)

CommitTransactionResult = _reflection.GeneratedProtocolMessageType('CommitTransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CommitTransactionResult)
  })
_sym_db.RegisterMessage(CommitTransactionResult)

RollbackTransactionRequest = _reflection.GeneratedProtocolMessageType('RollbackTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RollbackTransactionRequest)
  })
_sym_db.RegisterMessage(RollbackTransactionRequest)

RollbackTransactionResponse = _reflection.GeneratedProtocolMessageType('RollbackTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.RollbackTransactionResponse)
  })
_sym_db.RegisterMessage(RollbackTransactionResponse)

StoragePolicyDescription = _reflection.GeneratedProtocolMessageType('StoragePolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STORAGEPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.StoragePolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _STORAGEPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.StoragePolicyDescription)
  })
_sym_db.RegisterMessage(StoragePolicyDescription)
_sym_db.RegisterMessage(StoragePolicyDescription.LabelsEntry)

CompactionPolicyDescription = _reflection.GeneratedProtocolMessageType('CompactionPolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPACTIONPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.CompactionPolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _COMPACTIONPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CompactionPolicyDescription)
  })
_sym_db.RegisterMessage(CompactionPolicyDescription)
_sym_db.RegisterMessage(CompactionPolicyDescription.LabelsEntry)

PartitioningPolicyDescription = _reflection.GeneratedProtocolMessageType('PartitioningPolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.PartitioningPolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _PARTITIONINGPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.PartitioningPolicyDescription)
  })
_sym_db.RegisterMessage(PartitioningPolicyDescription)
_sym_db.RegisterMessage(PartitioningPolicyDescription.LabelsEntry)

ExecutionPolicyDescription = _reflection.GeneratedProtocolMessageType('ExecutionPolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTIONPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.ExecutionPolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTIONPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecutionPolicyDescription)
  })
_sym_db.RegisterMessage(ExecutionPolicyDescription)
_sym_db.RegisterMessage(ExecutionPolicyDescription.LabelsEntry)

ReplicationPolicyDescription = _reflection.GeneratedProtocolMessageType('ReplicationPolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATIONPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.ReplicationPolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _REPLICATIONPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReplicationPolicyDescription)
  })
_sym_db.RegisterMessage(ReplicationPolicyDescription)
_sym_db.RegisterMessage(ReplicationPolicyDescription.LabelsEntry)

CachingPolicyDescription = _reflection.GeneratedProtocolMessageType('CachingPolicyDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CACHINGPOLICYDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.CachingPolicyDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CACHINGPOLICYDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.CachingPolicyDescription)
  })
_sym_db.RegisterMessage(CachingPolicyDescription)
_sym_db.RegisterMessage(CachingPolicyDescription.LabelsEntry)

TableProfileDescription = _reflection.GeneratedProtocolMessageType('TableProfileDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TABLEPROFILEDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.TableProfileDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TABLEPROFILEDESCRIPTION,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.TableProfileDescription)
  })
_sym_db.RegisterMessage(TableProfileDescription)
_sym_db.RegisterMessage(TableProfileDescription.LabelsEntry)

DescribeTableOptionsRequest = _reflection.GeneratedProtocolMessageType('DescribeTableOptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLEOPTIONSREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableOptionsRequest)
  })
_sym_db.RegisterMessage(DescribeTableOptionsRequest)

DescribeTableOptionsResponse = _reflection.GeneratedProtocolMessageType('DescribeTableOptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLEOPTIONSRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableOptionsResponse)
  })
_sym_db.RegisterMessage(DescribeTableOptionsResponse)

DescribeTableOptionsResult = _reflection.GeneratedProtocolMessageType('DescribeTableOptionsResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLEOPTIONSRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.DescribeTableOptionsResult)
  })
_sym_db.RegisterMessage(DescribeTableOptionsResult)

KeyRange = _reflection.GeneratedProtocolMessageType('KeyRange', (_message.Message,), {
  'DESCRIPTOR' : _KEYRANGE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.KeyRange)
  })
_sym_db.RegisterMessage(KeyRange)

ReadTableRequest = _reflection.GeneratedProtocolMessageType('ReadTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _READTABLEREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadTableRequest)
  })
_sym_db.RegisterMessage(ReadTableRequest)

ReadTableResponse = _reflection.GeneratedProtocolMessageType('ReadTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _READTABLERESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadTableResponse)
  })
_sym_db.RegisterMessage(ReadTableResponse)

ReadTableResult = _reflection.GeneratedProtocolMessageType('ReadTableResult', (_message.Message,), {
  'DESCRIPTOR' : _READTABLERESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadTableResult)
  })
_sym_db.RegisterMessage(ReadTableResult)

ReadRowsRequest = _reflection.GeneratedProtocolMessageType('ReadRowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _READROWSREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadRowsRequest)
  })
_sym_db.RegisterMessage(ReadRowsRequest)

ReadRowsResponse = _reflection.GeneratedProtocolMessageType('ReadRowsResponse', (_message.Message,), {
  'DESCRIPTOR' : _READROWSRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ReadRowsResponse)
  })
_sym_db.RegisterMessage(ReadRowsResponse)

BulkUpsertRequest = _reflection.GeneratedProtocolMessageType('BulkUpsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _BULKUPSERTREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BulkUpsertRequest)
  })
_sym_db.RegisterMessage(BulkUpsertRequest)

BulkUpsertResponse = _reflection.GeneratedProtocolMessageType('BulkUpsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _BULKUPSERTRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BulkUpsertResponse)
  })
_sym_db.RegisterMessage(BulkUpsertResponse)

BulkUpsertResult = _reflection.GeneratedProtocolMessageType('BulkUpsertResult', (_message.Message,), {
  'DESCRIPTOR' : _BULKUPSERTRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.BulkUpsertResult)
  })
_sym_db.RegisterMessage(BulkUpsertResult)

ExecuteScanQueryRequest = _reflection.GeneratedProtocolMessageType('ExecuteScanQueryRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTESCANQUERYREQUEST_PARAMETERSENTRY,
    '__module__' : 'protos.ydb_table_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteScanQueryRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTESCANQUERYREQUEST,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteScanQueryRequest)
  })
_sym_db.RegisterMessage(ExecuteScanQueryRequest)
_sym_db.RegisterMessage(ExecuteScanQueryRequest.ParametersEntry)

ExecuteScanQueryPartialResponse = _reflection.GeneratedProtocolMessageType('ExecuteScanQueryPartialResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESCANQUERYPARTIALRESPONSE,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteScanQueryPartialResponse)
  })
_sym_db.RegisterMessage(ExecuteScanQueryPartialResponse)

ExecuteScanQueryPartialResult = _reflection.GeneratedProtocolMessageType('ExecuteScanQueryPartialResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESCANQUERYPARTIALRESULT,
  '__module__' : 'protos.ydb_table_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Table.ExecuteScanQueryPartialResult)
  })
_sym_db.RegisterMessage(ExecuteScanQueryPartialResult)


DESCRIPTOR._options = None
_CHANGEFEED_ATTRIBUTESENTRY._options = None
_CHANGEFEED.fields_by_name['attributes']._options = None
_CHANGEFEED.fields_by_name['aws_region']._options = None
_CHANGEFEEDDESCRIPTION_ATTRIBUTESENTRY._options = None
_CREATETABLEREQUEST_ATTRIBUTESENTRY._options = None
_CREATETABLEREQUEST.fields_by_name['attributes']._options = None
_ALTERTABLEREQUEST_ALTERATTRIBUTESENTRY._options = None
_ALTERTABLEREQUEST.fields_by_name['alter_attributes']._options = None
_DESCRIBETABLERESULT_ATTRIBUTESENTRY._options = None
_EXECUTEDATAQUERYREQUEST_PARAMETERSENTRY._options = None
_QUERYMETA_PARAMETERSTYPESENTRY._options = None
_PREPAREQUERYRESULT_PARAMETERSTYPESENTRY._options = None
_STORAGEPOLICYDESCRIPTION_LABELSENTRY._options = None
_COMPACTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
_PARTITIONINGPOLICYDESCRIPTION_LABELSENTRY._options = None
_EXECUTIONPOLICYDESCRIPTION_LABELSENTRY._options = None
_REPLICATIONPOLICYDESCRIPTION_LABELSENTRY._options = None
_CACHINGPOLICYDESCRIPTION_LABELSENTRY._options = None
_TABLEPROFILEDESCRIPTION_LABELSENTRY._options = None
_EXECUTESCANQUERYREQUEST_PARAMETERSENTRY._options = None
# @@protoc_insertion_point(module_scope)
