# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_federated_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos.annotations import sensitive_pb2 as protos_dot_annotations_dot_sensitive__pb2
from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_federated_query.proto',
  package='FederatedQuery',
  syntax='proto3',
  serialized_options=b'\n$tech.ydb.proto.draft.federated.queryZGgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_FederatedQuery\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&draft/protos/ydb_federated_query.proto\x12\x0e\x46\x65\x64\x65ratedQuery\x1a\"protos/annotations/sensitive.proto\x1a#protos/annotations/validation.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x16protos/ydb_value.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"{\n\x03\x41\x63l\x12\x32\n\nvisibility\x18\x01 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"@\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\t\n\x05SCOPE\x10\x02\"\x83\x03\n\x06Limits\x12!\n\x0fvcpu_rate_limit\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0f\x66low_rate_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fvcpu_time_limit\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_size\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_rows\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1e\n\x0cmemory_limit\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\nresult_ttl\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x11\x65xecution_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x38\n\x12\x65xecution_deadline\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\t\n\x07timeout\"\xef\x03\n\x14StreamingDisposition\x12(\n\x06oldest\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05\x66resh\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x42\n\tfrom_time\x18\x03 \x01(\x0b\x32-.FederatedQuery.StreamingDisposition.FromTimeH\x00\x12@\n\x08time_ago\x18\x04 \x01(\x0b\x32,.FederatedQuery.StreamingDisposition.TimeAgoH\x00\x12W\n\x14\x66rom_last_checkpoint\x18\x05 \x01(\x0b\x32\x37.FederatedQuery.StreamingDisposition.FromLastCheckpointH\x00\x1a\x39\n\x08\x46romTime\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x36\n\x07TimeAgo\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a#\n\x12\x46romLastCheckpoint\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x42\r\n\x0b\x64isposition\"\xe8\x05\n\x0cQueryContent\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12 \n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12&\n\x06limits\x18\x04 \x01(\x0b\x32\x16.FederatedQuery.Limits\x12\x1a\n\x04text\x18\x05 \x01(\tB\x0c\xa2\xe6*\x08\n\x06\x08\x01\x10\x80\xa0\x06\x12\x11\n\tautomatic\x18\x06 \x01(\x08\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\x12\x64\n\x12\x65xecution_settings\x18\n \x03(\x0b\x32\x33.FederatedQuery.QueryContent.ExecutionSettingsEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x38\n\x06syntax\x18\x0b \x01(\x0e\x32(.FederatedQuery.QueryContent.QuerySyntax\x12N\n\nparameters\x18\x0c \x03(\x0b\x32,.FederatedQuery.QueryContent.ParametersEntryB\x0c\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\x1a\x38\n\x16\x45xecutionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"E\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tANALYTICS\x10\x01\x12\r\n\tSTREAMING\x10\x02\"?\n\x0bQuerySyntax\x12\x1c\n\x18QUERY_SYNTAX_UNSPECIFIED\x10\x00\x12\n\n\x06YQL_V1\x10\x01\x12\x06\n\x02PG\x10\x02\"\xe5\x01\n\nCommonMeta\x12\x17\n\x02id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x1f\n\ncreated_by\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12 \n\x0bmodified_by\x18\x03 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x08revision\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xbf\x06\n\tQueryMeta\x12*\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x30\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x37\n\x06status\x18\x05 \x01(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatus\x12\x1f\n\x17last_job_query_revision\x18\x06 \x01(\x03\x12\x13\n\x0blast_job_id\x18\x07 \x01(\t\x12-\n\texpire_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10result_expire_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_by\x18\n \x01(\t\x12\x14\n\naborted_by\x18\x0b \x01(\tH\x00\x12\x13\n\tpaused_by\x18\x0c \x01(\tH\x00\x12\x1d\n\x15has_saved_checkpoints\x18\r \x01(\x08\"\x83\x02\n\rComputeStatus\x12\x1e\n\x1a\x43OMPUTE_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x13\n\x0f\x41\x42ORTED_BY_USER\x10\x02\x12\x15\n\x11\x41\x42ORTED_BY_SYSTEM\x10\x03\x12\x14\n\x10\x41\x42ORTING_BY_USER\x10\x04\x12\x16\n\x12\x41\x42ORTING_BY_SYSTEM\x10\x05\x12\x0c\n\x08RESUMING\x10\x06\x12\x0b\n\x07RUNNING\x10\x07\x12\r\n\tCOMPLETED\x10\x08\x12\x0e\n\nCOMPLETING\x10\x0c\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\r\x12\n\n\x06PAUSED\x10\x0b\x12\x0b\n\x07PAUSING\x10\nB\x08\n\x06\x61\x63tion\"\xc9\x01\n\nBriefQuery\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\'\n\x04meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x05 \x01(\x08\"\x19\n\tQueryPlan\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x18\n\x08QueryAst\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"]\n\rResultSetMeta\x12\x1b\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\x12\x1c\n\nrows_count\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x11\n\ttruncated\x18\x03 \x01(\x08\"\x1c\n\rQueryTimeline\x12\x0b\n\x03svg\x18\x01 \x01(\t\"\xa7\x03\n\x05Query\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12-\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\'\n\x04plan\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryPlan\x12&\n\x05issue\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0ftransient_issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\nstatistics\x18\x06 \x01(\x0b\x32\x1f.FederatedQuery.QueryStatistics\x12\x36\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1d.FederatedQuery.ResultSetMeta\x12%\n\x03\x61st\x18\x08 \x01(\x0b\x32\x18.FederatedQuery.QueryAst\x12/\n\x08timeline\x18\t \x01(\x0b\x32\x1d.FederatedQuery.QueryTimeline\"\x1f\n\x0fQueryStatistics\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x8e\x02\n\x12\x43reateQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12-\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\x31\n\x0c\x65xecute_mode\x18\x03 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x39\n\x0b\x64isposition\x18\x04 \x01(\x0b\x32$.FederatedQuery.StreamingDisposition\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x43reateQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\".\n\x11\x43reateQueryResult\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x93\x04\n\x12ListQueriesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x39\n\x06\x66ilter\x18\x04 \x01(\x0b\x32).FederatedQuery.ListQueriesRequest.Filter\x1a\xcc\x02\n\x06\x46ilter\x12:\n\nquery_type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12?\n\x06status\x18\x02 \x03(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatusB\x06\x9a\xe6*\x02\x18\x14\x12\x31\n\x04mode\x18\x03 \x03(\x0e\x32\x1b.FederatedQuery.ExecuteModeB\x06\x9a\xe6*\x02\x18\x14\x12\x15\n\x04name\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x05 \x01(\x08\x12\x32\n\nvisibility\x18\x06 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x30\n\tautomatic\x18\x07 \x01(\x0e\x32\x1d.FederatedQuery.AutomaticType\"C\n\x13ListQueriesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"`\n\x11ListQueriesResult\x12)\n\x05query\x18\x01 \x03(\x0b\x32\x1a.FederatedQuery.BriefQuery\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"p\n\x14\x44\x65scribeQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"E\n\x15\x44\x65scribeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\";\n\x13\x44\x65scribeQueryResult\x12$\n\x05query\x18\x01 \x01(\x0b\x32\x15.FederatedQuery.Query\"q\n\x15GetQueryStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"F\n\x16GetQueryStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x14GetQueryStatusResult\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatus\x12\x15\n\rmeta_revision\x18\x02 \x01(\x03\"\xb5\x01\n\x12\x44\x65leteQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x44\x65leteQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x44\x65leteQueryResult\"\x8a\x03\n\x12ModifyQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\x31\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x39\n\x0b\x64isposition\x18\x05 \x01(\x0b\x32$.FederatedQuery.StreamingDisposition\x12\x36\n\x0fstate_load_mode\x18\x06 \x01(\x0e\x32\x1d.FederatedQuery.StateLoadMode\x12#\n\x11previous_revision\x18\x07 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13ModifyQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11ModifyQueryResult\"\xe3\x01\n\x13\x43ontrolQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12+\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x1b.FederatedQuery.QueryAction\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"D\n\x14\x43ontrolQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ontrolQueryResult\"\xed\x01\n\x08\x42riefJob\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12-\n\nquery_meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\x12\n\nquery_name\x18\t \x01(\t\x12\x32\n\nvisibility\x18\n \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x80\x05\n\x03Job\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x0c\n\x04text\x18\x02 \x01(\t\x12-\n\nquery_meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\'\n\x04plan\x18\x04 \x01(\x0b\x32\x19.FederatedQuery.QueryPlan\x12&\n\x05issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\nstatistics\x18\x06 \x01(\x0b\x32\x1f.FederatedQuery.QueryStatistics\x12\x36\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1d.FederatedQuery.ResultSetMeta\x12%\n\x03\x61st\x18\x08 \x01(\x0b\x32\x18.FederatedQuery.QueryAst\x12\x12\n\nquery_name\x18\t \x01(\t\x12 \n\x03\x61\x63l\x18\n \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x06syntax\x18\r \x01(\x0e\x32(.FederatedQuery.QueryContent.QuerySyntax\x12\x37\n\nparameters\x18\x0e \x03(\x0b\x32#.FederatedQuery.Job.ParametersEntry\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"\x8c\x02\n\x0fListJobsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x10\n\x08query_id\x18\x05 \x01(\t\x12\x36\n\x06\x66ilter\x18\x04 \x01(\x0b\x32&.FederatedQuery.ListJobsRequest.Filter\x1a:\n\x06\x46ilter\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\"@\n\x10ListJobsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Y\n\x0eListJobsResult\x12%\n\x03job\x18\x01 \x03(\x0b\x32\x18.FederatedQuery.BriefJob\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"l\n\x12\x44\x65scribeJobRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x06job_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"C\n\x13\x44\x65scribeJobResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"5\n\x11\x44\x65scribeJobResult\x12 \n\x03job\x18\x01 \x01(\x0b\x32\x13.FederatedQuery.Job\"\x15\n\x13\x43urrentIAMTokenAuth\"\n\n\x08NoneAuth\")\n\x12ServiceAccountAuth\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\'\n\tTokenAuth\x12\x1a\n\x05token\x18\x01 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\"\xe6\x01\n\x07IamAuth\x12:\n\x0b\x63urrent_iam\x18\x01 \x01(\x0b\x32#.FederatedQuery.CurrentIAMTokenAuthH\x00\x12=\n\x0fservice_account\x18\x02 \x01(\x0b\x32\".FederatedQuery.ServiceAccountAuthH\x00\x12(\n\x04none\x18\x03 \x01(\x0b\x32\x18.FederatedQuery.NoneAuthH\x00\x12*\n\x05token\x18\x04 \x01(\x0b\x32\x19.FederatedQuery.TokenAuthH\x00\x42\n\n\x08identity\"\xb0\x01\n\x0b\x44\x61taStreams\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\x12\x16\n\x0eshared_reading\x18\x06 \x01(\x08\"g\n\nMonitoring\x12\x18\n\x07project\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\x18\n\x07\x63luster\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12%\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\x98\x01\n\x0bYdbDatabase\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"\xf8\x01\n\x11\x43lickHouseCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12%\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"Y\n\x17ObjectStorageConnection\x12\x17\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\x91\x02\n\x11PostgreSQLCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x17\n\x06schema\x18\t \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"\xcb\x01\n\x10GreenplumCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x04 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x17\n\x06schema\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x06 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\xae\x01\n\x0cMySQLCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x04 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12%\n\x04\x61uth\x18\x05 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"C\n\x07Logging\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\xa4\x01\n\x10IcebergWarehouse\x12\x31\n\x02s3\x18\x01 \x01(\x0b\x32#.FederatedQuery.IcebergWarehouse.S3H\x00\x1aR\n\x02S3\x12\x1c\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x12\x1a\n\x04path\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x01\x88\x01\x01\x42\t\n\x07_bucketB\x07\n\x05_pathB\t\n\x07payload\"\xc0\x02\n\x0eIcebergCatalog\x12\x37\n\x06hadoop\x18\x01 \x01(\x0b\x32%.FederatedQuery.IcebergCatalog.HadoopH\x00\x12\x46\n\x0ehive_metastore\x18\x02 \x01(\x0b\x32,.FederatedQuery.IcebergCatalog.HiveMetastoreH\x00\x1a\x37\n\x06Hadoop\x12\x1f\n\tdirectory\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x42\x0c\n\n_directory\x1ai\n\rHiveMetastore\x12\x19\n\x03uri\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x12#\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x01\x88\x01\x01\x42\x06\n\x04_uriB\x10\n\x0e_database_nameB\t\n\x07payload\"\xa0\x01\n\x07Iceberg\x12/\n\x0ewarehouse_auth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x33\n\twarehouse\x18\x03 \x01(\x0b\x32 .FederatedQuery.IcebergWarehouse\x12/\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32\x1e.FederatedQuery.IcebergCatalog\"\xc0\x06\n\x11\x43onnectionSetting\x12\x33\n\x0cydb_database\x18\x01 \x01(\x0b\x32\x1b.FederatedQuery.YdbDatabaseH\x00\x12?\n\x12\x63lickhouse_cluster\x18\x02 \x01(\x0b\x32!.FederatedQuery.ClickHouseClusterH\x00\x12\x33\n\x0c\x64\x61ta_streams\x18\x03 \x01(\x0b\x32\x1b.FederatedQuery.DataStreamsH\x00\x12\x41\n\x0eobject_storage\x18\x04 \x01(\x0b\x32\'.FederatedQuery.ObjectStorageConnectionH\x00\x12\x30\n\nmonitoring\x18\x05 \x01(\x0b\x32\x1a.FederatedQuery.MonitoringH\x00\x12?\n\x12postgresql_cluster\x18\x06 \x01(\x0b\x32!.FederatedQuery.PostgreSQLClusterH\x00\x12=\n\x11greenplum_cluster\x18\x07 \x01(\x0b\x32 .FederatedQuery.GreenplumClusterH\x00\x12\x35\n\rmysql_cluster\x18\x08 \x01(\x0b\x32\x1c.FederatedQuery.MySQLClusterH\x00\x12*\n\x07logging\x18\t \x01(\x0b\x32\x17.FederatedQuery.LoggingH\x00\x12*\n\x07iceberg\x18\n \x01(\x0b\x32\x17.FederatedQuery.IcebergH\x00\"\xed\x01\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cYDB_DATABASE\x10\x01\x12\x16\n\x12\x43LICKHOUSE_CLUSTER\x10\x02\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x03\x12\x12\n\x0eOBJECT_STORAGE\x10\x04\x12\x0e\n\nMONITORING\x10\x05\x12\x16\n\x12POSTGRESQL_CLUSTER\x10\x06\x12\x15\n\x11GREENPLUM_CLUSTER\x10\x07\x12\x11\n\rMYSQL_CLUSTER\x10\x08\x12\x0b\n\x07LOGGING\x10\t\x12\x0b\n\x07ICEBERG\x10\nB\x0c\n\nconnection\"\xa2\x01\n\x11\x43onnectionContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x32\n\x07setting\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionSetting\x12 \n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"j\n\nConnection\x12\x32\n\x07\x63ontent\x18\x01 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12(\n\x04meta\x18\x02 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\"\xaa\x01\n\x17\x43reateConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x32\n\x07\x63ontent\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x43reateConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"<\n\x16\x43reateConnectionResult\x12\"\n\rconnection_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\x84\x03\n\x16ListConnectionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12=\n\x06\x66ilter\x18\x04 \x01(\x0b\x32-.FederatedQuery.ListConnectionsRequest.Filter\x1a\xb5\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\x12I\n\x0f\x63onnection_type\x18\x03 \x01(\x0e\x32\x30.FederatedQuery.ConnectionSetting.ConnectionType\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"G\n\x17ListConnectionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"i\n\x15ListConnectionsResult\x12.\n\nconnection\x18\x01 \x03(\x0b\x32\x1a.FederatedQuery.Connection\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"z\n\x19\x44\x65scribeConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"J\n\x1a\x44\x65scribeConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x18\x44\x65scribeConnectionResult\x12.\n\nconnection\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.Connection\"\xf3\x01\n\x17ModifyConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x32\n\x07\x63ontent\x18\x03 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18ModifyConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16ModifyConnectionResult\"\xbf\x01\n\x17\x44\x65leteConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x44\x65leteConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16\x44\x65leteConnectionResult\"\x86\x01\n\x15TestConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x32\n\x07setting\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionSetting\"F\n\x16TestConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14TestConnectionResult\"\xcc\x01\n\x14GetResultDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\x10result_set_index\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\x12\x18\n\x06offset\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\x05limit\x18\x05 \x01(\x03\x42\r\xb2\xe6*\t[1; 1000]\"E\n\x15GetResultDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"9\n\x13GetResultDataResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\".\n\x06Schema\x12$\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.ColumnB\x07\x9a\xe6*\x03\x18\xe8\x07\"\xa2\x02\n\x12\x44\x61taStreamsBinding\x12 \n\x0bstream_name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x0b\x63ompression\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\x06schema\x18\x04 \x01(\x0b\x32\x16.FederatedQuery.Schema\x12U\n\x0e\x66ormat_setting\x18\x05 \x03(\x0b\x32\x35.FederatedQuery.DataStreamsBinding.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x04\n\x14ObjectStorageBinding\x12;\n\x06subset\x18\x01 \x03(\x0b\x32+.FederatedQuery.ObjectStorageBinding.Subset\x1a\xbc\x03\n\x06Subset\x12!\n\x0cpath_pattern\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12^\n\x0e\x66ormat_setting\x18\x03 \x03(\x0b\x32>.FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x12\x1c\n\x0b\x63ompression\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\x06schema\x18\x05 \x01(\x0b\x32\x16.FederatedQuery.Schema\x12O\n\nprojection\x18\x06 \x03(\x0b\x32;.FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry\x12\x16\n\x0epartitioned_by\x18\x07 \x03(\t\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fProjectionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x0e\x42indingSetting\x12:\n\x0c\x64\x61ta_streams\x18\x01 \x01(\x0b\x32\".FederatedQuery.DataStreamsBindingH\x00\x12>\n\x0eobject_storage\x18\x02 \x01(\x0b\x32$.FederatedQuery.ObjectStorageBindingH\x00\"Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x01\x12\x12\n\x0eOBJECT_STORAGE\x10\x02\x42\t\n\x07\x62inding\"\xe5\x01\n\x0c\x42riefBinding\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12(\n\x04meta\x18\x03 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.FederatedQuery.BindingSetting.BindingType\x12\x32\n\nvisibility\x18\x05 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"\xc0\x01\n\x0e\x42indingContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07setting\x18\x03 \x01(\x0b\x32\x1e.FederatedQuery.BindingSetting\x12 \n\x03\x61\x63l\x18\x04 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"d\n\x07\x42inding\x12/\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12(\n\x04meta\x18\x02 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\"\xa4\x01\n\x14\x43reateBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x43reateBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"6\n\x13\x43reateBindingResult\x12\x1f\n\nbinding_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xd3\x02\n\x13ListBindingsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.FederatedQuery.ListBindingsRequest.Filter\x1a\x8a\x01\n\x06\x46ilter\x12\x1e\n\rconnection_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x03 \x01(\x08\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"D\n\x14ListBindingsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x12ListBindingsResult\x12-\n\x07\x62inding\x18\x01 \x03(\x0b\x32\x1c.FederatedQuery.BriefBinding\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"t\n\x16\x44\x65scribeBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"G\n\x17\x44\x65scribeBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"A\n\x15\x44\x65scribeBindingResult\x12(\n\x07\x62inding\x18\x01 \x01(\x0b\x32\x17.FederatedQuery.Binding\"\xea\x01\n\x14ModifyBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15ModifyBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13ModifyBindingResult\"\xb9\x01\n\x14\x44\x65leteBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x44\x65leteBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x44\x65leteBindingResult*q\n\x0b\x45xecuteMode\x12\x1c\n\x18\x45XECUTE_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAVE\x10\x01\x12\t\n\x05PARSE\x10\x02\x12\x0b\n\x07\x43OMPILE\x10\x03\x12\x0c\n\x08VALIDATE\x10\x04\x12\x0b\n\x07\x45XPLAIN\x10\x05\x12\x07\n\x03RUN\x10\x06*y\n\x0bQueryAction\x12\x1c\n\x18QUERY_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05PAUSE\x10\x01\x12\x14\n\x10PAUSE_GRACEFULLY\x10\x02\x12\t\n\x05\x41\x42ORT\x10\x03\x12\x14\n\x10\x41\x42ORT_GRACEFULLY\x10\x04\x12\n\n\x06RESUME\x10\x05*U\n\rStateLoadMode\x12\x1f\n\x1bSTATE_LOAD_MODE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x18\n\x14\x46ROM_LAST_CHECKPOINT\x10\x02*Q\n\rAutomaticType\x12\x1e\n\x1a\x41UTOMATIC_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tAUTOMATIC\x10\x01\x12\x11\n\rNOT_AUTOMATIC\x10\x02\x42r\n$tech.ydb.proto.draft.federated.queryZGgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_FederatedQuery\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__value__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_EXECUTEMODE = _descriptor.EnumDescriptor(
  name='ExecuteMode',
  full_name='FederatedQuery.ExecuteMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXECUTE_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPILE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALIDATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPLAIN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17540,
  serialized_end=17653,
)
_sym_db.RegisterEnumDescriptor(_EXECUTEMODE)

ExecuteMode = enum_type_wrapper.EnumTypeWrapper(_EXECUTEMODE)
_QUERYACTION = _descriptor.EnumDescriptor(
  name='QueryAction',
  full_name='FederatedQuery.QueryAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QUERY_ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSE_GRACEFULLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORT_GRACEFULLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17655,
  serialized_end=17776,
)
_sym_db.RegisterEnumDescriptor(_QUERYACTION)

QueryAction = enum_type_wrapper.EnumTypeWrapper(_QUERYACTION)
_STATELOADMODE = _descriptor.EnumDescriptor(
  name='StateLoadMode',
  full_name='FederatedQuery.StateLoadMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_LOAD_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FROM_LAST_CHECKPOINT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17778,
  serialized_end=17863,
)
_sym_db.RegisterEnumDescriptor(_STATELOADMODE)

StateLoadMode = enum_type_wrapper.EnumTypeWrapper(_STATELOADMODE)
_AUTOMATICTYPE = _descriptor.EnumDescriptor(
  name='AutomaticType',
  full_name='FederatedQuery.AutomaticType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTOMATIC_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTOMATIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_AUTOMATIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17865,
  serialized_end=17946,
)
_sym_db.RegisterEnumDescriptor(_AUTOMATICTYPE)

AutomaticType = enum_type_wrapper.EnumTypeWrapper(_AUTOMATICTYPE)
EXECUTE_MODE_UNSPECIFIED = 0
SAVE = 1
PARSE = 2
COMPILE = 3
VALIDATE = 4
EXPLAIN = 5
RUN = 6
QUERY_ACTION_UNSPECIFIED = 0
PAUSE = 1
PAUSE_GRACEFULLY = 2
ABORT = 3
ABORT_GRACEFULLY = 4
RESUME = 5
STATE_LOAD_MODE_UNSPECIFIED = 0
EMPTY = 1
FROM_LAST_CHECKPOINT = 2
AUTOMATIC_TYPE_UNSPECIFIED = 0
AUTOMATIC = 1
NOT_AUTOMATIC = 2


_ACL_VISIBILITY = _descriptor.EnumDescriptor(
  name='Visibility',
  full_name='FederatedQuery.Acl.Visibility',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISIBILITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCOPE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=368,
  serialized_end=432,
)
_sym_db.RegisterEnumDescriptor(_ACL_VISIBILITY)

_QUERYCONTENT_QUERYTYPE = _descriptor.EnumDescriptor(
  name='QueryType',
  full_name='FederatedQuery.QueryContent.QueryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QUERY_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANALYTICS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAMING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1933,
  serialized_end=2002,
)
_sym_db.RegisterEnumDescriptor(_QUERYCONTENT_QUERYTYPE)

_QUERYCONTENT_QUERYSYNTAX = _descriptor.EnumDescriptor(
  name='QuerySyntax',
  full_name='FederatedQuery.QueryContent.QuerySyntax',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QUERY_SYNTAX_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YQL_V1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2004,
  serialized_end=2067,
)
_sym_db.RegisterEnumDescriptor(_QUERYCONTENT_QUERYSYNTAX)

_QUERYMETA_COMPUTESTATUS = _descriptor.EnumDescriptor(
  name='ComputeStatus',
  full_name='FederatedQuery.QueryMeta.ComputeStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPUTE_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTED_BY_USER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTED_BY_SYSTEM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTING_BY_USER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTING_BY_SYSTEM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESUMING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETING', index=9, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=10, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILING', index=11, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=12, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSING', index=13, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2864,
  serialized_end=3123,
)
_sym_db.RegisterEnumDescriptor(_QUERYMETA_COMPUTESTATUS)

_CONNECTIONSETTING_CONNECTIONTYPE = _descriptor.EnumDescriptor(
  name='ConnectionType',
  full_name='FederatedQuery.ConnectionSetting.ConnectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDB_DATABASE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLUSTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_STREAMS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONITORING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POSTGRESQL_CLUSTER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREENPLUM_CLUSTER', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MYSQL_CLUSTER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGGING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICEBERG', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11328,
  serialized_end=11565,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONSETTING_CONNECTIONTYPE)

_BINDINGSETTING_BINDINGTYPE = _descriptor.EnumDescriptor(
  name='BindingType',
  full_name='FederatedQuery.BindingSetting.BindingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BINDING_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_STREAMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15237,
  serialized_end=15318,
)
_sym_db.RegisterEnumDescriptor(_BINDINGSETTING_BINDINGTYPE)


_ACL = _descriptor.Descriptor(
  name='Acl',
  full_name='FederatedQuery.Acl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.Acl.visibility', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACL_VISIBILITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=432,
)


_LIMITS = _descriptor.Descriptor(
  name='Limits',
  full_name='FederatedQuery.Limits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcpu_rate_limit', full_name='FederatedQuery.Limits.vcpu_rate_limit', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_rate_limit', full_name='FederatedQuery.Limits.flow_rate_limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcpu_time_limit', full_name='FederatedQuery.Limits.vcpu_time_limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_result_size', full_name='FederatedQuery.Limits.max_result_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_result_rows', full_name='FederatedQuery.Limits.max_result_rows', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='FederatedQuery.Limits.memory_limit', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_ttl', full_name='FederatedQuery.Limits.result_ttl', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_timeout', full_name='FederatedQuery.Limits.execution_timeout', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_deadline', full_name='FederatedQuery.Limits.execution_deadline', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='timeout', full_name='FederatedQuery.Limits.timeout',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=435,
  serialized_end=822,
)


_STREAMINGDISPOSITION_FROMTIME = _descriptor.Descriptor(
  name='FromTime',
  full_name='FederatedQuery.StreamingDisposition.FromTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FederatedQuery.StreamingDisposition.FromTime.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1212,
)

_STREAMINGDISPOSITION_TIMEAGO = _descriptor.Descriptor(
  name='TimeAgo',
  full_name='FederatedQuery.StreamingDisposition.TimeAgo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='FederatedQuery.StreamingDisposition.TimeAgo.duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1268,
)

_STREAMINGDISPOSITION_FROMLASTCHECKPOINT = _descriptor.Descriptor(
  name='FromLastCheckpoint',
  full_name='FederatedQuery.StreamingDisposition.FromLastCheckpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='FederatedQuery.StreamingDisposition.FromLastCheckpoint.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1305,
)

_STREAMINGDISPOSITION = _descriptor.Descriptor(
  name='StreamingDisposition',
  full_name='FederatedQuery.StreamingDisposition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldest', full_name='FederatedQuery.StreamingDisposition.oldest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fresh', full_name='FederatedQuery.StreamingDisposition.fresh', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_time', full_name='FederatedQuery.StreamingDisposition.from_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_ago', full_name='FederatedQuery.StreamingDisposition.time_ago', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_last_checkpoint', full_name='FederatedQuery.StreamingDisposition.from_last_checkpoint', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMINGDISPOSITION_FROMTIME, _STREAMINGDISPOSITION_TIMEAGO, _STREAMINGDISPOSITION_FROMLASTCHECKPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='disposition', full_name='FederatedQuery.StreamingDisposition.disposition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=825,
  serialized_end=1320,
)


_QUERYCONTENT_EXECUTIONSETTINGSENTRY = _descriptor.Descriptor(
  name='ExecutionSettingsEntry',
  full_name='FederatedQuery.QueryContent.ExecutionSettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.QueryContent.ExecutionSettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.QueryContent.ExecutionSettingsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1807,
  serialized_end=1863,
)

_QUERYCONTENT_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='FederatedQuery.QueryContent.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.QueryContent.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.QueryContent.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1865,
  serialized_end=1931,
)

_QUERYCONTENT = _descriptor.Descriptor(
  name='QueryContent',
  full_name='FederatedQuery.QueryContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='FederatedQuery.QueryContent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.QueryContent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='FederatedQuery.QueryContent.acl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limits', full_name='FederatedQuery.QueryContent.limits', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='FederatedQuery.QueryContent.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\010\n\006\010\001\020\200\240\006', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='FederatedQuery.QueryContent.automatic', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='FederatedQuery.QueryContent.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200P', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_settings', full_name='FederatedQuery.QueryContent.execution_settings', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syntax', full_name='FederatedQuery.QueryContent.syntax', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='FederatedQuery.QueryContent.parameters', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\346*\010\n\006\n\004\010\001\020d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYCONTENT_EXECUTIONSETTINGSENTRY, _QUERYCONTENT_PARAMETERSENTRY, ],
  enum_types=[
    _QUERYCONTENT_QUERYTYPE,
    _QUERYCONTENT_QUERYSYNTAX,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=2067,
)


_COMMONMETA = _descriptor.Descriptor(
  name='CommonMeta',
  full_name='FederatedQuery.CommonMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='FederatedQuery.CommonMeta.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='FederatedQuery.CommonMeta.created_by', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_by', full_name='FederatedQuery.CommonMeta.modified_by', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='FederatedQuery.CommonMeta.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at', full_name='FederatedQuery.CommonMeta.modified_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='FederatedQuery.CommonMeta.revision', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2070,
  serialized_end=2299,
)


_QUERYMETA = _descriptor.Descriptor(
  name='QueryMeta',
  full_name='FederatedQuery.QueryMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='FederatedQuery.QueryMeta.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='FederatedQuery.QueryMeta.submitted_at', index=1,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='FederatedQuery.QueryMeta.started_at', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished_at', full_name='FederatedQuery.QueryMeta.finished_at', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_mode', full_name='FederatedQuery.QueryMeta.execute_mode', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='FederatedQuery.QueryMeta.status', index=5,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_job_query_revision', full_name='FederatedQuery.QueryMeta.last_job_query_revision', index=6,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_job_id', full_name='FederatedQuery.QueryMeta.last_job_id', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='FederatedQuery.QueryMeta.expire_at', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_expire_at', full_name='FederatedQuery.QueryMeta.result_expire_at', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_by', full_name='FederatedQuery.QueryMeta.started_by', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aborted_by', full_name='FederatedQuery.QueryMeta.aborted_by', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paused_by', full_name='FederatedQuery.QueryMeta.paused_by', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_saved_checkpoints', full_name='FederatedQuery.QueryMeta.has_saved_checkpoints', index=13,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUERYMETA_COMPUTESTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='FederatedQuery.QueryMeta.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2302,
  serialized_end=3133,
)


_BRIEFQUERY = _descriptor.Descriptor(
  name='BriefQuery',
  full_name='FederatedQuery.BriefQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='FederatedQuery.BriefQuery.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.BriefQuery.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.BriefQuery.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.BriefQuery.visibility', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='FederatedQuery.BriefQuery.automatic', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3136,
  serialized_end=3337,
)


_QUERYPLAN = _descriptor.Descriptor(
  name='QueryPlan',
  full_name='FederatedQuery.QueryPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json', full_name='FederatedQuery.QueryPlan.json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3339,
  serialized_end=3364,
)


_QUERYAST = _descriptor.Descriptor(
  name='QueryAst',
  full_name='FederatedQuery.QueryAst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='FederatedQuery.QueryAst.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3366,
  serialized_end=3390,
)


_RESULTSETMETA = _descriptor.Descriptor(
  name='ResultSetMeta',
  full_name='FederatedQuery.ResultSetMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='FederatedQuery.ResultSetMeta.column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows_count', full_name='FederatedQuery.ResultSetMeta.rows_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncated', full_name='FederatedQuery.ResultSetMeta.truncated', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3392,
  serialized_end=3485,
)


_QUERYTIMELINE = _descriptor.Descriptor(
  name='QueryTimeline',
  full_name='FederatedQuery.QueryTimeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='svg', full_name='FederatedQuery.QueryTimeline.svg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3487,
  serialized_end=3515,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='FederatedQuery.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.Query.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.Query.content', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan', full_name='FederatedQuery.Query.plan', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue', full_name='FederatedQuery.Query.issue', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transient_issue', full_name='FederatedQuery.Query.transient_issue', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='FederatedQuery.Query.statistics', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_meta', full_name='FederatedQuery.Query.result_set_meta', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ast', full_name='FederatedQuery.Query.ast', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeline', full_name='FederatedQuery.Query.timeline', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3518,
  serialized_end=3941,
)


_QUERYSTATISTICS = _descriptor.Descriptor(
  name='QueryStatistics',
  full_name='FederatedQuery.QueryStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json', full_name='FederatedQuery.QueryStatistics.json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3943,
  serialized_end=3974,
)


_CREATEQUERYREQUEST = _descriptor.Descriptor(
  name='CreateQueryRequest',
  full_name='FederatedQuery.CreateQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.CreateQueryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.CreateQueryRequest.content', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_mode', full_name='FederatedQuery.CreateQueryRequest.execute_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disposition', full_name='FederatedQuery.CreateQueryRequest.disposition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.CreateQueryRequest.idempotency_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3977,
  serialized_end=4247,
)


_CREATEQUERYRESPONSE = _descriptor.Descriptor(
  name='CreateQueryResponse',
  full_name='FederatedQuery.CreateQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.CreateQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4249,
  serialized_end=4316,
)


_CREATEQUERYRESULT = _descriptor.Descriptor(
  name='CreateQueryResult',
  full_name='FederatedQuery.CreateQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.CreateQueryResult.query_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4318,
  serialized_end=4364,
)


_LISTQUERIESREQUEST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='FederatedQuery.ListQueriesRequest.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_type', full_name='FederatedQuery.ListQueriesRequest.Filter.query_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='FederatedQuery.ListQueriesRequest.Filter.status', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002\030\024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='FederatedQuery.ListQueriesRequest.Filter.mode', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002\030\024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.ListQueriesRequest.Filter.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by_me', full_name='FederatedQuery.ListQueriesRequest.Filter.created_by_me', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.ListQueriesRequest.Filter.visibility', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='FederatedQuery.ListQueriesRequest.Filter.automatic', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4566,
  serialized_end=4898,
)

_LISTQUERIESREQUEST = _descriptor.Descriptor(
  name='ListQueriesRequest',
  full_name='FederatedQuery.ListQueriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ListQueriesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='FederatedQuery.ListQueriesRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='FederatedQuery.ListQueriesRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010[1; 100]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='FederatedQuery.ListQueriesRequest.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTQUERIESREQUEST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4367,
  serialized_end=4898,
)


_LISTQUERIESRESPONSE = _descriptor.Descriptor(
  name='ListQueriesResponse',
  full_name='FederatedQuery.ListQueriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ListQueriesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4900,
  serialized_end=4967,
)


_LISTQUERIESRESULT = _descriptor.Descriptor(
  name='ListQueriesResult',
  full_name='FederatedQuery.ListQueriesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='FederatedQuery.ListQueriesResult.query', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='FederatedQuery.ListQueriesResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4969,
  serialized_end=5065,
)


_DESCRIBEQUERYREQUEST = _descriptor.Descriptor(
  name='DescribeQueryRequest',
  full_name='FederatedQuery.DescribeQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DescribeQueryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.DescribeQueryRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5067,
  serialized_end=5179,
)


_DESCRIBEQUERYRESPONSE = _descriptor.Descriptor(
  name='DescribeQueryResponse',
  full_name='FederatedQuery.DescribeQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DescribeQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5181,
  serialized_end=5250,
)


_DESCRIBEQUERYRESULT = _descriptor.Descriptor(
  name='DescribeQueryResult',
  full_name='FederatedQuery.DescribeQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='FederatedQuery.DescribeQueryResult.query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5252,
  serialized_end=5311,
)


_GETQUERYSTATUSREQUEST = _descriptor.Descriptor(
  name='GetQueryStatusRequest',
  full_name='FederatedQuery.GetQueryStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.GetQueryStatusRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.GetQueryStatusRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5313,
  serialized_end=5426,
)


_GETQUERYSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetQueryStatusResponse',
  full_name='FederatedQuery.GetQueryStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.GetQueryStatusResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5428,
  serialized_end=5498,
)


_GETQUERYSTATUSRESULT = _descriptor.Descriptor(
  name='GetQueryStatusResult',
  full_name='FederatedQuery.GetQueryStatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='FederatedQuery.GetQueryStatusResult.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta_revision', full_name='FederatedQuery.GetQueryStatusResult.meta_revision', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5500,
  serialized_end=5602,
)


_DELETEQUERYREQUEST = _descriptor.Descriptor(
  name='DeleteQueryRequest',
  full_name='FederatedQuery.DeleteQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DeleteQueryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.DeleteQueryRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.DeleteQueryRequest.previous_revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.DeleteQueryRequest.idempotency_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5605,
  serialized_end=5786,
)


_DELETEQUERYRESPONSE = _descriptor.Descriptor(
  name='DeleteQueryResponse',
  full_name='FederatedQuery.DeleteQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DeleteQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=5855,
)


_DELETEQUERYRESULT = _descriptor.Descriptor(
  name='DeleteQueryResult',
  full_name='FederatedQuery.DeleteQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5857,
  serialized_end=5876,
)


_MODIFYQUERYREQUEST = _descriptor.Descriptor(
  name='ModifyQueryRequest',
  full_name='FederatedQuery.ModifyQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ModifyQueryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.ModifyQueryRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.ModifyQueryRequest.content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_mode', full_name='FederatedQuery.ModifyQueryRequest.execute_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disposition', full_name='FederatedQuery.ModifyQueryRequest.disposition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_load_mode', full_name='FederatedQuery.ModifyQueryRequest.state_load_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.ModifyQueryRequest.previous_revision', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.ModifyQueryRequest.idempotency_key', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5879,
  serialized_end=6273,
)


_MODIFYQUERYRESPONSE = _descriptor.Descriptor(
  name='ModifyQueryResponse',
  full_name='FederatedQuery.ModifyQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ModifyQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6275,
  serialized_end=6342,
)


_MODIFYQUERYRESULT = _descriptor.Descriptor(
  name='ModifyQueryResult',
  full_name='FederatedQuery.ModifyQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6344,
  serialized_end=6363,
)


_CONTROLQUERYREQUEST = _descriptor.Descriptor(
  name='ControlQueryRequest',
  full_name='FederatedQuery.ControlQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ControlQueryRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.ControlQueryRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='FederatedQuery.ControlQueryRequest.action', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.ControlQueryRequest.previous_revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.ControlQueryRequest.idempotency_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6366,
  serialized_end=6593,
)


_CONTROLQUERYRESPONSE = _descriptor.Descriptor(
  name='ControlQueryResponse',
  full_name='FederatedQuery.ControlQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ControlQueryResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6595,
  serialized_end=6663,
)


_CONTROLQUERYRESULT = _descriptor.Descriptor(
  name='ControlQueryResult',
  full_name='FederatedQuery.ControlQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6665,
  serialized_end=6685,
)


_BRIEFJOB = _descriptor.Descriptor(
  name='BriefJob',
  full_name='FederatedQuery.BriefJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.BriefJob.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_meta', full_name='FederatedQuery.BriefJob.query_meta', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_name', full_name='FederatedQuery.BriefJob.query_name', index=2,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.BriefJob.visibility', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='FederatedQuery.BriefJob.automatic', index=4,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='FederatedQuery.BriefJob.expire_at', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6688,
  serialized_end=6925,
)


_JOB_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='FederatedQuery.Job.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.Job.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.Job.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1865,
  serialized_end=1931,
)

_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='FederatedQuery.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.Job.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='FederatedQuery.Job.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_meta', full_name='FederatedQuery.Job.query_meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan', full_name='FederatedQuery.Job.plan', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue', full_name='FederatedQuery.Job.issue', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='FederatedQuery.Job.statistics', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_meta', full_name='FederatedQuery.Job.result_set_meta', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ast', full_name='FederatedQuery.Job.ast', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_name', full_name='FederatedQuery.Job.query_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='FederatedQuery.Job.acl', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='FederatedQuery.Job.automatic', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='FederatedQuery.Job.expire_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syntax', full_name='FederatedQuery.Job.syntax', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='FederatedQuery.Job.parameters', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOB_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6928,
  serialized_end=7568,
)


_LISTJOBSREQUEST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='FederatedQuery.ListJobsRequest.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.ListJobsRequest.Filter.query_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by_me', full_name='FederatedQuery.ListJobsRequest.Filter.created_by_me', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7781,
  serialized_end=7839,
)

_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='FederatedQuery.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ListJobsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='FederatedQuery.ListJobsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='FederatedQuery.ListJobsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010[1; 100]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.ListJobsRequest.query_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='FederatedQuery.ListJobsRequest.filter', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTJOBSREQUEST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7571,
  serialized_end=7839,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='FederatedQuery.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ListJobsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7841,
  serialized_end=7905,
)


_LISTJOBSRESULT = _descriptor.Descriptor(
  name='ListJobsResult',
  full_name='FederatedQuery.ListJobsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='FederatedQuery.ListJobsResult.job', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='FederatedQuery.ListJobsResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7907,
  serialized_end=7996,
)


_DESCRIBEJOBREQUEST = _descriptor.Descriptor(
  name='DescribeJobRequest',
  full_name='FederatedQuery.DescribeJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DescribeJobRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='FederatedQuery.DescribeJobRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7998,
  serialized_end=8106,
)


_DESCRIBEJOBRESPONSE = _descriptor.Descriptor(
  name='DescribeJobResponse',
  full_name='FederatedQuery.DescribeJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DescribeJobResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8108,
  serialized_end=8175,
)


_DESCRIBEJOBRESULT = _descriptor.Descriptor(
  name='DescribeJobResult',
  full_name='FederatedQuery.DescribeJobResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='FederatedQuery.DescribeJobResult.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8177,
  serialized_end=8230,
)


_CURRENTIAMTOKENAUTH = _descriptor.Descriptor(
  name='CurrentIAMTokenAuth',
  full_name='FederatedQuery.CurrentIAMTokenAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8232,
  serialized_end=8253,
)


_NONEAUTH = _descriptor.Descriptor(
  name='NoneAuth',
  full_name='FederatedQuery.NoneAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8255,
  serialized_end=8265,
)


_SERVICEACCOUNTAUTH = _descriptor.Descriptor(
  name='ServiceAccountAuth',
  full_name='FederatedQuery.ServiceAccountAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='FederatedQuery.ServiceAccountAuth.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8267,
  serialized_end=8308,
)


_TOKENAUTH = _descriptor.Descriptor(
  name='TokenAuth',
  full_name='FederatedQuery.TokenAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='FederatedQuery.TokenAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8310,
  serialized_end=8349,
)


_IAMAUTH = _descriptor.Descriptor(
  name='IamAuth',
  full_name='FederatedQuery.IamAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_iam', full_name='FederatedQuery.IamAuth.current_iam', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account', full_name='FederatedQuery.IamAuth.service_account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='none', full_name='FederatedQuery.IamAuth.none', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='FederatedQuery.IamAuth.token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identity', full_name='FederatedQuery.IamAuth.identity',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8352,
  serialized_end=8582,
)


_DATASTREAMS = _descriptor.Descriptor(
  name='DataStreams',
  full_name='FederatedQuery.DataStreams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.DataStreams.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.DataStreams.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='FederatedQuery.DataStreams.endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='FederatedQuery.DataStreams.database', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='FederatedQuery.DataStreams.secure', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_reading', full_name='FederatedQuery.DataStreams.shared_reading', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8585,
  serialized_end=8761,
)


_MONITORING = _descriptor.Descriptor(
  name='Monitoring',
  full_name='FederatedQuery.Monitoring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='FederatedQuery.Monitoring.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\310\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='FederatedQuery.Monitoring.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\310\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.Monitoring.auth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8763,
  serialized_end=8866,
)


_YDBDATABASE = _descriptor.Descriptor(
  name='YdbDatabase',
  full_name='FederatedQuery.YdbDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.YdbDatabase.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.YdbDatabase.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='FederatedQuery.YdbDatabase.endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='FederatedQuery.YdbDatabase.database', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='FederatedQuery.YdbDatabase.secure', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8869,
  serialized_end=9021,
)


_CLICKHOUSECLUSTER = _descriptor.Descriptor(
  name='ClickHouseCluster',
  full_name='FederatedQuery.ClickHouseCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.ClickHouseCluster.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='FederatedQuery.ClickHouseCluster.database_name', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='login', full_name='FederatedQuery.ClickHouseCluster.login', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='FederatedQuery.ClickHouseCluster.password', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.ClickHouseCluster.auth', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='FederatedQuery.ClickHouseCluster.host', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='FederatedQuery.ClickHouseCluster.port', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\n[0; 65536]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='FederatedQuery.ClickHouseCluster.secure', index=7,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9024,
  serialized_end=9272,
)


_OBJECTSTORAGECONNECTION = _descriptor.Descriptor(
  name='ObjectStorageConnection',
  full_name='FederatedQuery.ObjectStorageConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='FederatedQuery.ObjectStorageConnection.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.ObjectStorageConnection.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9274,
  serialized_end=9363,
)


_POSTGRESQLCLUSTER = _descriptor.Descriptor(
  name='PostgreSQLCluster',
  full_name='FederatedQuery.PostgreSQLCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.PostgreSQLCluster.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='FederatedQuery.PostgreSQLCluster.database_name', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='login', full_name='FederatedQuery.PostgreSQLCluster.login', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='FederatedQuery.PostgreSQLCluster.password', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='FederatedQuery.PostgreSQLCluster.schema', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.PostgreSQLCluster.auth', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='FederatedQuery.PostgreSQLCluster.host', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='FederatedQuery.PostgreSQLCluster.port', index=7,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\n[0; 65536]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='FederatedQuery.PostgreSQLCluster.secure', index=8,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9366,
  serialized_end=9639,
)


_GREENPLUMCLUSTER = _descriptor.Descriptor(
  name='GreenplumCluster',
  full_name='FederatedQuery.GreenplumCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.GreenplumCluster.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='FederatedQuery.GreenplumCluster.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='login', full_name='FederatedQuery.GreenplumCluster.login', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='FederatedQuery.GreenplumCluster.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='FederatedQuery.GreenplumCluster.schema', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.GreenplumCluster.auth', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9642,
  serialized_end=9845,
)


_MYSQLCLUSTER = _descriptor.Descriptor(
  name='MySQLCluster',
  full_name='FederatedQuery.MySQLCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='FederatedQuery.MySQLCluster.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='FederatedQuery.MySQLCluster.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='login', full_name='FederatedQuery.MySQLCluster.login', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='FederatedQuery.MySQLCluster.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010\270\346*\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.MySQLCluster.auth', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9848,
  serialized_end=10022,
)


_LOGGING = _descriptor.Descriptor(
  name='Logging',
  full_name='FederatedQuery.Logging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='FederatedQuery.Logging.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='FederatedQuery.Logging.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10024,
  serialized_end=10091,
)


_ICEBERGWAREHOUSE_S3 = _descriptor.Descriptor(
  name='S3',
  full_name='FederatedQuery.IcebergWarehouse.S3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='FederatedQuery.IcebergWarehouse.S3.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='FederatedQuery.IcebergWarehouse.S3.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_bucket', full_name='FederatedQuery.IcebergWarehouse.S3._bucket',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_path', full_name='FederatedQuery.IcebergWarehouse.S3._path',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10165,
  serialized_end=10247,
)

_ICEBERGWAREHOUSE = _descriptor.Descriptor(
  name='IcebergWarehouse',
  full_name='FederatedQuery.IcebergWarehouse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s3', full_name='FederatedQuery.IcebergWarehouse.s3', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ICEBERGWAREHOUSE_S3, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='FederatedQuery.IcebergWarehouse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10094,
  serialized_end=10258,
)


_ICEBERGCATALOG_HADOOP = _descriptor.Descriptor(
  name='Hadoop',
  full_name='FederatedQuery.IcebergCatalog.Hadoop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='directory', full_name='FederatedQuery.IcebergCatalog.Hadoop.directory', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_directory', full_name='FederatedQuery.IcebergCatalog.Hadoop._directory',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10408,
  serialized_end=10463,
)

_ICEBERGCATALOG_HIVEMETASTORE = _descriptor.Descriptor(
  name='HiveMetastore',
  full_name='FederatedQuery.IcebergCatalog.HiveMetastore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='FederatedQuery.IcebergCatalog.HiveMetastore.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='FederatedQuery.IcebergCatalog.HiveMetastore.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_uri', full_name='FederatedQuery.IcebergCatalog.HiveMetastore._uri',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_database_name', full_name='FederatedQuery.IcebergCatalog.HiveMetastore._database_name',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10465,
  serialized_end=10570,
)

_ICEBERGCATALOG = _descriptor.Descriptor(
  name='IcebergCatalog',
  full_name='FederatedQuery.IcebergCatalog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hadoop', full_name='FederatedQuery.IcebergCatalog.hadoop', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hive_metastore', full_name='FederatedQuery.IcebergCatalog.hive_metastore', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ICEBERGCATALOG_HADOOP, _ICEBERGCATALOG_HIVEMETASTORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='FederatedQuery.IcebergCatalog.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10261,
  serialized_end=10581,
)


_ICEBERG = _descriptor.Descriptor(
  name='Iceberg',
  full_name='FederatedQuery.Iceberg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warehouse_auth', full_name='FederatedQuery.Iceberg.warehouse_auth', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warehouse', full_name='FederatedQuery.Iceberg.warehouse', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catalog', full_name='FederatedQuery.Iceberg.catalog', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10584,
  serialized_end=10744,
)


_CONNECTIONSETTING = _descriptor.Descriptor(
  name='ConnectionSetting',
  full_name='FederatedQuery.ConnectionSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ydb_database', full_name='FederatedQuery.ConnectionSetting.ydb_database', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clickhouse_cluster', full_name='FederatedQuery.ConnectionSetting.clickhouse_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_streams', full_name='FederatedQuery.ConnectionSetting.data_streams', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_storage', full_name='FederatedQuery.ConnectionSetting.object_storage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='FederatedQuery.ConnectionSetting.monitoring', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postgresql_cluster', full_name='FederatedQuery.ConnectionSetting.postgresql_cluster', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='greenplum_cluster', full_name='FederatedQuery.ConnectionSetting.greenplum_cluster', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mysql_cluster', full_name='FederatedQuery.ConnectionSetting.mysql_cluster', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging', full_name='FederatedQuery.ConnectionSetting.logging', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iceberg', full_name='FederatedQuery.ConnectionSetting.iceberg', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONSETTING_CONNECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='FederatedQuery.ConnectionSetting.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10747,
  serialized_end=11579,
)


_CONNECTIONCONTENT = _descriptor.Descriptor(
  name='ConnectionContent',
  full_name='FederatedQuery.ConnectionContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.ConnectionContent.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='FederatedQuery.ConnectionContent.setting', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='FederatedQuery.ConnectionContent.acl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='FederatedQuery.ConnectionContent.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200P', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11582,
  serialized_end=11744,
)


_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='FederatedQuery.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.Connection.content', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.Connection.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11746,
  serialized_end=11852,
)


_CREATECONNECTIONREQUEST = _descriptor.Descriptor(
  name='CreateConnectionRequest',
  full_name='FederatedQuery.CreateConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.CreateConnectionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.CreateConnectionRequest.content', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.CreateConnectionRequest.idempotency_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11855,
  serialized_end=12025,
)


_CREATECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='CreateConnectionResponse',
  full_name='FederatedQuery.CreateConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.CreateConnectionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12027,
  serialized_end=12099,
)


_CREATECONNECTIONRESULT = _descriptor.Descriptor(
  name='CreateConnectionResult',
  full_name='FederatedQuery.CreateConnectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.CreateConnectionResult.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12101,
  serialized_end=12161,
)


_LISTCONNECTIONSREQUEST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='FederatedQuery.ListConnectionsRequest.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.ListConnectionsRequest.Filter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by_me', full_name='FederatedQuery.ListConnectionsRequest.Filter.created_by_me', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_type', full_name='FederatedQuery.ListConnectionsRequest.Filter.connection_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.ListConnectionsRequest.Filter.visibility', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12371,
  serialized_end=12552,
)

_LISTCONNECTIONSREQUEST = _descriptor.Descriptor(
  name='ListConnectionsRequest',
  full_name='FederatedQuery.ListConnectionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ListConnectionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='FederatedQuery.ListConnectionsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='FederatedQuery.ListConnectionsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010[1; 100]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='FederatedQuery.ListConnectionsRequest.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONNECTIONSREQUEST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12164,
  serialized_end=12552,
)


_LISTCONNECTIONSRESPONSE = _descriptor.Descriptor(
  name='ListConnectionsResponse',
  full_name='FederatedQuery.ListConnectionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ListConnectionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12554,
  serialized_end=12625,
)


_LISTCONNECTIONSRESULT = _descriptor.Descriptor(
  name='ListConnectionsResult',
  full_name='FederatedQuery.ListConnectionsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='FederatedQuery.ListConnectionsResult.connection', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='FederatedQuery.ListConnectionsResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12627,
  serialized_end=12732,
)


_DESCRIBECONNECTIONREQUEST = _descriptor.Descriptor(
  name='DescribeConnectionRequest',
  full_name='FederatedQuery.DescribeConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DescribeConnectionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.DescribeConnectionRequest.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12734,
  serialized_end=12856,
)


_DESCRIBECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DescribeConnectionResponse',
  full_name='FederatedQuery.DescribeConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DescribeConnectionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12858,
  serialized_end=12932,
)


_DESCRIBECONNECTIONRESULT = _descriptor.Descriptor(
  name='DescribeConnectionResult',
  full_name='FederatedQuery.DescribeConnectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='FederatedQuery.DescribeConnectionResult.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12934,
  serialized_end=13008,
)


_MODIFYCONNECTIONREQUEST = _descriptor.Descriptor(
  name='ModifyConnectionRequest',
  full_name='FederatedQuery.ModifyConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ModifyConnectionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.ModifyConnectionRequest.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.ModifyConnectionRequest.content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.ModifyConnectionRequest.previous_revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.ModifyConnectionRequest.idempotency_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13011,
  serialized_end=13254,
)


_MODIFYCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='ModifyConnectionResponse',
  full_name='FederatedQuery.ModifyConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ModifyConnectionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13256,
  serialized_end=13328,
)


_MODIFYCONNECTIONRESULT = _descriptor.Descriptor(
  name='ModifyConnectionResult',
  full_name='FederatedQuery.ModifyConnectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13330,
  serialized_end=13354,
)


_DELETECONNECTIONREQUEST = _descriptor.Descriptor(
  name='DeleteConnectionRequest',
  full_name='FederatedQuery.DeleteConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DeleteConnectionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.DeleteConnectionRequest.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.DeleteConnectionRequest.previous_revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.DeleteConnectionRequest.idempotency_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13357,
  serialized_end=13548,
)


_DELETECONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DeleteConnectionResponse',
  full_name='FederatedQuery.DeleteConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DeleteConnectionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13550,
  serialized_end=13622,
)


_DELETECONNECTIONRESULT = _descriptor.Descriptor(
  name='DeleteConnectionResult',
  full_name='FederatedQuery.DeleteConnectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13624,
  serialized_end=13648,
)


_TESTCONNECTIONREQUEST = _descriptor.Descriptor(
  name='TestConnectionRequest',
  full_name='FederatedQuery.TestConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.TestConnectionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='FederatedQuery.TestConnectionRequest.setting', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13651,
  serialized_end=13785,
)


_TESTCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='TestConnectionResponse',
  full_name='FederatedQuery.TestConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.TestConnectionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13787,
  serialized_end=13857,
)


_TESTCONNECTIONRESULT = _descriptor.Descriptor(
  name='TestConnectionResult',
  full_name='FederatedQuery.TestConnectionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13859,
  serialized_end=13881,
)


_GETRESULTDATAREQUEST = _descriptor.Descriptor(
  name='GetResultDataRequest',
  full_name='FederatedQuery.GetResultDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.GetResultDataRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='FederatedQuery.GetResultDataRequest.query_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_index', full_name='FederatedQuery.GetResultDataRequest.result_set_index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='FederatedQuery.GetResultDataRequest.offset', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='FederatedQuery.GetResultDataRequest.limit', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\t[1; 1000]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13884,
  serialized_end=14088,
)


_GETRESULTDATARESPONSE = _descriptor.Descriptor(
  name='GetResultDataResponse',
  full_name='FederatedQuery.GetResultDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.GetResultDataResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14090,
  serialized_end=14159,
)


_GETRESULTDATARESULT = _descriptor.Descriptor(
  name='GetResultDataResult',
  full_name='FederatedQuery.GetResultDataResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_set', full_name='FederatedQuery.GetResultDataResult.result_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14161,
  serialized_end=14218,
)


_SCHEMA = _descriptor.Descriptor(
  name='Schema',
  full_name='FederatedQuery.Schema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='FederatedQuery.Schema.column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\003\030\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14220,
  serialized_end=14266,
)


_DATASTREAMSBINDING_FORMATSETTINGENTRY = _descriptor.Descriptor(
  name='FormatSettingEntry',
  full_name='FederatedQuery.DataStreamsBinding.FormatSettingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.DataStreamsBinding.FormatSettingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.DataStreamsBinding.FormatSettingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14507,
  serialized_end=14559,
)

_DATASTREAMSBINDING = _descriptor.Descriptor(
  name='DataStreamsBinding',
  full_name='FederatedQuery.DataStreamsBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='FederatedQuery.DataStreamsBinding.stream_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='FederatedQuery.DataStreamsBinding.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='FederatedQuery.DataStreamsBinding.compression', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='FederatedQuery.DataStreamsBinding.schema', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_setting', full_name='FederatedQuery.DataStreamsBinding.format_setting', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATASTREAMSBINDING_FORMATSETTINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14269,
  serialized_end=14559,
)


_OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY = _descriptor.Descriptor(
  name='FormatSettingEntry',
  full_name='FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14507,
  serialized_end=14559,
)

_OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY = _descriptor.Descriptor(
  name='ProjectionEntry',
  full_name='FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15043,
  serialized_end=15092,
)

_OBJECTSTORAGEBINDING_SUBSET = _descriptor.Descriptor(
  name='Subset',
  full_name='FederatedQuery.ObjectStorageBinding.Subset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_pattern', full_name='FederatedQuery.ObjectStorageBinding.Subset.path_pattern', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='FederatedQuery.ObjectStorageBinding.Subset.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_setting', full_name='FederatedQuery.ObjectStorageBinding.Subset.format_setting', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='FederatedQuery.ObjectStorageBinding.Subset.compression', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='FederatedQuery.ObjectStorageBinding.Subset.schema', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projection', full_name='FederatedQuery.ObjectStorageBinding.Subset.projection', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioned_by', full_name='FederatedQuery.ObjectStorageBinding.Subset.partitioned_by', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY, _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14648,
  serialized_end=15092,
)

_OBJECTSTORAGEBINDING = _descriptor.Descriptor(
  name='ObjectStorageBinding',
  full_name='FederatedQuery.ObjectStorageBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subset', full_name='FederatedQuery.ObjectStorageBinding.subset', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTSTORAGEBINDING_SUBSET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14562,
  serialized_end=15092,
)


_BINDINGSETTING = _descriptor.Descriptor(
  name='BindingSetting',
  full_name='FederatedQuery.BindingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_streams', full_name='FederatedQuery.BindingSetting.data_streams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_storage', full_name='FederatedQuery.BindingSetting.object_storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BINDINGSETTING_BINDINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='binding', full_name='FederatedQuery.BindingSetting.binding',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=15095,
  serialized_end=15329,
)


_BRIEFBINDING = _descriptor.Descriptor(
  name='BriefBinding',
  full_name='FederatedQuery.BriefBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.BriefBinding.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.BriefBinding.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.BriefBinding.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='FederatedQuery.BriefBinding.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.BriefBinding.visibility', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15332,
  serialized_end=15561,
)


_BINDINGCONTENT = _descriptor.Descriptor(
  name='BindingContent',
  full_name='FederatedQuery.BindingContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.BindingContent.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.BindingContent.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='FederatedQuery.BindingContent.setting', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='FederatedQuery.BindingContent.acl', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='FederatedQuery.BindingContent.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200P', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15564,
  serialized_end=15756,
)


_BINDING = _descriptor.Descriptor(
  name='Binding',
  full_name='FederatedQuery.Binding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.Binding.content', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='FederatedQuery.Binding.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15758,
  serialized_end=15858,
)


_CREATEBINDINGREQUEST = _descriptor.Descriptor(
  name='CreateBindingRequest',
  full_name='FederatedQuery.CreateBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.CreateBindingRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.CreateBindingRequest.content', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.CreateBindingRequest.idempotency_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15861,
  serialized_end=16025,
)


_CREATEBINDINGRESPONSE = _descriptor.Descriptor(
  name='CreateBindingResponse',
  full_name='FederatedQuery.CreateBindingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.CreateBindingResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16027,
  serialized_end=16096,
)


_CREATEBINDINGRESULT = _descriptor.Descriptor(
  name='CreateBindingResult',
  full_name='FederatedQuery.CreateBindingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='binding_id', full_name='FederatedQuery.CreateBindingResult.binding_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16098,
  serialized_end=16152,
)


_LISTBINDINGSREQUEST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='FederatedQuery.ListBindingsRequest.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='FederatedQuery.ListBindingsRequest.Filter.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='FederatedQuery.ListBindingsRequest.Filter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by_me', full_name='FederatedQuery.ListBindingsRequest.Filter.created_by_me', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='FederatedQuery.ListBindingsRequest.Filter.visibility', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16356,
  serialized_end=16494,
)

_LISTBINDINGSREQUEST = _descriptor.Descriptor(
  name='ListBindingsRequest',
  full_name='FederatedQuery.ListBindingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ListBindingsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='FederatedQuery.ListBindingsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='FederatedQuery.ListBindingsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\010[1; 100]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='FederatedQuery.ListBindingsRequest.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTBINDINGSREQUEST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16155,
  serialized_end=16494,
)


_LISTBINDINGSRESPONSE = _descriptor.Descriptor(
  name='ListBindingsResponse',
  full_name='FederatedQuery.ListBindingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ListBindingsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16496,
  serialized_end=16564,
)


_LISTBINDINGSRESULT = _descriptor.Descriptor(
  name='ListBindingsResult',
  full_name='FederatedQuery.ListBindingsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='binding', full_name='FederatedQuery.ListBindingsResult.binding', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='FederatedQuery.ListBindingsResult.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16566,
  serialized_end=16667,
)


_DESCRIBEBINDINGREQUEST = _descriptor.Descriptor(
  name='DescribeBindingRequest',
  full_name='FederatedQuery.DescribeBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DescribeBindingRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binding_id', full_name='FederatedQuery.DescribeBindingRequest.binding_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16669,
  serialized_end=16785,
)


_DESCRIBEBINDINGRESPONSE = _descriptor.Descriptor(
  name='DescribeBindingResponse',
  full_name='FederatedQuery.DescribeBindingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DescribeBindingResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16787,
  serialized_end=16858,
)


_DESCRIBEBINDINGRESULT = _descriptor.Descriptor(
  name='DescribeBindingResult',
  full_name='FederatedQuery.DescribeBindingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='binding', full_name='FederatedQuery.DescribeBindingResult.binding', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16860,
  serialized_end=16925,
)


_MODIFYBINDINGREQUEST = _descriptor.Descriptor(
  name='ModifyBindingRequest',
  full_name='FederatedQuery.ModifyBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.ModifyBindingRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binding_id', full_name='FederatedQuery.ModifyBindingRequest.binding_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='FederatedQuery.ModifyBindingRequest.content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.ModifyBindingRequest.previous_revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.ModifyBindingRequest.idempotency_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16928,
  serialized_end=17162,
)


_MODIFYBINDINGRESPONSE = _descriptor.Descriptor(
  name='ModifyBindingResponse',
  full_name='FederatedQuery.ModifyBindingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.ModifyBindingResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17164,
  serialized_end=17233,
)


_MODIFYBINDINGRESULT = _descriptor.Descriptor(
  name='ModifyBindingResult',
  full_name='FederatedQuery.ModifyBindingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17235,
  serialized_end=17256,
)


_DELETEBINDINGREQUEST = _descriptor.Descriptor(
  name='DeleteBindingRequest',
  full_name='FederatedQuery.DeleteBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='FederatedQuery.DeleteBindingRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binding_id', full_name='FederatedQuery.DeleteBindingRequest.binding_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\007\n\005\010\001\020\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_revision', full_name='FederatedQuery.DeleteBindingRequest.previous_revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='FederatedQuery.DeleteBindingRequest.idempotency_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17259,
  serialized_end=17444,
)


_DELETEBINDINGRESPONSE = _descriptor.Descriptor(
  name='DeleteBindingResponse',
  full_name='FederatedQuery.DeleteBindingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='FederatedQuery.DeleteBindingResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17446,
  serialized_end=17515,
)


_DELETEBINDINGRESULT = _descriptor.Descriptor(
  name='DeleteBindingResult',
  full_name='FederatedQuery.DeleteBindingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17517,
  serialized_end=17538,
)

_ACL.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_ACL_VISIBILITY.containing_type = _ACL
_LIMITS.fields_by_name['result_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LIMITS.fields_by_name['execution_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LIMITS.fields_by_name['execution_deadline'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LIMITS.oneofs_by_name['timeout'].fields.append(
  _LIMITS.fields_by_name['execution_timeout'])
_LIMITS.fields_by_name['execution_timeout'].containing_oneof = _LIMITS.oneofs_by_name['timeout']
_LIMITS.oneofs_by_name['timeout'].fields.append(
  _LIMITS.fields_by_name['execution_deadline'])
_LIMITS.fields_by_name['execution_deadline'].containing_oneof = _LIMITS.oneofs_by_name['timeout']
_STREAMINGDISPOSITION_FROMTIME.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMINGDISPOSITION_FROMTIME.containing_type = _STREAMINGDISPOSITION
_STREAMINGDISPOSITION_TIMEAGO.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMINGDISPOSITION_TIMEAGO.containing_type = _STREAMINGDISPOSITION
_STREAMINGDISPOSITION_FROMLASTCHECKPOINT.containing_type = _STREAMINGDISPOSITION
_STREAMINGDISPOSITION.fields_by_name['oldest'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_STREAMINGDISPOSITION.fields_by_name['fresh'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_STREAMINGDISPOSITION.fields_by_name['from_time'].message_type = _STREAMINGDISPOSITION_FROMTIME
_STREAMINGDISPOSITION.fields_by_name['time_ago'].message_type = _STREAMINGDISPOSITION_TIMEAGO
_STREAMINGDISPOSITION.fields_by_name['from_last_checkpoint'].message_type = _STREAMINGDISPOSITION_FROMLASTCHECKPOINT
_STREAMINGDISPOSITION.oneofs_by_name['disposition'].fields.append(
  _STREAMINGDISPOSITION.fields_by_name['oldest'])
_STREAMINGDISPOSITION.fields_by_name['oldest'].containing_oneof = _STREAMINGDISPOSITION.oneofs_by_name['disposition']
_STREAMINGDISPOSITION.oneofs_by_name['disposition'].fields.append(
  _STREAMINGDISPOSITION.fields_by_name['fresh'])
_STREAMINGDISPOSITION.fields_by_name['fresh'].containing_oneof = _STREAMINGDISPOSITION.oneofs_by_name['disposition']
_STREAMINGDISPOSITION.oneofs_by_name['disposition'].fields.append(
  _STREAMINGDISPOSITION.fields_by_name['from_time'])
_STREAMINGDISPOSITION.fields_by_name['from_time'].containing_oneof = _STREAMINGDISPOSITION.oneofs_by_name['disposition']
_STREAMINGDISPOSITION.oneofs_by_name['disposition'].fields.append(
  _STREAMINGDISPOSITION.fields_by_name['time_ago'])
_STREAMINGDISPOSITION.fields_by_name['time_ago'].containing_oneof = _STREAMINGDISPOSITION.oneofs_by_name['disposition']
_STREAMINGDISPOSITION.oneofs_by_name['disposition'].fields.append(
  _STREAMINGDISPOSITION.fields_by_name['from_last_checkpoint'])
_STREAMINGDISPOSITION.fields_by_name['from_last_checkpoint'].containing_oneof = _STREAMINGDISPOSITION.oneofs_by_name['disposition']
_QUERYCONTENT_EXECUTIONSETTINGSENTRY.containing_type = _QUERYCONTENT
_QUERYCONTENT_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_QUERYCONTENT_PARAMETERSENTRY.containing_type = _QUERYCONTENT
_QUERYCONTENT.fields_by_name['type'].enum_type = _QUERYCONTENT_QUERYTYPE
_QUERYCONTENT.fields_by_name['acl'].message_type = _ACL
_QUERYCONTENT.fields_by_name['limits'].message_type = _LIMITS
_QUERYCONTENT.fields_by_name['execution_settings'].message_type = _QUERYCONTENT_EXECUTIONSETTINGSENTRY
_QUERYCONTENT.fields_by_name['syntax'].enum_type = _QUERYCONTENT_QUERYSYNTAX
_QUERYCONTENT.fields_by_name['parameters'].message_type = _QUERYCONTENT_PARAMETERSENTRY
_QUERYCONTENT_QUERYTYPE.containing_type = _QUERYCONTENT
_QUERYCONTENT_QUERYSYNTAX.containing_type = _QUERYCONTENT
_COMMONMETA.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMONMETA.fields_by_name['modified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA.fields_by_name['common'].message_type = _COMMONMETA
_QUERYMETA.fields_by_name['submitted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA.fields_by_name['finished_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA.fields_by_name['execute_mode'].enum_type = _EXECUTEMODE
_QUERYMETA.fields_by_name['status'].enum_type = _QUERYMETA_COMPUTESTATUS
_QUERYMETA.fields_by_name['expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA.fields_by_name['result_expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYMETA_COMPUTESTATUS.containing_type = _QUERYMETA
_QUERYMETA.oneofs_by_name['action'].fields.append(
  _QUERYMETA.fields_by_name['aborted_by'])
_QUERYMETA.fields_by_name['aborted_by'].containing_oneof = _QUERYMETA.oneofs_by_name['action']
_QUERYMETA.oneofs_by_name['action'].fields.append(
  _QUERYMETA.fields_by_name['paused_by'])
_QUERYMETA.fields_by_name['paused_by'].containing_oneof = _QUERYMETA.oneofs_by_name['action']
_BRIEFQUERY.fields_by_name['type'].enum_type = _QUERYCONTENT_QUERYTYPE
_BRIEFQUERY.fields_by_name['meta'].message_type = _QUERYMETA
_BRIEFQUERY.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_RESULTSETMETA.fields_by_name['column'].message_type = protos_dot_ydb__value__pb2._COLUMN
_QUERY.fields_by_name['meta'].message_type = _QUERYMETA
_QUERY.fields_by_name['content'].message_type = _QUERYCONTENT
_QUERY.fields_by_name['plan'].message_type = _QUERYPLAN
_QUERY.fields_by_name['issue'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_QUERY.fields_by_name['transient_issue'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_QUERY.fields_by_name['statistics'].message_type = _QUERYSTATISTICS
_QUERY.fields_by_name['result_set_meta'].message_type = _RESULTSETMETA
_QUERY.fields_by_name['ast'].message_type = _QUERYAST
_QUERY.fields_by_name['timeline'].message_type = _QUERYTIMELINE
_CREATEQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEQUERYREQUEST.fields_by_name['content'].message_type = _QUERYCONTENT
_CREATEQUERYREQUEST.fields_by_name['execute_mode'].enum_type = _EXECUTEMODE
_CREATEQUERYREQUEST.fields_by_name['disposition'].message_type = _STREAMINGDISPOSITION
_CREATEQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTQUERIESREQUEST_FILTER.fields_by_name['query_type'].enum_type = _QUERYCONTENT_QUERYTYPE
_LISTQUERIESREQUEST_FILTER.fields_by_name['status'].enum_type = _QUERYMETA_COMPUTESTATUS
_LISTQUERIESREQUEST_FILTER.fields_by_name['mode'].enum_type = _EXECUTEMODE
_LISTQUERIESREQUEST_FILTER.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_LISTQUERIESREQUEST_FILTER.fields_by_name['automatic'].enum_type = _AUTOMATICTYPE
_LISTQUERIESREQUEST_FILTER.containing_type = _LISTQUERIESREQUEST
_LISTQUERIESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTQUERIESREQUEST.fields_by_name['filter'].message_type = _LISTQUERIESREQUEST_FILTER
_LISTQUERIESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTQUERIESRESULT.fields_by_name['query'].message_type = _BRIEFQUERY
_DESCRIBEQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEQUERYRESULT.fields_by_name['query'].message_type = _QUERY
_GETQUERYSTATUSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETQUERYSTATUSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETQUERYSTATUSRESULT.fields_by_name['status'].enum_type = _QUERYMETA_COMPUTESTATUS
_DELETEQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DELETEQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_MODIFYQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MODIFYQUERYREQUEST.fields_by_name['content'].message_type = _QUERYCONTENT
_MODIFYQUERYREQUEST.fields_by_name['execute_mode'].enum_type = _EXECUTEMODE
_MODIFYQUERYREQUEST.fields_by_name['disposition'].message_type = _STREAMINGDISPOSITION
_MODIFYQUERYREQUEST.fields_by_name['state_load_mode'].enum_type = _STATELOADMODE
_MODIFYQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_CONTROLQUERYREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CONTROLQUERYREQUEST.fields_by_name['action'].enum_type = _QUERYACTION
_CONTROLQUERYRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_BRIEFJOB.fields_by_name['meta'].message_type = _COMMONMETA
_BRIEFJOB.fields_by_name['query_meta'].message_type = _QUERYMETA
_BRIEFJOB.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_BRIEFJOB.fields_by_name['expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_JOB_PARAMETERSENTRY.containing_type = _JOB
_JOB.fields_by_name['meta'].message_type = _COMMONMETA
_JOB.fields_by_name['query_meta'].message_type = _QUERYMETA
_JOB.fields_by_name['plan'].message_type = _QUERYPLAN
_JOB.fields_by_name['issue'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_JOB.fields_by_name['statistics'].message_type = _QUERYSTATISTICS
_JOB.fields_by_name['result_set_meta'].message_type = _RESULTSETMETA
_JOB.fields_by_name['ast'].message_type = _QUERYAST
_JOB.fields_by_name['acl'].message_type = _ACL
_JOB.fields_by_name['expire_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['syntax'].enum_type = _QUERYCONTENT_QUERYSYNTAX
_JOB.fields_by_name['parameters'].message_type = _JOB_PARAMETERSENTRY
_LISTJOBSREQUEST_FILTER.containing_type = _LISTJOBSREQUEST
_LISTJOBSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTJOBSREQUEST.fields_by_name['filter'].message_type = _LISTJOBSREQUEST_FILTER
_LISTJOBSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTJOBSRESULT.fields_by_name['job'].message_type = _BRIEFJOB
_DESCRIBEJOBREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEJOBRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEJOBRESULT.fields_by_name['job'].message_type = _JOB
_IAMAUTH.fields_by_name['current_iam'].message_type = _CURRENTIAMTOKENAUTH
_IAMAUTH.fields_by_name['service_account'].message_type = _SERVICEACCOUNTAUTH
_IAMAUTH.fields_by_name['none'].message_type = _NONEAUTH
_IAMAUTH.fields_by_name['token'].message_type = _TOKENAUTH
_IAMAUTH.oneofs_by_name['identity'].fields.append(
  _IAMAUTH.fields_by_name['current_iam'])
_IAMAUTH.fields_by_name['current_iam'].containing_oneof = _IAMAUTH.oneofs_by_name['identity']
_IAMAUTH.oneofs_by_name['identity'].fields.append(
  _IAMAUTH.fields_by_name['service_account'])
_IAMAUTH.fields_by_name['service_account'].containing_oneof = _IAMAUTH.oneofs_by_name['identity']
_IAMAUTH.oneofs_by_name['identity'].fields.append(
  _IAMAUTH.fields_by_name['none'])
_IAMAUTH.fields_by_name['none'].containing_oneof = _IAMAUTH.oneofs_by_name['identity']
_IAMAUTH.oneofs_by_name['identity'].fields.append(
  _IAMAUTH.fields_by_name['token'])
_IAMAUTH.fields_by_name['token'].containing_oneof = _IAMAUTH.oneofs_by_name['identity']
_DATASTREAMS.fields_by_name['auth'].message_type = _IAMAUTH
_MONITORING.fields_by_name['auth'].message_type = _IAMAUTH
_YDBDATABASE.fields_by_name['auth'].message_type = _IAMAUTH
_CLICKHOUSECLUSTER.fields_by_name['auth'].message_type = _IAMAUTH
_OBJECTSTORAGECONNECTION.fields_by_name['auth'].message_type = _IAMAUTH
_POSTGRESQLCLUSTER.fields_by_name['auth'].message_type = _IAMAUTH
_GREENPLUMCLUSTER.fields_by_name['auth'].message_type = _IAMAUTH
_MYSQLCLUSTER.fields_by_name['auth'].message_type = _IAMAUTH
_LOGGING.fields_by_name['auth'].message_type = _IAMAUTH
_ICEBERGWAREHOUSE_S3.containing_type = _ICEBERGWAREHOUSE
_ICEBERGWAREHOUSE_S3.oneofs_by_name['_bucket'].fields.append(
  _ICEBERGWAREHOUSE_S3.fields_by_name['bucket'])
_ICEBERGWAREHOUSE_S3.fields_by_name['bucket'].containing_oneof = _ICEBERGWAREHOUSE_S3.oneofs_by_name['_bucket']
_ICEBERGWAREHOUSE_S3.oneofs_by_name['_path'].fields.append(
  _ICEBERGWAREHOUSE_S3.fields_by_name['path'])
_ICEBERGWAREHOUSE_S3.fields_by_name['path'].containing_oneof = _ICEBERGWAREHOUSE_S3.oneofs_by_name['_path']
_ICEBERGWAREHOUSE.fields_by_name['s3'].message_type = _ICEBERGWAREHOUSE_S3
_ICEBERGWAREHOUSE.oneofs_by_name['payload'].fields.append(
  _ICEBERGWAREHOUSE.fields_by_name['s3'])
_ICEBERGWAREHOUSE.fields_by_name['s3'].containing_oneof = _ICEBERGWAREHOUSE.oneofs_by_name['payload']
_ICEBERGCATALOG_HADOOP.containing_type = _ICEBERGCATALOG
_ICEBERGCATALOG_HADOOP.oneofs_by_name['_directory'].fields.append(
  _ICEBERGCATALOG_HADOOP.fields_by_name['directory'])
_ICEBERGCATALOG_HADOOP.fields_by_name['directory'].containing_oneof = _ICEBERGCATALOG_HADOOP.oneofs_by_name['_directory']
_ICEBERGCATALOG_HIVEMETASTORE.containing_type = _ICEBERGCATALOG
_ICEBERGCATALOG_HIVEMETASTORE.oneofs_by_name['_uri'].fields.append(
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['uri'])
_ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['uri'].containing_oneof = _ICEBERGCATALOG_HIVEMETASTORE.oneofs_by_name['_uri']
_ICEBERGCATALOG_HIVEMETASTORE.oneofs_by_name['_database_name'].fields.append(
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['database_name'])
_ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['database_name'].containing_oneof = _ICEBERGCATALOG_HIVEMETASTORE.oneofs_by_name['_database_name']
_ICEBERGCATALOG.fields_by_name['hadoop'].message_type = _ICEBERGCATALOG_HADOOP
_ICEBERGCATALOG.fields_by_name['hive_metastore'].message_type = _ICEBERGCATALOG_HIVEMETASTORE
_ICEBERGCATALOG.oneofs_by_name['payload'].fields.append(
  _ICEBERGCATALOG.fields_by_name['hadoop'])
_ICEBERGCATALOG.fields_by_name['hadoop'].containing_oneof = _ICEBERGCATALOG.oneofs_by_name['payload']
_ICEBERGCATALOG.oneofs_by_name['payload'].fields.append(
  _ICEBERGCATALOG.fields_by_name['hive_metastore'])
_ICEBERGCATALOG.fields_by_name['hive_metastore'].containing_oneof = _ICEBERGCATALOG.oneofs_by_name['payload']
_ICEBERG.fields_by_name['warehouse_auth'].message_type = _IAMAUTH
_ICEBERG.fields_by_name['warehouse'].message_type = _ICEBERGWAREHOUSE
_ICEBERG.fields_by_name['catalog'].message_type = _ICEBERGCATALOG
_CONNECTIONSETTING.fields_by_name['ydb_database'].message_type = _YDBDATABASE
_CONNECTIONSETTING.fields_by_name['clickhouse_cluster'].message_type = _CLICKHOUSECLUSTER
_CONNECTIONSETTING.fields_by_name['data_streams'].message_type = _DATASTREAMS
_CONNECTIONSETTING.fields_by_name['object_storage'].message_type = _OBJECTSTORAGECONNECTION
_CONNECTIONSETTING.fields_by_name['monitoring'].message_type = _MONITORING
_CONNECTIONSETTING.fields_by_name['postgresql_cluster'].message_type = _POSTGRESQLCLUSTER
_CONNECTIONSETTING.fields_by_name['greenplum_cluster'].message_type = _GREENPLUMCLUSTER
_CONNECTIONSETTING.fields_by_name['mysql_cluster'].message_type = _MYSQLCLUSTER
_CONNECTIONSETTING.fields_by_name['logging'].message_type = _LOGGING
_CONNECTIONSETTING.fields_by_name['iceberg'].message_type = _ICEBERG
_CONNECTIONSETTING_CONNECTIONTYPE.containing_type = _CONNECTIONSETTING
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['ydb_database'])
_CONNECTIONSETTING.fields_by_name['ydb_database'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['clickhouse_cluster'])
_CONNECTIONSETTING.fields_by_name['clickhouse_cluster'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['data_streams'])
_CONNECTIONSETTING.fields_by_name['data_streams'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['object_storage'])
_CONNECTIONSETTING.fields_by_name['object_storage'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['monitoring'])
_CONNECTIONSETTING.fields_by_name['monitoring'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['postgresql_cluster'])
_CONNECTIONSETTING.fields_by_name['postgresql_cluster'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['greenplum_cluster'])
_CONNECTIONSETTING.fields_by_name['greenplum_cluster'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['mysql_cluster'])
_CONNECTIONSETTING.fields_by_name['mysql_cluster'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['logging'])
_CONNECTIONSETTING.fields_by_name['logging'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONSETTING.oneofs_by_name['connection'].fields.append(
  _CONNECTIONSETTING.fields_by_name['iceberg'])
_CONNECTIONSETTING.fields_by_name['iceberg'].containing_oneof = _CONNECTIONSETTING.oneofs_by_name['connection']
_CONNECTIONCONTENT.fields_by_name['setting'].message_type = _CONNECTIONSETTING
_CONNECTIONCONTENT.fields_by_name['acl'].message_type = _ACL
_CONNECTION.fields_by_name['content'].message_type = _CONNECTIONCONTENT
_CONNECTION.fields_by_name['meta'].message_type = _COMMONMETA
_CREATECONNECTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATECONNECTIONREQUEST.fields_by_name['content'].message_type = _CONNECTIONCONTENT
_CREATECONNECTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTCONNECTIONSREQUEST_FILTER.fields_by_name['connection_type'].enum_type = _CONNECTIONSETTING_CONNECTIONTYPE
_LISTCONNECTIONSREQUEST_FILTER.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_LISTCONNECTIONSREQUEST_FILTER.containing_type = _LISTCONNECTIONSREQUEST
_LISTCONNECTIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTCONNECTIONSREQUEST.fields_by_name['filter'].message_type = _LISTCONNECTIONSREQUEST_FILTER
_LISTCONNECTIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTCONNECTIONSRESULT.fields_by_name['connection'].message_type = _CONNECTION
_DESCRIBECONNECTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBECONNECTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBECONNECTIONRESULT.fields_by_name['connection'].message_type = _CONNECTION
_MODIFYCONNECTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MODIFYCONNECTIONREQUEST.fields_by_name['content'].message_type = _CONNECTIONCONTENT
_MODIFYCONNECTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DELETECONNECTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DELETECONNECTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_TESTCONNECTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_TESTCONNECTIONREQUEST.fields_by_name['setting'].message_type = _CONNECTIONSETTING
_TESTCONNECTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETRESULTDATAREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETRESULTDATARESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETRESULTDATARESULT.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_SCHEMA.fields_by_name['column'].message_type = protos_dot_ydb__value__pb2._COLUMN
_DATASTREAMSBINDING_FORMATSETTINGENTRY.containing_type = _DATASTREAMSBINDING
_DATASTREAMSBINDING.fields_by_name['schema'].message_type = _SCHEMA
_DATASTREAMSBINDING.fields_by_name['format_setting'].message_type = _DATASTREAMSBINDING_FORMATSETTINGENTRY
_OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY.containing_type = _OBJECTSTORAGEBINDING_SUBSET
_OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY.containing_type = _OBJECTSTORAGEBINDING_SUBSET
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting'].message_type = _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['schema'].message_type = _SCHEMA
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['projection'].message_type = _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY
_OBJECTSTORAGEBINDING_SUBSET.containing_type = _OBJECTSTORAGEBINDING
_OBJECTSTORAGEBINDING.fields_by_name['subset'].message_type = _OBJECTSTORAGEBINDING_SUBSET
_BINDINGSETTING.fields_by_name['data_streams'].message_type = _DATASTREAMSBINDING
_BINDINGSETTING.fields_by_name['object_storage'].message_type = _OBJECTSTORAGEBINDING
_BINDINGSETTING_BINDINGTYPE.containing_type = _BINDINGSETTING
_BINDINGSETTING.oneofs_by_name['binding'].fields.append(
  _BINDINGSETTING.fields_by_name['data_streams'])
_BINDINGSETTING.fields_by_name['data_streams'].containing_oneof = _BINDINGSETTING.oneofs_by_name['binding']
_BINDINGSETTING.oneofs_by_name['binding'].fields.append(
  _BINDINGSETTING.fields_by_name['object_storage'])
_BINDINGSETTING.fields_by_name['object_storage'].containing_oneof = _BINDINGSETTING.oneofs_by_name['binding']
_BRIEFBINDING.fields_by_name['meta'].message_type = _COMMONMETA
_BRIEFBINDING.fields_by_name['type'].enum_type = _BINDINGSETTING_BINDINGTYPE
_BRIEFBINDING.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_BINDINGCONTENT.fields_by_name['setting'].message_type = _BINDINGSETTING
_BINDINGCONTENT.fields_by_name['acl'].message_type = _ACL
_BINDING.fields_by_name['content'].message_type = _BINDINGCONTENT
_BINDING.fields_by_name['meta'].message_type = _COMMONMETA
_CREATEBINDINGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEBINDINGREQUEST.fields_by_name['content'].message_type = _BINDINGCONTENT
_CREATEBINDINGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTBINDINGSREQUEST_FILTER.fields_by_name['visibility'].enum_type = _ACL_VISIBILITY
_LISTBINDINGSREQUEST_FILTER.containing_type = _LISTBINDINGSREQUEST
_LISTBINDINGSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTBINDINGSREQUEST.fields_by_name['filter'].message_type = _LISTBINDINGSREQUEST_FILTER
_LISTBINDINGSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTBINDINGSRESULT.fields_by_name['binding'].message_type = _BRIEFBINDING
_DESCRIBEBINDINGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEBINDINGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEBINDINGRESULT.fields_by_name['binding'].message_type = _BINDING
_MODIFYBINDINGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MODIFYBINDINGREQUEST.fields_by_name['content'].message_type = _BINDINGCONTENT
_MODIFYBINDINGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DELETEBINDINGREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DELETEBINDINGRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['Acl'] = _ACL
DESCRIPTOR.message_types_by_name['Limits'] = _LIMITS
DESCRIPTOR.message_types_by_name['StreamingDisposition'] = _STREAMINGDISPOSITION
DESCRIPTOR.message_types_by_name['QueryContent'] = _QUERYCONTENT
DESCRIPTOR.message_types_by_name['CommonMeta'] = _COMMONMETA
DESCRIPTOR.message_types_by_name['QueryMeta'] = _QUERYMETA
DESCRIPTOR.message_types_by_name['BriefQuery'] = _BRIEFQUERY
DESCRIPTOR.message_types_by_name['QueryPlan'] = _QUERYPLAN
DESCRIPTOR.message_types_by_name['QueryAst'] = _QUERYAST
DESCRIPTOR.message_types_by_name['ResultSetMeta'] = _RESULTSETMETA
DESCRIPTOR.message_types_by_name['QueryTimeline'] = _QUERYTIMELINE
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['QueryStatistics'] = _QUERYSTATISTICS
DESCRIPTOR.message_types_by_name['CreateQueryRequest'] = _CREATEQUERYREQUEST
DESCRIPTOR.message_types_by_name['CreateQueryResponse'] = _CREATEQUERYRESPONSE
DESCRIPTOR.message_types_by_name['CreateQueryResult'] = _CREATEQUERYRESULT
DESCRIPTOR.message_types_by_name['ListQueriesRequest'] = _LISTQUERIESREQUEST
DESCRIPTOR.message_types_by_name['ListQueriesResponse'] = _LISTQUERIESRESPONSE
DESCRIPTOR.message_types_by_name['ListQueriesResult'] = _LISTQUERIESRESULT
DESCRIPTOR.message_types_by_name['DescribeQueryRequest'] = _DESCRIBEQUERYREQUEST
DESCRIPTOR.message_types_by_name['DescribeQueryResponse'] = _DESCRIBEQUERYRESPONSE
DESCRIPTOR.message_types_by_name['DescribeQueryResult'] = _DESCRIBEQUERYRESULT
DESCRIPTOR.message_types_by_name['GetQueryStatusRequest'] = _GETQUERYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetQueryStatusResponse'] = _GETQUERYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetQueryStatusResult'] = _GETQUERYSTATUSRESULT
DESCRIPTOR.message_types_by_name['DeleteQueryRequest'] = _DELETEQUERYREQUEST
DESCRIPTOR.message_types_by_name['DeleteQueryResponse'] = _DELETEQUERYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteQueryResult'] = _DELETEQUERYRESULT
DESCRIPTOR.message_types_by_name['ModifyQueryRequest'] = _MODIFYQUERYREQUEST
DESCRIPTOR.message_types_by_name['ModifyQueryResponse'] = _MODIFYQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ModifyQueryResult'] = _MODIFYQUERYRESULT
DESCRIPTOR.message_types_by_name['ControlQueryRequest'] = _CONTROLQUERYREQUEST
DESCRIPTOR.message_types_by_name['ControlQueryResponse'] = _CONTROLQUERYRESPONSE
DESCRIPTOR.message_types_by_name['ControlQueryResult'] = _CONTROLQUERYRESULT
DESCRIPTOR.message_types_by_name['BriefJob'] = _BRIEFJOB
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['ListJobsResult'] = _LISTJOBSRESULT
DESCRIPTOR.message_types_by_name['DescribeJobRequest'] = _DESCRIBEJOBREQUEST
DESCRIPTOR.message_types_by_name['DescribeJobResponse'] = _DESCRIBEJOBRESPONSE
DESCRIPTOR.message_types_by_name['DescribeJobResult'] = _DESCRIBEJOBRESULT
DESCRIPTOR.message_types_by_name['CurrentIAMTokenAuth'] = _CURRENTIAMTOKENAUTH
DESCRIPTOR.message_types_by_name['NoneAuth'] = _NONEAUTH
DESCRIPTOR.message_types_by_name['ServiceAccountAuth'] = _SERVICEACCOUNTAUTH
DESCRIPTOR.message_types_by_name['TokenAuth'] = _TOKENAUTH
DESCRIPTOR.message_types_by_name['IamAuth'] = _IAMAUTH
DESCRIPTOR.message_types_by_name['DataStreams'] = _DATASTREAMS
DESCRIPTOR.message_types_by_name['Monitoring'] = _MONITORING
DESCRIPTOR.message_types_by_name['YdbDatabase'] = _YDBDATABASE
DESCRIPTOR.message_types_by_name['ClickHouseCluster'] = _CLICKHOUSECLUSTER
DESCRIPTOR.message_types_by_name['ObjectStorageConnection'] = _OBJECTSTORAGECONNECTION
DESCRIPTOR.message_types_by_name['PostgreSQLCluster'] = _POSTGRESQLCLUSTER
DESCRIPTOR.message_types_by_name['GreenplumCluster'] = _GREENPLUMCLUSTER
DESCRIPTOR.message_types_by_name['MySQLCluster'] = _MYSQLCLUSTER
DESCRIPTOR.message_types_by_name['Logging'] = _LOGGING
DESCRIPTOR.message_types_by_name['IcebergWarehouse'] = _ICEBERGWAREHOUSE
DESCRIPTOR.message_types_by_name['IcebergCatalog'] = _ICEBERGCATALOG
DESCRIPTOR.message_types_by_name['Iceberg'] = _ICEBERG
DESCRIPTOR.message_types_by_name['ConnectionSetting'] = _CONNECTIONSETTING
DESCRIPTOR.message_types_by_name['ConnectionContent'] = _CONNECTIONCONTENT
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['CreateConnectionRequest'] = _CREATECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['CreateConnectionResponse'] = _CREATECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateConnectionResult'] = _CREATECONNECTIONRESULT
DESCRIPTOR.message_types_by_name['ListConnectionsRequest'] = _LISTCONNECTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListConnectionsResponse'] = _LISTCONNECTIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListConnectionsResult'] = _LISTCONNECTIONSRESULT
DESCRIPTOR.message_types_by_name['DescribeConnectionRequest'] = _DESCRIBECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DescribeConnectionResponse'] = _DESCRIBECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DescribeConnectionResult'] = _DESCRIBECONNECTIONRESULT
DESCRIPTOR.message_types_by_name['ModifyConnectionRequest'] = _MODIFYCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['ModifyConnectionResponse'] = _MODIFYCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['ModifyConnectionResult'] = _MODIFYCONNECTIONRESULT
DESCRIPTOR.message_types_by_name['DeleteConnectionRequest'] = _DELETECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteConnectionResponse'] = _DELETECONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteConnectionResult'] = _DELETECONNECTIONRESULT
DESCRIPTOR.message_types_by_name['TestConnectionRequest'] = _TESTCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['TestConnectionResponse'] = _TESTCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['TestConnectionResult'] = _TESTCONNECTIONRESULT
DESCRIPTOR.message_types_by_name['GetResultDataRequest'] = _GETRESULTDATAREQUEST
DESCRIPTOR.message_types_by_name['GetResultDataResponse'] = _GETRESULTDATARESPONSE
DESCRIPTOR.message_types_by_name['GetResultDataResult'] = _GETRESULTDATARESULT
DESCRIPTOR.message_types_by_name['Schema'] = _SCHEMA
DESCRIPTOR.message_types_by_name['DataStreamsBinding'] = _DATASTREAMSBINDING
DESCRIPTOR.message_types_by_name['ObjectStorageBinding'] = _OBJECTSTORAGEBINDING
DESCRIPTOR.message_types_by_name['BindingSetting'] = _BINDINGSETTING
DESCRIPTOR.message_types_by_name['BriefBinding'] = _BRIEFBINDING
DESCRIPTOR.message_types_by_name['BindingContent'] = _BINDINGCONTENT
DESCRIPTOR.message_types_by_name['Binding'] = _BINDING
DESCRIPTOR.message_types_by_name['CreateBindingRequest'] = _CREATEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['CreateBindingResponse'] = _CREATEBINDINGRESPONSE
DESCRIPTOR.message_types_by_name['CreateBindingResult'] = _CREATEBINDINGRESULT
DESCRIPTOR.message_types_by_name['ListBindingsRequest'] = _LISTBINDINGSREQUEST
DESCRIPTOR.message_types_by_name['ListBindingsResponse'] = _LISTBINDINGSRESPONSE
DESCRIPTOR.message_types_by_name['ListBindingsResult'] = _LISTBINDINGSRESULT
DESCRIPTOR.message_types_by_name['DescribeBindingRequest'] = _DESCRIBEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['DescribeBindingResponse'] = _DESCRIBEBINDINGRESPONSE
DESCRIPTOR.message_types_by_name['DescribeBindingResult'] = _DESCRIBEBINDINGRESULT
DESCRIPTOR.message_types_by_name['ModifyBindingRequest'] = _MODIFYBINDINGREQUEST
DESCRIPTOR.message_types_by_name['ModifyBindingResponse'] = _MODIFYBINDINGRESPONSE
DESCRIPTOR.message_types_by_name['ModifyBindingResult'] = _MODIFYBINDINGRESULT
DESCRIPTOR.message_types_by_name['DeleteBindingRequest'] = _DELETEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['DeleteBindingResponse'] = _DELETEBINDINGRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBindingResult'] = _DELETEBINDINGRESULT
DESCRIPTOR.enum_types_by_name['ExecuteMode'] = _EXECUTEMODE
DESCRIPTOR.enum_types_by_name['QueryAction'] = _QUERYACTION
DESCRIPTOR.enum_types_by_name['StateLoadMode'] = _STATELOADMODE
DESCRIPTOR.enum_types_by_name['AutomaticType'] = _AUTOMATICTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Acl = _reflection.GeneratedProtocolMessageType('Acl', (_message.Message,), {
  'DESCRIPTOR' : _ACL,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Acl)
  })
_sym_db.RegisterMessage(Acl)

Limits = _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
  'DESCRIPTOR' : _LIMITS,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Limits)
  })
_sym_db.RegisterMessage(Limits)

StreamingDisposition = _reflection.GeneratedProtocolMessageType('StreamingDisposition', (_message.Message,), {

  'FromTime' : _reflection.GeneratedProtocolMessageType('FromTime', (_message.Message,), {
    'DESCRIPTOR' : _STREAMINGDISPOSITION_FROMTIME,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.StreamingDisposition.FromTime)
    })
  ,

  'TimeAgo' : _reflection.GeneratedProtocolMessageType('TimeAgo', (_message.Message,), {
    'DESCRIPTOR' : _STREAMINGDISPOSITION_TIMEAGO,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.StreamingDisposition.TimeAgo)
    })
  ,

  'FromLastCheckpoint' : _reflection.GeneratedProtocolMessageType('FromLastCheckpoint', (_message.Message,), {
    'DESCRIPTOR' : _STREAMINGDISPOSITION_FROMLASTCHECKPOINT,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.StreamingDisposition.FromLastCheckpoint)
    })
  ,
  'DESCRIPTOR' : _STREAMINGDISPOSITION,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.StreamingDisposition)
  })
_sym_db.RegisterMessage(StreamingDisposition)
_sym_db.RegisterMessage(StreamingDisposition.FromTime)
_sym_db.RegisterMessage(StreamingDisposition.TimeAgo)
_sym_db.RegisterMessage(StreamingDisposition.FromLastCheckpoint)

QueryContent = _reflection.GeneratedProtocolMessageType('QueryContent', (_message.Message,), {

  'ExecutionSettingsEntry' : _reflection.GeneratedProtocolMessageType('ExecutionSettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYCONTENT_EXECUTIONSETTINGSENTRY,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.QueryContent.ExecutionSettingsEntry)
    })
  ,

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYCONTENT_PARAMETERSENTRY,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.QueryContent.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYCONTENT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryContent)
  })
_sym_db.RegisterMessage(QueryContent)
_sym_db.RegisterMessage(QueryContent.ExecutionSettingsEntry)
_sym_db.RegisterMessage(QueryContent.ParametersEntry)

CommonMeta = _reflection.GeneratedProtocolMessageType('CommonMeta', (_message.Message,), {
  'DESCRIPTOR' : _COMMONMETA,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CommonMeta)
  })
_sym_db.RegisterMessage(CommonMeta)

QueryMeta = _reflection.GeneratedProtocolMessageType('QueryMeta', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMETA,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryMeta)
  })
_sym_db.RegisterMessage(QueryMeta)

BriefQuery = _reflection.GeneratedProtocolMessageType('BriefQuery', (_message.Message,), {
  'DESCRIPTOR' : _BRIEFQUERY,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.BriefQuery)
  })
_sym_db.RegisterMessage(BriefQuery)

QueryPlan = _reflection.GeneratedProtocolMessageType('QueryPlan', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPLAN,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryPlan)
  })
_sym_db.RegisterMessage(QueryPlan)

QueryAst = _reflection.GeneratedProtocolMessageType('QueryAst', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryAst)
  })
_sym_db.RegisterMessage(QueryAst)

ResultSetMeta = _reflection.GeneratedProtocolMessageType('ResultSetMeta', (_message.Message,), {
  'DESCRIPTOR' : _RESULTSETMETA,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ResultSetMeta)
  })
_sym_db.RegisterMessage(ResultSetMeta)

QueryTimeline = _reflection.GeneratedProtocolMessageType('QueryTimeline', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTIMELINE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryTimeline)
  })
_sym_db.RegisterMessage(QueryTimeline)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Query)
  })
_sym_db.RegisterMessage(Query)

QueryStatistics = _reflection.GeneratedProtocolMessageType('QueryStatistics', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATISTICS,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.QueryStatistics)
  })
_sym_db.RegisterMessage(QueryStatistics)

CreateQueryRequest = _reflection.GeneratedProtocolMessageType('CreateQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateQueryRequest)
  })
_sym_db.RegisterMessage(CreateQueryRequest)

CreateQueryResponse = _reflection.GeneratedProtocolMessageType('CreateQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateQueryResponse)
  })
_sym_db.RegisterMessage(CreateQueryResponse)

CreateQueryResult = _reflection.GeneratedProtocolMessageType('CreateQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateQueryResult)
  })
_sym_db.RegisterMessage(CreateQueryResult)

ListQueriesRequest = _reflection.GeneratedProtocolMessageType('ListQueriesRequest', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTQUERIESREQUEST_FILTER,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.ListQueriesRequest.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTQUERIESREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListQueriesRequest)
  })
_sym_db.RegisterMessage(ListQueriesRequest)
_sym_db.RegisterMessage(ListQueriesRequest.Filter)

ListQueriesResponse = _reflection.GeneratedProtocolMessageType('ListQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListQueriesResponse)
  })
_sym_db.RegisterMessage(ListQueriesResponse)

ListQueriesResult = _reflection.GeneratedProtocolMessageType('ListQueriesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListQueriesResult)
  })
_sym_db.RegisterMessage(ListQueriesResult)

DescribeQueryRequest = _reflection.GeneratedProtocolMessageType('DescribeQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEQUERYREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeQueryRequest)
  })
_sym_db.RegisterMessage(DescribeQueryRequest)

DescribeQueryResponse = _reflection.GeneratedProtocolMessageType('DescribeQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEQUERYRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeQueryResponse)
  })
_sym_db.RegisterMessage(DescribeQueryResponse)

DescribeQueryResult = _reflection.GeneratedProtocolMessageType('DescribeQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEQUERYRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeQueryResult)
  })
_sym_db.RegisterMessage(DescribeQueryResult)

GetQueryStatusRequest = _reflection.GeneratedProtocolMessageType('GetQueryStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSTATUSREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetQueryStatusRequest)
  })
_sym_db.RegisterMessage(GetQueryStatusRequest)

GetQueryStatusResponse = _reflection.GeneratedProtocolMessageType('GetQueryStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSTATUSRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetQueryStatusResponse)
  })
_sym_db.RegisterMessage(GetQueryStatusResponse)

GetQueryStatusResult = _reflection.GeneratedProtocolMessageType('GetQueryStatusResult', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSTATUSRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetQueryStatusResult)
  })
_sym_db.RegisterMessage(GetQueryStatusResult)

DeleteQueryRequest = _reflection.GeneratedProtocolMessageType('DeleteQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEQUERYREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteQueryRequest)
  })
_sym_db.RegisterMessage(DeleteQueryRequest)

DeleteQueryResponse = _reflection.GeneratedProtocolMessageType('DeleteQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEQUERYRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteQueryResponse)
  })
_sym_db.RegisterMessage(DeleteQueryResponse)

DeleteQueryResult = _reflection.GeneratedProtocolMessageType('DeleteQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _DELETEQUERYRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteQueryResult)
  })
_sym_db.RegisterMessage(DeleteQueryResult)

ModifyQueryRequest = _reflection.GeneratedProtocolMessageType('ModifyQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYQUERYREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyQueryRequest)
  })
_sym_db.RegisterMessage(ModifyQueryRequest)

ModifyQueryResponse = _reflection.GeneratedProtocolMessageType('ModifyQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYQUERYRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyQueryResponse)
  })
_sym_db.RegisterMessage(ModifyQueryResponse)

ModifyQueryResult = _reflection.GeneratedProtocolMessageType('ModifyQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYQUERYRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyQueryResult)
  })
_sym_db.RegisterMessage(ModifyQueryResult)

ControlQueryRequest = _reflection.GeneratedProtocolMessageType('ControlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLQUERYREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ControlQueryRequest)
  })
_sym_db.RegisterMessage(ControlQueryRequest)

ControlQueryResponse = _reflection.GeneratedProtocolMessageType('ControlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLQUERYRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ControlQueryResponse)
  })
_sym_db.RegisterMessage(ControlQueryResponse)

ControlQueryResult = _reflection.GeneratedProtocolMessageType('ControlQueryResult', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLQUERYRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ControlQueryResult)
  })
_sym_db.RegisterMessage(ControlQueryResult)

BriefJob = _reflection.GeneratedProtocolMessageType('BriefJob', (_message.Message,), {
  'DESCRIPTOR' : _BRIEFJOB,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.BriefJob)
  })
_sym_db.RegisterMessage(BriefJob)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOB_PARAMETERSENTRY,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.Job.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _JOB,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Job)
  })
_sym_db.RegisterMessage(Job)
_sym_db.RegisterMessage(Job.ParametersEntry)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTJOBSREQUEST_FILTER,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.ListJobsRequest.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)
_sym_db.RegisterMessage(ListJobsRequest.Filter)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

ListJobsResult = _reflection.GeneratedProtocolMessageType('ListJobsResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListJobsResult)
  })
_sym_db.RegisterMessage(ListJobsResult)

DescribeJobRequest = _reflection.GeneratedProtocolMessageType('DescribeJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEJOBREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeJobRequest)
  })
_sym_db.RegisterMessage(DescribeJobRequest)

DescribeJobResponse = _reflection.GeneratedProtocolMessageType('DescribeJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEJOBRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeJobResponse)
  })
_sym_db.RegisterMessage(DescribeJobResponse)

DescribeJobResult = _reflection.GeneratedProtocolMessageType('DescribeJobResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEJOBRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeJobResult)
  })
_sym_db.RegisterMessage(DescribeJobResult)

CurrentIAMTokenAuth = _reflection.GeneratedProtocolMessageType('CurrentIAMTokenAuth', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTIAMTOKENAUTH,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CurrentIAMTokenAuth)
  })
_sym_db.RegisterMessage(CurrentIAMTokenAuth)

NoneAuth = _reflection.GeneratedProtocolMessageType('NoneAuth', (_message.Message,), {
  'DESCRIPTOR' : _NONEAUTH,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.NoneAuth)
  })
_sym_db.RegisterMessage(NoneAuth)

ServiceAccountAuth = _reflection.GeneratedProtocolMessageType('ServiceAccountAuth', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTAUTH,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ServiceAccountAuth)
  })
_sym_db.RegisterMessage(ServiceAccountAuth)

TokenAuth = _reflection.GeneratedProtocolMessageType('TokenAuth', (_message.Message,), {
  'DESCRIPTOR' : _TOKENAUTH,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.TokenAuth)
  })
_sym_db.RegisterMessage(TokenAuth)

IamAuth = _reflection.GeneratedProtocolMessageType('IamAuth', (_message.Message,), {
  'DESCRIPTOR' : _IAMAUTH,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.IamAuth)
  })
_sym_db.RegisterMessage(IamAuth)

DataStreams = _reflection.GeneratedProtocolMessageType('DataStreams', (_message.Message,), {
  'DESCRIPTOR' : _DATASTREAMS,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DataStreams)
  })
_sym_db.RegisterMessage(DataStreams)

Monitoring = _reflection.GeneratedProtocolMessageType('Monitoring', (_message.Message,), {
  'DESCRIPTOR' : _MONITORING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Monitoring)
  })
_sym_db.RegisterMessage(Monitoring)

YdbDatabase = _reflection.GeneratedProtocolMessageType('YdbDatabase', (_message.Message,), {
  'DESCRIPTOR' : _YDBDATABASE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.YdbDatabase)
  })
_sym_db.RegisterMessage(YdbDatabase)

ClickHouseCluster = _reflection.GeneratedProtocolMessageType('ClickHouseCluster', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSECLUSTER,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ClickHouseCluster)
  })
_sym_db.RegisterMessage(ClickHouseCluster)

ObjectStorageConnection = _reflection.GeneratedProtocolMessageType('ObjectStorageConnection', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTORAGECONNECTION,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ObjectStorageConnection)
  })
_sym_db.RegisterMessage(ObjectStorageConnection)

PostgreSQLCluster = _reflection.GeneratedProtocolMessageType('PostgreSQLCluster', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESQLCLUSTER,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.PostgreSQLCluster)
  })
_sym_db.RegisterMessage(PostgreSQLCluster)

GreenplumCluster = _reflection.GeneratedProtocolMessageType('GreenplumCluster', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMCLUSTER,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GreenplumCluster)
  })
_sym_db.RegisterMessage(GreenplumCluster)

MySQLCluster = _reflection.GeneratedProtocolMessageType('MySQLCluster', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLCLUSTER,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.MySQLCluster)
  })
_sym_db.RegisterMessage(MySQLCluster)

Logging = _reflection.GeneratedProtocolMessageType('Logging', (_message.Message,), {
  'DESCRIPTOR' : _LOGGING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Logging)
  })
_sym_db.RegisterMessage(Logging)

IcebergWarehouse = _reflection.GeneratedProtocolMessageType('IcebergWarehouse', (_message.Message,), {

  'S3' : _reflection.GeneratedProtocolMessageType('S3', (_message.Message,), {
    'DESCRIPTOR' : _ICEBERGWAREHOUSE_S3,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.IcebergWarehouse.S3)
    })
  ,
  'DESCRIPTOR' : _ICEBERGWAREHOUSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.IcebergWarehouse)
  })
_sym_db.RegisterMessage(IcebergWarehouse)
_sym_db.RegisterMessage(IcebergWarehouse.S3)

IcebergCatalog = _reflection.GeneratedProtocolMessageType('IcebergCatalog', (_message.Message,), {

  'Hadoop' : _reflection.GeneratedProtocolMessageType('Hadoop', (_message.Message,), {
    'DESCRIPTOR' : _ICEBERGCATALOG_HADOOP,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.IcebergCatalog.Hadoop)
    })
  ,

  'HiveMetastore' : _reflection.GeneratedProtocolMessageType('HiveMetastore', (_message.Message,), {
    'DESCRIPTOR' : _ICEBERGCATALOG_HIVEMETASTORE,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.IcebergCatalog.HiveMetastore)
    })
  ,
  'DESCRIPTOR' : _ICEBERGCATALOG,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.IcebergCatalog)
  })
_sym_db.RegisterMessage(IcebergCatalog)
_sym_db.RegisterMessage(IcebergCatalog.Hadoop)
_sym_db.RegisterMessage(IcebergCatalog.HiveMetastore)

Iceberg = _reflection.GeneratedProtocolMessageType('Iceberg', (_message.Message,), {
  'DESCRIPTOR' : _ICEBERG,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Iceberg)
  })
_sym_db.RegisterMessage(Iceberg)

ConnectionSetting = _reflection.GeneratedProtocolMessageType('ConnectionSetting', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONSETTING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ConnectionSetting)
  })
_sym_db.RegisterMessage(ConnectionSetting)

ConnectionContent = _reflection.GeneratedProtocolMessageType('ConnectionContent', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONCONTENT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ConnectionContent)
  })
_sym_db.RegisterMessage(ConnectionContent)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Connection)
  })
_sym_db.RegisterMessage(Connection)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)

CreateConnectionResponse = _reflection.GeneratedProtocolMessageType('CreateConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateConnectionResponse)
  })
_sym_db.RegisterMessage(CreateConnectionResponse)

CreateConnectionResult = _reflection.GeneratedProtocolMessageType('CreateConnectionResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateConnectionResult)
  })
_sym_db.RegisterMessage(CreateConnectionResult)

ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONNECTIONSREQUEST_FILTER,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.ListConnectionsRequest.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)
_sym_db.RegisterMessage(ListConnectionsRequest.Filter)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

ListConnectionsResult = _reflection.GeneratedProtocolMessageType('ListConnectionsResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListConnectionsResult)
  })
_sym_db.RegisterMessage(ListConnectionsResult)

DescribeConnectionRequest = _reflection.GeneratedProtocolMessageType('DescribeConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONNECTIONREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeConnectionRequest)
  })
_sym_db.RegisterMessage(DescribeConnectionRequest)

DescribeConnectionResponse = _reflection.GeneratedProtocolMessageType('DescribeConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONNECTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeConnectionResponse)
  })
_sym_db.RegisterMessage(DescribeConnectionResponse)

DescribeConnectionResult = _reflection.GeneratedProtocolMessageType('DescribeConnectionResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONNECTIONRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeConnectionResult)
  })
_sym_db.RegisterMessage(DescribeConnectionResult)

ModifyConnectionRequest = _reflection.GeneratedProtocolMessageType('ModifyConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYCONNECTIONREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyConnectionRequest)
  })
_sym_db.RegisterMessage(ModifyConnectionRequest)

ModifyConnectionResponse = _reflection.GeneratedProtocolMessageType('ModifyConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYCONNECTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyConnectionResponse)
  })
_sym_db.RegisterMessage(ModifyConnectionResponse)

ModifyConnectionResult = _reflection.GeneratedProtocolMessageType('ModifyConnectionResult', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYCONNECTIONRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyConnectionResult)
  })
_sym_db.RegisterMessage(ModifyConnectionResult)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

DeleteConnectionResponse = _reflection.GeneratedProtocolMessageType('DeleteConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteConnectionResponse)
  })
_sym_db.RegisterMessage(DeleteConnectionResponse)

DeleteConnectionResult = _reflection.GeneratedProtocolMessageType('DeleteConnectionResult', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteConnectionResult)
  })
_sym_db.RegisterMessage(DeleteConnectionResult)

TestConnectionRequest = _reflection.GeneratedProtocolMessageType('TestConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.TestConnectionRequest)
  })
_sym_db.RegisterMessage(TestConnectionRequest)

TestConnectionResponse = _reflection.GeneratedProtocolMessageType('TestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.TestConnectionResponse)
  })
_sym_db.RegisterMessage(TestConnectionResponse)

TestConnectionResult = _reflection.GeneratedProtocolMessageType('TestConnectionResult', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.TestConnectionResult)
  })
_sym_db.RegisterMessage(TestConnectionResult)

GetResultDataRequest = _reflection.GeneratedProtocolMessageType('GetResultDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTDATAREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetResultDataRequest)
  })
_sym_db.RegisterMessage(GetResultDataRequest)

GetResultDataResponse = _reflection.GeneratedProtocolMessageType('GetResultDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTDATARESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetResultDataResponse)
  })
_sym_db.RegisterMessage(GetResultDataResponse)

GetResultDataResult = _reflection.GeneratedProtocolMessageType('GetResultDataResult', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTDATARESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.GetResultDataResult)
  })
_sym_db.RegisterMessage(GetResultDataResult)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Schema)
  })
_sym_db.RegisterMessage(Schema)

DataStreamsBinding = _reflection.GeneratedProtocolMessageType('DataStreamsBinding', (_message.Message,), {

  'FormatSettingEntry' : _reflection.GeneratedProtocolMessageType('FormatSettingEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASTREAMSBINDING_FORMATSETTINGENTRY,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.DataStreamsBinding.FormatSettingEntry)
    })
  ,
  'DESCRIPTOR' : _DATASTREAMSBINDING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DataStreamsBinding)
  })
_sym_db.RegisterMessage(DataStreamsBinding)
_sym_db.RegisterMessage(DataStreamsBinding.FormatSettingEntry)

ObjectStorageBinding = _reflection.GeneratedProtocolMessageType('ObjectStorageBinding', (_message.Message,), {

  'Subset' : _reflection.GeneratedProtocolMessageType('Subset', (_message.Message,), {

    'FormatSettingEntry' : _reflection.GeneratedProtocolMessageType('FormatSettingEntry', (_message.Message,), {
      'DESCRIPTOR' : _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY,
      '__module__' : 'draft.protos.ydb_federated_query_pb2'
      # @@protoc_insertion_point(class_scope:FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntry)
      })
    ,

    'ProjectionEntry' : _reflection.GeneratedProtocolMessageType('ProjectionEntry', (_message.Message,), {
      'DESCRIPTOR' : _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY,
      '__module__' : 'draft.protos.ydb_federated_query_pb2'
      # @@protoc_insertion_point(class_scope:FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry)
      })
    ,
    'DESCRIPTOR' : _OBJECTSTORAGEBINDING_SUBSET,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.ObjectStorageBinding.Subset)
    })
  ,
  'DESCRIPTOR' : _OBJECTSTORAGEBINDING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ObjectStorageBinding)
  })
_sym_db.RegisterMessage(ObjectStorageBinding)
_sym_db.RegisterMessage(ObjectStorageBinding.Subset)
_sym_db.RegisterMessage(ObjectStorageBinding.Subset.FormatSettingEntry)
_sym_db.RegisterMessage(ObjectStorageBinding.Subset.ProjectionEntry)

BindingSetting = _reflection.GeneratedProtocolMessageType('BindingSetting', (_message.Message,), {
  'DESCRIPTOR' : _BINDINGSETTING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.BindingSetting)
  })
_sym_db.RegisterMessage(BindingSetting)

BriefBinding = _reflection.GeneratedProtocolMessageType('BriefBinding', (_message.Message,), {
  'DESCRIPTOR' : _BRIEFBINDING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.BriefBinding)
  })
_sym_db.RegisterMessage(BriefBinding)

BindingContent = _reflection.GeneratedProtocolMessageType('BindingContent', (_message.Message,), {
  'DESCRIPTOR' : _BINDINGCONTENT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.BindingContent)
  })
_sym_db.RegisterMessage(BindingContent)

Binding = _reflection.GeneratedProtocolMessageType('Binding', (_message.Message,), {
  'DESCRIPTOR' : _BINDING,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.Binding)
  })
_sym_db.RegisterMessage(Binding)

CreateBindingRequest = _reflection.GeneratedProtocolMessageType('CreateBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBINDINGREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateBindingRequest)
  })
_sym_db.RegisterMessage(CreateBindingRequest)

CreateBindingResponse = _reflection.GeneratedProtocolMessageType('CreateBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBINDINGRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateBindingResponse)
  })
_sym_db.RegisterMessage(CreateBindingResponse)

CreateBindingResult = _reflection.GeneratedProtocolMessageType('CreateBindingResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBINDINGRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.CreateBindingResult)
  })
_sym_db.RegisterMessage(CreateBindingResult)

ListBindingsRequest = _reflection.GeneratedProtocolMessageType('ListBindingsRequest', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTBINDINGSREQUEST_FILTER,
    '__module__' : 'draft.protos.ydb_federated_query_pb2'
    # @@protoc_insertion_point(class_scope:FederatedQuery.ListBindingsRequest.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTBINDINGSREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListBindingsRequest)
  })
_sym_db.RegisterMessage(ListBindingsRequest)
_sym_db.RegisterMessage(ListBindingsRequest.Filter)

ListBindingsResponse = _reflection.GeneratedProtocolMessageType('ListBindingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBINDINGSRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListBindingsResponse)
  })
_sym_db.RegisterMessage(ListBindingsResponse)

ListBindingsResult = _reflection.GeneratedProtocolMessageType('ListBindingsResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTBINDINGSRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ListBindingsResult)
  })
_sym_db.RegisterMessage(ListBindingsResult)

DescribeBindingRequest = _reflection.GeneratedProtocolMessageType('DescribeBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEBINDINGREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeBindingRequest)
  })
_sym_db.RegisterMessage(DescribeBindingRequest)

DescribeBindingResponse = _reflection.GeneratedProtocolMessageType('DescribeBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEBINDINGRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeBindingResponse)
  })
_sym_db.RegisterMessage(DescribeBindingResponse)

DescribeBindingResult = _reflection.GeneratedProtocolMessageType('DescribeBindingResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEBINDINGRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DescribeBindingResult)
  })
_sym_db.RegisterMessage(DescribeBindingResult)

ModifyBindingRequest = _reflection.GeneratedProtocolMessageType('ModifyBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYBINDINGREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyBindingRequest)
  })
_sym_db.RegisterMessage(ModifyBindingRequest)

ModifyBindingResponse = _reflection.GeneratedProtocolMessageType('ModifyBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYBINDINGRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyBindingResponse)
  })
_sym_db.RegisterMessage(ModifyBindingResponse)

ModifyBindingResult = _reflection.GeneratedProtocolMessageType('ModifyBindingResult', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYBINDINGRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.ModifyBindingResult)
  })
_sym_db.RegisterMessage(ModifyBindingResult)

DeleteBindingRequest = _reflection.GeneratedProtocolMessageType('DeleteBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBINDINGREQUEST,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteBindingRequest)
  })
_sym_db.RegisterMessage(DeleteBindingRequest)

DeleteBindingResponse = _reflection.GeneratedProtocolMessageType('DeleteBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBINDINGRESPONSE,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteBindingResponse)
  })
_sym_db.RegisterMessage(DeleteBindingResponse)

DeleteBindingResult = _reflection.GeneratedProtocolMessageType('DeleteBindingResult', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBINDINGRESULT,
  '__module__' : 'draft.protos.ydb_federated_query_pb2'
  # @@protoc_insertion_point(class_scope:FederatedQuery.DeleteBindingResult)
  })
_sym_db.RegisterMessage(DeleteBindingResult)


DESCRIPTOR._options = None
_LIMITS.fields_by_name['vcpu_rate_limit']._options = None
_LIMITS.fields_by_name['flow_rate_limit']._options = None
_LIMITS.fields_by_name['vcpu_time_limit']._options = None
_LIMITS.fields_by_name['max_result_size']._options = None
_LIMITS.fields_by_name['max_result_rows']._options = None
_LIMITS.fields_by_name['memory_limit']._options = None
_QUERYCONTENT_EXECUTIONSETTINGSENTRY._options = None
_QUERYCONTENT_PARAMETERSENTRY._options = None
_QUERYCONTENT.fields_by_name['name']._options = None
_QUERYCONTENT.fields_by_name['text']._options = None
_QUERYCONTENT.fields_by_name['description']._options = None
_QUERYCONTENT.fields_by_name['execution_settings']._options = None
_QUERYCONTENT.fields_by_name['parameters']._options = None
_COMMONMETA.fields_by_name['id']._options = None
_COMMONMETA.fields_by_name['created_by']._options = None
_COMMONMETA.fields_by_name['modified_by']._options = None
_COMMONMETA.fields_by_name['revision']._options = None
_BRIEFQUERY.fields_by_name['name']._options = None
_RESULTSETMETA.fields_by_name['rows_count']._options = None
_CREATEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
_CREATEQUERYRESULT.fields_by_name['query_id']._options = None
_LISTQUERIESREQUEST_FILTER.fields_by_name['status']._options = None
_LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._options = None
_LISTQUERIESREQUEST_FILTER.fields_by_name['name']._options = None
_LISTQUERIESREQUEST.fields_by_name['page_token']._options = None
_LISTQUERIESREQUEST.fields_by_name['limit']._options = None
_LISTQUERIESRESULT.fields_by_name['next_page_token']._options = None
_DESCRIBEQUERYREQUEST.fields_by_name['query_id']._options = None
_GETQUERYSTATUSREQUEST.fields_by_name['query_id']._options = None
_DELETEQUERYREQUEST.fields_by_name['query_id']._options = None
_DELETEQUERYREQUEST.fields_by_name['previous_revision']._options = None
_DELETEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
_MODIFYQUERYREQUEST.fields_by_name['query_id']._options = None
_MODIFYQUERYREQUEST.fields_by_name['previous_revision']._options = None
_MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._options = None
_CONTROLQUERYREQUEST.fields_by_name['query_id']._options = None
_CONTROLQUERYREQUEST.fields_by_name['previous_revision']._options = None
_CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._options = None
_JOB_PARAMETERSENTRY._options = None
_LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._options = None
_LISTJOBSREQUEST.fields_by_name['page_token']._options = None
_LISTJOBSREQUEST.fields_by_name['limit']._options = None
_LISTJOBSRESULT.fields_by_name['next_page_token']._options = None
_DESCRIBEJOBREQUEST.fields_by_name['job_id']._options = None
_SERVICEACCOUNTAUTH.fields_by_name['id']._options = None
_TOKENAUTH.fields_by_name['token']._options = None
_DATASTREAMS.fields_by_name['database_id']._options = None
_DATASTREAMS.fields_by_name['endpoint']._options = None
_DATASTREAMS.fields_by_name['database']._options = None
_MONITORING.fields_by_name['project']._options = None
_MONITORING.fields_by_name['cluster']._options = None
_YDBDATABASE.fields_by_name['database_id']._options = None
_YDBDATABASE.fields_by_name['endpoint']._options = None
_YDBDATABASE.fields_by_name['database']._options = None
_CLICKHOUSECLUSTER.fields_by_name['database_id']._options = None
_CLICKHOUSECLUSTER.fields_by_name['database_name']._options = None
_CLICKHOUSECLUSTER.fields_by_name['login']._options = None
_CLICKHOUSECLUSTER.fields_by_name['password']._options = None
_CLICKHOUSECLUSTER.fields_by_name['host']._options = None
_CLICKHOUSECLUSTER.fields_by_name['port']._options = None
_OBJECTSTORAGECONNECTION.fields_by_name['bucket']._options = None
_POSTGRESQLCLUSTER.fields_by_name['database_id']._options = None
_POSTGRESQLCLUSTER.fields_by_name['database_name']._options = None
_POSTGRESQLCLUSTER.fields_by_name['login']._options = None
_POSTGRESQLCLUSTER.fields_by_name['password']._options = None
_POSTGRESQLCLUSTER.fields_by_name['schema']._options = None
_POSTGRESQLCLUSTER.fields_by_name['host']._options = None
_POSTGRESQLCLUSTER.fields_by_name['port']._options = None
_GREENPLUMCLUSTER.fields_by_name['database_id']._options = None
_GREENPLUMCLUSTER.fields_by_name['database_name']._options = None
_GREENPLUMCLUSTER.fields_by_name['login']._options = None
_GREENPLUMCLUSTER.fields_by_name['password']._options = None
_GREENPLUMCLUSTER.fields_by_name['schema']._options = None
_MYSQLCLUSTER.fields_by_name['database_id']._options = None
_MYSQLCLUSTER.fields_by_name['database_name']._options = None
_MYSQLCLUSTER.fields_by_name['login']._options = None
_MYSQLCLUSTER.fields_by_name['password']._options = None
_ICEBERGWAREHOUSE_S3.fields_by_name['bucket']._options = None
_ICEBERGWAREHOUSE_S3.fields_by_name['path']._options = None
_ICEBERGCATALOG_HADOOP.fields_by_name['directory']._options = None
_ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['uri']._options = None
_ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['database_name']._options = None
_CONNECTIONCONTENT.fields_by_name['name']._options = None
_CONNECTIONCONTENT.fields_by_name['description']._options = None
_CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
_CREATECONNECTIONRESULT.fields_by_name['connection_id']._options = None
_LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._options = None
_LISTCONNECTIONSREQUEST.fields_by_name['page_token']._options = None
_LISTCONNECTIONSREQUEST.fields_by_name['limit']._options = None
_LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._options = None
_DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
_MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
_DELETECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
_DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
_GETRESULTDATAREQUEST.fields_by_name['query_id']._options = None
_GETRESULTDATAREQUEST.fields_by_name['result_set_index']._options = None
_GETRESULTDATAREQUEST.fields_by_name['offset']._options = None
_GETRESULTDATAREQUEST.fields_by_name['limit']._options = None
_SCHEMA.fields_by_name['column']._options = None
_DATASTREAMSBINDING_FORMATSETTINGENTRY._options = None
_DATASTREAMSBINDING.fields_by_name['stream_name']._options = None
_DATASTREAMSBINDING.fields_by_name['format']._options = None
_DATASTREAMSBINDING.fields_by_name['compression']._options = None
_DATASTREAMSBINDING.fields_by_name['format_setting']._options = None
_OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._options = None
_OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._options = None
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._options = None
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._options = None
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._options = None
_OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._options = None
_BRIEFBINDING.fields_by_name['name']._options = None
_BRIEFBINDING.fields_by_name['connection_id']._options = None
_BINDINGCONTENT.fields_by_name['name']._options = None
_BINDINGCONTENT.fields_by_name['connection_id']._options = None
_BINDINGCONTENT.fields_by_name['description']._options = None
_CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
_CREATEBINDINGRESULT.fields_by_name['binding_id']._options = None
_LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._options = None
_LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._options = None
_LISTBINDINGSREQUEST.fields_by_name['page_token']._options = None
_LISTBINDINGSREQUEST.fields_by_name['limit']._options = None
_LISTBINDINGSRESULT.fields_by_name['next_page_token']._options = None
_DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._options = None
_MODIFYBINDINGREQUEST.fields_by_name['binding_id']._options = None
_MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._options = None
_MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
_DELETEBINDINGREQUEST.fields_by_name['binding_id']._options = None
_DELETEBINDINGREQUEST.fields_by_name['previous_revision']._options = None
_DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
# @@protoc_insertion_point(module_scope)
